(* Content-type: application/mathematica *)

(*** Wolfram Notebook File ***)
(* http://www.wolfram.com/nb *)

(* CreatedBy='Mathematica 7.0' *)

(*CacheID: 234*)
(* Internal cache information:
NotebookFileLineBreakTest
NotebookFileLineBreakTest
NotebookDataPosition[       145,          7]
NotebookDataLength[     74000,       1998]
NotebookOptionsPosition[     66522,       1897]
NotebookOutlinePosition[     66897,       1914]
CellTagsIndexPosition[     66854,       1911]
WindowFrame->Normal*)

(* Beginning of Notebook Content *)
Notebook[{
Cell[TextData[{
 "Hyperbolic-plane tilings\n\nIncludes spherical and flat-plane tilings of \
Schwarz triangles\n\nAlgorithm:\nGenerate initial triangle\nGenerate next \
triangles by flipping each triangle over each edge\n\n\
MakeTriangles[ns_,ntri_]\nns -- parameters: {n1,n2,n3}\nntri -- number of \
triangles to make, stops if closed\nReturns {curvature, vertices, triangles}\n\
Triangle: {vertices, parity (1,-1)}\n\nAngles of the triangle: \
{Pi/n1,Pi/n2,Pi/n3}\n{2n1,2n2,2n3} triangles at each type of vertex\nSum > Pi \
-- sphere\nSum = Pi -- plane\nSum < Pi -- hyperbolic plane (pseudosphere)\n\n\
Surface constraints:\nSphere: x^2 + y^2 + z^2 = 1\nPlane: z = const.\nHyp \
pln: - x^2 - y^2 + z^2 = 1\n\nDisplayTriangles[trix_,proj_,tclr_]\ntrix - \
output of MakeTriangles\nproj: for non-flat output,\n\
\[OpenCurlyDoubleQuote]3D\[CloseCurlyDoubleQuote] - ",
 StyleBox["Mathematica",
  FontSlant->"Italic"],
 "\[CloseCurlyQuote]s 3D viewer (movable orthographic)\n\
\[OpenCurlyDoubleQuote]Gnomonic\[CloseCurlyDoubleQuote] - Straight-Line \
Geodesic: {x,y}/z\n\[OpenCurlyDoubleQuote]Conformal\[CloseCurlyDoubleQuote] - \
Stereographic, Equal-Angle: {x,y}/(1+z)\n\[OpenCurlyDoubleQuote]Equal-Area\
\[CloseCurlyDoubleQuote]: {x,y}/sqrt(2*(1+z))\ntclr - color function:\n- Arg \
- the \[OpenCurlyDoubleQuote]Triangle\[CloseCurlyDoubleQuote] object above\n- \
Returns - color, Line, Polygon objects for Graphics, Graphics3D\n\nGeodesics:\
\nSphere: X = P*cos(t) + Q*sin(t), X.X = P.P = Q.Q = 1, P.Q = 0\nPlane: \
straight line: X = X0 + X1*t\nHyp Pln: X = P*cosh(t) + Q*sinh(t), X.X = P.P = \
1, Q.Q = -1, P.Q = 0\nTangent: T = dX/dt\nAngle: cos(a) = \
(T1.T2)/sqrt((T1.T1)*(T2.T2))\n\n\nI\[CloseCurlyQuote]ve also done an \
infinitely large hyperbolic polygon rotated so that one vertex is at the \
origin. r0, the closest-approach parameter of a line, is sinh(u)\n\nAs \
line-location parameters s1 -> 0, one gets a circle (conformal) or an ellipse \
(gnomonic)\n\nThis is also a true of a circle. It is even true if the circle \
has been shifted a different distance, so that the origin is not on it.\n\n\
Links:\nUniform tilings in hyperbolic plane - Wikipedia - \
https://en.wikipedia.org/wiki/Uniform_tilings_in_hyperbolic_plane\nHyperbolic \
Planar Tesselations - http://www.plunk.org/~hatch/HyperbolicTesselations/\n\
Don Hatch\[CloseCurlyQuote]s Home Page - http://www.plunk.org/~hatch/ -- has \
some source code\nHyperbolic Tessellations - \
http://aleph0.clarku.edu/~djoyce/poincare/poincare.html\nHyperbolic Tilings - \
Math Images - http://mathforum.org/mathimages/index.php/Hyperbolic_Tilings\n\
Wolfram Demonstrations Project - \
http://demonstrations.wolfram.com/TilingTheHyperbolicPlaneWithRegularPolygons/\
 -- this and related ones may have useful Mma source code\nThe Geometry Page \
- http://superliminal.com/geometry/geometry.htm\nVirtual Reality Polyhedra - \
http://www.georgehart.com/virtual-polyhedra/vp.html\nSymmetry, Crystals and \
Polyhedra - http://www.uwgb.edu/dutchs/symmetry/symmetry.htm\nThe Geometry \
Junkyard: Hyperbolic Tiling - \
https://www.ics.uci.edu/~eppstein/junkyard/hypertile.html"
}], "Text",ExpressionUUID->"4c92b4fa-df7d-47e9-b2db-04395a4bfdb0"],

Cell[CellGroupData[{

Cell["Display Tilings", "Section",ExpressionUUID->"ec760301-562c-4988-be22-ff423d6417db"],

Cell[CellGroupData[{

Cell["Functions", "Subsection",ExpressionUUID->"f27d25b4-3bf5-4a46-a3dd-7a95da822843"],

Cell[BoxData[
 RowBox[{
  RowBox[{"ThirdVertex", "[", 
   RowBox[{
   "dgmet_", ",", "vt1_", ",", "vt2_", ",", "ca1_", ",", "ca2_", ",", "s_"}], 
   "]"}], " ", ":=", " ", 
  RowBox[{"Module", "[", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{
     "mv1", ",", "mv2", ",", "mdet", ",", "pv11", ",", "pv12", ",", "pv22", 
      ",", "pvdet"}], "}"}], ",", "\[IndentingNewLine]", 
    RowBox[{
     RowBox[{"mv1", " ", "=", " ", 
      RowBox[{"dgmet", "*", "vt1"}]}], ";", " ", 
     RowBox[{"mv2", " ", "=", " ", 
      RowBox[{"dgmet", "*", "vt2"}]}], ";", "\[IndentingNewLine]", 
     RowBox[{"mdet", " ", "=", " ", 
      RowBox[{"Times", " ", "@@", " ", "dgmet"}]}], ";", 
     "\[IndentingNewLine]", 
     RowBox[{"pv11", " ", "=", " ", 
      RowBox[{"mv1", ".", "vt1"}]}], ";", " ", 
     RowBox[{"pv12", " ", "=", " ", 
      RowBox[{"mv1", ".", "vt2"}]}], ";", " ", 
     RowBox[{"pv22", " ", "=", " ", 
      RowBox[{"mv2", ".", "vt2"}]}], ";", "\[IndentingNewLine]", 
     RowBox[{"pvdet", " ", "=", " ", 
      RowBox[{
       RowBox[{"pv11", "*", "pv22"}], " ", "-", " ", 
       RowBox[{"pv12", "^", "2"}]}]}], ";", "\[IndentingNewLine]", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{
        RowBox[{"vt1", "*", 
         RowBox[{"(", 
          RowBox[{
           RowBox[{"pv22", "*", "ca1"}], "-", 
           RowBox[{"pv12", "*", "ca2"}]}], ")"}]}], " ", "+", " ", 
        RowBox[{"vt2", "*", 
         RowBox[{"(", 
          RowBox[{
           RowBox[{"pv11", "*", "ca2"}], " ", "-", " ", 
           RowBox[{"pv12", "*", "ca1"}]}], ")"}]}], " ", "+", " ", 
        RowBox[{
         RowBox[{"Cross", "[", 
          RowBox[{"mv1", ",", "mv2"}], "]"}], "*", "s", "*", 
         RowBox[{"Sqrt", "[", 
          RowBox[{
           RowBox[{"(", 
            RowBox[{"pvdet", " ", "-", " ", 
             RowBox[{"(", 
              RowBox[{
               RowBox[{"pv22", "*", 
                RowBox[{"ca1", "^", "2"}]}], "-", 
               RowBox[{"2", "pv12", "*", "ca1", "*", "ca2"}], "+", 
               RowBox[{"pv11", "*", 
                RowBox[{"ca2", "^", "2"}]}]}], ")"}]}], ")"}], "/", "mdet"}], 
          "]"}]}]}], ")"}], "/", "pvdet"}]}]}], "\[IndentingNewLine]", 
   "]"}]}]], "Input",
 CellLabel->
  "In[158]:=",ExpressionUUID->"22eaef84-8000-42d2-a2e1-ce1500d5ea66"],

Cell[BoxData[
 RowBox[{
  RowBox[{"ThirdVertexVerify", "[", 
   RowBox[{
   "dgmet_", ",", "vt1_", ",", "vt2_", ",", "ca1_", ",", "ca2_", ",", "s_"}], 
   "]"}], " ", ":=", " ", 
  RowBox[{"Module", "[", 
   RowBox[{
    RowBox[{"{", "vt3", "}"}], ",", "\[IndentingNewLine]", 
    RowBox[{
     RowBox[{"vt3", " ", "=", " ", 
      RowBox[{"ThirdVertex", "[", 
       RowBox[{
       "dgmet", ",", "vt1", ",", "vt2", ",", "ca1", ",", "ca2", ",", "s"}], 
       "]"}]}], ";", "\[IndentingNewLine]", 
     RowBox[{
      RowBox[{"{", 
       RowBox[{
        RowBox[{
         RowBox[{
          RowBox[{"(", 
           RowBox[{"dgmet", "*", "vt1"}], ")"}], ".", "vt3"}], " ", "-", " ", 
         "ca1"}], ",", 
        RowBox[{
         RowBox[{
          RowBox[{"(", 
           RowBox[{"dgmet", "*", "vt2"}], ")"}], ".", "vt3"}], " ", "-", " ", 
         "ca2"}], ",", " ", 
        RowBox[{
         RowBox[{
          RowBox[{"(", 
           RowBox[{"dgmet", "*", "vt3"}], ")"}], ".", "vt3"}], " ", "-", " ", 
         "1"}]}], "}"}], " ", "//", " ", "Factor"}]}]}], 
   "\[IndentingNewLine]", "]"}]}]], "Input",
 CellLabel->
  "In[159]:=",ExpressionUUID->"84070511-2386-4933-87ed-f120f5540e1e"],

Cell[BoxData[
 RowBox[{"Table", "[", 
  RowBox[{
   RowBox[{"ThirdVertexVerify", "[", 
    RowBox[{
     RowBox[{"Array", "[", 
      RowBox[{"g", ",", "3"}], "]"}], ",", 
     RowBox[{"Array", "[", 
      RowBox[{"n1", ",", "3"}], "]"}], ",", 
     RowBox[{"Array", "[", 
      RowBox[{"n2", ",", "3"}], "]"}], ",", "c1", ",", "c2", ",", "s"}], 
    "]"}], ",", 
   RowBox[{"{", 
    RowBox[{"s", ",", 
     RowBox[{"-", "1"}], ",", "1", ",", "2"}], "}"}]}], "]"}]], "Input",
 CellLabel->
  "In[160]:=",ExpressionUUID->"d474a4d0-0731-40f5-ba03-691451f8537b"],

Cell[BoxData[
 RowBox[{
  RowBox[{"VertexReflection", "[", 
   RowBox[{"dgmet_", ",", "vt1_", ",", "vt2_", ",", "vt3_"}], "]"}], " ", ":=",
   " ", 
  RowBox[{"Module", "[", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{
     "mv1", ",", "mv2", ",", "pv11", ",", "pv12", ",", "pv22", ",", "ca1", 
      ",", "ca2"}], "}"}], ",", "\[IndentingNewLine]", 
    RowBox[{
     RowBox[{"mv1", " ", "=", " ", 
      RowBox[{"dgmet", "*", "vt1"}]}], ";", " ", 
     RowBox[{"mv2", " ", "=", " ", 
      RowBox[{"dgmet", "*", "vt2"}]}], ";", "\[IndentingNewLine]", 
     RowBox[{"pv11", " ", "=", " ", 
      RowBox[{"mv1", ".", "vt1"}]}], ";", " ", 
     RowBox[{"pv12", " ", "=", " ", 
      RowBox[{"mv1", ".", "vt2"}]}], ";", " ", 
     RowBox[{"pv22", " ", "=", " ", 
      RowBox[{"mv2", ".", "vt2"}]}], ";", "\[IndentingNewLine]", 
     RowBox[{"ca1", " ", "=", " ", 
      RowBox[{"mv1", ".", "vt3"}]}], ";", " ", 
     RowBox[{"ca2", " ", "=", " ", 
      RowBox[{"mv2", ".", "vt3"}]}], ";", "\[IndentingNewLine]", 
     RowBox[{
      RowBox[{"2", 
       RowBox[{
        RowBox[{"(", 
         RowBox[{
          RowBox[{"vt1", "*", 
           RowBox[{"(", 
            RowBox[{
             RowBox[{"pv22", "*", "ca1"}], "-", 
             RowBox[{"pv12", "*", "ca2"}]}], ")"}]}], " ", "+", " ", 
          RowBox[{"vt2", "*", 
           RowBox[{"(", 
            RowBox[{
             RowBox[{"pv11", "*", "ca2"}], " ", "-", " ", 
             RowBox[{"pv12", "*", "ca1"}]}], ")"}]}]}], ")"}], "/", 
        RowBox[{"(", 
         RowBox[{
          RowBox[{"pv11", "*", "pv22"}], " ", "-", " ", 
          RowBox[{"pv12", "^", "2"}]}], ")"}]}]}], " ", "-", " ", "vt3"}]}]}],
    "\[IndentingNewLine]", "]"}]}]], "Input",
 CellLabel->
  "In[161]:=",ExpressionUUID->"4d0dc103-834b-4240-8550-b600c2a16a87"],

Cell[BoxData[
 RowBox[{
  RowBox[{"Table", "[", 
   RowBox[{
    RowBox[{
     RowBox[{"VertexReflection", "[", 
      RowBox[{
       RowBox[{"Array", "[", 
        RowBox[{"g", ",", "3"}], "]"}], ",", 
       RowBox[{"Array", "[", 
        RowBox[{"n1", ",", "3"}], "]"}], ",", 
       RowBox[{"Array", "[", 
        RowBox[{"n2", ",", "3"}], "]"}], ",", 
       RowBox[{"ThirdVertex", "[", 
        RowBox[{
         RowBox[{"Array", "[", 
          RowBox[{"g", ",", "3"}], "]"}], ",", 
         RowBox[{"Array", "[", 
          RowBox[{"n1", ",", "3"}], "]"}], ",", 
         RowBox[{"Array", "[", 
          RowBox[{"n2", ",", "3"}], "]"}], ",", "c1", ",", "c2", ",", "s"}], 
        "]"}]}], "]"}], " ", "-", " ", 
     RowBox[{"ThirdVertex", "[", 
      RowBox[{
       RowBox[{"Array", "[", 
        RowBox[{"g", ",", "3"}], "]"}], ",", 
       RowBox[{"Array", "[", 
        RowBox[{"n1", ",", "3"}], "]"}], ",", 
       RowBox[{"Array", "[", 
        RowBox[{"n2", ",", "3"}], "]"}], ",", "c1", ",", "c2", ",", 
       RowBox[{"-", "s"}]}], "]"}]}], ",", 
    RowBox[{"{", 
     RowBox[{"s", ",", 
      RowBox[{"-", "1"}], ",", "1", ",", "2"}], "}"}]}], "]"}], " ", "//", 
  " ", "Factor"}]], "Input",
 CellLabel->
  "In[162]:=",ExpressionUUID->"b5567182-2e27-400f-9d4f-edcdd01327cb"],

Cell[BoxData[
 RowBox[{
  RowBox[{"PlaneVertexReflection", "[", 
   RowBox[{"vt1_", ",", "vt2_", ",", "vt3_"}], "]"}], " ", ":=", " ", 
  RowBox[{"Module", "[", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{"vt12", ",", "vt13"}], "}"}], ",", "\[IndentingNewLine]", 
    RowBox[{
     RowBox[{"vt12", " ", "=", " ", 
      RowBox[{"vt2", " ", "-", " ", "vt1"}]}], ";", "\[IndentingNewLine]", 
     RowBox[{"vt13", " ", "=", " ", 
      RowBox[{"vt3", " ", "-", " ", "vt1"}]}], ";", "\[IndentingNewLine]", 
     RowBox[{"vt1", " ", "+", " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{"2", 
         RowBox[{"(", 
          RowBox[{
           RowBox[{"(", 
            RowBox[{"vt12", ".", "vt13"}], ")"}], "/", 
           RowBox[{"(", 
            RowBox[{"vt12", ".", "vt12"}], ")"}]}], ")"}], "*", "vt12"}], " ",
         "-", " ", "vt13"}], ")"}]}]}]}], "\[IndentingNewLine]", 
   "]"}]}]], "Input",
 CellLabel->
  "In[163]:=",ExpressionUUID->"a9d3d7b1-9a1c-47cd-9011-74e833b9ec0c"],

Cell[BoxData[
 RowBox[{
  RowBox[{"GeneralVertexReflection", "[", 
   RowBox[{"curv_", ",", "vt1_", ",", "vt2_", ",", "vt3_"}], "]"}], " ", ":=",
   " ", 
  RowBox[{"Which", "[", 
   RowBox[{
    RowBox[{"curv", ">", "0"}], ",", 
    RowBox[{"VertexReflection", "[", 
     RowBox[{
      RowBox[{"{", 
       RowBox[{"1", ",", "1", ",", "1"}], "}"}], ",", "vt1", ",", "vt2", ",", 
      "vt3"}], "]"}], ",", 
    RowBox[{"curv", "\[Equal]", "0"}], ",", 
    RowBox[{"PlaneVertexReflection", "[", 
     RowBox[{"vt1", ",", "vt2", ",", "vt3"}], "]"}], ",", 
    RowBox[{"curv", "<", "0"}], ",", 
    RowBox[{"VertexReflection", "[", 
     RowBox[{
      RowBox[{"{", 
       RowBox[{
        RowBox[{"-", "1"}], ",", 
        RowBox[{"-", "1"}], ",", "1"}], "}"}], ",", "vt1", ",", "vt2", ",", 
      "vt3"}], "]"}]}], "]"}]}]], "Input",
 CellLabel->
  "In[164]:=",ExpressionUUID->"8980aa5a-200f-442b-bed1-bdec86230b2a"],

Cell[BoxData[
 RowBox[{
  RowBox[{"MakeInitialTriangle", "[", "ns_", "]"}], " ", ":=", " ", 
  RowBox[{"Module", "[", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{
     "curv", ",", "angs", ",", "c12", ",", "c13", ",", "s12", ",", "s13", ",",
       "v1", ",", "v2", ",", "v3"}], "}"}], ",", "\[IndentingNewLine]", 
    RowBox[{"(*", " ", 
     RowBox[{"Curvature", " ", "value"}], " ", "*)"}], "\[IndentingNewLine]", 
    
    RowBox[{
     RowBox[{"curv", " ", "=", " ", 
      RowBox[{"Sign", "[", 
       RowBox[{
        RowBox[{"Total", "[", 
         RowBox[{"1", "/", 
          RowBox[{"ns", "[", 
           RowBox[{"[", 
            RowBox[{";;", "3"}], "]"}], "]"}]}], "]"}], "-", "1"}], "]"}]}], 
     ";", "\[IndentingNewLine]", 
     RowBox[{"(*", " ", 
      RowBox[{"Initial", " ", "triangle"}], " ", "*)"}], 
     "\[IndentingNewLine]", 
     RowBox[{"angs", " ", "=", " ", 
      RowBox[{
       RowBox[{"Pi", "/", 
        RowBox[{"ns", "[", 
         RowBox[{"[", 
          RowBox[{";;", "3"}], "]"}], "]"}]}], " ", "//", " ", "N"}]}], ";", 
     "\[IndentingNewLine]", 
     RowBox[{"c12", " ", "=", " ", 
      RowBox[{
       RowBox[{"(", 
        RowBox[{
         RowBox[{"Cos", "[", 
          RowBox[{"angs", "[", 
           RowBox[{"[", "3", "]"}], "]"}], "]"}], " ", "+", " ", 
         RowBox[{
          RowBox[{"Cos", "[", 
           RowBox[{"angs", "[", 
            RowBox[{"[", "1", "]"}], "]"}], "]"}], "*", 
          RowBox[{"Cos", "[", 
           RowBox[{"angs", "[", 
            RowBox[{"[", "2", "]"}], "]"}], "]"}]}]}], ")"}], "/", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{"Sin", "[", 
          RowBox[{"angs", "[", 
           RowBox[{"[", "1", "]"}], "]"}], "]"}], "*", 
         RowBox[{"Sin", "[", 
          RowBox[{"angs", "[", 
           RowBox[{"[", "2", "]"}], "]"}], "]"}]}], ")"}]}]}], ";", 
     "\[IndentingNewLine]", 
     RowBox[{"c13", " ", "=", " ", 
      RowBox[{
       RowBox[{"(", 
        RowBox[{
         RowBox[{"Cos", "[", 
          RowBox[{"angs", "[", 
           RowBox[{"[", "2", "]"}], "]"}], "]"}], " ", "+", " ", 
         RowBox[{
          RowBox[{"Cos", "[", 
           RowBox[{"angs", "[", 
            RowBox[{"[", "1", "]"}], "]"}], "]"}], "*", 
          RowBox[{"Cos", "[", 
           RowBox[{"angs", "[", 
            RowBox[{"[", "3", "]"}], "]"}], "]"}]}]}], ")"}], "/", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{"Sin", "[", 
          RowBox[{"angs", "[", 
           RowBox[{"[", "1", "]"}], "]"}], "]"}], "*", 
         RowBox[{"Sin", "[", 
          RowBox[{"angs", "[", 
           RowBox[{"[", "3", "]"}], "]"}], "]"}]}], ")"}]}]}], ";", 
     "\[IndentingNewLine]", 
     RowBox[{"Which", "[", 
      RowBox[{
       RowBox[{"curv", ">", "0"}], ",", "\[IndentingNewLine]", 
       RowBox[{"(*", " ", 
        RowBox[{"Sphere", " ", "-", " ", 
         RowBox[{"use", " ", "spherical", " ", "trigonometry"}]}], " ", 
        "*)"}], "\[IndentingNewLine]", 
       RowBox[{
        RowBox[{"s12", " ", "=", " ", 
         RowBox[{"Sqrt", "[", 
          RowBox[{"1", "-", 
           RowBox[{"c12", "^", "2"}]}], "]"}]}], ";", "\[IndentingNewLine]", 
        RowBox[{"s13", " ", "=", " ", 
         RowBox[{"Sqrt", "[", 
          RowBox[{"1", "-", 
           RowBox[{"c13", "^", "2"}]}], "]"}]}], ";", "\[IndentingNewLine]", 
        RowBox[{"v1", " ", "=", " ", 
         RowBox[{"{", 
          RowBox[{"0", ",", "0", ",", "1"}], "}"}]}], ";", 
        "\[IndentingNewLine]", 
        RowBox[{"v2", " ", "=", " ", 
         RowBox[{"{", 
          RowBox[{"s12", ",", "0", ",", "c12"}], "}"}]}], ";", 
        "\[IndentingNewLine]", 
        RowBox[{"v3", " ", "=", " ", 
         RowBox[{"{", 
          RowBox[{
           RowBox[{"s13", "*", 
            RowBox[{"Cos", "[", 
             RowBox[{"angs", "[", 
              RowBox[{"[", "1", "]"}], "]"}], "]"}]}], ",", 
           RowBox[{"s13", "*", 
            RowBox[{"Sin", "[", 
             RowBox[{"angs", "[", 
              RowBox[{"[", "1", "]"}], "]"}], "]"}]}], ",", "c13"}], 
          "}"}]}]}], ",", "\[IndentingNewLine]", 
       RowBox[{"curv", " ", "\[Equal]", " ", "0"}], ",", 
       "\[IndentingNewLine]", 
       RowBox[{"(*", " ", 
        RowBox[{"Plane", " ", "-", " ", 
         RowBox[{"use", " ", "law", " ", "of", " ", "sines"}]}], " ", "*)"}], 
       "\[IndentingNewLine]", 
       RowBox[{
        RowBox[{"s12", " ", "=", " ", 
         RowBox[{"Sin", "[", 
          RowBox[{"angs", "[", 
           RowBox[{"[", "3", "]"}], "]"}], "]"}]}], ";", 
        "\[IndentingNewLine]", 
        RowBox[{"s13", " ", "=", " ", 
         RowBox[{"Sin", "[", 
          RowBox[{"angs", "[", 
           RowBox[{"[", "2", "]"}], "]"}], "]"}]}], ";", 
        "\[IndentingNewLine]", 
        RowBox[{"v1", " ", "=", " ", 
         RowBox[{"{", 
          RowBox[{"0", ",", "0"}], "}"}]}], ";", "\[IndentingNewLine]", 
        RowBox[{"v2", " ", "=", " ", 
         RowBox[{"{", 
          RowBox[{"s12", ",", "0"}], "}"}]}], ";", "\[IndentingNewLine]", 
        RowBox[{"v3", " ", "=", " ", 
         RowBox[{"{", 
          RowBox[{
           RowBox[{"s13", "*", 
            RowBox[{"Cos", "[", 
             RowBox[{"angs", "[", 
              RowBox[{"[", "1", "]"}], "]"}], "]"}]}], ",", 
           RowBox[{"s13", "*", 
            RowBox[{"Sin", "[", 
             RowBox[{"angs", "[", 
              RowBox[{"[", "1", "]"}], "]"}], "]"}]}]}], "}"}]}]}], ",", 
       "\[IndentingNewLine]", 
       RowBox[{"curv", " ", "<", " ", "0"}], ",", "\[IndentingNewLine]", 
       RowBox[{"(*", " ", 
        RowBox[{
         RowBox[{"Hyperbolic", " ", "plane"}], " ", "-", " ", 
         RowBox[{
         "analytically", " ", "continue", " ", "the", " ", "spherical", " ", 
          "trig"}]}], " ", "*)"}], "\[IndentingNewLine]", 
       RowBox[{
        RowBox[{"s12", " ", "=", " ", 
         RowBox[{"Sqrt", "[", 
          RowBox[{
           RowBox[{"c12", "^", "2"}], "-", "1"}], "]"}]}], ";", 
        "\[IndentingNewLine]", 
        RowBox[{"s13", " ", "=", " ", 
         RowBox[{"Sqrt", "[", 
          RowBox[{
           RowBox[{"c13", "^", "2"}], "-", "1"}], "]"}]}], ";", 
        "\[IndentingNewLine]", 
        RowBox[{"v1", " ", "=", " ", 
         RowBox[{"{", 
          RowBox[{"0", ",", "0", ",", "1"}], "}"}]}], ";", 
        "\[IndentingNewLine]", 
        RowBox[{"v2", " ", "=", " ", 
         RowBox[{"{", 
          RowBox[{"s12", ",", "0", ",", "c12"}], "}"}]}], ";", 
        "\[IndentingNewLine]", 
        RowBox[{"v3", " ", "=", " ", 
         RowBox[{"{", 
          RowBox[{
           RowBox[{"s13", "*", 
            RowBox[{"Cos", "[", 
             RowBox[{"angs", "[", 
              RowBox[{"[", "1", "]"}], "]"}], "]"}]}], ",", 
           RowBox[{"s13", "*", 
            RowBox[{"Sin", "[", 
             RowBox[{"angs", "[", 
              RowBox[{"[", "1", "]"}], "]"}], "]"}]}], ",", "c13"}], 
          "}"}]}]}]}], "\[IndentingNewLine]", "]"}], ";", 
     "\[IndentingNewLine]", 
     RowBox[{"(*", " ", 
      RowBox[{"Emit", " ", "the", " ", "curvature", " ", "also"}], " ", 
      "*)"}], "\[IndentingNewLine]", 
     RowBox[{"{", 
      RowBox[{"curv", ",", 
       RowBox[{"{", 
        RowBox[{"v1", ",", "v2", ",", "v3"}], "}"}]}], "}"}]}]}], 
   "\[IndentingNewLine]", "]"}]}]], "Input",
 CellLabel->
  "In[165]:=",ExpressionUUID->"701e94a4-f00d-4ad5-a367-b3582cfb979b"],

Cell[BoxData[
 RowBox[{
  RowBox[{"VtxDistance", "[", 
   RowBox[{"curv_", ",", "vtx_"}], "]"}], " ", ":=", " ", 
  RowBox[{"Which", "[", 
   RowBox[{
    RowBox[{"curv", ">", "0"}], ",", 
    RowBox[{"-", 
     RowBox[{"vtx", "[", 
      RowBox[{"[", "3", "]"}], "]"}]}], ",", 
    RowBox[{"curv", "\[Equal]", "0"}], ",", 
    RowBox[{"vtx", ".", "vtx"}], ",", 
    RowBox[{"curv", "<", "0"}], ",", 
    RowBox[{"vtx", "[", 
     RowBox[{"[", "3", "]"}], "]"}]}], "]"}]}]], "Input",
 CellLabel->
  "In[166]:=",ExpressionUUID->"a2b8ddcb-a34a-4433-95c3-d286ac33c3b2"],

Cell[BoxData[
 RowBox[{
  RowBox[{"MakeTriTolerance", " ", "=", " ", 
   RowBox[{"10.", "^", 
    RowBox[{"(", 
     RowBox[{"-", "8"}], ")"}]}]}], ";"}]], "Input",
 CellLabel->
  "In[167]:=",ExpressionUUID->"63443152-7ecb-470c-91b0-3f973a1af35c"],

Cell[BoxData[
 RowBox[{
  RowBox[{"MakeTriangles", "[", 
   RowBox[{"ns_", ",", "ntri_"}], "]"}], " ", ":=", " ", 
  RowBox[{"Module", "[", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{
     "curv", ",", "vts", ",", "vtdists", ",", "tris", ",", "vttrixs", ",", 
      "eds", ",", "kx", ",", "edvts", ",", "vtix1", ",", "edsvt1", ",", 
      "evoth", ",", "vtix2", ",", "triix", ",", "tri", ",", "vtix3", ",", 
      "vtrfl", ",", "ixrfl", ",", "ix", ",", "ntvts", ",", "ntrvts", ",", 
      "ntreds"}], "}"}], ",", "\[IndentingNewLine]", 
    RowBox[{"(*", " ", 
     RowBox[{
      RowBox[{"The", " ", "first", " ", 
       RowBox[{"triangle", ".", " ", "Setup"}], " ", "includes", " ", "a", 
       " ", "function", " ", "for", " ", "getting", " ", "triangle", " ", 
       "memberships", " ", "for", " ", "each", " ", 
       RowBox[{"vertex", ".", " ", "That"}], " ", "successfully", " ", 
       "optimizes", " ", "the", " ", "code"}], ";", " ", 
      RowBox[{
      "allocating", " ", "arrays", " ", "in", " ", "advance", " ", "for", " ",
        "the", " ", "vertices", " ", "and", " ", "triangles", " ", 
       RowBox[{"doesn", "'"}], 
       RowBox[{"t", "."}]}]}], " ", "*)"}], "\[IndentingNewLine]", 
    RowBox[{
     RowBox[{
      RowBox[{"{", 
       RowBox[{"curv", ",", "vts"}], "}"}], " ", "=", " ", 
      RowBox[{"MakeInitialTriangle", "[", "ns", "]"}]}], ";", 
     "\[IndentingNewLine]", 
     RowBox[{"vtdists", " ", "=", " ", 
      RowBox[{
       RowBox[{
        RowBox[{"VtxDistance", "[", 
         RowBox[{"curv", ",", "#"}], "]"}], "&"}], " ", "/@", " ", "vts"}]}], 
     ";", "\[IndentingNewLine]", 
     RowBox[{"Do", "[", 
      RowBox[{
       RowBox[{
        RowBox[{"vttrixs", "[", "k", "]"}], " ", "=", " ", 
        RowBox[{"{", "1", "}"}]}], ",", 
       RowBox[{"{", 
        RowBox[{"k", ",", "3"}], "}"}]}], "]"}], ";", "\[IndentingNewLine]", 
     RowBox[{"tris", " ", "=", " ", 
      RowBox[{"{", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"{", 
          RowBox[{"1", ",", "2", ",", "3"}], "}"}], ",", "1"}], "}"}], 
       "}"}]}], ";", "\[IndentingNewLine]", 
     RowBox[{"(*", " ", 
      RowBox[{"Boundary", " ", 
       RowBox[{"edges", ".", " ", "Use"}], " ", "this", " ", "to", " ", 
       "reduce", " ", "calculation", " ", "load"}], " ", "*)"}], 
     "\[IndentingNewLine]", 
     RowBox[{"eds", " ", "=", " ", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"{", 
         RowBox[{"1", ",", "2"}], "}"}], ",", 
        RowBox[{"{", 
         RowBox[{"1", ",", "3"}], "}"}], ",", 
        RowBox[{"{", 
         RowBox[{"2", ",", "3"}], "}"}]}], "}"}]}], ";", 
     "\[IndentingNewLine]", 
     RowBox[{"Do", "[", 
      RowBox[{"(*", " ", 
       RowBox[{"Is", " ", "the", " ", "surface", " ", 
        RowBox[{"closed", "?"}]}], " ", "*)"}], "\[IndentingNewLine]", 
      RowBox[{
       RowBox[{
        RowBox[{"If", "[", " ", 
         RowBox[{
          RowBox[{
           RowBox[{"Length", "[", "eds", "]"}], " ", "<=", " ", "0"}], ",", 
          RowBox[{"Break", "[", "]"}]}], "]"}], ";", "\[IndentingNewLine]", 
        RowBox[{"(*", " ", 
         RowBox[{"Find", " ", "the", " ", "closest", " ", "vertex"}], " ", 
         "*)"}], "\[IndentingNewLine]", 
        RowBox[{"edvts", " ", "=", " ", 
         RowBox[{"Union", "[", 
          RowBox[{"Flatten", "[", "eds", "]"}], "]"}]}], ";", 
        "\[IndentingNewLine]", 
        RowBox[{"vtix1", " ", "=", " ", 
         RowBox[{"edvts", "[", 
          RowBox[{"[", 
           RowBox[{"First", "[", 
            RowBox[{"Ordering", "[", 
             RowBox[{
              RowBox[{"vtdists", "[", 
               RowBox[{"[", "edvts", "]"}], "]"}], ",", "1"}], "]"}], "]"}], 
           "]"}], "]"}]}], ";", "\[IndentingNewLine]", 
        RowBox[{"(*", " ", 
         RowBox[{
          RowBox[{"Find", " ", "the", " ", "second"}], "-", 
          RowBox[{"closest", " ", "vertex", " ", 
           RowBox[{"that", "'"}], "s", " ", "in", " ", "an", " ", "edge"}]}], 
         " ", "*)"}], "\[IndentingNewLine]", 
        RowBox[{"edsvt1", " ", "=", " ", 
         RowBox[{"Select", "[", 
          RowBox[{"eds", ",", 
           RowBox[{
            RowBox[{"MemberQ", "[", 
             RowBox[{"#", ",", "vtix1"}], "]"}], "&"}]}], "]"}]}], ";", 
        "\[IndentingNewLine]", 
        RowBox[{"evoth", " ", "=", " ", 
         RowBox[{
          RowBox[{
           RowBox[{"First", "[", 
            RowBox[{"Complement", "[", 
             RowBox[{"#", ",", 
              RowBox[{"{", "vtix1", "}"}]}], "]"}], "]"}], "&"}], " ", "/@", 
          " ", "edsvt1"}]}], ";", "\[IndentingNewLine]", 
        RowBox[{"vtix2", " ", "=", " ", 
         RowBox[{"evoth", "[", 
          RowBox[{"[", 
           RowBox[{"First", "[", 
            RowBox[{"Ordering", "[", 
             RowBox[{
              RowBox[{"vtdists", "[", 
               RowBox[{"[", "evoth", "]"}], "]"}], ",", "1"}], "]"}], "]"}], 
           "]"}], "]"}]}], ";", "\[IndentingNewLine]", 
        RowBox[{"(*", " ", 
         RowBox[{
         "Find", " ", "the", " ", "triangle", " ", "that", " ", "contains", 
          " ", "both", " ", "of", " ", "them"}], " ", "*)"}], 
        "\[IndentingNewLine]", 
        RowBox[{"triix", " ", "=", " ", 
         RowBox[{"First", "[", 
          RowBox[{"Intersection", "[", 
           RowBox[{
            RowBox[{"vttrixs", "[", "vtix1", "]"}], ",", 
            RowBox[{"vttrixs", "[", "vtix2", "]"}]}], "]"}], "]"}]}], ";", 
        "\[IndentingNewLine]", 
        RowBox[{"tri", " ", "=", " ", 
         RowBox[{"tris", "[", 
          RowBox[{"[", "triix", "]"}], "]"}]}], ";", "\[IndentingNewLine]", 
        RowBox[{"vtix3", " ", "=", " ", 
         RowBox[{"First", "[", 
          RowBox[{"Complement", "[", 
           RowBox[{
            RowBox[{"tri", "[", 
             RowBox[{"[", "1", "]"}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"vtix1", ",", "vtix2"}], "}"}]}], "]"}], "]"}]}], ";", 
        "\[IndentingNewLine]", 
        RowBox[{"(*", " ", 
         RowBox[{"Construct", " ", "the", " ", "reflected", " ", 
          RowBox[{"triangle", "."}]}], " ", "*)"}], "\[IndentingNewLine]", 
        RowBox[{"vtrfl", " ", "=", " ", 
         RowBox[{"GeneralVertexReflection", "[", 
          RowBox[{"curv", ",", 
           RowBox[{"vts", "[", 
            RowBox[{"[", "vtix1", "]"}], "]"}], ",", 
           RowBox[{"vts", "[", 
            RowBox[{"[", "vtix2", "]"}], "]"}], ",", 
           RowBox[{"vts", "[", 
            RowBox[{"[", "vtix3", "]"}], "]"}]}], "]"}]}], ";", 
        "\[IndentingNewLine]", 
        RowBox[{"ixrfl", " ", "=", " ", 
         RowBox[{
          RowBox[{"Length", "[", "vts", "]"}], " ", "+", " ", "1"}]}], ";", 
        "\[IndentingNewLine]", 
        RowBox[{"(*", " ", 
         RowBox[{
         "Is", " ", "the", " ", "new", " ", "vertex", " ", "an", " ", 
          "existing", " ", 
          RowBox[{"one", "?"}]}], " ", "*)"}], "\[IndentingNewLine]", 
        RowBox[{"Do", "[", 
         RowBox[{
          RowBox[{"If", "[", 
           RowBox[{
            RowBox[{
             RowBox[{"(", 
              RowBox[{
               RowBox[{
                RowBox[{"(", 
                 RowBox[{"#", ".", "#"}], ")"}], "&"}], " ", "@", " ", 
               RowBox[{"(", 
                RowBox[{"vtrfl", "-", 
                 RowBox[{"vts", "[", 
                  RowBox[{"[", "ix", "]"}], "]"}]}], ")"}]}], ")"}], " ", "<",
              " ", 
             RowBox[{"MakeTriTolerance", "^", "2"}]}], ",", 
            "\[IndentingNewLine]", 
            RowBox[{
             RowBox[{"ixrfl", " ", "=", " ", "ix"}], ";", " ", 
             RowBox[{"Break", "[", "]"}]}]}], "]"}], ",", 
          RowBox[{"{", 
           RowBox[{"ix", ",", "edvts"}], "}"}]}], "]"}], ";", 
        "\[IndentingNewLine]", 
        RowBox[{"(*", " ", 
         RowBox[{"Compose", " ", "the", " ", "new", " ", "triangle"}], " ", 
         "*)"}], "\[IndentingNewLine]", 
        RowBox[{"AppendTo", "[", 
         RowBox[{
          RowBox[{"vttrixs", "[", "vtix1", "]"}], ",", 
          RowBox[{
           RowBox[{"Length", "[", "tris", "]"}], "+", "1"}]}], "]"}], ";", 
        "\[IndentingNewLine]", 
        RowBox[{"AppendTo", "[", 
         RowBox[{
          RowBox[{"vttrixs", "[", "vtix2", "]"}], ",", 
          RowBox[{
           RowBox[{"Length", "[", "tris", "]"}], "+", "1"}]}], "]"}], ";", 
        "\[IndentingNewLine]", 
        RowBox[{"If", "[", 
         RowBox[{
          RowBox[{"ixrfl", " ", ">", " ", 
           RowBox[{"Length", "[", "vts", "]"}]}], ",", "\[IndentingNewLine]", 
          
          RowBox[{
           RowBox[{"AppendTo", "[", 
            RowBox[{"vts", ",", "vtrfl"}], "]"}], ";", "\[IndentingNewLine]", 
           
           RowBox[{"AppendTo", "[", 
            RowBox[{"vtdists", ",", " ", 
             RowBox[{"VtxDistance", "[", 
              RowBox[{"curv", ",", "vtrfl"}], "]"}]}], "]"}], ";", 
           "\[IndentingNewLine]", 
           RowBox[{
            RowBox[{"vttrixs", "[", 
             RowBox[{"Length", "[", "vts", "]"}], "]"}], " ", "=", " ", 
            RowBox[{"{", 
             RowBox[{
              RowBox[{"Length", "[", "tris", "]"}], "+", "1"}], "}"}]}]}], 
          ",", "\[IndentingNewLine]", 
          RowBox[{"AppendTo", "[", 
           RowBox[{
            RowBox[{"vttrixs", "[", "ixrfl", "]"}], ",", 
            RowBox[{
             RowBox[{"Length", "[", "tris", "]"}], "+", "1"}]}], "]"}]}], 
         "\[IndentingNewLine]", "]"}], ";", "\[IndentingNewLine]", 
        RowBox[{"ntrvts", " ", "=", " ", 
         RowBox[{"Table", "[", 
          RowBox[{
           RowBox[{"If", "[", 
            RowBox[{
             RowBox[{
              RowBox[{"tri", "[", 
               RowBox[{"[", 
                RowBox[{"1", ",", "k"}], "]"}], "]"}], " ", "\[Equal]", " ", 
              "vtix3"}], ",", "ixrfl", ",", 
             RowBox[{"tri", "[", 
              RowBox[{"[", 
               RowBox[{"1", ",", "k"}], "]"}], "]"}]}], "]"}], ",", 
           RowBox[{"{", 
            RowBox[{"k", ",", "3"}], "}"}]}], "]"}]}], ";", 
        "\[IndentingNewLine]", 
        RowBox[{"AppendTo", "[", 
         RowBox[{"tris", ",", 
          RowBox[{"{", 
           RowBox[{"ntrvts", ",", 
            RowBox[{"-", 
             RowBox[{"tri", "[", 
              RowBox[{"[", "2", "]"}], "]"}]}]}], "}"}]}], "]"}], ";", 
        "\[IndentingNewLine]", 
        RowBox[{"ntreds", " ", "=", 
         RowBox[{
          RowBox[{
           RowBox[{"Sort", "[", 
            RowBox[{"ntrvts", "[", 
             RowBox[{"[", "#", "]"}], "]"}], "]"}], "&"}], " ", "/@", " ", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"1", ",", "2"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{"1", ",", "3"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{"2", ",", "3"}], "}"}]}], "}"}]}]}], ";", 
        "\[IndentingNewLine]", 
        RowBox[{"eds", " ", "=", " ", 
         RowBox[{"Union", "[", 
          RowBox[{
           RowBox[{"Complement", "[", 
            RowBox[{"eds", ",", "ntreds"}], "]"}], ",", 
           RowBox[{"Complement", "[", 
            RowBox[{"ntreds", ",", "eds"}], "]"}]}], "]"}]}]}], ",", 
       "\[IndentingNewLine]", 
       RowBox[{"{", 
        RowBox[{"kx", ",", 
         RowBox[{"ntri", "-", "1"}]}], "}"}]}], "]"}], ";", 
     "\[IndentingNewLine]", 
     RowBox[{"{", 
      RowBox[{"curv", ",", "vts", ",", "tris"}], "}"}]}]}], 
   "\[IndentingNewLine]", "]"}]}]], "Input",
 CellLabel->
  "In[168]:=",ExpressionUUID->"adbaf30c-f7ef-4b57-9350-04b771bf629f"],

Cell[BoxData[
 RowBox[{
  RowBox[{"TrimVertices", "[", 
   RowBox[{"vts_", ",", "tris_", ",", "cond_"}], "]"}], " ", ":=", " ", 
  RowBox[{"Module", "[", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{
     "vtconds", ",", "vtixs", ",", "selixs", ",", "ngslixs", ",", "trimvts", 
      ",", "trimtris", ",", "k", ",", "tmixs"}], "}"}], ",", 
    "\[IndentingNewLine]", 
    RowBox[{
     RowBox[{"vtconds", " ", "=", " ", 
      RowBox[{"cond", " ", "/@", " ", "vts"}]}], ";", "\[IndentingNewLine]", 
     RowBox[{"vtixs", " ", "=", " ", 
      RowBox[{"Range", "[", 
       RowBox[{"Length", "[", "vts", "]"}], "]"}]}], ";", 
     "\[IndentingNewLine]", 
     RowBox[{"selixs", " ", "=", " ", 
      RowBox[{
       RowBox[{
        RowBox[{"#", "[", 
         RowBox[{"[", "2", "]"}], "]"}], "&"}], " ", "/@", " ", 
       RowBox[{"Select", "[", 
        RowBox[{
         RowBox[{"Transpose", "[", 
          RowBox[{"{", 
           RowBox[{"vtconds", ",", "vtixs"}], "}"}], "]"}], ",", 
         RowBox[{
          RowBox[{"#", "[", 
           RowBox[{"[", "1", "]"}], "]"}], "&"}]}], "]"}]}]}], ";", 
     "\[IndentingNewLine]", 
     RowBox[{"ngslixs", " ", "=", " ", 
      RowBox[{"Complement", "[", 
       RowBox[{"vtixs", ",", "selixs"}], "]"}]}], ";", "\[IndentingNewLine]", 
     
     RowBox[{"trimvts", " ", "=", " ", 
      RowBox[{"vts", "[", 
       RowBox[{"[", "selixs", "]"}], "]"}]}], ";", "\[IndentingNewLine]", 
     RowBox[{"trimtris", " ", "=", " ", 
      RowBox[{"Select", "[", 
       RowBox[{"tris", ",", 
        RowBox[{
         RowBox[{
          RowBox[{"Length", "[", 
           RowBox[{"Complement", "[", 
            RowBox[{
             RowBox[{"#", "[", 
              RowBox[{"[", "1", "]"}], "]"}], ",", "ngslixs"}], "]"}], "]"}], 
          " ", "\[Equal]", " ", "3"}], "&"}]}], "]"}]}], ";", 
     "\[IndentingNewLine]", 
     RowBox[{"Do", "[", 
      RowBox[{
       RowBox[{
        RowBox[{"tmixs", "[", 
         RowBox[{"selixs", "[", 
          RowBox[{"[", "k", "]"}], "]"}], "]"}], " ", "=", " ", "k"}], ",", 
       RowBox[{"{", 
        RowBox[{"k", ",", 
         RowBox[{"Length", "[", "selixs", "]"}]}], "}"}]}], "]"}], ";", 
     "\[IndentingNewLine]", 
     RowBox[{"trimtris", " ", "=", " ", 
      RowBox[{
       RowBox[{
        RowBox[{"{", 
         RowBox[{
          RowBox[{"tmixs", " ", "/@", " ", 
           RowBox[{"#", "[", 
            RowBox[{"[", "1", "]"}], "]"}]}], ",", 
          RowBox[{"#", "[", 
           RowBox[{"[", "2", "]"}], "]"}]}], "}"}], "&"}], " ", "/@", " ", 
       "trimtris"}]}], ";", "\[IndentingNewLine]", 
     RowBox[{"{", 
      RowBox[{"trimvts", ",", "trimtris"}], "}"}]}]}], "\[IndentingNewLine]", 
   "]"}]}]], "Input",
 CellLabel->
  "In[169]:=",ExpressionUUID->"d20df5f0-b634-4b49-9c4c-90112650fff2"],

Cell[BoxData[
 RowBox[{
  RowBox[{"DisplayTriangles", "[", 
   RowBox[{"trix_", ",", "proj_", ",", "tclr_"}], "]"}], " ", ":=", " ", 
  RowBox[{"Module", "[", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{"curv", ",", "vts", ",", "tris", ",", "vtsx", ",", "trisx"}], 
     "}"}], ",", "\[IndentingNewLine]", 
    RowBox[{
     RowBox[{
      RowBox[{"{", 
       RowBox[{"curv", ",", "vts", ",", "tris"}], "}"}], " ", "=", " ", 
      "trix"}], ";", "\[IndentingNewLine]", 
     RowBox[{"If", "[", 
      RowBox[{
       RowBox[{"curv", " ", "\[NotEqual]", " ", "0"}], ",", 
       "\[IndentingNewLine]", 
       RowBox[{"Switch", "[", 
        RowBox[{
        "proj", ",", "\[IndentingNewLine]", "\"\<3D\>\"", ",", 
         "\[IndentingNewLine]", 
         RowBox[{"Graphics3D", "[", 
          RowBox[{
           RowBox[{"GraphicsComplex", "[", 
            RowBox[{"vts", ",", 
             RowBox[{"tclr", " ", "/@", " ", "tris"}]}], "]"}], ",", 
           RowBox[{"SphericalRegion", "\[Rule]", "True"}]}], "]"}], ",", 
         "\[IndentingNewLine]", "\"\<Gnomonic\>\"", ",", 
         "\[IndentingNewLine]", 
         RowBox[{
          RowBox[{
           RowBox[{"{", 
            RowBox[{"vtsx", ",", "trisx"}], "}"}], " ", "=", " ", 
           RowBox[{"TrimVertices", "[", 
            RowBox[{"vts", ",", "tris", ",", 
             RowBox[{
              RowBox[{
               RowBox[{"#", "[", 
                RowBox[{"[", "3", "]"}], "]"}], ">", "MakeTriTolerance"}], 
              "&"}]}], "]"}]}], ";", "\[IndentingNewLine]", 
          RowBox[{"vtsx", " ", "=", " ", 
           RowBox[{
            RowBox[{
             RowBox[{
              RowBox[{"{", 
               RowBox[{
                RowBox[{"#", "[", 
                 RowBox[{"[", "1", "]"}], "]"}], ",", 
                RowBox[{"#", "[", 
                 RowBox[{"[", "2", "]"}], "]"}]}], "}"}], "/", 
              RowBox[{"#", "[", 
               RowBox[{"[", "3", "]"}], "]"}]}], "&"}], " ", "/@", " ", 
            "vtsx"}]}], ";", "\[IndentingNewLine]", 
          RowBox[{"Graphics", "[", 
           RowBox[{"GraphicsComplex", "[", 
            RowBox[{"vtsx", ",", 
             RowBox[{"tclr", " ", "/@", " ", "trisx"}]}], "]"}], "]"}]}], ",",
          "\[IndentingNewLine]", "\"\<Conformal\>\"", ",", 
         "\[IndentingNewLine]", 
         RowBox[{
          RowBox[{
           RowBox[{"{", 
            RowBox[{"vtsx", ",", "trisx"}], "}"}], " ", "=", " ", 
           RowBox[{"TrimVertices", "[", 
            RowBox[{"vts", ",", "tris", ",", 
             RowBox[{
              RowBox[{
               RowBox[{"#", "[", 
                RowBox[{"[", "3", "]"}], "]"}], ">", 
               RowBox[{
                RowBox[{"-", "1"}], "+", "MakeTriTolerance"}]}], "&"}]}], 
            "]"}]}], ";", "\[IndentingNewLine]", 
          RowBox[{"vtsx", " ", "=", " ", 
           RowBox[{
            RowBox[{
             RowBox[{
              RowBox[{"{", 
               RowBox[{
                RowBox[{"#", "[", 
                 RowBox[{"[", "1", "]"}], "]"}], ",", 
                RowBox[{"#", "[", 
                 RowBox[{"[", "2", "]"}], "]"}]}], "}"}], "/", 
              RowBox[{"(", 
               RowBox[{"1", "+", 
                RowBox[{"#", "[", 
                 RowBox[{"[", "3", "]"}], "]"}]}], ")"}]}], "&"}], " ", "/@", 
            " ", "vtsx"}]}], ";", "\[IndentingNewLine]", 
          RowBox[{"Graphics", "[", 
           RowBox[{"GraphicsComplex", "[", 
            RowBox[{"vtsx", ",", 
             RowBox[{"tclr", " ", "/@", " ", "trisx"}]}], "]"}], "]"}]}], ",",
          "\[IndentingNewLine]", "\"\<Equal-Area\>\"", ",", 
         "\[IndentingNewLine]", 
         RowBox[{
          RowBox[{
           RowBox[{"{", 
            RowBox[{"vtsx", ",", "trisx"}], "}"}], " ", "=", " ", 
           RowBox[{"TrimVertices", "[", 
            RowBox[{"vts", ",", "tris", ",", 
             RowBox[{
              RowBox[{
               RowBox[{"#", "[", 
                RowBox[{"[", "3", "]"}], "]"}], ">", 
               RowBox[{
                RowBox[{"-", "1"}], "+", "MakeTriTolerance"}]}], "&"}]}], 
            "]"}]}], ";", "\[IndentingNewLine]", 
          RowBox[{"vtsx", " ", "=", " ", 
           RowBox[{
            RowBox[{
             RowBox[{
              RowBox[{"{", 
               RowBox[{
                RowBox[{"#", "[", 
                 RowBox[{"[", "1", "]"}], "]"}], ",", 
                RowBox[{"#", "[", 
                 RowBox[{"[", "2", "]"}], "]"}]}], "}"}], "/", 
              RowBox[{"Sqrt", "[", 
               RowBox[{"2", 
                RowBox[{"(", 
                 RowBox[{"1", "+", 
                  RowBox[{"#", "[", 
                   RowBox[{"[", "3", "]"}], "]"}]}], ")"}]}], "]"}]}], "&"}], 
            " ", "/@", " ", "vtsx"}]}], ";", "\[IndentingNewLine]", 
          RowBox[{"Graphics", "[", 
           RowBox[{"GraphicsComplex", "[", 
            RowBox[{"vtsx", ",", 
             RowBox[{"tclr", " ", "/@", " ", "trisx"}]}], "]"}], "]"}]}]}], 
        "\[IndentingNewLine]", "]"}], ",", "\[IndentingNewLine]", 
       RowBox[{"Graphics", "[", 
        RowBox[{"GraphicsComplex", "[", 
         RowBox[{"vts", ",", 
          RowBox[{"tclr", " ", "/@", " ", "tris"}]}], "]"}], "]"}]}], 
      "\[IndentingNewLine]", "]"}]}]}], "\[IndentingNewLine]", 
   "]"}]}]], "Input",
 CellLabel->
  "In[170]:=",ExpressionUUID->"4c859e5e-6ceb-4c65-88d6-6c0d2bb6533a"],

Cell[BoxData[
 RowBox[{
  RowBox[{"TriColorBoth", " ", "=", " ", 
   RowBox[{"{", 
    RowBox[{"Red", ",", " ", "Green", ",", " ", "Blue"}], "}"}]}], 
  ";"}]], "Input",
 CellLabel->
  "In[171]:=",ExpressionUUID->"0e92e694-acf9-4baa-b7bf-190a707cbcba"],

Cell[BoxData[
 RowBox[{
  RowBox[{"TriColorPos", " ", "=", " ", 
   RowBox[{"Lighter", " ", "/@", " ", "TriColorBoth"}]}], ";"}]], "Input",
 CellLabel->
  "In[172]:=",ExpressionUUID->"5657c704-7a7e-4503-9c0c-bc0d426a2d94"],

Cell[BoxData[
 RowBox[{
  RowBox[{"TriColorNeg", " ", "=", " ", 
   RowBox[{"Darker", " ", "/@", " ", "TriColorBoth"}]}], ";"}]], "Input",
 CellLabel->
  "In[173]:=",ExpressionUUID->"4f86ae07-6e92-40a8-b238-638ba5d565e7"],

Cell[BoxData[
 RowBox[{
  RowBox[{"TriColored", "[", "tri_", "]"}], " ", ":=", " ", 
  RowBox[{"{", 
   RowBox[{
    RowBox[{"EdgeForm", "[", "]"}], ",", 
    RowBox[{"Polygon", "[", 
     RowBox[{
      RowBox[{"tri", "[", 
       RowBox[{"[", "1", "]"}], "]"}], ",", 
      RowBox[{"VertexColors", "\[Rule]", "TriColorBoth"}]}], "]"}]}], 
   "}"}]}]], "Input",
 CellLabel->
  "In[174]:=",ExpressionUUID->"1776b80e-8b65-4546-bb21-59f0017108bc"],

Cell[BoxData[
 RowBox[{
  RowBox[{"ParTriColored", "[", "tri_", "]"}], " ", ":=", " ", 
  RowBox[{"{", 
   RowBox[{
    RowBox[{"EdgeForm", "[", "]"}], ",", 
    RowBox[{"Polygon", "[", 
     RowBox[{
      RowBox[{"tri", "[", 
       RowBox[{"[", "1", "]"}], "]"}], ",", 
      RowBox[{"VertexColors", "\[Rule]", 
       RowBox[{"If", "[", 
        RowBox[{
         RowBox[{
          RowBox[{"tri", "[", 
           RowBox[{"[", "2", "]"}], "]"}], "\[GreaterEqual]", "0"}], ",", 
         "TriColorPos", ",", "TriColorNeg"}], "]"}]}]}], "]"}]}], 
   "}"}]}]], "Input",
 CellLabel->
  "In[175]:=",ExpressionUUID->"6a145203-e39a-4295-a59b-e37071bfeee5"],

Cell[BoxData[
 RowBox[{
  RowBox[{"Bdries", "[", 
   RowBox[{"tri_", ",", "i1_", ",", "i2_"}], "]"}], " ", ":=", " ", 
  RowBox[{"{", 
   RowBox[{"Black", ",", 
    RowBox[{"Line", "[", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"tri", "[", 
        RowBox[{"[", 
         RowBox[{"1", ",", "i1"}], "]"}], "]"}], ",", 
       RowBox[{"tri", "[", 
        RowBox[{"[", 
         RowBox[{"1", ",", "i2"}], "]"}], "]"}]}], "}"}], "]"}], ",", 
    RowBox[{"EdgeForm", "[", 
     RowBox[{"{", "}"}], "]"}], ",", "LightGray", ",", 
    RowBox[{"Polygon", "[", 
     RowBox[{"tri", "[", 
      RowBox[{"[", "1", "]"}], "]"}], "]"}]}], "}"}]}]], "Input",
 CellLabel->
  "In[176]:=",ExpressionUUID->"91b71bcd-2dff-416b-a74b-fbf24f1a420a"],

Cell[BoxData[
 RowBox[{
  RowBox[{"Bdries12", "[", "tri_", "]"}], " ", ":=", " ", 
  RowBox[{"Bdries", "[", 
   RowBox[{"tri", ",", "1", ",", "2"}], "]"}]}]], "Input",
 CellLabel->
  "In[177]:=",ExpressionUUID->"6d1ae950-fc18-4979-b20a-68dfbae4730c"],

Cell[BoxData[
 RowBox[{
  RowBox[{"Bdries13", "[", "tri_", "]"}], " ", ":=", " ", 
  RowBox[{"Bdries", "[", 
   RowBox[{"tri", ",", "1", ",", "3"}], "]"}]}]], "Input",
 CellLabel->
  "In[178]:=",ExpressionUUID->"4a4e7195-bdb3-4114-9210-35ed047e6177"],

Cell[BoxData[
 RowBox[{
  RowBox[{"Bdries23", "[", "tri_", "]"}], " ", ":=", " ", 
  RowBox[{"Bdries", "[", 
   RowBox[{"tri", ",", "2", ",", "3"}], "]"}]}]], "Input",
 CellLabel->
  "In[179]:=",ExpressionUUID->"d6a1591d-c8c9-4391-b625-a9356555d84c"]
}, Closed]],

Cell[CellGroupData[{

Cell["Displays", "Subsection",ExpressionUUID->"a975b733-9924-41f7-940a-efac81d8a581"],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"{", 
    RowBox[{"tm", ",", "ts"}], "}"}], " ", "=", " ", 
   RowBox[{"Timing", "[", 
    RowBox[{"MakeTriangles", "[", 
     RowBox[{
      RowBox[{"{", 
       RowBox[{"2", ",", "3", ",", "7"}], "}"}], ",", "1000"}], "]"}], 
    "]"}]}], ";", " ", 
  RowBox[{"{", 
   RowBox[{"tm", ",", " ", 
    RowBox[{"Length", " ", "/@", " ", "ts"}]}], "}"}]}]], "Input",
 CellLabel->
  "In[180]:=",ExpressionUUID->"bfc3a781-2e55-4b65-8de8-bbebcdc8efed"],

Cell[BoxData[
 RowBox[{"Manipulate", "[", 
  RowBox[{
   RowBox[{"DisplayTriangles", "[", 
    RowBox[{"ts", ",", "proj", ",", "tclr"}], "]"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"proj", ",", "\"\<Conformal\>\""}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
      "\"\<3D\>\"", ",", "\"\<Gnomonic\>\"", ",", "\"\<Conformal\>\"", ",", 
       "\"\<Equal-Area\>\""}], "}"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"tclr", ",", "ParTriColored"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
      "TriColored", ",", "ParTriColored", ",", "Bdries12", ",", "Bdries13", 
       ",", "Bdries23"}], "}"}]}], "}"}]}], "]"}]], "Input",
 CellLabel->
  "In[181]:=",ExpressionUUID->"93579cc5-f27a-427f-a889-12b20d2a99d9"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["Large Hyperbolic Polygons", "Section",ExpressionUUID->"9ba4c586-a758-4c12-9564-d84292c428ee"],

Cell[CellGroupData[{

Cell["Polygon", "Subsection",ExpressionUUID->"5e482e29-5a9f-459b-a2b8-ce50de6e4b7a"],

Cell[BoxData[
 RowBox[{"(*", " ", 
  RowBox[{
   RowBox[{
    RowBox[{"Hyperbolic", " ", 
     RowBox[{"line", ":", " ", "r0"}]}], " ", "=", " ", 
    RowBox[{"sinh", 
     RowBox[{"(", 
      RowBox[{"min", " ", "distance", " ", "from", " ", "origin"}], ")"}]}]}],
    ",", " ", 
   RowBox[{"s", " ", "=", " ", 
    RowBox[{
     RowBox[{"sinh", 
      RowBox[{
       RowBox[{"(", 
        RowBox[{"distance", " ", "along", " ", "line"}], ")"}], ".", " ", 
       "Try"}], " ", "to", " ", "take", " ", "r0"}], "\[Rule]", 
     "infinity"}]}]}], " ", "*)"}]], "Input",
 CellLabel->
  "In[182]:=",ExpressionUUID->"0c67f280-743c-46b5-803f-790baa521648"],

Cell[BoxData[
 RowBox[{
  RowBox[{"hypline", " ", "=", " ", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"r0", "*", 
      RowBox[{"Sqrt", "[", 
       RowBox[{"1", "+", 
        RowBox[{"s", "^", "2"}]}], "]"}]}], ",", "s", ",", 
     RowBox[{
      RowBox[{"Sqrt", "[", 
       RowBox[{"1", "+", 
        RowBox[{"r0", "^", "2"}]}], "]"}], "*", 
      RowBox[{"Sqrt", "[", 
       RowBox[{"1", "+", 
        RowBox[{"s", "^", "2"}]}], "]"}]}]}], "}"}]}], ";"}]], "Input",
 CellLabel->
  "In[183]:=",ExpressionUUID->"abd2f8d7-54fa-41ce-907b-cf515ddf18f3"],

Cell[BoxData[
 RowBox[{"(*", " ", 
  RowBox[{
   RowBox[{"Rotate", " ", "to", " ", "place", " ", "s"}], " ", "=", " ", 
   RowBox[{
    RowBox[{"s1", " ", "in", " ", "the", " ", "x"}], "-", 
    RowBox[{"z", " ", "plane"}]}]}], " ", "*)"}]], "Input",
 CellLabel->
  "In[184]:=",ExpressionUUID->"7f3da505-ace0-4776-a8ed-aefef788a57f"],

Cell[BoxData[
 RowBox[{
  RowBox[{"hyprot1", " ", "=", " ", 
   RowBox[{
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
         RowBox[{"r0", "*", 
          RowBox[{"Sqrt", "[", 
           RowBox[{"1", "+", 
            RowBox[{"s1", "^", "2"}]}], "]"}]}], ",", "s1", ",", "0"}], "}"}],
        ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "s1"}], ",", 
         RowBox[{"r0", "*", 
          RowBox[{"Sqrt", "[", 
           RowBox[{"1", "+", 
            RowBox[{"s1", "^", "2"}]}], "]"}]}], ",", "0"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"0", ",", "0", ",", "0"}], "}"}]}], "}"}], "/", 
     RowBox[{"Sqrt", "[", 
      RowBox[{
       RowBox[{"r0", "^", "2"}], "+", 
       RowBox[{"s1", "^", "2"}], "+", 
       RowBox[{
        RowBox[{"r0", "^", "2"}], "*", 
        RowBox[{"s1", "^", "2"}]}]}], "]"}]}], " ", "+", " ", 
    RowBox[{"{", 
     RowBox[{
      RowBox[{"{", 
       RowBox[{"0", ",", "0", ",", "0"}], "}"}], ",", 
      RowBox[{"{", 
       RowBox[{"0", ",", "0", ",", "0"}], "}"}], ",", 
      RowBox[{"{", 
       RowBox[{"0", ",", "0", ",", "1"}], "}"}]}], "}"}]}]}], ";"}]], "Input",\

 CellLabel->
  "In[185]:=",ExpressionUUID->"bff598ed-1776-40f4-a58a-11f105da6c75"],

Cell[BoxData[
 RowBox[{"(*", " ", 
  RowBox[{
   RowBox[{"Rotate", " ", "to", " ", "place", " ", "s"}], " ", "=", " ", 
   RowBox[{"s1", " ", "at", " ", "the", " ", "origin"}]}], " ", 
  "*)"}]], "Input",
 CellLabel->
  "In[186]:=",ExpressionUUID->"627c0bce-a238-42b6-a899-73d8357f3124"],

Cell[BoxData[
 RowBox[{
  RowBox[{"hyprot2", " ", "=", " ", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{
        RowBox[{"Sqrt", "[", 
         RowBox[{"1", "+", 
          RowBox[{"r0", "^", "2"}]}], "]"}], "*", 
        RowBox[{"Sqrt", "[", 
         RowBox[{"1", "+", 
          RowBox[{"s1", "^", "2"}]}], "]"}]}], ",", "0", ",", 
       RowBox[{"-", 
        RowBox[{"Sqrt", "[", 
         RowBox[{
          RowBox[{"r0", "^", "2"}], "+", 
          RowBox[{"s1", "^", "2"}], "+", 
          RowBox[{
           RowBox[{"r0", "^", "2"}], "*", 
           RowBox[{"s1", "^", "2"}]}]}], "]"}]}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"0", ",", "1", ",", "0"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"-", 
        RowBox[{"Sqrt", "[", 
         RowBox[{
          RowBox[{"r0", "^", "2"}], "+", 
          RowBox[{"s1", "^", "2"}], "+", 
          RowBox[{
           RowBox[{"r0", "^", "2"}], "*", 
           RowBox[{"s1", "^", "2"}]}]}], "]"}]}], ",", "0", ",", 
       RowBox[{
        RowBox[{"Sqrt", "[", 
         RowBox[{"1", "+", 
          RowBox[{"r0", "^", "2"}]}], "]"}], "*", 
        RowBox[{"Sqrt", "[", 
         RowBox[{"1", "+", 
          RowBox[{"s1", "^", "2"}]}], "]"}]}]}], "}"}]}], "}"}]}], 
  ";"}]], "Input",
 CellLabel->
  "In[187]:=",ExpressionUUID->"9557ff52-f9b2-4f89-b889-86e06ca88c15"],

Cell[BoxData[
 RowBox[{"hypelnrt", " ", "=", " ", 
  RowBox[{
   RowBox[{"Limit", "[", 
    RowBox[{
     RowBox[{"hyprot2", ".", "hyprot1", ".", "hypline"}], ",", 
     RowBox[{"r0", "\[Rule]", "Infinity"}]}], "]"}], " ", "//", " ", 
   "Factor"}]}]], "Input",
 CellLabel->
  "In[188]:=",ExpressionUUID->"59eea505-ada7-4cc3-aa30-5223d3613d8e"],

Cell[BoxData[
 RowBox[{"(*", " ", 
  RowBox[{"{", 
   RowBox[{
    RowBox[{"tanh", 
     RowBox[{"(", "s1", ")"}], "*", "sinh", 
     RowBox[{"(", 
      RowBox[{"s", "-", "s1"}], ")"}]}], ",", " ", 
    RowBox[{"sech", 
     RowBox[{"(", "s1", ")"}], "*", "sinh", 
     RowBox[{"(", 
      RowBox[{"s", "-", "s1"}], ")"}]}], ",", " ", 
    RowBox[{"cosh", 
     RowBox[{"(", 
      RowBox[{"s", "-", "s1"}], ")"}]}]}], " "}], "*)"}]], "Input",
 CellLabel->
  "In[189]:=",ExpressionUUID->"a20e964e-2037-4fd8-93bd-fbe4ea600ee8"],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{
    RowBox[{"Sqrt", "[", 
     RowBox[{"1", "+", 
      RowBox[{"s1", "^", "2"}]}], "]"}], "*", 
    RowBox[{"D", "[", 
     RowBox[{"hypelnrt", ",", "s"}], "]"}]}], " ", "/.", " ", 
   RowBox[{"s", "\[Rule]", "s1"}]}], " ", "//", " ", "Simplify"}]], "Input",
 CellLabel->
  "In[190]:=",ExpressionUUID->"983d5752-d4e4-4010-a940-ec1950fd007f"],

Cell[BoxData[
 RowBox[{"(*", " ", 
  RowBox[{
   RowBox[{"Tangent", " ", "at", " ", 
    RowBox[{"origin", ":", " ", 
     RowBox[{
      RowBox[{
       RowBox[{"{", 
        RowBox[{
         RowBox[{"tanh", 
          RowBox[{"(", "s1", ")"}]}], ",", " ", 
         RowBox[{"sech", 
          RowBox[{"(", "s1", ")"}]}], ",", " ", "0"}], "}"}], " ", "--"}], 
      " ", "interior", " ", "angle"}]}]}], " ", "=", " ", 
   RowBox[{"pi", " ", "-", " ", 
    RowBox[{"2", "*", "arctan", 
     RowBox[{"(", 
      RowBox[{"sinh", 
       RowBox[{"(", "s1", ")"}]}], ")"}]}]}]}], " ", "*)"}]], "Input",
 CellLabel->
  "In[191]:=",ExpressionUUID->"cb932ecc-0277-47c8-9c37-e73601f5b8d6"],

Cell[BoxData[
 RowBox[{"(*", " ", 
  RowBox[{
   RowBox[{
    RowBox[{"Rotate", " ", "by", " ", "2", "n"}], "+", 
    RowBox[{
    "1", " ", "to", " ", "get", " ", "polygon", " ", "segments", " ", 
     "offset", " ", "by", " ", "n", " ", "from", " ", "this", " ", 
     RowBox[{"one", " ", "--"}], " ", "s"}]}], " ", "=", " ", 
   RowBox[{
    RowBox[{
     RowBox[{"-", "s1"}], " ", "for", " ", "n", " ", "is", " ", "s"}], " ", 
    "=", " ", 
    RowBox[{"s1", " ", "for", " ", 
     RowBox[{"(", 
      RowBox[{"n", "+", "1"}], ")"}]}]}]}], " ", "*)"}]], "Input",
 CellLabel->
  "In[192]:=",ExpressionUUID->"3fac391e-dd85-4bd1-b32a-881d490228be"],

Cell[BoxData[
 RowBox[{
  RowBox[{"hyprot1rlnang", " ", "=", " ", 
   RowBox[{
    RowBox[{"(", 
     RowBox[{
      RowBox[{"2", "n"}], "+", "1"}], ")"}], 
    RowBox[{"s1", "/", 
     RowBox[{"Sqrt", "[", 
      RowBox[{
       RowBox[{"r0", "^", "2"}], "+", 
       RowBox[{"s1", "^", "2"}], "+", 
       RowBox[{
        RowBox[{"r0", "^", "2"}], "*", 
        RowBox[{"s1", "^", "2"}]}]}], "]"}]}]}]}], ";"}]], "Input",
 CellLabel->
  "In[193]:=",ExpressionUUID->"a79ee520-9d88-43ff-a857-a3ae26427458"],

Cell[BoxData[
 RowBox[{
  RowBox[{"hyprot1rln", " ", "=", " ", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{"1", "-", 
        RowBox[{
         RowBox[{"hyprot1rlnang", "^", "2"}], "/", "2"}]}], ",", 
       "hyprot1rlnang", ",", "0"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"-", "hyprot1rlnang"}], ",", 
       RowBox[{"1", "-", 
        RowBox[{
         RowBox[{"hyprot1rlnang", "^", "2"}], "/", "2"}]}], ",", "0"}], "}"}],
      ",", 
     RowBox[{"{", 
      RowBox[{"0", ",", "0", ",", "1"}], "}"}]}], "}"}]}], ";"}]], "Input",
 CellLabel->
  "In[194]:=",ExpressionUUID->"58b0a67d-2fdf-49cf-9ccb-2e9f28bc1608"],

Cell[BoxData[
 RowBox[{
  RowBox[{"hypelnrtxrtn", " ", "=", " ", 
   RowBox[{
    RowBox[{"Limit", "[", 
     RowBox[{
      RowBox[{"hyprot2", ".", "hyprot1rln", ".", "hypline"}], ",", 
      RowBox[{"r0", "\[Rule]", "Infinity"}]}], "]"}], " ", "//", " ", 
    "Factor"}]}], ";"}]], "Input",
 CellLabel->
  "In[195]:=",ExpressionUUID->"5da24202-4a09-478a-ac86-f1ad6add3e4a"],

Cell[BoxData[
 RowBox[{
  RowBox[{"showhypplycrv", "[", 
   RowBox[{"nmax_", ",", "smax_", ",", "pjfden_"}], "]"}], " ", ":=", " ", 
  RowBox[{"Module", "[", 
   RowBox[{
    RowBox[{"{", "lns", "}"}], ",", "\[IndentingNewLine]", 
    RowBox[{
     RowBox[{"lns", " ", "=", " ", 
      RowBox[{"hypelnrtxrtn", " ", "/.", " ", 
       RowBox[{"s1", "\[Rule]", "smax"}]}]}], ";", "\[IndentingNewLine]", 
     RowBox[{"ParametricPlot", "[", 
      RowBox[{
       RowBox[{"Table", "[", 
        RowBox[{
         RowBox[{
          RowBox[{"{", 
           RowBox[{
            RowBox[{"-", "1"}], ",", "1"}], "}"}], "*", 
          RowBox[{
           RowBox[{"Most", "[", "lns", "]"}], "/", 
           RowBox[{"pjfden", "[", 
            RowBox[{"Last", "[", "lns", "]"}], "]"}]}]}], ",", 
         RowBox[{"{", 
          RowBox[{"n", ",", 
           RowBox[{"-", "nmax"}], ",", 
           RowBox[{"nmax", "-", "1"}]}], "}"}]}], "]"}], ",", 
       RowBox[{"{", 
        RowBox[{"s", ",", 
         RowBox[{"-", "smax"}], ",", "smax"}], "}"}], ",", 
       RowBox[{"AxesOrigin", "\[Rule]", 
        RowBox[{"{", 
         RowBox[{"0", ",", "0"}], "}"}]}]}], "]"}]}]}], "\[IndentingNewLine]",
    "]"}]}]], "Input",
 CellLabel->
  "In[196]:=",ExpressionUUID->"19155cce-74d8-48e3-bff3-f908123f3269"],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"pjfdval", "[", "\"\<Gnomonic\>\"", "]"}], " ", "=", " ", 
   RowBox[{"Function", "[", 
    RowBox[{
     RowBox[{"{", "z", "}"}], ",", "z"}], "]"}]}], ";"}]], "Input",
 CellLabel->
  "In[197]:=",ExpressionUUID->"516f1763-2e34-4be3-9c29-f846621900f3"],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"pjfdval", "[", "\"\<Conformal\>\"", "]"}], " ", "=", " ", 
   RowBox[{"Function", "[", 
    RowBox[{
     RowBox[{"{", "z", "}"}], ",", 
     RowBox[{"1", "+", "z"}]}], "]"}]}], ";"}]], "Input",
 CellLabel->
  "In[198]:=",ExpressionUUID->"88c7942b-1337-4a07-a23a-5dc5f83fe3ba"],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"pjfdval", "[", "\"\<Equal-Area\>\"", "]"}], " ", "=", " ", 
   RowBox[{"Function", "[", 
    RowBox[{
     RowBox[{"{", "z", "}"}], ",", 
     RowBox[{"Sqrt", "[", 
      RowBox[{"2", 
       RowBox[{"(", 
        RowBox[{"1", "+", "z"}], ")"}]}], "]"}]}], "]"}]}], ";"}]], "Input",
 CellLabel->
  "In[199]:=",ExpressionUUID->"9d5b34b5-9863-44af-8988-2ef2eb9cce2a"],

Cell[BoxData[
 RowBox[{"Show", "[", 
  RowBox[{
   RowBox[{"Table", "[", 
    RowBox[{
     RowBox[{"showhypplycrv", "[", 
      RowBox[{"10", ",", "0.3", ",", 
       RowBox[{"pjfdval", "[", "type", "]"}]}], "]"}], ",", 
     RowBox[{"{", 
      RowBox[{"type", ",", 
       RowBox[{"{", 
        RowBox[{"\"\<Gnomonic\>\"", ",", "\"\<Conformal\>\""}], "}"}]}], 
      "}"}]}], "]"}], ",", 
   RowBox[{"PolarPlot", "[", 
    RowBox[{"1", ",", 
     RowBox[{"{", 
      RowBox[{"a", ",", 
       RowBox[{
        RowBox[{"-", "Pi"}], "/", "2"}], ",", 
       RowBox[{"Pi", "/", "2"}]}], "}"}]}], "]"}], ",", 
   RowBox[{"PlotRange", "\[Rule]", "All"}]}], "]"}]], "Input",
 CellLabel->
  "In[200]:=",ExpressionUUID->"b8d3ed3c-73d0-4420-9113-b1317678259d"],

Cell[BoxData[
 RowBox[{"(*", " ", 
  RowBox[{
   RowBox[{
   "Outer", " ", "boundary", " ", "of", " ", "projected", " ", "value"}], ",",
    " ", 
   RowBox[{"then", " ", "gnomonic"}], ",", " ", 
   RowBox[{"then", " ", "conformal"}]}], " ", "*)"}]], "Input",
 CellLabel->
  "In[201]:=",ExpressionUUID->"c6c1b4f1-376e-4334-9325-48022e05863b"]
}, Closed]],

Cell[CellGroupData[{

Cell["Circle", "Subsection",ExpressionUUID->"b3521982-7fb9-48e8-b823-8836f50f2cf2"],

Cell[BoxData[
 RowBox[{
  RowBox[{"hypcir", " ", "=", " ", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"r0", "*", 
      RowBox[{"Cos", "[", "a", "]"}]}], ",", 
     RowBox[{"r0", "*", 
      RowBox[{"Sin", "[", "a", "]"}]}], ",", 
     RowBox[{"Sqrt", "[", 
      RowBox[{"1", "+", 
       RowBox[{"r0", "^", "2"}]}], "]"}]}], "}"}]}], ";"}]], "Input",
 CellLabel->
  "In[202]:=",ExpressionUUID->"c660309e-ccca-4315-871c-99f63789c31c"],

Cell[BoxData[
 RowBox[{
  RowBox[{"hcrot", " ", "=", " ", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{"Sqrt", "[", 
        RowBox[{"1", "+", 
         RowBox[{"r1", "^", "2"}]}], "]"}], ",", "0", ",", 
       RowBox[{"-", "r1"}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"0", ",", "1", ",", "0"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"-", "r1"}], ",", "0", ",", 
       RowBox[{"Sqrt", "[", 
        RowBox[{"1", "+", 
         RowBox[{"r1", "^", "2"}]}], "]"}]}], "}"}]}], "}"}]}], 
  ";"}]], "Input",
 CellLabel->
  "In[203]:=",ExpressionUUID->"fb762747-70e1-422e-82ce-a2e1763605bb"],

Cell[BoxData[
 RowBox[{"hypcred", " ", "=", " ", 
  RowBox[{
   RowBox[{"hcrot", ".", "hypcir"}], " ", "//", " ", "Factor"}]}]], "Input",
 CellLabel->
  "In[204]:=",ExpressionUUID->"1a0fda0e-140d-4836-b293-6e62b237d498"],

Cell[BoxData[
 RowBox[{
  RowBox[{"Total", "[", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{"1", ",", "1", ",", 
      RowBox[{"-", "1"}]}], "}"}], ".", 
    RowBox[{"hypcred", "^", "2"}]}], "]"}], " ", "//", " ", 
  "TrigReduce"}]], "Input",
 CellLabel->
  "In[205]:=",ExpressionUUID->"e9d46cad-96ac-4bcd-b06e-6c65b79263ae"],

Cell[BoxData[
 RowBox[{
  RowBox[{"shiftellip", "[", 
   RowBox[{"x_", ",", "shft_", ",", "ax1_", ",", "ax2_"}], "]"}], " ", ":=", 
  " ", 
  RowBox[{
   RowBox[{"Total", "[", 
    RowBox[{
     RowBox[{
      RowBox[{"(", 
       RowBox[{"1", "/", 
        RowBox[{"{", 
         RowBox[{"ax1", ",", "ax2"}], "}"}]}], ")"}], "^", "2"}], "*", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{"x", "-", 
        RowBox[{"{", 
         RowBox[{"shft", ",", "0"}], "}"}]}], ")"}], "^", "2"}]}], "]"}], " ",
    "-", " ", "1"}]}]], "Input",
 CellLabel->
  "In[206]:=",ExpressionUUID->"05dc8789-adf2-445e-9107-b0595191384b"],

Cell[BoxData[
 RowBox[{"(*", " ", "Gnomonic", " ", "*)"}]], "Input",
 CellLabel->
  "In[207]:=",ExpressionUUID->"9866396a-705f-4e1f-9c95-b284ba7d7a96"],

Cell[BoxData[
 RowBox[{
  RowBox[{"ofstgnom", " ", "=", " ", 
   RowBox[{
    RowBox[{"(", 
     RowBox[{"r1", "*", 
      RowBox[{"Sqrt", "[", 
       RowBox[{"1", "+", 
        RowBox[{"r1", "^", "2"}]}], "]"}]}], ")"}], "/", 
    RowBox[{"(", 
     RowBox[{"1", "+", 
      RowBox[{"r0", "^", "2"}], "+", 
      RowBox[{"r1", "^", "2"}]}], ")"}]}]}], ";"}]], "Input",
 CellLabel->
  "In[208]:=",ExpressionUUID->"f60acfd1-c3ed-445e-9503-2b091f0bc5e8"],

Cell[BoxData[
 RowBox[{
  RowBox[{"axofstgnom", " ", "=", " ", 
   RowBox[{
    RowBox[{"(", 
     RowBox[{"r0", "*", 
      RowBox[{"Sqrt", "[", 
       RowBox[{"1", "+", 
        RowBox[{"r0", "^", "2"}]}], "]"}]}], ")"}], "/", 
    RowBox[{"(", 
     RowBox[{"1", "+", 
      RowBox[{"r0", "^", "2"}], "+", 
      RowBox[{"r1", "^", "2"}]}], ")"}]}]}], ";"}]], "Input",
 CellLabel->
  "In[209]:=",ExpressionUUID->"f8473759-cb9f-4009-b99c-36e7e2818164"],

Cell[BoxData[
 RowBox[{
  RowBox[{"axperpgnom", " ", "=", " ", 
   RowBox[{"r0", "/", 
    RowBox[{"Sqrt", "[", 
     RowBox[{"1", "+", 
      RowBox[{"r0", "^", "2"}], "+", 
      RowBox[{"r1", "^", "2"}]}], "]"}]}]}], ";"}]], "Input",
 CellLabel->
  "In[210]:=",ExpressionUUID->"d3ea935f-3dd9-428e-97c4-2d8ff41e82a9"],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"shiftellip", "[", 
    RowBox[{
     RowBox[{
      RowBox[{"Most", "[", "hypcred", "]"}], "/", 
      RowBox[{"Last", "[", "hypcred", "]"}]}], ",", 
     RowBox[{"-", "ofstgnom"}], ",", "axofstgnom", ",", "axperpgnom"}], "]"}],
    " ", "//", " ", "Factor"}], " ", "//", " ", "TrigReduce"}]], "Input",
 CellLabel->
  "In[211]:=",ExpressionUUID->"580690a2-0e3f-45a7-9ba8-ed321fd15ea6"],

Cell[BoxData[
 RowBox[{"(*", " ", "Conformal", " ", "*)"}]], "Input",
 CellLabel->
  "In[212]:=",ExpressionUUID->"8947bd86-64ae-4560-81d7-283ef0829a5c"],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"{", 
    RowBox[{"ofstconf", ",", "radconf"}], "}"}], " ", "=", " ", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{"r1", ",", "r0"}], "}"}], "/", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{"Sqrt", "[", 
       RowBox[{"1", "+", 
        RowBox[{"r0", "^", "2"}]}], "]"}], "+", 
      RowBox[{"Sqrt", "[", 
       RowBox[{"1", "+", 
        RowBox[{"r1", "^", "2"}]}], "]"}]}], ")"}]}]}], ";"}]], "Input",
 CellLabel->
  "In[213]:=",ExpressionUUID->"b98d62f6-5a70-4a86-bcc1-28f89ace88b0"],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"shiftellip", "[", 
    RowBox[{
     RowBox[{
      RowBox[{"Most", "[", "hypcred", "]"}], "/", 
      RowBox[{"(", 
       RowBox[{"1", "+", 
        RowBox[{"Last", "[", "hypcred", "]"}]}], ")"}]}], ",", 
     RowBox[{"-", "ofstconf"}], ",", "radconf", ",", "radconf"}], "]"}], " ", 
   "//", " ", "Factor"}], " ", "//", " ", "TrigReduce"}]], "Input",
 CellLabel->
  "In[214]:=",ExpressionUUID->"95005113-d1a7-4de3-acbd-2a059dc96448"]
}, Closed]],

Cell[CellGroupData[{

Cell["Line", "Subsection",ExpressionUUID->"fb60670d-4b33-4d01-b5d9-b39ca1269a1f"],

Cell[BoxData[
 RowBox[{"(*", " ", "Gnomonic", " ", "*)"}]], "Input",
 CellLabel->
  "In[215]:=",ExpressionUUID->"c7fc3087-eafb-4144-a6bc-8816c890978d"],

Cell[BoxData[
 RowBox[{"lngnom", " ", "=", " ", 
  RowBox[{
   RowBox[{"Most", "[", "hypline", "]"}], "/", 
   RowBox[{"Last", "[", "hypline", "]"}]}]}]], "Input",
 CellLabel->
  "In[216]:=",ExpressionUUID->"0c45a363-8158-46eb-92f0-ab5ed32a104d"],

Cell[BoxData[
 RowBox[{"(*", " ", 
  RowBox[{"A", " ", "line"}], " ", "*)"}]], "Input",
 CellLabel->
  "In[217]:=",ExpressionUUID->"1f94eb23-acc9-4c51-909c-8b7f1dc1b3c3"],

Cell[BoxData[
 RowBox[{"(*", " ", "Conformal", " ", "*)"}]], "Input",
 CellLabel->
  "In[218]:=",ExpressionUUID->"ec870512-bc9e-4809-a21e-e31d5ed8a2af"],

Cell[BoxData[
 RowBox[{
  RowBox[{"lnconf", " ", "=", " ", 
   RowBox[{
    RowBox[{"Most", "[", "hypline", "]"}], "/", 
    RowBox[{"(", 
     RowBox[{"1", "+", 
      RowBox[{"Last", "[", "hypline", "]"}]}], ")"}]}]}], ";"}]], "Input",
 CellLabel->
  "In[219]:=",ExpressionUUID->"30195161-b5e9-4c85-b637-e86285d85b2d"],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{
    RowBox[{"r0", "^", "2"}], "*", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{
       RowBox[{"(", 
        RowBox[{
         RowBox[{"lnconf", "[", 
          RowBox[{"[", "1", "]"}], "]"}], "-", 
         RowBox[{
          RowBox[{"Sqrt", "[", 
           RowBox[{"1", "+", 
            RowBox[{"r0", "^", "2"}]}], "]"}], "/", "r0"}]}], ")"}], "^", 
       "2"}], " ", "+", " ", 
      RowBox[{
       RowBox[{"lnconf", "[", 
        RowBox[{"[", "2", "]"}], "]"}], "^", "2"}]}], ")"}]}], " ", "-", " ", 
   "1"}], " ", "//", " ", "Factor"}]], "Input",
 CellLabel->
  "In[220]:=",ExpressionUUID->"feb56c11-75af-467a-9bf5-0b2efcb6015c"],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{
    RowBox[{"lnconf", "[", 
     RowBox[{"[", "1", "]"}], "]"}], "^", "2"}], " ", "-", " ", 
   RowBox[{"2", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{"Sqrt", "[", 
       RowBox[{"1", "+", 
        RowBox[{"r0", "^", "2"}]}], "]"}], "/", "r0"}], ")"}], "*", 
    RowBox[{"lnconf", "[", 
     RowBox[{"[", "1", "]"}], "]"}]}], "+", " ", 
   RowBox[{
    RowBox[{"lnconf", "[", 
     RowBox[{"[", "2", "]"}], "]"}], "^", "2"}], " ", "+", " ", "1"}], " ", "//",
   " ", "Factor"}]], "Input",
 CellLabel->
  "In[221]:=",ExpressionUUID->"46e4a9dd-aaa3-4a64-819a-8f32e95edd44"],

Cell[BoxData[
 RowBox[{"(*", " ", 
  RowBox[{"A", " ", "hyperbola"}], " ", "*)"}]], "Input",
 CellLabel->
  "In[222]:=",ExpressionUUID->"9ff1a73d-6d66-43e5-ab74-e348c095d88b"]
}, Closed]]
}, Closed]]
},
WindowSize->{640, 696},
WindowMargins->{{Automatic, 250}, {Automatic, 8}},
ShowSelection->True,
FrontEndVersion->"11.3 for Mac OS X x86 (32-bit, 64-bit Kernel) (March 5, \
2018)",
StyleDefinitions->"Default.nb"
]
(* End of Notebook Content *)

(* Internal cache information *)
(*CellTagsOutline
CellTagsIndex->{}
*)
(*CellTagsIndex
CellTagsIndex->{}
*)
(*NotebookFileOutline
Notebook[{
Cell[545, 20, 3198, 46, 1645, "Text",ExpressionUUID->"4c92b4fa-df7d-47e9-b2db-04395a4bfdb0"],
Cell[CellGroupData[{
Cell[3768, 70, 89, 0, 67, "Section",ExpressionUUID->"ec760301-562c-4988-be22-ff423d6417db"],
Cell[CellGroupData[{
Cell[3882, 74, 86, 0, 54, "Subsection",ExpressionUUID->"f27d25b4-3bf5-4a46-a3dd-7a95da822843"],
Cell[3971, 76, 2314, 60, 241, "Input",ExpressionUUID->"22eaef84-8000-42d2-a2e1-ce1500d5ea66"],
Cell[6288, 138, 1201, 35, 136, "Input",ExpressionUUID->"84070511-2386-4933-87ed-f120f5540e1e"],
Cell[7492, 175, 559, 16, 52, "Input",ExpressionUUID->"d474a4d0-0731-40f5-ba03-691451f8537b"],
Cell[8054, 193, 1808, 47, 178, "Input",ExpressionUUID->"4d0dc103-834b-4240-8550-b600c2a16a87"],
Cell[9865, 242, 1296, 36, 94, "Input",ExpressionUUID->"b5567182-2e27-400f-9d4f-edcdd01327cb"],
Cell[11164, 280, 994, 26, 115, "Input",ExpressionUUID->"a9d3d7b1-9a1c-47cd-9011-74e833b9ec0c"],
Cell[12161, 308, 918, 25, 94, "Input",ExpressionUUID->"8980aa5a-200f-442b-bed1-bdec86230b2a"],
Cell[13082, 335, 7442, 197, 766, "Input",ExpressionUUID->"701e94a4-f00d-4ad5-a367-b3582cfb979b"],
Cell[20527, 534, 566, 16, 52, "Input",ExpressionUUID->"a2b8ddcb-a34a-4433-95c3-d286ac33c3b2"],
Cell[21096, 552, 247, 7, 30, "Input",ExpressionUUID->"63443152-7ecb-470c-91b0-3f973a1af35c"],
Cell[21346, 561, 11701, 290, 1102, "Input",ExpressionUUID->"adbaf30c-f7ef-4b57-9350-04b771bf629f"],
Cell[33050, 853, 2811, 76, 325, "Input",ExpressionUUID->"d20df5f0-b634-4b49-9c4c-90112650fff2"],
Cell[35864, 931, 5466, 136, 577, "Input",ExpressionUUID->"4c859e5e-6ceb-4c65-88d6-6c0d2bb6533a"],
Cell[41333, 1069, 252, 7, 30, "Input",ExpressionUUID->"0e92e694-acf9-4baa-b7bf-190a707cbcba"],
Cell[41588, 1078, 222, 5, 30, "Input",ExpressionUUID->"5657c704-7a7e-4503-9c0c-bc0d426a2d94"],
Cell[41813, 1085, 221, 5, 30, "Input",ExpressionUUID->"4f86ae07-6e92-40a8-b238-638ba5d565e7"],
Cell[42037, 1092, 445, 13, 52, "Input",ExpressionUUID->"1776b80e-8b65-4546-bb21-59f0017108bc"],
Cell[42485, 1107, 654, 19, 73, "Input",ExpressionUUID->"6a145203-e39a-4295-a59b-e37071bfeee5"],
Cell[43142, 1128, 736, 21, 73, "Input",ExpressionUUID->"91b71bcd-2dff-416b-a74b-fbf24f1a420a"],
Cell[43881, 1151, 250, 6, 30, "Input",ExpressionUUID->"6d1ae950-fc18-4979-b20a-68dfbae4730c"],
Cell[44134, 1159, 250, 6, 30, "Input",ExpressionUUID->"4a4e7195-bdb3-4114-9210-35ed047e6177"],
Cell[44387, 1167, 250, 6, 30, "Input",ExpressionUUID->"d6a1591d-c8c9-4391-b625-a9356555d84c"]
}, Closed]],
Cell[CellGroupData[{
Cell[44674, 1178, 85, 0, 38, "Subsection",ExpressionUUID->"a975b733-9924-41f7-940a-efac81d8a581"],
Cell[44762, 1180, 491, 15, 52, "Input",ExpressionUUID->"bfc3a781-2e55-4b65-8de8-bbebcdc8efed"],
Cell[45256, 1197, 788, 22, 115, "Input",ExpressionUUID->"93579cc5-f27a-427f-a889-12b20d2a99d9"]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[46093, 1225, 99, 0, 67, "Section",ExpressionUUID->"9ba4c586-a758-4c12-9564-d84292c428ee"],
Cell[CellGroupData[{
Cell[46217, 1229, 84, 0, 44, "Subsection",ExpressionUUID->"5e482e29-5a9f-459b-a2b8-ce50de6e4b7a"],
Cell[46304, 1231, 652, 19, 54, "Input",ExpressionUUID->"0c67f280-743c-46b5-803f-790baa521648"],
Cell[46959, 1252, 555, 17, 32, "Input",ExpressionUUID->"abd2f8d7-54fa-41ce-907b-cf515ddf18f3"],
Cell[47517, 1271, 333, 8, 32, "Input",ExpressionUUID->"7f3da505-ace0-4776-a8ed-aefef788a57f"],
Cell[47853, 1281, 1271, 40, 96, "Input",ExpressionUUID->"bff598ed-1776-40f4-a58a-11f105da6c75"],
Cell[49127, 1323, 287, 7, 32, "Input",ExpressionUUID->"627c0bce-a238-42b6-a899-73d8357f3124"],
Cell[49417, 1332, 1391, 43, 117, "Input",ExpressionUUID->"9557ff52-f9b2-4f89-b889-86e06ca88c15"],
Cell[50811, 1377, 344, 9, 32, "Input",ExpressionUUID->"59eea505-ada7-4cc3-aa30-5223d3613d8e"],
Cell[51158, 1388, 527, 16, 32, "Input",ExpressionUUID->"a20e964e-2037-4fd8-93bd-fbe4ea600ee8"],
Cell[51688, 1406, 389, 11, 32, "Input",ExpressionUUID->"983d5752-d4e4-4010-a940-ec1950fd007f"],
Cell[52080, 1419, 682, 20, 75, "Input",ExpressionUUID->"cb932ecc-0277-47c8-9c37-e73601f5b8d6"],
Cell[52765, 1441, 650, 17, 54, "Input",ExpressionUUID->"3fac391e-dd85-4bd1-b32a-881d490228be"],
Cell[53418, 1460, 507, 16, 32, "Input",ExpressionUUID->"a79ee520-9d88-43ff-a857-a3ae26427458"],
Cell[53928, 1478, 676, 21, 54, "Input",ExpressionUUID->"58b0a67d-2fdf-49cf-9ccb-2e9f28bc1608"],
Cell[54607, 1501, 375, 10, 54, "Input",ExpressionUUID->"5da24202-4a09-478a-ac86-f1ad6add3e4a"],
Cell[54985, 1513, 1300, 35, 117, "Input",ExpressionUUID->"19155cce-74d8-48e3-bff3-f908123f3269"],
Cell[56288, 1550, 297, 8, 32, "Input",ExpressionUUID->"516f1763-2e34-4be3-9c29-f846621900f3"],
Cell[56588, 1560, 324, 9, 32, "Input",ExpressionUUID->"88c7942b-1337-4a07-a23a-5dc5f83fe3ba"],
Cell[56915, 1571, 412, 12, 32, "Input",ExpressionUUID->"9d5b34b5-9863-44af-8988-2ef2eb9cce2a"],
Cell[57330, 1585, 754, 22, 75, "Input",ExpressionUUID->"b8d3ed3c-73d0-4420-9113-b1317678259d"],
Cell[58087, 1609, 342, 9, 54, "Input",ExpressionUUID->"c6c1b4f1-376e-4334-9325-48022e05863b"]
}, Closed]],
Cell[CellGroupData[{
Cell[58466, 1623, 83, 0, 36, "Subsection",ExpressionUUID->"b3521982-7fb9-48e8-b823-8836f50f2cf2"],
Cell[58552, 1625, 436, 13, 32, "Input",ExpressionUUID->"c660309e-ccca-4315-871c-99f63789c31c"],
Cell[58991, 1640, 655, 21, 54, "Input",ExpressionUUID->"fb762747-70e1-422e-82ce-a2e1763605bb"],
Cell[59649, 1663, 220, 5, 32, "Input",ExpressionUUID->"1a0fda0e-140d-4836-b293-6e62b237d498"],
Cell[59872, 1670, 325, 10, 32, "Input",ExpressionUUID->"e9d46cad-96ac-4bcd-b06e-6c65b79263ae"],
Cell[60200, 1682, 620, 20, 54, "Input",ExpressionUUID->"05dc8789-adf2-445e-9107-b0595191384b"],
Cell[60823, 1704, 151, 3, 32, "Input",ExpressionUUID->"9866396a-705f-4e1f-9c95-b284ba7d7a96"],
Cell[60977, 1709, 453, 14, 32, "Input",ExpressionUUID->"f60acfd1-c3ed-445e-9503-2b091f0bc5e8"],
Cell[61433, 1725, 455, 14, 32, "Input",ExpressionUUID->"f8473759-cb9f-4009-b99c-36e7e2818164"],
Cell[61891, 1741, 319, 9, 32, "Input",ExpressionUUID->"d3ea935f-3dd9-428e-97c4-2d8ff41e82a9"],
Cell[62213, 1752, 432, 11, 54, "Input",ExpressionUUID->"580690a2-0e3f-45a7-9ba8-ed321fd15ea6"],
Cell[62648, 1765, 152, 3, 32, "Input",ExpressionUUID->"8947bd86-64ae-4560-81d7-283ef0829a5c"],
Cell[62803, 1770, 536, 17, 32, "Input",ExpressionUUID->"b98d62f6-5a70-4a86-bcc1-28f89ace88b0"],
Cell[63342, 1789, 483, 13, 54, "Input",ExpressionUUID->"95005113-d1a7-4de3-acbd-2a059dc96448"]
}, Closed]],
Cell[CellGroupData[{
Cell[63862, 1807, 81, 0, 36, "Subsection",ExpressionUUID->"fb60670d-4b33-4d01-b5d9-b39ca1269a1f"],
Cell[63946, 1809, 151, 3, 32, "Input",ExpressionUUID->"c7fc3087-eafb-4144-a6bc-8816c890978d"],
Cell[64100, 1814, 246, 6, 32, "Input",ExpressionUUID->"0c45a363-8158-46eb-92f0-ab5ed32a104d"],
Cell[64349, 1822, 170, 4, 32, "Input",ExpressionUUID->"1f94eb23-acc9-4c51-909c-8b7f1dc1b3c3"],
Cell[64522, 1828, 152, 3, 32, "Input",ExpressionUUID->"ec870512-bc9e-4809-a21e-e31d5ed8a2af"],
Cell[64677, 1833, 320, 9, 32, "Input",ExpressionUUID->"30195161-b5e9-4c85-b637-e86285d85b2d"],
Cell[65000, 1844, 689, 22, 54, "Input",ExpressionUUID->"feb56c11-75af-467a-9bf5-0b2efcb6015c"],
Cell[65692, 1868, 624, 19, 54, "Input",ExpressionUUID->"46e4a9dd-aaa3-4a64-819a-8f32e95edd44"],
Cell[66319, 1889, 175, 4, 32, "Input",ExpressionUUID->"9ff1a73d-6d66-43e5-ab74-e348c095d88b"]
}, Closed]]
}, Closed]]
}
]
*)

