(* Content-type: application/mathematica *)

(*** Wolfram Notebook File ***)
(* http://www.wolfram.com/nb *)

(* CreatedBy='Mathematica 7.0' *)

(*CacheID: 234*)
(* Internal cache information:
NotebookFileLineBreakTest
NotebookFileLineBreakTest
NotebookDataPosition[       145,          7]
NotebookDataLength[     64128,       1790]
NotebookOptionsPosition[     62253,       1736]
NotebookOutlinePosition[     62632,       1753]
CellTagsIndexPosition[     62589,       1750]
WindowFrame->Normal*)

(* Beginning of Notebook Content *)
Notebook[{
Cell["\<\
Makes an image from another image by tiling the original image using various \
symmetries.

TileImage[center_,tlfunc_,tlfparams_,nsamps_,img_]
Args:
Center for the transformation (horizontal, vertical)
Transformation function on pixel coordinates
Args parameters coords - returns new coords
Parameters for that function
Number of samples per pixel (at least 1: more is smoother but more \
time-consuming))
Mma image object

Returns transformed image

Rosette[center_,params_,nsamps_,img_]
Args:
Center
Params: list of
- Starting angle in radians
 - Number of divisions
 - Whether cyclic (False) or dihedral (True)
Number of samples per pixel
Mma image object

Returns transformed image

Types: C(n), D(n)

Frieze[center_,params_,nsamps_,img_] 
Args:
Center
Params:
- Type: 1 to 7
- Starting angle in radians
- Length of repeat
- Starting angle of second line in radians (only for 1, 5)
Number of samples per pixel
Mma image object

Returns transformed image

Types: p1, p11m, p11g, p1m1 p2, p2mm, p2mg

Wallpaper[center_,params_,nsamps_,img_]
Args:
Center
Params:
- Type: 1 to 17
- Starting angle in radians
- Length of repeat
- Starting angle of second line in radians (1, 2, 5, 9)
- Length of second repeat (1 to 4, 6 to 8)
Number of samples per pixel
Mma image object

Returns transformed image

Types: p1, p2, pm, pg, cm, pmm, pmg, pgg, cmm, p4, p4m, p4g, p3, p3m1, p31m, \
p6, p6m

LogSpiral[center_,params_,nsamps_,img_] 
Args:
Center
Params
- Starting angle in radians
- Starting radius
- Pitch
Number of samples per pixel
Mma image object

Returns transformed image


OSX Core Image filters: which groups they implement
CIAffineTile -- 1 -- p1
CIEightfoldReflectedTile -- 11 -- p4m
CIFourfoldReflectedTile -- 6 -- pmm
CIFourfoldRotatedTile -- 10 -- p4
CIFourfoldTranslatedTile -- 1 -- p1
CIGlideReflectedTile -- 4 -- pg
CIKaleidoscope -- rosette groups D(n) dihedral
CIOpTile -- modified 1 -- p1
CIParallelogramTile -- 6 -- pmm
CIPerspectiveTile -- modified 1 -- p1
CISixfoldReflectedTile -- 15 -- p31m
CISixfoldRotatedTile -- 16 -- p6
CITriangleTile -- 14 -- p3m1
CITwelvefoldReflectedTile -- 17 -- p6m\
\>", "Text"],

Cell[BoxData[
 RowBox[{"(*", " ", 
  RowBox[{
  "Creates", " ", "an", " ", "array", " ", "of", " ", "indices", " ", "and", 
   " ", "works", " ", "with", " ", "it"}], " ", "*)"}]], "Input"],

Cell[BoxData[
 RowBox[{
  RowBox[{"TileImage", "[", 
   RowBox[{
   "center_", ",", "tlfunc_", ",", "tlfparams_", ",", "nsamps_", ",", 
    "img_"}], "]"}], " ", ":=", " ", 
  RowBox[{"Module", "[", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{
     "srcimg", ",", "srcdata", ",", "dstdata", ",", "nh", ",", "nv", ",", 
      "nhxt", ",", "nvxt", ",", "ixs", ",", "tfct", ",", "clpf", ",", 
      "prfc"}], "}"}], ",", "\[IndentingNewLine]", 
    RowBox[{"(*", " ", 
     RowBox[{
     "Need", " ", "to", " ", "reflect", " ", "the", " ", "image", " ", "to", 
      " ", "count", " ", "the", " ", "center", " ", "from", " ", "the", " ", 
      "bottom", " ", "instead", " ", "of", " ", "from", " ", "the", " ", 
      "top"}], " ", "*)"}], "\[IndentingNewLine]", 
    RowBox[{
     RowBox[{"srcimg", " ", "=", " ", 
      RowBox[{"ImageReflect", "[", 
       RowBox[{"Image", "[", 
        RowBox[{"img", ",", "\"\<Real\>\""}], "]"}], "]"}]}], ";", 
     "\[IndentingNewLine]", 
     RowBox[{"srcdata", " ", "=", " ", 
      RowBox[{"ImageData", "[", "srcimg", "]"}]}], ";", "\[IndentingNewLine]", 
     RowBox[{"(*", " ", 
      RowBox[{"Horizontal", ",", " ", 
       RowBox[{"then", " ", "vertical"}]}], " ", "*)"}], 
     "\[IndentingNewLine]", 
     RowBox[{
      RowBox[{"{", 
       RowBox[{"nh", ",", "nv"}], "}"}], " ", "=", " ", 
      RowBox[{"ImageDimensions", "[", "srcimg", "]"}]}], ";", 
     "\[IndentingNewLine]", "\[IndentingNewLine]", 
     RowBox[{"(*", " ", 
      RowBox[{
       RowBox[{"For", " ", "each", " ", "destination", " ", "pixel"}], ",", 
       " ", 
       RowBox[{
        RowBox[{"its", " ", "source"}], "-", 
        RowBox[{"pixel", " ", 
         RowBox[{"index", ".", " ", "Indexed"}], " ", "vertical"}]}], ",", 
       " ", 
       RowBox[{
        RowBox[{"horizontal", ".", " ", "Made"}], " ", "oversized", " ", "to",
         " ", "do", " ", "antialiasing"}]}], " ", "*)"}], 
     "\[IndentingNewLine]", 
     RowBox[{"nhxt", " ", "=", " ", 
      RowBox[{"nsamps", "*", "nh"}]}], ";", " ", 
     RowBox[{"nvxt", " ", "=", " ", 
      RowBox[{"nsamps", "*", "nv"}]}], ";", "\[IndentingNewLine]", 
     RowBox[{"ixs", " ", "=", " ", 
      RowBox[{
       RowBox[{
        RowBox[{"(", 
         RowBox[{
          RowBox[{"Outer", "[", 
           RowBox[{"List", ",", 
            RowBox[{"Range", "[", "nvxt", "]"}], ",", 
            RowBox[{"Range", "[", "nhxt", "]"}]}], "]"}], " ", "-", " ", 
          "0.5"}], ")"}], "/", "nsamps"}], " ", "+", " ", "0.5"}]}], ";", 
     "\[IndentingNewLine]", 
     RowBox[{"ixs", " ", "=", " ", 
      RowBox[{"Map", "[", 
       RowBox[{
        RowBox[{
         RowBox[{
          RowBox[{"Reverse", "[", "#", "]"}], "-", "center"}], "&"}], ",", 
        "ixs", ",", 
        RowBox[{"{", "2", "}"}]}], "]"}]}], ";", "\[IndentingNewLine]", 
     RowBox[{"ixs", " ", "=", " ", 
      RowBox[{"Map", "[", 
       RowBox[{
        RowBox[{
         RowBox[{"tlfunc", "[", 
          RowBox[{"tlfparams", ",", "#"}], "]"}], "&"}], ",", "ixs", ",", 
        RowBox[{"{", "2", "}"}]}], "]"}]}], ";", "\[IndentingNewLine]", 
     RowBox[{"ixs", " ", "=", " ", 
      RowBox[{"Map", "[", 
       RowBox[{
        RowBox[{
         RowBox[{
          RowBox[{"Reverse", "[", "#", "]"}], "+", "center"}], "&"}], ",", 
        "ixs", ",", 
        RowBox[{"{", "2", "}"}]}], "]"}]}], ";", "\[IndentingNewLine]", 
     RowBox[{"ixs", " ", "=", " ", 
      RowBox[{"Round", "[", "ixs", "]"}]}], ";", "\[IndentingNewLine]", 
     RowBox[{"ixs", " ", "=", " ", 
      RowBox[{"Map", "[", 
       RowBox[{
        RowBox[{
         RowBox[{"{", 
          RowBox[{
           RowBox[{"Clip", "[", 
            RowBox[{
             RowBox[{"#", "[", 
              RowBox[{"[", "1", "]"}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"1", ",", "nv"}], "}"}]}], "]"}], ",", 
           RowBox[{"Clip", "[", 
            RowBox[{
             RowBox[{"#", "[", 
              RowBox[{"[", "2", "]"}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"1", ",", "nh"}], "}"}]}], "]"}]}], "}"}], "&"}], ",", 
        "ixs", ",", 
        RowBox[{"{", "2", "}"}]}], "]"}]}], ";", "\[IndentingNewLine]", 
     RowBox[{"(*", " ", 
      RowBox[{"Get", " ", "the", " ", "new", " ", "image"}], " ", "*)"}], 
     "\[IndentingNewLine]", 
     RowBox[{"dstdata", " ", "=", " ", 
      RowBox[{"Map", "[", 
       RowBox[{
        RowBox[{
         RowBox[{"srcdata", "[", 
          RowBox[{"[", 
           RowBox[{
            RowBox[{"#", "[", 
             RowBox[{"[", "1", "]"}], "]"}], ",", 
            RowBox[{"#", "[", 
             RowBox[{"[", "2", "]"}], "]"}]}], "]"}], "]"}], "&"}], ",", 
        "ixs", ",", 
        RowBox[{"{", "2", "}"}]}], "]"}]}], ";", "\[IndentingNewLine]", 
     "\[IndentingNewLine]", 
     RowBox[{"(*", " ", 
      RowBox[{
       RowBox[{"Undo", " ", "that", " ", "reflection"}], ",", " ", 
       RowBox[{"get", " ", "to", " ", "the", " ", "original", " ", "size"}]}],
       " ", "*)"}], "\[IndentingNewLine]", 
     RowBox[{"ImageReflect", "[", 
      RowBox[{"ImageResize", "[", 
       RowBox[{
        RowBox[{"Image", "[", "dstdata", "]"}], ",", 
        RowBox[{"{", 
         RowBox[{"nh", ",", "nv"}], "}"}]}], "]"}], "]"}]}]}], 
   "\[IndentingNewLine]", "]"}]}]], "Input"],

Cell[BoxData[
 RowBox[{"(*", " ", 
  RowBox[{"The", " ", "original", " ", 
   RowBox[{"version", ":", " ", 
    RowBox[{"point", " ", "by", " ", "point"}]}]}], " ", "*)"}]], "Input"],

Cell[BoxData[
 RowBox[{
  RowBox[{"OldTileImage", "[", 
   RowBox[{
   "center_", ",", "tlfunc_", ",", "tlfparams_", ",", "nsamps_", ",", 
    "img_"}], "]"}], " ", ":=", " ", 
  RowBox[{"Module", "[", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{
     "srcimg", ",", "srcdata", ",", "dstdata", ",", "zero", ",", "nsr", ",", 
      "cv", ",", "ch", ",", "nv", ",", "nh", ",", "iv", ",", "ih", ",", "jv", 
      ",", "jh", ",", "kv", ",", "kh", ",", "lv", ",", "lh", ",", "prs"}], 
     "}"}], ",", "\[IndentingNewLine]", 
    RowBox[{
     RowBox[{
      RowBox[{"{", 
       RowBox[{"ch", ",", "cv"}], "}"}], " ", "=", " ", "center"}], ";", 
     "\[IndentingNewLine]", 
     RowBox[{"(*", " ", 
      RowBox[{
      "Need", " ", "to", " ", "reflect", " ", "the", " ", "image", " ", "to", 
       " ", "count", " ", "the", " ", "center", " ", "from", " ", "the", " ", 
       "bottom", " ", "instead", " ", "of", " ", "from", " ", "the", " ", 
       "top"}], " ", "*)"}], "\[IndentingNewLine]", 
     RowBox[{"srcimg", " ", "=", " ", 
      RowBox[{"ImageReflect", "[", 
       RowBox[{"Image", "[", 
        RowBox[{"img", ",", "\"\<Real\>\""}], "]"}], "]"}]}], ";", 
     "\[IndentingNewLine]", 
     RowBox[{"srcdata", " ", "=", " ", 
      RowBox[{"ImageData", "[", "srcimg", "]"}]}], ";", "\[IndentingNewLine]", 
     RowBox[{
      RowBox[{"{", 
       RowBox[{"nh", ",", "nv"}], "}"}], " ", "=", " ", 
      RowBox[{"ImageDimensions", "[", "srcimg", "]"}]}], ";", 
     "\[IndentingNewLine]", 
     RowBox[{"nsr", " ", "=", " ", 
      RowBox[{"1.0", "/", "nsamps"}]}], ";", "\[IndentingNewLine]", 
     RowBox[{"dstdata", " ", "=", " ", 
      RowBox[{
       RowBox[{"nsr", "^", "2"}], "*", 
       RowBox[{"Table", "[", 
        RowBox[{
         RowBox[{"Sum", "[", "\[IndentingNewLine]", 
          RowBox[{
           RowBox[{
            RowBox[{"kv", " ", "=", " ", 
             RowBox[{"iv", " ", "+", " ", 
              RowBox[{
               RowBox[{"(", 
                RowBox[{"1", "/", "2"}], ")"}], "*", 
               RowBox[{"(", 
                RowBox[{
                 RowBox[{"nsr", "*", 
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"2", "*", "jv"}], "-", "1"}], ")"}]}], "-", "1"}],
                 ")"}]}], " ", "-", " ", "cv"}]}], ";", " ", 
            "\[IndentingNewLine]", 
            RowBox[{"kh", " ", "=", " ", 
             RowBox[{"ih", " ", "+", " ", 
              RowBox[{
               RowBox[{"(", 
                RowBox[{"1", "/", "2"}], ")"}], "*", 
               RowBox[{"(", 
                RowBox[{
                 RowBox[{"nsr", "*", 
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"2", "*", "jh"}], "-", "1"}], ")"}]}], "-", "1"}],
                 ")"}]}], " ", "-", " ", "ch"}]}], ";", "\[IndentingNewLine]", 
            RowBox[{"prs", " ", "=", "  ", 
             RowBox[{"tlfunc", "[", 
              RowBox[{"tlfparams", ",", 
               RowBox[{"{", 
                RowBox[{"kh", ",", "kv"}], "}"}]}], "]"}]}], ";", 
            "\[IndentingNewLine]", 
            RowBox[{"lv", " ", "=", " ", 
             RowBox[{"Round", "[", 
              RowBox[{
               RowBox[{"prs", "[", 
                RowBox[{"[", "2", "]"}], "]"}], " ", "+", " ", "cv"}], 
              "]"}]}], ";", " ", "\[IndentingNewLine]", 
            RowBox[{"lv", " ", "=", " ", 
             RowBox[{"Min", "[", 
              RowBox[{
               RowBox[{"Max", "[", 
                RowBox[{"lv", ",", "1"}], "]"}], ",", "nv"}], "]"}]}], ";", 
            "\[IndentingNewLine]", 
            RowBox[{"lh", " ", "=", " ", 
             RowBox[{"Round", "[", 
              RowBox[{
               RowBox[{"prs", "[", 
                RowBox[{"[", "1", "]"}], "]"}], " ", "+", " ", "ch"}], 
              "]"}]}], ";", "\[IndentingNewLine]", 
            RowBox[{"lh", " ", "=", " ", 
             RowBox[{"Min", "[", 
              RowBox[{
               RowBox[{"Max", "[", 
                RowBox[{"lh", ",", "1"}], "]"}], ",", "nh"}], "]"}]}], ";", 
            "\[IndentingNewLine]", 
            RowBox[{"srcdata", "[", 
             RowBox[{"[", 
              RowBox[{"lv", ",", "lh"}], "]"}], "]"}]}], ",", 
           "\[IndentingNewLine]", 
           RowBox[{"{", 
            RowBox[{"jv", ",", "nsamps"}], "}"}], ",", 
           RowBox[{"{", 
            RowBox[{"jh", ",", "nsamps"}], "}"}]}], "]"}], ",", 
         RowBox[{"{", 
          RowBox[{"iv", ",", "nv"}], "}"}], ",", 
         RowBox[{"{", 
          RowBox[{"ih", ",", "nh"}], "}"}]}], "]"}]}]}], ";", 
     "\[IndentingNewLine]", 
     RowBox[{"(*", " ", 
      RowBox[{"Undo", " ", "that", " ", "reflection"}], " ", "*)"}], 
     "\[IndentingNewLine]", 
     RowBox[{"ImageReflect", "[", 
      RowBox[{"Image", "[", "dstdata", "]"}], "]"}]}]}], 
   "\[IndentingNewLine]", "]"}]}]], "Input"],

Cell[BoxData[
 RowBox[{"(*", " ", 
  RowBox[{"For", " ", "rosette", " ", "groups"}], " ", "*)"}]], "Input"],

Cell[BoxData[
 RowBox[{
  RowBox[{"RosetteTlf", "[", 
   RowBox[{"params_", ",", "pt_"}], "]"}], " ", ":=", " ", 
  RowBox[{"Module", "[", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{
     "a0", ",", "n", ",", "cd", ",", "x", ",", "y", ",", "r", ",", "a"}], 
     "}"}], ",", "\[IndentingNewLine]", 
    RowBox[{
     RowBox[{
      RowBox[{"{", 
       RowBox[{"a0", ",", "n", ",", "cd"}], "}"}], " ", "=", " ", "params"}], 
     ";", "\[IndentingNewLine]", 
     RowBox[{
      RowBox[{"{", 
       RowBox[{"x", ",", "y"}], "}"}], " ", "=", " ", "pt"}], ";", 
     "\[IndentingNewLine]", 
     RowBox[{"r", " ", "=", " ", 
      RowBox[{"Sqrt", "[", 
       RowBox[{
        RowBox[{"x", "^", "2"}], "+", 
        RowBox[{"y", "^", "2"}]}], "]"}]}], ";", "\[IndentingNewLine]", 
     RowBox[{"a", " ", "=", " ", 
      RowBox[{"If", "[", 
       RowBox[{
        RowBox[{
         RowBox[{"x", " ", "\[Equal]", " ", "0"}], " ", "&&", " ", 
         RowBox[{"y", " ", "\[Equal]", " ", "0"}]}], ",", "0", ",", " ", 
        RowBox[{"ArcTan", "[", 
         RowBox[{"x", ",", "y"}], "]"}]}], "]"}]}], ";", 
     "\[IndentingNewLine]", 
     RowBox[{"a", " ", "=", " ", 
      RowBox[{"Mod", "[", 
       RowBox[{
        RowBox[{
         RowBox[{"(", 
          RowBox[{"n", "/", 
           RowBox[{"(", 
            RowBox[{"2", "*", "Pi"}], ")"}]}], ")"}], "*", 
         RowBox[{"(", 
          RowBox[{"a", "-", "a0"}], ")"}]}], ",", "1"}], "]"}]}], ";", 
     "\[IndentingNewLine]", 
     RowBox[{"If", "[", 
      RowBox[{"cd", ",", 
       RowBox[{"If", "[", 
        RowBox[{
         RowBox[{"a", " ", ">", " ", 
          RowBox[{"1", "/", "2"}]}], ",", 
         RowBox[{"a", " ", "=", " ", 
          RowBox[{"1", " ", "-", " ", "a"}]}]}], "]"}]}], "]"}], ";", 
     "\[IndentingNewLine]", 
     RowBox[{"a", " ", "=", " ", 
      RowBox[{"a0", " ", "+", " ", 
       RowBox[{
        RowBox[{"(", 
         RowBox[{
          RowBox[{"(", 
           RowBox[{"2", "*", "Pi"}], ")"}], "/", "n"}], ")"}], "*", "a"}]}]}],
      ";", "\[IndentingNewLine]", 
     RowBox[{"r", "*", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"Cos", "[", "a", "]"}], ",", 
        RowBox[{"Sin", "[", "a", "]"}]}], "}"}]}]}]}], "\[IndentingNewLine]", 
   "]"}]}]], "Input"],

Cell[BoxData[
 RowBox[{
  RowBox[{"Rosette", "[", 
   RowBox[{"center_", ",", "params_", ",", "nsamps_", ",", "img_"}], "]"}], 
  " ", ":=", " ", "\[IndentingNewLine]", 
  RowBox[{"TileImage", "[", 
   RowBox[{
   "center", ",", "RosetteTlf", ",", "params", ",", "nsamps", ",", "img"}], 
   "]"}]}]], "Input"],

Cell[BoxData[
 RowBox[{"(*", " ", 
  RowBox[{"For", " ", "lattice", " ", "groups"}], " ", "*)"}]], "Input"],

Cell[BoxData[
 RowBox[{
  RowBox[{"LatticeTlf", "[", 
   RowBox[{"params_", ",", "pt_"}], "]"}], " ", ":=", " ", 
  RowBox[{"Module", "[", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{
     "lat", ",", "invlat", ",", "tlfunc", ",", "tlfparams", ",", "ptx"}], 
     "}"}], ",", "\[IndentingNewLine]", 
    RowBox[{
     RowBox[{
      RowBox[{"{", 
       RowBox[{"lat", ",", "invlat", ",", "tlfunc", ",", "tlfparams"}], "}"}],
       " ", "=", " ", "params"}], ";", "\[IndentingNewLine]", 
     RowBox[{"ptx", " ", "=", " ", 
      RowBox[{"invlat", ".", "pt"}]}], ";", "\[IndentingNewLine]", 
     RowBox[{"ptx", " ", "=", " ", 
      RowBox[{"tlfunc", "[", 
       RowBox[{"tlfparams", ",", "ptx"}], "]"}]}], ";", "\[IndentingNewLine]", 
     RowBox[{"lat", ".", "ptx"}]}]}], "]"}]}]], "Input"],

Cell[BoxData[
 RowBox[{
  RowBox[{"LatticeTileImage", "[", 
   RowBox[{
   "center_", ",", "latparams_", ",", "tlfunc_", ",", "tlfparams_", ",", 
    "nsamps_", ",", "img_"}], "]"}], " ", ":=", " ", 
  RowBox[{"Module", "[", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{
     "a1", ",", "l1", ",", "a2", ",", "l2", ",", "lat", ",", "invlat", ",", 
      "ltfparams"}], "}"}], ",", "\[IndentingNewLine]", 
    RowBox[{
     RowBox[{
      RowBox[{"{", 
       RowBox[{"a1", ",", "l1", ",", "a2", ",", "l2"}], "}"}], " ", "=", " ", 
      "latparams"}], ";", "\[IndentingNewLine]", 
     RowBox[{"lat", " ", "=", 
      RowBox[{"1.0", "*", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"{", 
          RowBox[{
           RowBox[{"l1", "*", 
            RowBox[{"Cos", "[", "a1", "]"}]}], ",", 
           RowBox[{"l2", "*", 
            RowBox[{"Cos", "[", "a2", "]"}]}]}], "}"}], ",", 
         RowBox[{"{", 
          RowBox[{
           RowBox[{"l1", "*", 
            RowBox[{"Sin", "[", "a1", "]"}]}], ",", 
           RowBox[{"l2", "*", 
            RowBox[{"Sin", "[", "a2", "]"}]}]}], "}"}]}], "}"}]}]}], ";", 
     "\[IndentingNewLine]", 
     RowBox[{"invlat", " ", "=", " ", 
      RowBox[{"Inverse", "[", "lat", "]"}]}], ";", "\[IndentingNewLine]", 
     RowBox[{"ltfparams", " ", "=", " ", 
      RowBox[{"{", 
       RowBox[{"lat", ",", "invlat", ",", "tlfunc", ",", "tlfparams"}], 
       "}"}]}], ";", "\[IndentingNewLine]", 
     RowBox[{"TileImage", "[", 
      RowBox[{
      "center", ",", "LatticeTlf", ",", "ltfparams", ",", "nsamps", ",", 
       "img"}], "]"}]}]}], "\[IndentingNewLine]", "]"}]}]], "Input"],

Cell[BoxData[
 RowBox[{"(*", " ", 
  RowBox[{"For", " ", "frieze", " ", "groups"}], " ", "*)"}]], "Input"],

Cell[BoxData[
 RowBox[{
  RowBox[{"FriezeTlf", "[", 
   RowBox[{"params_", ",", "pt_"}], "]"}], " ", ":=", " ", 
  RowBox[{"Module", "[", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{"type", ",", "x", ",", "y"}], "}"}], ",", "\[IndentingNewLine]", 
    
    RowBox[{
     RowBox[{
      RowBox[{"{", 
       RowBox[{"x", ",", "y"}], "}"}], " ", "=", " ", "pt"}], ";", 
     "\[IndentingNewLine]", 
     RowBox[{"type", " ", "=", " ", "params"}], ";", "\[IndentingNewLine]", 
     RowBox[{"x", " ", "=", " ", 
      RowBox[{"Mod", "[", 
       RowBox[{"x", ",", "1"}], "]"}]}], ";", "\[IndentingNewLine]", 
     RowBox[{"Switch", "[", 
      RowBox[{
      "type", ",", "\[IndentingNewLine]", "1", ",", "\[IndentingNewLine]", 
       "Null", ",", "\[IndentingNewLine]", "2", ",", "\[IndentingNewLine]", 
       RowBox[{"If", "[", 
        RowBox[{
         RowBox[{"y", " ", "<", " ", "0"}], ",", " ", 
         RowBox[{"y", " ", "*=", " ", 
          RowBox[{"-", "1"}]}]}], "]"}], ",", "\[IndentingNewLine]", "3", ",",
        "\[IndentingNewLine]", 
       RowBox[{"If", "[", 
        RowBox[{
         RowBox[{"x", " ", ">", " ", 
          RowBox[{"1", "/", "2"}]}], ",", " ", 
         RowBox[{"y", " ", "*=", " ", 
          RowBox[{"-", "1"}]}]}], "]"}], ",", "\[IndentingNewLine]", "4", ",",
        "\[IndentingNewLine]", 
       RowBox[{"If", "[", 
        RowBox[{
         RowBox[{"x", " ", ">", " ", 
          RowBox[{"1", "/", "2"}]}], ",", 
         RowBox[{"x", " ", "*=", " ", 
          RowBox[{"-", "1"}]}]}], "]"}], ",", "\[IndentingNewLine]", "5", ",",
        "\[IndentingNewLine]", 
       RowBox[{"If", "[", 
        RowBox[{
         RowBox[{"y", " ", "<", " ", "0"}], ",", " ", 
         RowBox[{
          RowBox[{"x", " ", "*=", " ", 
           RowBox[{"-", "1"}]}], ";", " ", 
          RowBox[{"y", "*=", " ", 
           RowBox[{"-", "1"}]}]}]}], "]"}], ",", "\[IndentingNewLine]", "6", 
       ",", "\[IndentingNewLine]", 
       RowBox[{
        RowBox[{"If", "[", 
         RowBox[{
          RowBox[{"y", " ", "<", " ", "0"}], ",", " ", 
          RowBox[{"y", " ", "*=", " ", 
           RowBox[{"-", "1"}]}]}], "]"}], ";", " ", 
        RowBox[{"If", "[", 
         RowBox[{
          RowBox[{"x", " ", ">", " ", 
           RowBox[{"1", "/", "2"}]}], ",", " ", 
          RowBox[{"x", " ", "*=", " ", 
           RowBox[{"-", "1"}]}]}], "]"}]}], ",", "\[IndentingNewLine]", "7", 
       ",", "\[IndentingNewLine]", 
       RowBox[{
        RowBox[{"If", "[", 
         RowBox[{
          RowBox[{"y", " ", "<", " ", "0"}], ",", "  ", 
          RowBox[{
           RowBox[{"x", " ", "+=", " ", 
            RowBox[{"1", "/", "2"}]}], ";", 
           RowBox[{"x", " ", "=", " ", 
            RowBox[{"Mod", "[", 
             RowBox[{"x", ",", "1"}], "]"}]}], ";", " ", 
           RowBox[{"y", " ", "*=", " ", 
            RowBox[{"-", "1"}]}]}]}], "]"}], ";", " ", 
        RowBox[{"If", "[", 
         RowBox[{
          RowBox[{"x", " ", ">", " ", 
           RowBox[{"1", "/", "2"}]}], ",", " ", 
          RowBox[{"x", " ", "*=", " ", 
           RowBox[{"-", "1"}]}]}], "]"}]}]}], "\[IndentingNewLine]", "]"}], 
     ";", "\[IndentingNewLine]", 
     RowBox[{"x", " ", "=", " ", 
      RowBox[{"Mod", "[", 
       RowBox[{"x", ",", "1"}], "]"}]}], ";", "\[IndentingNewLine]", 
     RowBox[{"{", 
      RowBox[{"x", ",", "y"}], "}"}]}]}], "]"}]}]], "Input"],

Cell[BoxData[
 RowBox[{
  RowBox[{"Frieze", "[", 
   RowBox[{"center_", ",", "params_", ",", "nsamps_", ",", "img_"}], "]"}], 
  " ", ":=", " ", 
  RowBox[{"Module", "[", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{"type", ",", "a1", ",", "l1", ",", "a2", ",", "l2"}], "}"}], ",",
     "\[IndentingNewLine]", 
    RowBox[{
     RowBox[{"type", " ", "=", " ", 
      RowBox[{"First", "[", "params", "]"}]}], ";", "\[IndentingNewLine]", 
     RowBox[{"Which", "[", 
      RowBox[{
       RowBox[{"MemberQ", "[", 
        RowBox[{
         RowBox[{"{", 
          RowBox[{"1", ",", "5"}], "}"}], ",", "type"}], "]"}], ",", 
       RowBox[{
        RowBox[{"{", 
         RowBox[{"type", ",", "a1", ",", "l1", ",", "a2"}], "}"}], " ", "=", 
        " ", "params"}], ",", "\[IndentingNewLine]", 
       RowBox[{"MemberQ", "[", 
        RowBox[{
         RowBox[{"{", 
          RowBox[{"2", ",", "3", ",", "4", ",", "6", ",", "7"}], "}"}], ",", 
         "type"}], "]"}], ",", 
       RowBox[{
        RowBox[{
         RowBox[{"{", 
          RowBox[{"type", ",", "a1", ",", "l1"}], "}"}], " ", "=", " ", 
         "params"}], ";", 
        RowBox[{"a2", " ", "=", " ", 
         RowBox[{"a1", " ", "+", " ", 
          RowBox[{"Pi", "/", "2"}]}]}]}], ",", "\[IndentingNewLine]", "True", 
       ",", 
       RowBox[{"Return", "[", "]"}]}], "]"}], ";", "\[IndentingNewLine]", 
     RowBox[{"l2", " ", "=", " ", "l1"}], ";", "\[IndentingNewLine]", 
     RowBox[{"LatticeTileImage", "[", 
      RowBox[{"center", ",", 
       RowBox[{"{", 
        RowBox[{"a1", ",", "l1", ",", "a2", ",", "l2"}], "}"}], ",", 
       "FriezeTlf", ",", "type", ",", "nsamps", ",", "img"}], "]"}]}]}], 
   "\[IndentingNewLine]", "]"}]}]], "Input"],

Cell[BoxData[
 RowBox[{"(*", " ", 
  RowBox[{"For", " ", "wallpaper", " ", "groups"}], " ", "*)"}]], "Input"],

Cell[BoxData[
 RowBox[{
  RowBox[{"WallpaperTlf", "[", 
   RowBox[{"params_", ",", "pt_"}], "]"}], " ", ":=", " ", 
  RowBox[{"Module", "[", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{"type", ",", "x", ",", "y", ",", "z"}], "}"}], ",", 
    "\[IndentingNewLine]", 
    RowBox[{
     RowBox[{
      RowBox[{"{", 
       RowBox[{"x", ",", "y"}], "}"}], " ", "=", " ", "pt"}], ";", 
     "\[IndentingNewLine]", 
     RowBox[{"type", " ", "=", " ", "params"}], ";", "\[IndentingNewLine]", 
     RowBox[{"x", " ", "=", " ", 
      RowBox[{"Mod", "[", 
       RowBox[{"x", ",", "1"}], "]"}]}], ";", " ", 
     RowBox[{"y", " ", "=", " ", 
      RowBox[{"Mod", "[", 
       RowBox[{"y", ",", "1"}], "]"}]}], ";", "\[IndentingNewLine]", 
     RowBox[{"Switch", "[", 
      RowBox[{
      "type", ",", "\[IndentingNewLine]", "1", ",", "\[IndentingNewLine]", 
       "Null", ",", "\[IndentingNewLine]", "2", ",", "\[IndentingNewLine]", 
       RowBox[{"If", "[", 
        RowBox[{
         RowBox[{"y", " ", ">", " ", 
          RowBox[{"1", "/", "2"}]}], ",", " ", 
         RowBox[{
          RowBox[{"x", " ", "*=", " ", 
           RowBox[{"-", "1"}]}], ";", " ", 
          RowBox[{"y", " ", "*=", " ", 
           RowBox[{"-", "1"}]}]}]}], "]"}], ",", "\[IndentingNewLine]", "3", 
       ",", "\[IndentingNewLine]", 
       RowBox[{"If", "[", 
        RowBox[{
         RowBox[{"y", " ", ">", " ", 
          RowBox[{"1", "/", "2"}]}], ",", " ", 
         RowBox[{"y", " ", "*=", " ", 
          RowBox[{"-", "1"}]}]}], "]"}], ",", "\[IndentingNewLine]", "4", ",",
        "\[IndentingNewLine]", 
       RowBox[{"If", "[", 
        RowBox[{
         RowBox[{"y", " ", ">", " ", 
          RowBox[{"1", "/", "2"}]}], ",", " ", 
         RowBox[{
          RowBox[{"x", " ", "+=", " ", 
           RowBox[{"1", "/", "2"}]}], ";", 
          RowBox[{"x", " ", "=", " ", 
           RowBox[{"Mod", "[", 
            RowBox[{"x", ",", "1"}], "]"}]}], ";", 
          RowBox[{"y", " ", "*=", " ", 
           RowBox[{"-", "1"}]}]}]}], "]"}], ",", "\[IndentingNewLine]", "5", 
       ",", "\[IndentingNewLine]", 
       RowBox[{"If", "[", 
        RowBox[{
         RowBox[{"y", " ", ">", " ", "x"}], ",", " ", 
         RowBox[{
          RowBox[{"z", " ", "=", " ", "x"}], ";", " ", 
          RowBox[{"x", " ", "=", " ", "y"}], ";", " ", 
          RowBox[{"y", " ", "=", " ", "z"}]}]}], "]"}], ",", 
       "\[IndentingNewLine]", "6", ",", "\[IndentingNewLine]", 
       RowBox[{
        RowBox[{"If", "[", 
         RowBox[{
          RowBox[{"x", " ", ">", " ", 
           RowBox[{"1", "/", "2"}]}], ",", " ", 
          RowBox[{"x", " ", "*=", " ", 
           RowBox[{"-", "1"}]}]}], "]"}], ";", " ", 
        RowBox[{"If", "[", 
         RowBox[{
          RowBox[{"y", " ", ">", " ", 
           RowBox[{"1", "/", "2"}]}], ",", " ", 
          RowBox[{"y", " ", "*=", " ", 
           RowBox[{"-", "1"}]}]}], "]"}]}], ",", "\[IndentingNewLine]", "7", 
       ",", "\[IndentingNewLine]", 
       RowBox[{
        RowBox[{"If", "[", 
         RowBox[{
          RowBox[{"y", " ", ">", " ", 
           RowBox[{"1", "/", "2"}]}], ",", 
          RowBox[{
           RowBox[{"x", " ", "+=", " ", 
            RowBox[{"1", "/", "2"}]}], ";", " ", 
           RowBox[{"x", " ", "=", " ", 
            RowBox[{"Mod", "[", 
             RowBox[{"x", ",", "1"}], "]"}]}], ";", " ", 
           RowBox[{"y", " ", "*=", " ", 
            RowBox[{"-", "1"}]}]}]}], "]"}], ";", " ", 
        RowBox[{"If", "[", 
         RowBox[{
          RowBox[{"x", " ", ">", " ", 
           RowBox[{"1", "/", "2"}]}], ",", " ", 
          RowBox[{"x", " ", "*=", " ", 
           RowBox[{"-", "1"}]}]}], "]"}]}], ",", "\[IndentingNewLine]", "8", 
       ",", "\[IndentingNewLine]", 
       RowBox[{
        RowBox[{"If", "[", 
         RowBox[{
          RowBox[{"y", " ", ">", " ", 
           RowBox[{"1", "/", "2"}]}], ",", " ", 
          RowBox[{
           RowBox[{"x", " ", "*=", " ", 
            RowBox[{"-", "1"}]}], ";", " ", 
           RowBox[{"y", " ", "*=", " ", 
            RowBox[{"-", "1"}]}], ";", 
           RowBox[{"x", " ", "=", " ", 
            RowBox[{"Mod", "[", 
             RowBox[{"x", ",", "1"}], "]"}]}], ";", " ", 
           RowBox[{"y", " ", "=", " ", 
            RowBox[{"Mod", "[", 
             RowBox[{"y", ",", "1"}], "]"}]}]}]}], "]"}], ";", 
        RowBox[{"If", "[", 
         RowBox[{
          RowBox[{
           RowBox[{"x", "+", "y"}], " ", "<", " ", 
           RowBox[{"1", "/", "2"}]}], ",", 
          RowBox[{
           RowBox[{"x", "+=", " ", 
            RowBox[{"1", "/", "2"}]}], ";", " ", 
           RowBox[{"y", " ", "=", " ", 
            RowBox[{
             RowBox[{"1", "/", "2"}], " ", "-", " ", "y"}]}]}]}], "]"}], ";", 
        " ", 
        RowBox[{"If", "[", 
         RowBox[{
          RowBox[{
           RowBox[{"x", "-", "y"}], " ", ">", " ", 
           RowBox[{"1", "/", "2"}]}], ",", " ", 
          RowBox[{
           RowBox[{"x", " ", "-=", " ", 
            RowBox[{"1", "/", "2"}]}], ";", " ", 
           RowBox[{"y", " ", "=", " ", 
            RowBox[{
             RowBox[{"1", "/", "2"}], " ", "-", " ", "y"}]}]}]}], "]"}]}], 
       ",", "\[IndentingNewLine]", "9", ",", "\[IndentingNewLine]", 
       RowBox[{
        RowBox[{"If", "[", 
         RowBox[{
          RowBox[{
           RowBox[{"x", "+", "y"}], " ", "\[GreaterEqual]", "1"}], ",", " ", 
          RowBox[{
           RowBox[{"z", " ", "=", " ", "x"}], ";", " ", 
           RowBox[{"x", " ", "=", " ", "y"}], ";", " ", 
           RowBox[{"y", " ", "=", " ", "z"}], ";", " ", 
           RowBox[{"x", " ", "*=", " ", 
            RowBox[{"-", "1"}]}], ";", " ", 
           RowBox[{"y", " ", "*=", " ", 
            RowBox[{"-", "1"}]}]}]}], "]"}], ";", " ", 
        RowBox[{"If", "[", 
         RowBox[{
          RowBox[{"y", " ", ">", " ", "x"}], ",", " ", 
          RowBox[{
           RowBox[{"z", " ", "=", " ", "x"}], ";", " ", 
           RowBox[{"x", " ", "=", " ", "y"}], ";", " ", 
           RowBox[{"y", " ", "=", " ", "z"}]}]}], "]"}]}], ",", 
       "\[IndentingNewLine]", "10", ",", "\[IndentingNewLine]", 
       RowBox[{"If", "[", 
        RowBox[{
         RowBox[{"y", " ", ">", " ", 
          RowBox[{"1", "/", "2"}]}], ",", " ", 
         RowBox[{"If", "[", 
          RowBox[{
           RowBox[{"x", " ", ">", " ", 
            RowBox[{"1", "/", "2"}]}], ",", 
           RowBox[{
            RowBox[{"x", " ", "=", " ", 
             RowBox[{"1", "-", "x"}]}], ";", " ", 
            RowBox[{"y", " ", "=", " ", 
             RowBox[{"1", "-", "y"}]}]}], ",", " ", 
           RowBox[{
            RowBox[{"z", " ", "=", " ", "x"}], ";", " ", 
            RowBox[{"x", " ", "=", " ", "y"}], ";", " ", 
            RowBox[{"y", " ", "=", " ", "z"}], ";", " ", 
            RowBox[{"x", " ", "*=", " ", 
             RowBox[{"-", "1"}]}]}]}], "]"}], ",", " ", 
         RowBox[{"If", "[", 
          RowBox[{
           RowBox[{"x", " ", ">", " ", 
            RowBox[{"1", "/", "2"}]}], ",", " ", 
           RowBox[{
            RowBox[{"z", " ", "=", " ", "x"}], ";", " ", 
            RowBox[{"x", " ", "=", " ", "y"}], ";", " ", 
            RowBox[{"y", " ", "=", " ", "z"}], ";", " ", 
            RowBox[{"y", " ", "*=", " ", 
             RowBox[{"-", "1"}]}]}]}], "]"}]}], "]"}], ",", 
       "\[IndentingNewLine]", "11", ",", "\[IndentingNewLine]", 
       RowBox[{
        RowBox[{"If", "[", 
         RowBox[{
          RowBox[{"y", " ", ">", " ", 
           RowBox[{"1", "/", "2"}]}], ",", " ", 
          RowBox[{"If", "[", 
           RowBox[{
            RowBox[{"x", " ", ">", " ", 
             RowBox[{"1", "/", "2"}]}], ",", 
            RowBox[{
             RowBox[{"x", " ", "=", " ", 
              RowBox[{"1", "-", "x"}]}], ";", " ", 
             RowBox[{"y", " ", "=", " ", 
              RowBox[{"1", "-", "y"}]}]}], ",", " ", 
            RowBox[{
             RowBox[{"z", " ", "=", " ", "x"}], ";", " ", 
             RowBox[{"x", " ", "=", " ", "y"}], ";", " ", 
             RowBox[{"y", " ", "=", " ", "z"}], ";", " ", 
             RowBox[{"x", " ", "*=", " ", 
              RowBox[{"-", "1"}]}]}]}], "]"}], ",", " ", 
          RowBox[{"If", "[", 
           RowBox[{
            RowBox[{"x", " ", ">", " ", 
             RowBox[{"1", "/", "2"}]}], ",", " ", 
            RowBox[{
             RowBox[{"z", " ", "=", " ", "x"}], ";", " ", 
             RowBox[{"x", " ", "=", " ", "y"}], ";", " ", 
             RowBox[{"y", " ", "=", " ", "z"}], ";", " ", 
             RowBox[{"y", " ", "*=", " ", 
              RowBox[{"-", "1"}]}]}]}], "]"}]}], "]"}], ";", " ", 
        RowBox[{"x", " ", "=", " ", 
         RowBox[{"Mod", "[", 
          RowBox[{"x", ",", "1"}], "]"}]}], ";", " ", 
        RowBox[{"y", " ", "=", " ", 
         RowBox[{"Mod", "[", 
          RowBox[{"y", ",", "1"}], "]"}]}], ";", " ", 
        RowBox[{"If", "[", 
         RowBox[{
          RowBox[{"y", " ", ">", " ", "x"}], ",", " ", 
          RowBox[{
           RowBox[{"z", " ", "=", " ", "x"}], ";", " ", 
           RowBox[{"x", " ", "=", " ", "y"}], ";", " ", 
           RowBox[{"y", " ", "=", " ", "z"}]}]}], "]"}]}], ",", 
       "\[IndentingNewLine]", "12", ",", "\[IndentingNewLine]", 
       RowBox[{
        RowBox[{"If", "[", 
         RowBox[{
          RowBox[{"y", " ", ">", " ", 
           RowBox[{"1", "/", "2"}]}], ",", " ", 
          RowBox[{"If", "[", 
           RowBox[{
            RowBox[{"x", " ", ">", " ", 
             RowBox[{"1", "/", "2"}]}], ",", 
            RowBox[{
             RowBox[{"x", " ", "=", " ", 
              RowBox[{"1", "-", "x"}]}], ";", " ", 
             RowBox[{"y", " ", "=", " ", 
              RowBox[{"1", "-", "y"}]}]}], ",", " ", 
            RowBox[{
             RowBox[{"z", " ", "=", " ", "x"}], ";", " ", 
             RowBox[{"x", " ", "=", " ", "y"}], ";", " ", 
             RowBox[{"y", " ", "=", " ", "z"}], ";", " ", 
             RowBox[{"x", " ", "*=", " ", 
              RowBox[{"-", "1"}]}]}]}], "]"}], ",", " ", 
          RowBox[{"If", "[", 
           RowBox[{
            RowBox[{"x", " ", ">", " ", 
             RowBox[{"1", "/", "2"}]}], ",", " ", 
            RowBox[{
             RowBox[{"z", " ", "=", " ", "x"}], ";", " ", 
             RowBox[{"x", " ", "=", " ", "y"}], ";", " ", 
             RowBox[{"y", " ", "=", " ", "z"}], ";", " ", 
             RowBox[{"y", " ", "*=", " ", 
              RowBox[{"-", "1"}]}]}]}], "]"}]}], "]"}], ";", " ", 
        RowBox[{"x", " ", "=", " ", 
         RowBox[{"Mod", "[", 
          RowBox[{"x", ",", "1"}], "]"}]}], ";", " ", 
        RowBox[{"y", " ", "=", " ", 
         RowBox[{"Mod", "[", 
          RowBox[{"y", ",", "1"}], "]"}]}], ";", " ", 
        RowBox[{"If", "[", 
         RowBox[{
          RowBox[{
           RowBox[{"x", "+", "y"}], " ", ">", " ", 
           RowBox[{"1", "/", "2"}]}], ",", " ", 
          RowBox[{
           RowBox[{"z", " ", "=", " ", "x"}], ";", " ", 
           RowBox[{"x", " ", "=", " ", "y"}], ";", " ", 
           RowBox[{"y", " ", "=", " ", "z"}], ";", " ", 
           RowBox[{"x", " ", "=", " ", 
            RowBox[{
             RowBox[{"1", "/", "2"}], "-", "x"}]}], ";", " ", 
           RowBox[{"y", " ", "=", " ", 
            RowBox[{
             RowBox[{"1", "/", "2"}], "-", "y"}]}]}]}], "]"}]}], ",", 
       "\[IndentingNewLine]", "13", ",", "\[IndentingNewLine]", 
       RowBox[{"If", "[", 
        RowBox[{
         RowBox[{"y", " ", ">", " ", "x"}], ",", 
         RowBox[{
          RowBox[{"If", "[", 
           RowBox[{
            RowBox[{
             RowBox[{
              RowBox[{"2", "x"}], "+", "y"}], " ", "<", " ", "1"}], ",", 
            RowBox[{
             RowBox[{"z", " ", "=", " ", "y"}], ";", " ", 
             RowBox[{"y", " ", "=", " ", 
              RowBox[{
               RowBox[{"-", "x"}], "-", "y", " ", "+", " ", "1"}]}], ";", " ", 
             RowBox[{"x", " ", "=", " ", "z"}]}]}], "]"}], ";", " ", 
          RowBox[{"If", "[", 
           RowBox[{
            RowBox[{
             RowBox[{"x", "+", 
              RowBox[{"2", "y"}]}], " ", ">", " ", "2"}], ",", 
            RowBox[{
             RowBox[{"z", " ", "=", " ", "x"}], ";", " ", 
             RowBox[{"x", " ", "=", " ", 
              RowBox[{
               RowBox[{"-", "x"}], "-", "y", " ", "+", " ", "2"}]}], ";", " ", 
             RowBox[{"y", " ", "=", " ", "z"}]}]}], "]"}]}], ",", " ", 
         RowBox[{
          RowBox[{"If", "[", 
           RowBox[{
            RowBox[{
             RowBox[{"x", "+", 
              RowBox[{"2", "y"}]}], " ", "<", " ", "1"}], ",", " ", 
            RowBox[{
             RowBox[{"z", " ", "=", " ", "x"}], ";", " ", 
             RowBox[{"x", " ", "=", " ", 
              RowBox[{
               RowBox[{"-", "x"}], "-", "y", " ", "+", " ", "1"}]}], ";", " ", 
             RowBox[{"y", " ", "=", " ", "z"}]}]}], "]"}], ";", 
          RowBox[{"If", "[", 
           RowBox[{
            RowBox[{
             RowBox[{
              RowBox[{"2", "x"}], "+", "y"}], " ", ">", " ", "2"}], ",", 
            RowBox[{
             RowBox[{"z", " ", "=", " ", "y"}], ";", " ", 
             RowBox[{"y", " ", "=", " ", 
              RowBox[{
               RowBox[{"-", "x"}], "-", "y", " ", "+", " ", "2"}]}], ";", " ", 
             RowBox[{"x", " ", "=", " ", "z"}]}]}], "]"}]}]}], "]"}], ",", 
       "\[IndentingNewLine]", "14", ",", "\[IndentingNewLine]", 
       RowBox[{
        RowBox[{"If", "[", 
         RowBox[{
          RowBox[{"y", " ", ">", " ", "x"}], ",", 
          RowBox[{
           RowBox[{"If", "[", 
            RowBox[{
             RowBox[{
              RowBox[{
               RowBox[{"2", "x"}], "+", "y"}], " ", "<", " ", "1"}], ",", 
             RowBox[{
              RowBox[{"z", " ", "=", " ", "y"}], ";", " ", 
              RowBox[{"y", " ", "=", " ", 
               RowBox[{
                RowBox[{"-", "x"}], "-", "y", " ", "+", " ", "1"}]}], ";", 
              " ", 
              RowBox[{"x", " ", "=", " ", "z"}]}]}], "]"}], ";", " ", 
           RowBox[{"If", "[", 
            RowBox[{
             RowBox[{
              RowBox[{"x", "+", 
               RowBox[{"2", "y"}]}], " ", ">", " ", "2"}], ",", 
             RowBox[{
              RowBox[{"z", " ", "=", " ", "x"}], ";", " ", 
              RowBox[{"x", " ", "=", " ", 
               RowBox[{
                RowBox[{"-", "x"}], "-", "y", " ", "+", " ", "2"}]}], ";", 
              " ", 
              RowBox[{"y", " ", "=", " ", "z"}]}]}], "]"}]}], ",", " ", 
          RowBox[{
           RowBox[{"If", "[", 
            RowBox[{
             RowBox[{
              RowBox[{"x", "+", 
               RowBox[{"2", "y"}]}], " ", "<", " ", "1"}], ",", " ", 
             RowBox[{
              RowBox[{"z", " ", "=", " ", "x"}], ";", " ", 
              RowBox[{"x", " ", "=", " ", 
               RowBox[{
                RowBox[{"-", "x"}], "-", "y", " ", "+", " ", "1"}]}], ";", 
              " ", 
              RowBox[{"y", " ", "=", " ", "z"}]}]}], "]"}], ";", 
           RowBox[{"If", "[", 
            RowBox[{
             RowBox[{
              RowBox[{
               RowBox[{"2", "x"}], "+", "y"}], " ", ">", " ", "2"}], ",", 
             RowBox[{
              RowBox[{"z", " ", "=", " ", "y"}], ";", " ", 
              RowBox[{"y", " ", "=", " ", 
               RowBox[{
                RowBox[{"-", "x"}], "-", "y", " ", "+", " ", "2"}]}], ";", 
              " ", 
              RowBox[{"x", " ", "=", " ", "z"}]}]}], "]"}]}]}], "]"}], ";", 
        "\[IndentingNewLine]", 
        RowBox[{"If", "[", 
         RowBox[{
          RowBox[{"y", " ", ">", " ", "x"}], ",", 
          RowBox[{
           RowBox[{"z", " ", "=", " ", "x"}], ";", " ", 
           RowBox[{"x", " ", "=", " ", "y"}], ";", " ", 
           RowBox[{"y", " ", "=", " ", "z"}]}]}], "]"}]}], ",", 
       "\[IndentingNewLine]", "15", ",", "\[IndentingNewLine]", 
       RowBox[{
        RowBox[{"If", "[", 
         RowBox[{
          RowBox[{"y", " ", ">", " ", "x"}], ",", 
          RowBox[{
           RowBox[{"If", "[", 
            RowBox[{
             RowBox[{
              RowBox[{
               RowBox[{"2", "x"}], "+", "y"}], " ", "<", " ", "1"}], ",", 
             RowBox[{
              RowBox[{"z", " ", "=", " ", "y"}], ";", " ", 
              RowBox[{"y", " ", "=", " ", 
               RowBox[{
                RowBox[{"-", "x"}], "-", "y", " ", "+", " ", "1"}]}], ";", 
              " ", 
              RowBox[{"x", " ", "=", " ", "z"}]}]}], "]"}], ";", " ", 
           RowBox[{"If", "[", 
            RowBox[{
             RowBox[{
              RowBox[{"x", "+", 
               RowBox[{"2", "y"}]}], " ", ">", " ", "2"}], ",", 
             RowBox[{
              RowBox[{"z", " ", "=", " ", "x"}], ";", " ", 
              RowBox[{"x", " ", "=", " ", 
               RowBox[{
                RowBox[{"-", "x"}], "-", "y", " ", "+", " ", "2"}]}], ";", 
              " ", 
              RowBox[{"y", " ", "=", " ", "z"}]}]}], "]"}]}], ",", " ", 
          RowBox[{
           RowBox[{"If", "[", 
            RowBox[{
             RowBox[{
              RowBox[{"x", "+", 
               RowBox[{"2", "y"}]}], " ", "<", " ", "1"}], ",", " ", 
             RowBox[{
              RowBox[{"z", " ", "=", " ", "x"}], ";", " ", 
              RowBox[{"x", " ", "=", " ", 
               RowBox[{
                RowBox[{"-", "x"}], "-", "y", " ", "+", " ", "1"}]}], ";", 
              " ", 
              RowBox[{"y", " ", "=", " ", "z"}]}]}], "]"}], ";", 
           RowBox[{"If", "[", 
            RowBox[{
             RowBox[{
              RowBox[{
               RowBox[{"2", "x"}], "+", "y"}], " ", ">", " ", "2"}], ",", 
             RowBox[{
              RowBox[{"z", " ", "=", " ", "y"}], ";", " ", 
              RowBox[{"y", " ", "=", " ", 
               RowBox[{
                RowBox[{"-", "x"}], "-", "y", " ", "+", " ", "2"}]}], ";", 
              " ", 
              RowBox[{"x", " ", "=", " ", "z"}]}]}], "]"}]}]}], "]"}], ";", 
        "\[IndentingNewLine]", 
        RowBox[{"If", "[", 
         RowBox[{
          RowBox[{
           RowBox[{"x", "+", "y"}], ">", "1"}], ",", 
          RowBox[{
           RowBox[{"z", " ", "=", " ", "x"}], ";", " ", 
           RowBox[{"x", " ", "=", " ", "y"}], ";", " ", 
           RowBox[{"y", " ", "=", " ", "z"}], ";", " ", 
           RowBox[{"x", "*=", " ", 
            RowBox[{"-", "1"}]}], ";", " ", 
           RowBox[{"y", " ", "*=", " ", 
            RowBox[{"-", "1"}]}]}]}], "]"}]}], ",", "\[IndentingNewLine]", 
       "16", ",", "\[IndentingNewLine]", 
       RowBox[{
        RowBox[{"If", "[", 
         RowBox[{
          RowBox[{"y", " ", ">", " ", "x"}], ",", 
          RowBox[{
           RowBox[{"If", "[", 
            RowBox[{
             RowBox[{
              RowBox[{
               RowBox[{"2", "x"}], "+", "y"}], " ", "<", " ", "1"}], ",", 
             RowBox[{
              RowBox[{"z", " ", "=", " ", "y"}], ";", " ", 
              RowBox[{"y", " ", "=", " ", 
               RowBox[{
                RowBox[{"-", "x"}], "-", "y", " ", "+", " ", "1"}]}], ";", 
              " ", 
              RowBox[{"x", " ", "=", " ", "z"}]}]}], "]"}], ";", " ", 
           RowBox[{"If", "[", 
            RowBox[{
             RowBox[{
              RowBox[{"x", "+", 
               RowBox[{"2", "y"}]}], " ", ">", " ", "2"}], ",", 
             RowBox[{
              RowBox[{"z", " ", "=", " ", "x"}], ";", " ", 
              RowBox[{"x", " ", "=", " ", 
               RowBox[{
                RowBox[{"-", "x"}], "-", "y", " ", "+", " ", "2"}]}], ";", 
              " ", 
              RowBox[{"y", " ", "=", " ", "z"}]}]}], "]"}]}], ",", " ", 
          RowBox[{
           RowBox[{"If", "[", 
            RowBox[{
             RowBox[{
              RowBox[{"x", "+", 
               RowBox[{"2", "y"}]}], " ", "<", " ", "1"}], ",", " ", 
             RowBox[{
              RowBox[{"z", " ", "=", " ", "x"}], ";", " ", 
              RowBox[{"x", " ", "=", " ", 
               RowBox[{
                RowBox[{"-", "x"}], "-", "y", " ", "+", " ", "1"}]}], ";", 
              " ", 
              RowBox[{"y", " ", "=", " ", "z"}]}]}], "]"}], ";", 
           RowBox[{"If", "[", 
            RowBox[{
             RowBox[{
              RowBox[{
               RowBox[{"2", "x"}], "+", "y"}], " ", ">", " ", "2"}], ",", 
             RowBox[{
              RowBox[{"z", " ", "=", " ", "y"}], ";", " ", 
              RowBox[{"y", " ", "=", " ", 
               RowBox[{
                RowBox[{"-", "x"}], "-", "y", " ", "+", " ", "2"}]}], ";", 
              " ", 
              RowBox[{"x", " ", "=", " ", "z"}]}]}], "]"}]}]}], "]"}], ";", 
        "\[IndentingNewLine]", 
        RowBox[{"If", "[", 
         RowBox[{
          RowBox[{
           RowBox[{"x", "+", "y"}], ">", "1"}], ",", " ", 
          RowBox[{
           RowBox[{"x", "*=", " ", 
            RowBox[{"-", "1"}]}], ";", " ", 
           RowBox[{"y", " ", "*=", " ", 
            RowBox[{"-", "1"}]}]}]}], "]"}]}], ",", "\[IndentingNewLine]", 
       "17", ",", "\[IndentingNewLine]", 
       RowBox[{
        RowBox[{"If", "[", 
         RowBox[{
          RowBox[{"y", " ", ">", " ", "x"}], ",", 
          RowBox[{
           RowBox[{"If", "[", 
            RowBox[{
             RowBox[{
              RowBox[{
               RowBox[{"2", "x"}], "+", "y"}], " ", "<", " ", "1"}], ",", 
             RowBox[{
              RowBox[{"z", " ", "=", " ", "y"}], ";", " ", 
              RowBox[{"y", " ", "=", " ", 
               RowBox[{
                RowBox[{"-", "x"}], "-", "y", " ", "+", " ", "1"}]}], ";", 
              " ", 
              RowBox[{"x", " ", "=", " ", "z"}]}]}], "]"}], ";", " ", 
           RowBox[{"If", "[", 
            RowBox[{
             RowBox[{
              RowBox[{"x", "+", 
               RowBox[{"2", "y"}]}], " ", ">", " ", "2"}], ",", 
             RowBox[{
              RowBox[{"z", " ", "=", " ", "x"}], ";", " ", 
              RowBox[{"x", " ", "=", " ", 
               RowBox[{
                RowBox[{"-", "x"}], "-", "y", " ", "+", " ", "2"}]}], ";", 
              " ", 
              RowBox[{"y", " ", "=", " ", "z"}]}]}], "]"}]}], ",", " ", 
          RowBox[{
           RowBox[{"If", "[", 
            RowBox[{
             RowBox[{
              RowBox[{"x", "+", 
               RowBox[{"2", "y"}]}], " ", "<", " ", "1"}], ",", " ", 
             RowBox[{
              RowBox[{"z", " ", "=", " ", "x"}], ";", " ", 
              RowBox[{"x", " ", "=", " ", 
               RowBox[{
                RowBox[{"-", "x"}], "-", "y", " ", "+", " ", "1"}]}], ";", 
              " ", 
              RowBox[{"y", " ", "=", " ", "z"}]}]}], "]"}], ";", 
           RowBox[{"If", "[", 
            RowBox[{
             RowBox[{
              RowBox[{
               RowBox[{"2", "x"}], "+", "y"}], " ", ">", " ", "2"}], ",", 
             RowBox[{
              RowBox[{"z", " ", "=", " ", "y"}], ";", " ", 
              RowBox[{"y", " ", "=", " ", 
               RowBox[{
                RowBox[{"-", "x"}], "-", "y", " ", "+", " ", "2"}]}], ";", 
              " ", 
              RowBox[{"x", " ", "=", " ", "z"}]}]}], "]"}]}]}], "]"}], ";", 
        "\[IndentingNewLine]", 
        RowBox[{"If", "[", 
         RowBox[{
          RowBox[{
           RowBox[{"x", "+", "y"}], ">", "1"}], ",", 
          RowBox[{
           RowBox[{"z", " ", "=", " ", "x"}], ";", " ", 
           RowBox[{"x", " ", "=", " ", "y"}], ";", " ", 
           RowBox[{"y", " ", "=", " ", "z"}], ";", " ", 
           RowBox[{"x", "*=", " ", 
            RowBox[{"-", "1"}]}], ";", " ", 
           RowBox[{"y", " ", "*=", " ", 
            RowBox[{"-", "1"}]}]}]}], "]"}], ";", 
        RowBox[{"x", " ", "=", " ", 
         RowBox[{"Mod", "[", 
          RowBox[{"x", ",", "1"}], "]"}]}], ";", " ", 
        RowBox[{"y", " ", "=", " ", 
         RowBox[{"Mod", "[", 
          RowBox[{"y", ",", "1"}], "]"}]}], ";", 
        RowBox[{"If", "[", 
         RowBox[{
          RowBox[{"y", " ", ">", " ", "x"}], ",", " ", 
          RowBox[{
           RowBox[{"z", " ", "=", " ", "x"}], ";", " ", 
           RowBox[{"x", " ", "=", " ", "y"}], ";", " ", 
           RowBox[{"y", " ", "=", " ", "z"}]}]}], "]"}]}]}], 
      "\[IndentingNewLine]", "]"}], ";", "\[IndentingNewLine]", 
     RowBox[{"x", " ", "=", " ", 
      RowBox[{"Mod", "[", 
       RowBox[{"x", ",", "1"}], "]"}]}], ";", " ", 
     RowBox[{"y", " ", "=", " ", 
      RowBox[{"Mod", "[", 
       RowBox[{"y", ",", "1"}], "]"}]}], ";", "\[IndentingNewLine]", 
     RowBox[{"{", 
      RowBox[{"x", ",", "y"}], "}"}]}]}], "]"}]}]], "Input"],

Cell[BoxData[
 RowBox[{
  RowBox[{"Wallpaper", "[", 
   RowBox[{"center_", ",", "params_", ",", "nsamps_", ",", "img_"}], "]"}], 
  " ", ":=", "  ", 
  RowBox[{"Module", "[", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{"type", ",", "a1", ",", "l1", ",", "a2", ",", "l2"}], "}"}], ",",
     "\[IndentingNewLine]", 
    RowBox[{
     RowBox[{"type", " ", "=", " ", 
      RowBox[{"First", "[", "params", "]"}]}], ";", "\[IndentingNewLine]", 
     RowBox[{"Which", "[", 
      RowBox[{
       RowBox[{"MemberQ", "[", 
        RowBox[{
         RowBox[{"{", 
          RowBox[{"1", ",", "2"}], "}"}], ",", "type"}], "]"}], ",", 
       RowBox[{
        RowBox[{"{", 
         RowBox[{"type", ",", "a1", ",", "l1", ",", "a2", ",", "l2"}], "}"}], 
        " ", "=", " ", "params"}], ",", "\[IndentingNewLine]", 
       RowBox[{"MemberQ", "[", 
        RowBox[{
         RowBox[{"{", 
          RowBox[{"3", ",", "4", ",", "6", ",", "7", ",", "8"}], "}"}], ",", 
         "type"}], "]"}], ",", 
       RowBox[{
        RowBox[{
         RowBox[{"{", 
          RowBox[{"type", ",", "a1", ",", "l1", ",", "l2"}], "}"}], " ", "=", 
         " ", "params"}], ";", 
        RowBox[{"a2", " ", "=", " ", 
         RowBox[{"a1", " ", "+", " ", 
          RowBox[{"Pi", "/", "2"}]}]}]}], ",", "\[IndentingNewLine]", 
       RowBox[{"MemberQ", "[", 
        RowBox[{
         RowBox[{"{", 
          RowBox[{"5", ",", "9"}], "}"}], ",", "type"}], "]"}], ",", " ", 
       RowBox[{
        RowBox[{
         RowBox[{"{", 
          RowBox[{"type", ",", "a1", ",", "l1", ",", "a2"}], "}"}], " ", "=", 
         " ", "params"}], ";", 
        RowBox[{"l2", " ", "=", " ", "l1"}]}], ",", "\[IndentingNewLine]", 
       RowBox[{"MemberQ", "[", 
        RowBox[{
         RowBox[{"{", 
          RowBox[{"10", ",", "11", ",", "12"}], "}"}], ",", "type"}], "]"}], 
       ",", 
       RowBox[{
        RowBox[{
         RowBox[{"{", 
          RowBox[{"type", ",", "a1", ",", "l1"}], "}"}], " ", "=", " ", 
         "params"}], ";", 
        RowBox[{"a2", " ", "=", " ", 
         RowBox[{"a1", " ", "+", " ", 
          RowBox[{"Pi", "/", "2"}]}]}], ";", " ", 
        RowBox[{"l2", " ", "=", " ", "l1"}]}], ",", "\[IndentingNewLine]", 
       RowBox[{"MemberQ", "[", 
        RowBox[{
         RowBox[{"{", 
          RowBox[{"13", ",", "14", ",", "15", ",", "16", ",", "17"}], "}"}], 
         ",", "type"}], "]"}], ",", 
       RowBox[{
        RowBox[{
         RowBox[{"{", 
          RowBox[{"type", ",", "a1", ",", "l1"}], "}"}], " ", "=", " ", 
         "params"}], ";", 
        RowBox[{"a2", " ", "=", " ", 
         RowBox[{"a1", " ", "+", " ", 
          RowBox[{"Pi", "/", "3"}]}]}], ";", " ", 
        RowBox[{"l2", " ", "=", " ", "l1"}]}], ",", "\[IndentingNewLine]", 
       "True", ",", 
       RowBox[{"Return", "[", "]"}]}], "]"}], ";", "\[IndentingNewLine]", 
     RowBox[{"LatticeTileImage", "[", 
      RowBox[{"center", ",", 
       RowBox[{"{", 
        RowBox[{"a1", ",", "l1", ",", "a2", ",", "l2"}], "}"}], ",", 
       "WallpaperTlf", ",", "type", ",", "nsamps", ",", "img"}], "]"}]}]}], 
   "\[IndentingNewLine]", "]"}]}]], "Input"],

Cell[BoxData[
 RowBox[{"(*", " ", 
  RowBox[{"For", " ", "the", " ", "logarithmic", " ", 
   RowBox[{"spiral", " ", "--"}], " ", "just", " ", "do", " ", "p1", " ", 
   "for", " ", 
   RowBox[{"now", ".", " ", "Can"}], " ", "use", " ", "other", " ", 
   "wallpaper", " ", "groups", " ", "if", " ", 
   RowBox[{"desired", "."}]}], " ", "*)"}]], "Input"],

Cell[BoxData[
 RowBox[{
  RowBox[{"LogSpiralTlf", "[", 
   RowBox[{"params_", ",", "pt_"}], "]"}], " ", ":=", " ", 
  RowBox[{"Module", "[", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{
     "a0", ",", "r0", ",", "pitch", ",", "rptang", ",", "x", ",", "y", ",", 
      "r", ",", "a", ",", "lra", ",", "n", ",", "rx"}], "}"}], ",", 
    "\[IndentingNewLine]", 
    RowBox[{
     RowBox[{
      RowBox[{"{", 
       RowBox[{"a0", ",", "r0", ",", "pitch", ",", "rptang"}], "}"}], " ", 
      "=", " ", "params"}], ";", "\[IndentingNewLine]", 
     RowBox[{"x", "  ", "=", " ", 
      RowBox[{"pt", "[", 
       RowBox[{"[", "1", "]"}], "]"}]}], ";", " ", 
     RowBox[{"y", " ", "=", " ", 
      RowBox[{"pt", "[", 
       RowBox[{"[", "2", "]"}], "]"}]}], ";", "\[IndentingNewLine]", 
     RowBox[{"r", " ", "=", " ", 
      RowBox[{"Sqrt", "[", 
       RowBox[{
        RowBox[{"x", "^", "2"}], "+", 
        RowBox[{"y", "^", "2"}]}], "]"}]}], ";", " ", 
     RowBox[{"a", " ", "=", " ", 
      RowBox[{
       RowBox[{"If", "[", 
        RowBox[{
         RowBox[{
          RowBox[{"x", "\[Equal]", "0"}], "&&", 
          RowBox[{"y", "\[Equal]", "0"}]}], ",", "0", ",", 
         RowBox[{"ArcTan", "[", 
          RowBox[{"x", ",", "y"}], "]"}]}], "]"}], " ", "-", " ", "a0"}]}], 
     ";", "\[IndentingNewLine]", 
     RowBox[{"If", "[", 
      RowBox[{
       RowBox[{"r", "\[Equal]", "0"}], ",", 
       RowBox[{"Return", "[", 
        RowBox[{"r0", "*", 
         RowBox[{"{", 
          RowBox[{
           RowBox[{"Cos", "[", "a0", "]"}], ",", 
           RowBox[{"Sin", "[", "a0", "]"}]}], "}"}]}], "]"}]}], "]"}], ";", 
     "\[IndentingNewLine]", 
     RowBox[{"lra", " ", "=", " ", 
      RowBox[{
       RowBox[{
        RowBox[{"Log", "[", 
         RowBox[{"r", "/", "r0"}], "]"}], "/", "pitch"}], "  ", "-", " ", 
       "a"}]}], ";", "\[IndentingNewLine]", 
     RowBox[{"n", " ", "=", " ", 
      RowBox[{"Floor", "[", 
       RowBox[{"lra", "/", 
        RowBox[{"(", 
         RowBox[{"2", "*", "Pi"}], ")"}]}], "]"}]}], ";", 
     "\[IndentingNewLine]", 
     RowBox[{"lra", " ", "-=", " ", 
      RowBox[{
       RowBox[{"(", 
        RowBox[{"2", "*", "Pi"}], ")"}], "*", "n"}]}], ";", 
     "\[IndentingNewLine]", 
     RowBox[{"a", " ", "+=", " ", 
      RowBox[{
       RowBox[{"(", 
        RowBox[{"2", "*", "Pi"}], ")"}], "*", "n"}]}], ";", 
     "\[IndentingNewLine]", 
     RowBox[{"a", " ", "-=", " ", 
      RowBox[{"rptang", "*", 
       RowBox[{"Floor", "[", 
        RowBox[{"a", "/", "rptang"}], "]"}]}]}], ";", "\[IndentingNewLine]", 
     RowBox[{"rx", " ", "=", " ", 
      RowBox[{"r0", "*", 
       RowBox[{"Exp", "[", 
        RowBox[{"pitch", "*", 
         RowBox[{"(", 
          RowBox[{"lra", "+", "a"}], ")"}]}], "]"}]}]}], ";", 
     "\[IndentingNewLine]", 
     RowBox[{"a", " ", "+=", " ", "a0"}], ";", "\[IndentingNewLine]", 
     RowBox[{"rx", "*", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"Cos", "[", "a", "]"}], ",", 
        RowBox[{"Sin", "[", "a", "]"}]}], "}"}]}]}]}], "\[IndentingNewLine]", 
   "]"}]}]], "Input"],

Cell[BoxData[
 RowBox[{
  RowBox[{"LogSpiral", "[", 
   RowBox[{"center_", ",", "params_", ",", "nsamps_", ",", "img_"}], "]"}], 
  " ", ":=", " ", "\[IndentingNewLine]", 
  RowBox[{"TileImage", "[", 
   RowBox[{
   "center", ",", "LogSpiralTlf", ",", "params", ",", "nsamps", ",", "img"}], 
   "]"}]}]], "Input"],

Cell[BoxData[
 RowBox[{"(*", " ", 
  RowBox[{"Test", " ", "images"}], " ", "*)"}]], "Input"],

Cell[BoxData[
 RowBox[{
  RowBox[{"rose", " ", "=", " ", 
   RowBox[{"Import", "[", "\"\<ExampleData/rose.gif\>\"", "]"}]}], 
  ";"}]], "Input"],

Cell[BoxData[
 RowBox[{"Dimensions", "[", 
  RowBox[{"ImageData", "[", "rose", "]"}], "]"}]], "Input"],

Cell[BoxData[
 RowBox[{"lena", " ", "=", " ", 
  RowBox[{"Import", "[", "\"\<ExampleData/lena.tif\>\"", "]"}]}]], "Input"],

Cell[BoxData[
 RowBox[{"Dimensions", "[", 
  RowBox[{"ImageData", "[", "lena", "]"}], "]"}]], "Input"],

Cell[BoxData[
 RowBox[{"(*", " ", "Tests", " ", "*)"}]], "Input"],

Cell[BoxData[
 RowBox[{"Table", "[", 
  RowBox[{
   RowBox[{"Rosette", "[", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"75", ",", "58"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"0", ",", "k", ",", "rfl"}], "}"}], ",", "1", ",", "lena"}], 
    "]"}], " ", ",", 
   RowBox[{"{", 
    RowBox[{"k", ",", "1", ",", "5"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"rfl", ",", 
     RowBox[{"{", 
      RowBox[{"False", ",", " ", "True"}], "}"}]}], "}"}]}], "]"}]], "Input"],

Cell[BoxData[
 RowBox[{"Table", "[", 
  RowBox[{
   RowBox[{"Frieze", "[", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"75", ",", "58"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"t", ",", "0", ",", "50", ",", 
       RowBox[{"Pi", "/", "3"}]}], "}"}], ",", "1", ",", "lena"}], "]"}], ",", 
   RowBox[{"{", 
    RowBox[{"t", ",", 
     RowBox[{"{", 
      RowBox[{"1", ",", "5"}], "}"}]}], "}"}]}], "]"}]], "Input"],

Cell[BoxData[
 RowBox[{"Table", "[", 
  RowBox[{
   RowBox[{"Frieze", "[", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"75", ",", "58"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"t", ",", "0", ",", "50"}], "}"}], ",", "1", ",", "lena"}], 
    "]"}], ",", 
   RowBox[{"{", 
    RowBox[{"t", ",", 
     RowBox[{"{", 
      RowBox[{"2", ",", "3", ",", "4", ",", "6", ",", "7"}], "}"}]}], "}"}]}],
   "]"}]], "Input"],

Cell[BoxData[
 RowBox[{"Table", "[", 
  RowBox[{
   RowBox[{"Wallpaper", "[", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"75", ",", "58"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"t", ",", "0", ",", "80", ",", 
       RowBox[{"5", 
        RowBox[{"Pi", "/", "12"}]}], ",", "50"}], "}"}], ",", "1", ",", 
     "lena"}], "]"}], ",", 
   RowBox[{"{", 
    RowBox[{"t", ",", 
     RowBox[{"{", 
      RowBox[{"1", ",", "2"}], "}"}]}], "}"}]}], "]"}]], "Input"],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"Wallpaper", "[", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"75", ",", "58"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"#", ",", "0", ",", "80", ",", "50"}], "}"}], ",", "1", ",", 
     "lena"}], "]"}], "&"}], " ", "/@", " ", 
  RowBox[{"{", 
   RowBox[{"3", ",", "4", ",", "6", ",", "7", ",", "8"}], "}"}]}]], "Input"],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"Wallpaper", "[", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"75", ",", "58"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"#", ",", "0", ",", "50", ",", 
       RowBox[{"5", 
        RowBox[{"Pi", "/", "12"}]}]}], "}"}], ",", "1", ",", "lena"}], "]"}], 
   "&"}], " ", "/@", " ", 
  RowBox[{"{", 
   RowBox[{"5", ",", "9"}], "}"}]}]], "Input"],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"Wallpaper", "[", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"75", ",", "58"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"#", ",", "0", ",", "50"}], "}"}], ",", "1", ",", "lena"}], 
    "]"}], "&"}], " ", "/@", " ", 
  RowBox[{"{", 
   RowBox[{"10", ",", "11", ",", "12"}], "}"}]}]], "Input"],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"Wallpaper", "[", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"75", ",", "58"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"#", ",", "0", ",", "50"}], "}"}], ",", "1", ",", "lena"}], 
    "]"}], "&"}], " ", "/@", " ", 
  RowBox[{"{", 
   RowBox[{"13", ",", "14", ",", "15", ",", "16", ",", "17"}], 
   "}"}]}]], "Input"],

Cell[BoxData[
 RowBox[{"LogSpiral", "[", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{"75", ",", "58"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"0", ",", "25", ",", "0.1", ",", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{"3", "/", "7"}], ")"}], "*", "Pi"}]}], "}"}], ",", "1", ",", 
   "lena"}], "]"}]], "Input"],

Cell[BoxData[
 RowBox[{"(*", " ", 
  RowBox[{"Rotation", " ", "from", " ", "combination", " ", "of", " ", 
   RowBox[{"skews", " ", "--"}], " ", "fast", " ", "alternative"}], " ", 
  "*)"}]], "Input"],

Cell[BoxData[
 RowBox[{
  RowBox[{"skewx", "[", "t_", "]"}], " ", ":=", " ", 
  RowBox[{"{", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{"1", ",", "t"}], "}"}], ",", 
    RowBox[{"{", 
     RowBox[{"0", ",", "1"}], "}"}]}], "}"}]}]], "Input"],

Cell[BoxData[
 RowBox[{
  RowBox[{"skewy", "[", "t_", "]"}], " ", ":=", " ", 
  RowBox[{"{", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{"1", ",", "0"}], "}"}], ",", 
    RowBox[{"{", 
     RowBox[{"t", ",", "1"}], "}"}]}], "}"}]}]], "Input"],

Cell[BoxData[
 RowBox[{"(*", " ", 
  RowBox[{"t", " ", "=", " ", 
   RowBox[{"tan", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{"1", "/", "2"}], ")"}], "*", 
      RowBox[{"(", 
       RowBox[{"rotation", " ", "angle"}], ")"}]}], ")"}]}]}], " ", 
  "*)"}]], "Input"],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"{", 
    RowBox[{
     RowBox[{"(", 
      RowBox[{
       RowBox[{
        RowBox[{"skewx", "[", 
         RowBox[{"-", "t"}], "]"}], ".", 
        RowBox[{"skewy", "[", 
         RowBox[{"2", 
          RowBox[{"t", "/", 
           RowBox[{"(", 
            RowBox[{"1", "+", 
             RowBox[{"t", "^", "2"}]}], ")"}]}]}], "]"}], ".", 
        RowBox[{"skewx", "[", 
         RowBox[{"-", "t"}], "]"}]}], " ", "-", " ", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"{", 
          RowBox[{"cs", ",", 
           RowBox[{"-", "sn"}]}], "}"}], ",", 
         RowBox[{"{", 
          RowBox[{"sn", ",", "cs"}], "}"}]}], "}"}]}], ")"}], ",", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{
        RowBox[{"cs", "^", "2"}], "+", 
        RowBox[{"sn", "^", "2"}]}], ")"}], "-", "1"}]}], "}"}], " ", "/.", 
   " ", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"cs", "\[Rule]", 
      RowBox[{
       RowBox[{"(", 
        RowBox[{"1", "-", 
         RowBox[{"t", "^", "2"}]}], ")"}], "/", 
       RowBox[{"(", 
        RowBox[{"1", "+", 
         RowBox[{"t", "^", "2"}]}], ")"}]}]}], ",", 
     RowBox[{"sn", "\[Rule]", 
      RowBox[{
       RowBox[{"(", 
        RowBox[{"2", "t"}], ")"}], "/", 
       RowBox[{"(", 
        RowBox[{"1", "+", 
         RowBox[{"t", "^", "2"}]}], ")"}]}]}]}], "}"}]}], "//", " ", 
  "Factor"}]], "Input"]
},
WindowSize->{651, 788},
WindowMargins->{{Automatic, 16}, {Automatic, 0}},
ShowSelection->True,
FrontEndVersion->"11.0 for Mac OS X x86 (32-bit, 64-bit Kernel) (September \
21, 2016)",
StyleDefinitions->"Default.nb"
]
(* End of Notebook Content *)

(* Internal cache information *)
(*CellTagsOutline
CellTagsIndex->{}
*)
(*CellTagsIndex
CellTagsIndex->{}
*)
(*NotebookFileOutline
Notebook[{
Cell[545, 20, 2135, 90, 1683, "Text"],
Cell[2683, 112, 189, 4, 32, "Input"],
Cell[2875, 118, 5321, 137, 579, "Input"],
Cell[8199, 257, 182, 4, 32, "Input"],
Cell[8384, 263, 4922, 120, 495, "Input"],
Cell[13309, 385, 107, 2, 32, "Input"],
Cell[13419, 389, 2274, 66, 222, "Input"],
Cell[15696, 457, 309, 8, 54, "Input"],
Cell[16008, 467, 107, 2, 32, "Input"],
Cell[16118, 471, 795, 20, 138, "Input"],
Cell[16916, 493, 1639, 43, 180, "Input"],
Cell[18558, 538, 106, 2, 32, "Input"],
Cell[18667, 542, 3402, 87, 495, "Input"],
Cell[22072, 631, 1722, 44, 243, "Input"],
Cell[23797, 677, 109, 2, 32, "Input"],
Cell[23909, 681, 24770, 618, 1566, "Input"],
Cell[48682, 1301, 3140, 81, 348, "Input"],
Cell[51825, 1384, 351, 7, 54, "Input"],
Cell[52179, 1393, 3088, 86, 327, "Input"],
Cell[55270, 1481, 313, 8, 54, "Input"],
Cell[55586, 1491, 92, 2, 32, "Input"],
Cell[55681, 1495, 144, 4, 32, "Input"],
Cell[55828, 1501, 102, 2, 32, "Input"],
Cell[55933, 1505, 122, 2, 32, "Input"],
Cell[56058, 1509, 102, 2, 32, "Input"],
Cell[56163, 1513, 65, 1, 32, "Input"],
Cell[56231, 1516, 479, 15, 54, "Input"],
Cell[56713, 1533, 423, 13, 32, "Input"],
Cell[57139, 1548, 422, 14, 32, "Input"],
Cell[57564, 1564, 468, 15, 54, "Input"],
Cell[58035, 1581, 376, 11, 32, "Input"],
Cell[58414, 1594, 397, 13, 32, "Input"],
Cell[58814, 1609, 347, 11, 32, "Input"],
Cell[59164, 1622, 373, 12, 32, "Input"],
Cell[59540, 1636, 317, 10, 32, "Input"],
Cell[59860, 1648, 200, 4, 32, "Input"],
Cell[60063, 1654, 242, 8, 32, "Input"],
Cell[60308, 1664, 242, 8, 32, "Input"],
Cell[60553, 1674, 290, 10, 32, "Input"],
Cell[60846, 1686, 1403, 48, 75, "Input"]
}
]
*)

