(* Content-type: application/vnd.wolfram.mathematica *)

(*** Wolfram Notebook File ***)
(* http://www.wolfram.com/nb *)

(* CreatedBy='Mathematica 11.3' *)

(*CacheID: 234*)
(* Internal cache information:
NotebookFileLineBreakTest
NotebookFileLineBreakTest
NotebookDataPosition[       158,          7]
NotebookDataLength[    215511,       6138]
NotebookOptionsPosition[    194492,       5876]
NotebookOutlinePosition[    194846,       5892]
CellTagsIndexPosition[    194803,       5889]
WindowFrame->Normal*)

(* Beginning of Notebook Content *)
Notebook[{
Cell["\<\
Deformed Isohedral Dice

Attempts to find the possible deformations of isohedral dice.

The deformations must preserve the isohedral quality -- being face-transitive \
to within reflections.

Will find possible types by finding out which additional distinctions of \
vertex and edge an isohedron can have.

Axial: bipyramid, trapezohedron

All the rest: quasi-spherical: the regular Platonic solids and modifications \
of them
Labels for type of symmetry:
tet - tetrahedron
oct - octahedron, cube
ico - icosahedron, dodecahedron

Deformations found for:

Tetrahedron - any triangle shape.
Octahedron - 4-bipyramid.
Cube - 3-trapezohedron.
Rhombic dodecahedron - rhombi on octahedron - 3-vertices alternately inward \
and outward
Pentagonal dodecahedron - pentagons on tetrahedron - rather complicated shape
Deltoidal Icositetrahedron - kites on octahedron - 3-vertices alternately \
clockwise and counterclockwise

Icosahedron - axial stretch/squeeze, any others?

Pyramids on cube (tetrakis hexahedron) -- cube\[CloseCurlyQuote]s faces must \
be deformed with same edge lengths and with the same bending angles -- got \
some partial solutions
\
\>", "Text",ExpressionUUID->"09b02b91-3da4-44fc-aee9-4a7f6b8ff7a1"],

Cell[CellGroupData[{

Cell["Definitions", "Section",ExpressionUUID->"7d1e88bb-9c9f-443d-adf4-1adbf81a1d42"],

Cell[BoxData[
 RowBox[{
  RowBox[{"abssqr", "[", "x_", "]"}], " ", ":=", " ", 
  RowBox[{"x", ".", "x"}]}]], "Input",
 CellLabel->
  "In[283]:=",ExpressionUUID->"491cc2dd-6af0-4640-a671-e6ffbe9ba9d5"]
}, Closed]],

Cell[CellGroupData[{

Cell["Axial (others are quasi-spherical)", "Section",ExpressionUUID->"98632e64-564b-44c2-90df-34d432ef769b"],

Cell[BoxData[
 RowBox[{
  RowBox[{"cssntn", "[", "t_", "]"}], " ", ":=", " ", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{
     RowBox[{"1", "-", 
      RowBox[{"t", "^", "2"}]}], ",", 
     RowBox[{"2", "t"}]}], "}"}], "/", 
   RowBox[{"(", 
    RowBox[{"1", "+", 
     RowBox[{"t", "^", "2"}]}], ")"}]}]}]], "Input",
 CellLabel->
  "In[284]:=",ExpressionUUID->"0344b144-685e-4714-b103-7c416bbeed76"],

Cell[BoxData[
 RowBox[{
  RowBox[{"vtcyl", "[", 
   RowBox[{"r_", ",", "t_", ",", "z_"}], "]"}], " ", ":=", " ", 
  RowBox[{"Append", "[", 
   RowBox[{
    RowBox[{"r", "*", 
     RowBox[{"cssntn", "[", "t", "]"}]}], ",", "z"}], "]"}]}]], "Input",
 CellLabel->
  "In[285]:=",ExpressionUUID->"458e1eed-5f36-4e75-bff7-57570a6e2e1e"],

Cell[CellGroupData[{

Cell["Bipyramid", "Subsection",ExpressionUUID->"0ed4dba5-c768-4a69-8bff-9d4f41bcc3c6"],

Cell[BoxData[
 RowBox[{"(*", " ", 
  RowBox[{
   RowBox[{"North", " ", "pole"}], ",", " ", 
   RowBox[{"first", " ", "equator"}], ",", " ", 
   RowBox[{"second", " ", "equator"}], ",", " ", 
   RowBox[{"south", " ", "pole"}]}], " ", "*)"}]], "Input",
 CellLabel->
  "In[286]:=",ExpressionUUID->"c47c153a-6d5d-47f0-8709-0af9baffd27a"],

Cell[BoxData[
 RowBox[{
  RowBox[{"verts", "[", "\"\<bipyr\>\"", "]"}], " ", ":=", " ", 
  RowBox[{"{", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{"0", ",", "0", ",", "1"}], "}"}], ",", 
    RowBox[{"vtcyl", "[", 
     RowBox[{"r1", ",", "0", ",", "z"}], "]"}], ",", 
    RowBox[{"vtcyl", "[", 
     RowBox[{"r2", ",", "t", ",", 
      RowBox[{"-", "z"}]}], "]"}], ",", 
    RowBox[{"{", 
     RowBox[{"0", ",", "0", ",", 
      RowBox[{"-", "1"}]}], "}"}]}], "}"}]}]], "Input",
 CellLabel->
  "In[287]:=",ExpressionUUID->"1e2d53b8-2bf2-43ff-94eb-3b0e95dc34c0"],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{
    RowBox[{"{", 
     RowBox[{
      RowBox[{
       RowBox[{"abssqr", "[", 
        RowBox[{
         RowBox[{"#", "[", 
          RowBox[{"[", "1", "]"}], "]"}], "-", 
         RowBox[{"#", "[", 
          RowBox[{"[", "2", "]"}], "]"}]}], "]"}], "-", 
       RowBox[{"abssqr", "[", 
        RowBox[{
         RowBox[{"#", "[", 
          RowBox[{"[", "3", "]"}], "]"}], "-", 
         RowBox[{"#", "[", 
          RowBox[{"[", "4", "]"}], "]"}]}], "]"}]}], ",", 
      RowBox[{
       RowBox[{"abssqr", "[", 
        RowBox[{
         RowBox[{"#", "[", 
          RowBox[{"[", "1", "]"}], "]"}], "-", 
         RowBox[{"#", "[", 
          RowBox[{"[", "3", "]"}], "]"}]}], "]"}], "-", 
       RowBox[{"abssqr", "[", 
        RowBox[{
         RowBox[{"#", "[", 
          RowBox[{"[", "2", "]"}], "]"}], "-", 
         RowBox[{"#", "[", 
          RowBox[{"[", "4", "]"}], "]"}]}], "]"}]}]}], "}"}], "&"}], " ", "@",
    " ", 
   RowBox[{"verts", "[", "\"\<bipyr\>\"", "]"}]}], " ", "//", " ", 
  "Factor"}]], "Input",
 CellLabel->
  "In[288]:=",ExpressionUUID->"8f56246d-d3f6-4b99-afb4-5664184a94af"],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{
    RowBox[{"{", 
     RowBox[{
      RowBox[{
       RowBox[{"abssqr", "[", 
        RowBox[{
         RowBox[{"#", "[", 
          RowBox[{"[", "1", "]"}], "]"}], "-", 
         RowBox[{"#", "[", 
          RowBox[{"[", "2", "]"}], "]"}]}], "]"}], "-", 
       RowBox[{"abssqr", "[", 
        RowBox[{
         RowBox[{"#", "[", 
          RowBox[{"[", "2", "]"}], "]"}], "-", 
         RowBox[{"#", "[", 
          RowBox[{"[", "4", "]"}], "]"}]}], "]"}]}], ",", 
      RowBox[{
       RowBox[{"abssqr", "[", 
        RowBox[{
         RowBox[{"#", "[", 
          RowBox[{"[", "1", "]"}], "]"}], "-", 
         RowBox[{"#", "[", 
          RowBox[{"[", "3", "]"}], "]"}]}], "]"}], "-", 
       RowBox[{"abssqr", "[", 
        RowBox[{
         RowBox[{"#", "[", 
          RowBox[{"[", "3", "]"}], "]"}], "-", 
         RowBox[{"#", "[", 
          RowBox[{"[", "4", "]"}], "]"}]}], "]"}]}]}], "}"}], "&"}], " ", "@",
    " ", 
   RowBox[{"verts", "[", "\"\<bipyr\>\"", "]"}]}], " ", "//", " ", 
  "Factor"}]], "Input",
 CellLabel->
  "In[289]:=",ExpressionUUID->"5d10ba48-4270-408a-9a80-cdb2e7600b1a"],

Cell[BoxData[
 RowBox[{"(*", " ", 
  RowBox[{
  "Either", " ", "radial", " ", "or", " ", "axial", " ", "oscillations"}], 
  " ", "*)"}]], "Input",
 CellLabel->
  "In[290]:=",ExpressionUUID->"4b8f5214-235e-46e9-8075-7a0c8d92ed1a"]
}, Open  ]],

Cell[CellGroupData[{

Cell["Trapezohedron", "Subsection",ExpressionUUID->"31bab8ae-0f4c-4afb-85a3-298c2ae47e87"],

Cell[BoxData[
 RowBox[{"(*", " ", 
  RowBox[{
   RowBox[{"North", " ", "pole"}], ",", " ", 
   RowBox[{"first", " ", "equator"}], ",", " ", 
   RowBox[{"second", " ", "equator"}], ",", " ", 
   RowBox[{"third", " ", "equator"}]}], " ", "*)"}]], "Input",
 CellLabel->
  "In[291]:=",ExpressionUUID->"87c0e3b5-f9be-4b75-a32d-714bacd033f5"],

Cell[BoxData[
 RowBox[{
  RowBox[{"verts", "[", "\"\<tpzhd\>\"", "]"}], " ", ":=", " ", 
  RowBox[{"{", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{"0", ",", "0", ",", "1"}], "}"}], ",", 
    RowBox[{"vtcyl", "[", 
     RowBox[{"r", ",", 
      RowBox[{"-", "t1"}], ",", "z"}], "]"}], ",", 
    RowBox[{"vtcyl", "[", 
     RowBox[{"r", ",", "0", ",", 
      RowBox[{"-", "z"}]}], "]"}], ",", 
    RowBox[{"vtcyl", "[", 
     RowBox[{"r", ",", "t2", ",", "z"}], "]"}]}], "}"}]}]], "Input",
 CellLabel->
  "In[292]:=",ExpressionUUID->"5a1bf640-9631-44d8-b32c-2987244553e1"],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{
    RowBox[{"Det", "[", 
     RowBox[{"#", "[", 
      RowBox[{"[", 
       RowBox[{"2", ";;", "4"}], "]"}], "]"}], "]"}], "&"}], " ", "@", " ", 
   RowBox[{"(", 
    RowBox[{
     RowBox[{
      RowBox[{"(", 
       RowBox[{"#", " ", "-", " ", 
        RowBox[{"ConstantArray", "[", 
         RowBox[{
          RowBox[{"#", "[", 
           RowBox[{"[", "1", "]"}], "]"}], ",", 
          RowBox[{"Length", "[", "#", "]"}]}], "]"}]}], ")"}], "&"}], " ", 
     "@", " ", 
     RowBox[{"verts", "[", "\"\<tpzhd\>\"", "]"}]}], ")"}]}], " ", "//", " ", 
  "Factor"}]], "Input",
 CellLabel->
  "In[293]:=",ExpressionUUID->"4634fe46-9887-4529-b471-17f06469a1d5"]
}, Open  ]]
}, Closed]],

Cell[CellGroupData[{

Cell["Points", "Section",ExpressionUUID->"49a0a8c6-ee33-464e-9656-78f83e0d37d5"],

Cell[BoxData[
 RowBox[{
  RowBox[{"pt3d", "[", 
   RowBox[{"r_", ",", "a_", ",", "z_"}], "]"}], " ", ":=", " ", 
  RowBox[{"MapAll", "[", 
   RowBox[{"Factor", ",", 
    RowBox[{"{", 
     RowBox[{
      RowBox[{"r", "*", 
       RowBox[{"Cos", "[", "a", "]"}]}], ",", 
      RowBox[{"r", "*", 
       RowBox[{"Sin", "[", "a", "]"}]}], ",", "z"}], "}"}]}], 
   "]"}]}]], "Input",
 CellLabel->
  "In[294]:=",ExpressionUUID->"32e28f85-8aad-4eb5-99eb-74f62140cefa"],

Cell[BoxData[
 RowBox[{
  RowBox[{"circ3d", "[", 
   RowBox[{"z_", ",", "r_", ",", "n_", ",", "f_"}], "]"}], " ", ":=", " ", 
  RowBox[{"Table", "[", 
   RowBox[{
    RowBox[{"pt3d", "[", 
     RowBox[{"r", ",", 
      RowBox[{"2", 
       RowBox[{"Pi", "/", "n"}], "*", 
       RowBox[{"(", 
        RowBox[{"k", "+", "f"}], ")"}]}], ",", "z"}], "]"}], ",", 
    RowBox[{"{", 
     RowBox[{"k", ",", "0", ",", 
      RowBox[{"n", "-", "1"}]}], "}"}]}], "]"}]}]], "Input",
 CellLabel->
  "In[295]:=",ExpressionUUID->"800bfaf1-3fd2-49d3-a872-d51c2ab9023c"],

Cell[BoxData[
 RowBox[{
  RowBox[{"ccs3d", "[", "cclst_", "]"}], " ", ":=", " ", 
  RowBox[{"Join", " ", "@@", " ", 
   RowBox[{"(", 
    RowBox[{
     RowBox[{
      RowBox[{"circ3d", " ", "@@", " ", "#"}], "&"}], " ", "/@", " ", 
     "cclst"}], ")"}]}]}]], "Input",
 CellLabel->
  "In[296]:=",ExpressionUUID->"77d1d7ba-d25a-42fe-8892-5851d9eee599"],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"pts", "[", 
    RowBox[{"\"\<tet\>\"", ",", "\"\<vts\>\""}], "]"}], " ", "=", " ", 
   RowBox[{"ccs3d", "[", 
    RowBox[{"{", 
     RowBox[{
      RowBox[{"{", 
       RowBox[{"1", ",", "0", ",", "1", ",", "0"}], "}"}], ",", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{
         RowBox[{"-", "1"}], "/", "3"}], ",", 
        RowBox[{"2", 
         RowBox[{
          RowBox[{"Sqrt", "[", "2", "]"}], "/", "3"}]}], ",", "3", ",", "0"}],
        "}"}]}], "}"}], "]"}]}], ";"}]], "Input",
 CellLabel->
  "In[297]:=",ExpressionUUID->"c09da90c-441f-4ccf-b37e-acaaadce9375"],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"pts", "[", 
    RowBox[{"\"\<tet\>\"", ",", "\"\<eds\>\""}], "]"}], " ", "=", " ", 
   RowBox[{"ccs3d", "[", 
    RowBox[{"{", 
     RowBox[{
      RowBox[{"{", 
       RowBox[{
        RowBox[{"1", "/", 
         RowBox[{"Sqrt", "[", "3", "]"}]}], ",", 
        RowBox[{
         RowBox[{"Sqrt", "[", "2", "]"}], "/", 
         RowBox[{"Sqrt", "[", "3", "]"}]}], ",", "3", ",", "0"}], "}"}], ",", 
      
      RowBox[{"{", 
       RowBox[{
        RowBox[{
         RowBox[{"-", "1"}], "/", 
         RowBox[{"Sqrt", "[", "3", "]"}]}], ",", 
        RowBox[{
         RowBox[{"Sqrt", "[", "2", "]"}], "/", 
         RowBox[{"Sqrt", "[", "3", "]"}]}], ",", "3", ",", 
        RowBox[{"1", "/", "2"}]}], "}"}]}], "}"}], "]"}]}], ";"}]], "Input",
 CellLabel->
  "In[298]:=",ExpressionUUID->"d8f537a8-05fc-4088-a4ce-7e18a98ceec3"],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"pts", "[", 
    RowBox[{"\"\<tet\>\"", ",", "\"\<fcs\>\""}], "]"}], " ", "=", " ", 
   RowBox[{"ccs3d", "[", 
    RowBox[{"{", 
     RowBox[{
      RowBox[{"{", 
       RowBox[{
        RowBox[{"1", "/", "3"}], ",", 
        RowBox[{"2", 
         RowBox[{
          RowBox[{"Sqrt", "[", "2", "]"}], "/", "3"}]}], ",", "3", ",", 
        RowBox[{"1", "/", "2"}]}], "}"}], ",", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"-", "1"}], ",", "0", ",", "1", ",", "0"}], "}"}]}], "}"}], 
    "]"}]}], ";"}]], "Input",
 CellLabel->
  "In[299]:=",ExpressionUUID->"207c3d42-01d9-480e-bd29-bce3307b8b9c"],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"pts", "[", 
    RowBox[{"\"\<oct\>\"", ",", "\"\<vts\>\""}], "]"}], " ", "=", " ", 
   RowBox[{"ccs3d", "[", 
    RowBox[{"{", 
     RowBox[{
      RowBox[{"{", 
       RowBox[{"1", ",", "0", ",", "1", ",", "0"}], "}"}], ",", 
      RowBox[{"{", 
       RowBox[{"0", ",", "1", ",", "4", ",", "0"}], "}"}], ",", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"-", "1"}], ",", "0", ",", "1", ",", "0"}], "}"}]}], "}"}], 
    "]"}]}], ";"}]], "Input",
 CellLabel->
  "In[300]:=",ExpressionUUID->"bcc05416-c5b8-4edb-a19b-9977afd145bc"],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"pts", "[", 
    RowBox[{"\"\<oct\>\"", ",", "\"\<eds\>\""}], "]"}], " ", "=", " ", 
   RowBox[{"ccs3d", "[", 
    RowBox[{"{", 
     RowBox[{
      RowBox[{"{", 
       RowBox[{
        RowBox[{"1", "/", 
         RowBox[{"Sqrt", "[", "2", "]"}]}], ",", 
        RowBox[{"1", "/", 
         RowBox[{"Sqrt", "[", "2", "]"}]}], ",", "4", ",", "0"}], "}"}], ",", 
      
      RowBox[{"{", 
       RowBox[{"0", ",", "1", ",", "4", ",", 
        RowBox[{"1", "/", "2"}]}], "}"}], ",", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{
         RowBox[{"-", "1"}], "/", 
         RowBox[{"Sqrt", "[", "2", "]"}]}], ",", 
        RowBox[{"1", "/", 
         RowBox[{"Sqrt", "[", "2", "]"}]}], ",", "4", ",", "0"}], "}"}]}], 
     "}"}], "]"}]}], ";"}]], "Input",
 CellLabel->
  "In[301]:=",ExpressionUUID->"7e071110-74f4-4652-a8b8-9e5b376f2bd1"],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"pts", "[", 
    RowBox[{"\"\<oct\>\"", ",", "\"\<fcs\>\""}], "]"}], " ", "=", " ", 
   RowBox[{"ccs3d", "[", 
    RowBox[{"{", 
     RowBox[{
      RowBox[{"{", 
       RowBox[{
        RowBox[{"1", "/", 
         RowBox[{"Sqrt", "[", "3", "]"}]}], ",", 
        RowBox[{
         RowBox[{"Sqrt", "[", "2", "]"}], "/", 
         RowBox[{"Sqrt", "[", "3", "]"}]}], ",", "4", ",", 
        RowBox[{"1", "/", "2"}]}], "}"}], ",", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{
         RowBox[{"-", "1"}], "/", 
         RowBox[{"Sqrt", "[", "3", "]"}]}], ",", 
        RowBox[{
         RowBox[{"Sqrt", "[", "2", "]"}], "/", 
         RowBox[{"Sqrt", "[", "3", "]"}]}], ",", "4", ",", 
        RowBox[{"1", "/", "2"}]}], "}"}]}], "}"}], "]"}]}], ";"}]], "Input",
 CellLabel->
  "In[302]:=",ExpressionUUID->"bd3ab846-f6eb-48b5-b45a-a42f3cb129e5"],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"pts", "[", 
    RowBox[{"\"\<ico\>\"", ",", "\"\<vts\>\""}], "]"}], " ", "=", " ", 
   RowBox[{"ccs3d", "[", 
    RowBox[{"{", 
     RowBox[{
      RowBox[{"{", 
       RowBox[{"1", ",", "0", ",", "1", ",", "0"}], "}"}], ",", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"1", "/", 
         RowBox[{"Sqrt", "[", "5", "]"}]}], ",", 
        RowBox[{"2", "/", 
         RowBox[{"Sqrt", "[", "5", "]"}]}], ",", "5", ",", "0"}], "}"}], ",", 
      
      RowBox[{"{", 
       RowBox[{
        RowBox[{
         RowBox[{"-", "1"}], "/", 
         RowBox[{"Sqrt", "[", "5", "]"}]}], ",", 
        RowBox[{"2", "/", 
         RowBox[{"Sqrt", "[", "5", "]"}]}], ",", "5", ",", 
        RowBox[{"1", "/", "2"}]}], "}"}], ",", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"-", "1"}], ",", "0", ",", "1", ",", "0"}], "}"}]}], "}"}], 
    "]"}]}], ";"}]], "Input",
 CellLabel->
  "In[303]:=",ExpressionUUID->"f46bb0bb-93da-4bc6-9d54-57ef09f424b0"],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"pts", "[", 
    RowBox[{"\"\<ico\>\"", ",", "\"\<eds\>\""}], "]"}], " ", "=", " ", 
   RowBox[{"ccs3d", "[", 
    RowBox[{"{", 
     RowBox[{
      RowBox[{"{", 
       RowBox[{
        RowBox[{
         RowBox[{"Sqrt", "[", 
          RowBox[{"5", "+", 
           RowBox[{"Sqrt", "[", "5", "]"}]}], "]"}], "/", 
         RowBox[{"Sqrt", "[", "10", "]"}]}], ",", 
        RowBox[{
         RowBox[{"Sqrt", "[", 
          RowBox[{"5", "-", 
           RowBox[{"Sqrt", "[", "5", "]"}]}], "]"}], "/", 
         RowBox[{"Sqrt", "[", "10", "]"}]}], ",", "5", ",", "0"}], "}"}], ",", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{
         RowBox[{"Sqrt", "[", 
          RowBox[{"5", "-", 
           RowBox[{"Sqrt", "[", "5", "]"}]}], "]"}], "/", 
         RowBox[{"Sqrt", "[", "10", "]"}]}], ",", 
        RowBox[{
         RowBox[{"Sqrt", "[", 
          RowBox[{"5", "+", 
           RowBox[{"Sqrt", "[", "5", "]"}]}], "]"}], "/", 
         RowBox[{"Sqrt", "[", "10", "]"}]}], ",", "5", ",", 
        RowBox[{"1", "/", "2"}]}], "}"}], ",", 
      RowBox[{"{", 
       RowBox[{"0", ",", "1", ",", "10", ",", 
        RowBox[{"1", "/", "2"}]}], "}"}], ",", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{
         RowBox[{"-", 
          RowBox[{"Sqrt", "[", 
           RowBox[{"5", "-", 
            RowBox[{"Sqrt", "[", "5", "]"}]}], "]"}]}], "/", 
         RowBox[{"Sqrt", "[", "10", "]"}]}], ",", 
        RowBox[{
         RowBox[{"Sqrt", "[", 
          RowBox[{"5", "+", 
           RowBox[{"Sqrt", "[", "5", "]"}]}], "]"}], "/", 
         RowBox[{"Sqrt", "[", "10", "]"}]}], ",", "5", ",", "0"}], "}"}], ",", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{
         RowBox[{"-", 
          RowBox[{"Sqrt", "[", 
           RowBox[{"5", "+", 
            RowBox[{"Sqrt", "[", "5", "]"}]}], "]"}]}], "/", 
         RowBox[{"Sqrt", "[", "10", "]"}]}], ",", 
        RowBox[{
         RowBox[{"Sqrt", "[", 
          RowBox[{"5", "-", 
           RowBox[{"Sqrt", "[", "5", "]"}]}], "]"}], "/", 
         RowBox[{"Sqrt", "[", "10", "]"}]}], ",", "5", ",", 
        RowBox[{"1", "/", "2"}]}], "}"}]}], "}"}], "]"}]}], ";"}]], "Input",
 CellLabel->
  "In[304]:=",ExpressionUUID->"d0c4038b-3a07-4595-a996-b220bf5616ad"],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"pts", "[", 
    RowBox[{"\"\<ico\>\"", ",", "\"\<fcs\>\""}], "]"}], " ", "=", " ", 
   RowBox[{"ccs3d", "[", 
    RowBox[{"{", 
     RowBox[{
      RowBox[{"{", 
       RowBox[{
        RowBox[{
         RowBox[{"Sqrt", "[", 
          RowBox[{"5", "+", 
           RowBox[{"2", 
            RowBox[{"Sqrt", "[", "5", "]"}]}]}], "]"}], "/", 
         RowBox[{"Sqrt", "[", "15", "]"}]}], ",", 
        RowBox[{
         RowBox[{"Sqrt", "[", 
          RowBox[{"10", "-", 
           RowBox[{"2", 
            RowBox[{"Sqrt", "[", "5", "]"}]}]}], "]"}], "/", 
         RowBox[{"Sqrt", "[", "15", "]"}]}], ",", "5", ",", 
        RowBox[{"1", "/", "2"}]}], "}"}], ",", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{
         RowBox[{"Sqrt", "[", 
          RowBox[{"5", "-", 
           RowBox[{"2", 
            RowBox[{"Sqrt", "[", "5", "]"}]}]}], "]"}], "/", 
         RowBox[{"Sqrt", "[", "15", "]"}]}], ",", 
        RowBox[{
         RowBox[{"Sqrt", "[", 
          RowBox[{"10", "+", 
           RowBox[{"2", 
            RowBox[{"Sqrt", "[", "5", "]"}]}]}], "]"}], "/", 
         RowBox[{"Sqrt", "[", "15", "]"}]}], ",", "5", ",", 
        RowBox[{"1", "/", "2"}]}], "}"}], ",", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{
         RowBox[{"-", 
          RowBox[{"Sqrt", "[", 
           RowBox[{"5", "-", 
            RowBox[{"2", 
             RowBox[{"Sqrt", "[", "5", "]"}]}]}], "]"}]}], "/", 
         RowBox[{"Sqrt", "[", "15", "]"}]}], ",", 
        RowBox[{
         RowBox[{"Sqrt", "[", 
          RowBox[{"10", "+", 
           RowBox[{"2", 
            RowBox[{"Sqrt", "[", "5", "]"}]}]}], "]"}], "/", 
         RowBox[{"Sqrt", "[", "15", "]"}]}], ",", "5", ",", "0"}], "}"}], ",", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{
         RowBox[{"-", 
          RowBox[{"Sqrt", "[", 
           RowBox[{"5", "+", 
            RowBox[{"2", 
             RowBox[{"Sqrt", "[", "5", "]"}]}]}], "]"}]}], "/", 
         RowBox[{"Sqrt", "[", "15", "]"}]}], ",", 
        RowBox[{
         RowBox[{"Sqrt", "[", 
          RowBox[{"10", "-", 
           RowBox[{"2", 
            RowBox[{"Sqrt", "[", "5", "]"}]}]}], "]"}], "/", 
         RowBox[{"Sqrt", "[", "15", "]"}]}], ",", "5", ",", "0"}], "}"}]}], 
     "}"}], "]"}]}], ";"}]], "Input",
 CellLabel->
  "In[305]:=",ExpressionUUID->"4c159c18-34f9-410c-a87c-d3abb5df687d"],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{
    RowBox[{
     RowBox[{
      RowBox[{"Table", "[", 
       RowBox[{
        RowBox[{"abssqr", " ", "/@", " ", 
         RowBox[{"pts", "[", 
          RowBox[{"t1", ",", "t2"}], "]"}]}], ",", 
        RowBox[{"{", 
         RowBox[{"t1", ",", 
          RowBox[{"{", 
           RowBox[{"\"\<tet\>\"", ",", "\"\<oct\>\"", ",", "\"\<ico\>\""}], 
           "}"}]}], "}"}], ",", 
        RowBox[{"{", 
         RowBox[{"t2", ",", 
          RowBox[{"{", 
           RowBox[{"\"\<vts\>\"", ",", "\"\<eds\>\"", ",", "\"\<fcs\>\""}], 
           "}"}]}], "}"}]}], "]"}], " ", "-", " ", "1"}], " ", "//", " ", 
     "Expand"}], " ", "//", " ", "Factor"}], " ", "//", " ", "Flatten"}], " ",
   "//", " ", "Union"}]], "Input",
 CellLabel->
  "In[306]:=",ExpressionUUID->"6dbf652a-1eb4-4952-9c9c-1c21948ba7ea"]
}, Closed]],

Cell[CellGroupData[{

Cell["Incidence Graphs", "Section",ExpressionUUID->"f9f85292-e5d4-4cfc-b915-7d1b5f10e2e8"],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"igrf", "[", 
    RowBox[{"\"\<tet\>\"", ",", "\"\<vts\>\"", ",", "\"\<eds\>\""}], "]"}], 
   " ", "=", " ", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"1", ",", "2", ",", "3"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"1", ",", "6", ",", "4"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"2", ",", "4", ",", "5"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"3", ",", "5", ",", "6"}], "}"}]}], "}"}]}], ";"}]], "Input",
 CellLabel->
  "In[307]:=",ExpressionUUID->"a422fa16-67ef-4fc7-8f50-6bc3a6f8724a"],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"igrf", "[", 
    RowBox[{"\"\<tet\>\"", ",", "\"\<vts\>\"", ",", "\"\<fcs\>\""}], "]"}], 
   " ", "=", " ", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"1", ",", "2", ",", "3"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"3", ",", "4", ",", "1"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"1", ",", "4", ",", "2"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"2", ",", "4", ",", "3"}], "}"}]}], "}"}]}], ";"}]], "Input",
 CellLabel->
  "In[308]:=",ExpressionUUID->"248da275-6906-46d9-b14d-fe9a22fe520d"],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"igrf", "[", 
    RowBox[{"\"\<tet\>\"", ",", "\"\<eds\>\"", ",", "\"\<vts\>\""}], "]"}], 
   " ", "=", " ", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"1", ",", "2"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"1", ",", "3"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"1", ",", "4"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"2", ",", "3"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"3", ",", "4"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"2", ",", "4"}], "}"}]}], "}"}]}], ";"}]], "Input",
 CellLabel->
  "In[309]:=",ExpressionUUID->"3ebef03e-81e5-4516-a434-1dda1a14ad07"],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"igrf", "[", 
    RowBox[{"\"\<tet\>\"", ",", "\"\<eds\>\"", ",", "\"\<fcs\>\""}], "]"}], 
   " ", "=", " ", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"1", ",", "3"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"1", ",", "2"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"2", ",", "3"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"1", ",", "4"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"2", ",", "4"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"3", ",", "4"}], "}"}]}], "}"}]}], ";"}]], "Input",
 CellLabel->
  "In[310]:=",ExpressionUUID->"3aa94d71-53f0-44df-890d-e2ff58fb1ab9"],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"igrf", "[", 
    RowBox[{"\"\<tet\>\"", ",", "\"\<fcs\>\"", ",", "\"\<vts\>\""}], "]"}], 
   " ", "=", " ", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"1", ",", "2", ",", "3"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"1", ",", "3", ",", "4"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"1", ",", "4", ",", "2"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"2", ",", "4", ",", "3"}], "}"}]}], "}"}]}], ";"}]], "Input",
 CellLabel->
  "In[311]:=",ExpressionUUID->"81f1997f-e54d-484c-8cd6-73a4573b4700"],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"igrf", "[", 
    RowBox[{"\"\<tet\>\"", ",", "\"\<fcs\>\"", ",", "\"\<eds\>\""}], "]"}], 
   " ", "=", " ", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"1", ",", "4", ",", "2"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"2", ",", "5", ",", "3"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"3", ",", "6", ",", "1"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"4", ",", "6", ",", "5"}], "}"}]}], "}"}]}], ";"}]], "Input",
 CellLabel->
  "In[312]:=",ExpressionUUID->"f51dbef9-9638-4564-8fa6-ac1627ff708d"],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"igrf", "[", 
    RowBox[{"\"\<oct\>\"", ",", "\"\<vts\>\"", ",", "\"\<eds\>\""}], "]"}], 
   " ", "=", " ", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"1", ",", "2", ",", "3", ",", "4"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"1", ",", "8", ",", "9", ",", "5"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"2", ",", "5", ",", "10", ",", "6"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"3", ",", "6", ",", "11", ",", "7"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"4", ",", "7", ",", "12", ",", "8"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"9", ",", "12", ",", "11", ",", "10"}], "}"}]}], "}"}]}], 
  ";"}]], "Input",
 CellLabel->
  "In[313]:=",ExpressionUUID->"5a7c009d-8f22-41ce-8fd1-bb3f45c4ccb2"],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"igrf", "[", 
    RowBox[{"\"\<oct\>\"", ",", "\"\<vts\>\"", ",", "\"\<fcs\>\""}], "]"}], 
   " ", "=", " ", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"1", ",", "2", ",", "3", ",", "4"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"1", ",", "4", ",", "8", ",", "5"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"1", ",", "5", ",", "6", ",", "2"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"2", ",", "6", ",", "7", ",", "3"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"3", ",", "7", ",", "8", ",", "4"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"5", ",", "8", ",", "7", ",", "6"}], "}"}]}], "}"}]}], 
  ";"}]], "Input",
 CellLabel->
  "In[314]:=",ExpressionUUID->"b81d44ce-f140-4b63-99dd-31fdda3a4d68"],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"igrf", "[", 
    RowBox[{"\"\<oct\>\"", ",", "\"\<eds\>\"", ",", "\"\<vts\>\""}], "]"}], 
   " ", "=", " ", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"1", ",", "2"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"1", ",", "3"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"1", ",", "4"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"1", ",", "5"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"2", ",", "3"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"3", ",", "4"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"4", ",", "5"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"2", ",", "5"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"2", ",", "6"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"3", ",", "6"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"4", ",", "6"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"5", ",", "6"}], "}"}]}], "}"}]}], ";"}]], "Input",
 CellLabel->
  "In[315]:=",ExpressionUUID->"a6c882fb-9f10-48e7-bed9-6e304912f3e2"],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"igrf", "[", 
    RowBox[{"\"\<oct\>\"", ",", "\"\<eds\>\"", ",", "\"\<fcs\>\""}], "]"}], 
   " ", "=", " ", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"1", ",", "4"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"1", ",", "2"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"2", ",", "3"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"3", ",", "4"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"1", ",", "5"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"2", ",", "6"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"3", ",", "7"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"4", ",", "8"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"5", ",", "8"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"5", ",", "6"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"6", ",", "7"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"7", ",", "8"}], "}"}]}], "}"}]}], ";"}]], "Input",
 CellLabel->
  "In[316]:=",ExpressionUUID->"1045b627-1f17-4895-9e4e-e7c7718ca40c"],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"igrf", "[", 
    RowBox[{"\"\<oct\>\"", ",", "\"\<fcs\>\"", ",", "\"\<vts\>\""}], "]"}], 
   " ", "=", " ", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"1", ",", "2", ",", "3"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"1", ",", "3", ",", "4"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"1", ",", "4", ",", "5"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"1", ",", "5", ",", "2"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"2", ",", "6", ",", "3"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"3", ",", "6", ",", "4"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"4", ",", "6", ",", "5"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"2", ",", "5", ",", "6"}], "}"}]}], "}"}]}], ";"}]], "Input",
 CellLabel->
  "In[317]:=",ExpressionUUID->"bc24a8cd-f250-469d-a4fa-ca28d3f8c2c1"],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"igrf", "[", 
    RowBox[{"\"\<oct\>\"", ",", "\"\<fcs\>\"", ",", "\"\<eds\>\""}], "]"}], 
   " ", "=", " ", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"1", ",", "5", ",", "2"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"2", ",", "6", ",", "3"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"3", ",", "7", ",", "4"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"1", ",", "4", ",", "8"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"5", ",", "9", ",", "10"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"6", ",", "10", ",", "11"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"7", ",", "11", ",", "12"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"8", ",", "12", ",", "9"}], "}"}]}], "}"}]}], ";"}]], "Input",
 CellLabel->
  "In[318]:=",ExpressionUUID->"bdafb605-6afd-4da0-ad59-2565aaa175e2"],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"igrf", "[", 
    RowBox[{"\"\<ico\>\"", ",", "\"\<vts\>\"", ",", "\"\<eds\>\""}], "]"}], 
   " ", "=", " ", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"1", ",", "2", ",", "3", ",", "4", ",", "5"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"1", ",", "10", ",", "20", ",", "11", ",", "6"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"2", ",", "6", ",", "12", ",", "13", ",", "7"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"3", ",", "7", ",", "14", ",", "15", ",", "8"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"4", ",", "8", ",", "16", ",", "17", ",", "9"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"5", ",", "9", ",", "18", ",", "19", ",", "10"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"11", ",", "21", ",", "26", ",", "22", ",", "12"}], "}"}], ",", 
     
     RowBox[{"{", 
      RowBox[{"13", ",", "22", ",", "27", ",", "23", ",", "14"}], "}"}], ",", 
     
     RowBox[{"{", 
      RowBox[{"15", ",", "23", ",", "28", ",", "24", ",", "16"}], "}"}], ",", 
     
     RowBox[{"{", 
      RowBox[{"17", ",", "24", ",", "29", ",", "25", ",", "18"}], "}"}], ",", 
     
     RowBox[{"{", 
      RowBox[{"19", ",", "25", ",", "30", ",", "21", ",", "20"}], "}"}], ",", 
     
     RowBox[{"{", 
      RowBox[{"26", ",", "30", ",", "29", ",", "28", ",", "27"}], "}"}]}], 
    "}"}]}], ";"}]], "Input",
 CellLabel->
  "In[319]:=",ExpressionUUID->"2828d8ee-4586-4176-9ecc-5b80ca607856"],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"igrf", "[", 
    RowBox[{"\"\<ico\>\"", ",", "\"\<vts\>\"", ",", "\"\<fcs\>\""}], "]"}], 
   " ", "=", " ", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"1", ",", "2", ",", "3", ",", "4", ",", "5"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"1", ",", "5", ",", "10", ",", "11", ",", "6"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"1", ",", "6", ",", "12", ",", "7", ",", "2"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"2", ",", "7", ",", "13", ",", "8", ",", "3"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"3", ",", "8", ",", "14", ",", "9", ",", "4"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"4", ",", "9", ",", "15", ",", "10", ",", "5"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"6", ",", "11", ",", "16", ",", "17", ",", "12"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"7", ",", "12", ",", "17", ",", "18", ",", "13"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"8", ",", "13", ",", "18", ",", "19", ",", "14"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"9", ",", "14", ",", "19", ",", "20", ",", "15"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"10", ",", "15", ",", "20", ",", "16", ",", "11"}], "}"}], ",", 
     
     RowBox[{"{", 
      RowBox[{"16", ",", "20", ",", "19", ",", "18", ",", "17"}], "}"}]}], 
    "}"}]}], ";"}]], "Input",
 CellLabel->
  "In[320]:=",ExpressionUUID->"5fda78d3-3d52-4a73-8205-b9b656471940"],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"igrf", "[", 
    RowBox[{"\"\<ico\>\"", ",", "\"\<eds\>\"", ",", "\"\<vts\>\""}], "]"}], 
   " ", "=", " ", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"1", ",", "2"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"1", ",", "3"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"1", ",", "4"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"1", ",", "5"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"1", ",", "6"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"2", ",", "3"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"3", ",", "4"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"4", ",", "5"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"5", ",", "6"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"2", ",", "6"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"2", ",", "7"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"3", ",", "7"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"3", ",", "8"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"4", ",", "8"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"4", ",", "9"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"5", ",", "9"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"5", ",", "10"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"6", ",", "10"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"6", ",", "11"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"2", ",", "11"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"7", ",", "11"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"7", ",", "8"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"8", ",", "9"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"9", ",", "10"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"10", ",", "11"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"7", ",", "12"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"8", ",", "12"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"9", ",", "12"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"10", ",", "12"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"11", ",", "12"}], "}"}]}], "}"}]}], ";"}]], "Input",
 CellLabel->
  "In[321]:=",ExpressionUUID->"ace90b56-54e8-4f10-8d13-49b225feb249"],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"igrf", "[", 
    RowBox[{"\"\<ico\>\"", ",", "\"\<eds\>\"", ",", "\"\<fcs\>\""}], "]"}], 
   " ", "=", " ", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"1", ",", "5"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"1", ",", "2"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"2", ",", "3"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"3", ",", "4"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"4", ",", "5"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"1", ",", "6"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"2", ",", "7"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"3", ",", "8"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"4", ",", "9"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"5", ",", "10"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"6", ",", "11"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"6", ",", "12"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"7", ",", "12"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"7", ",", "13"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"8", ",", "13"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"8", ",", "14"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"9", ",", "14"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"9", ",", "15"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"10", ",", "15"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"10", ",", "11"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"11", ",", "16"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"12", ",", "17"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"13", ",", "18"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"14", ",", "19"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"15", ",", "20"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"16", ",", "17"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"17", ",", "18"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"18", ",", "19"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"19", ",", "20"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"16", ",", "20"}], "}"}]}], "}"}]}], ";"}]], "Input",
 CellLabel->
  "In[322]:=",ExpressionUUID->"63bce83c-64f4-4280-b786-fb8a6c969a5f"],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"igrf", "[", 
    RowBox[{"\"\<ico\>\"", ",", "\"\<fcs\>\"", ",", "\"\<vts\>\""}], "]"}], 
   " ", "=", " ", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"1", ",", "2", ",", "3"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"1", ",", "3", ",", "4"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"1", ",", "4", ",", "5"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"1", ",", "5", ",", "6"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"1", ",", "6", ",", "2"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"2", ",", "7", ",", "3"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"3", ",", "8", ",", "4"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"4", ",", "9", ",", "5"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"5", ",", "10", ",", "6"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"2", ",", "6", ",", "11"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"2", ",", "11", ",", "7"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"3", ",", "7", ",", "8"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"4", ",", "8", ",", "9"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"5", ",", "9", ",", "10"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"6", ",", "10", ",", "11"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"7", ",", "11", ",", "12"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"7", ",", "12", ",", "8"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"8", ",", "12", ",", "9"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"9", ",", "12", ",", "10"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"10", ",", "12", ",", "11"}], "}"}]}], "}"}]}], ";"}]], "Input",\

 CellLabel->
  "In[323]:=",ExpressionUUID->"f73c27ee-e495-4ddb-980a-97bb9172e9d3"],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"igrf", "[", 
    RowBox[{"\"\<ico\>\"", ",", "\"\<fcs\>\"", ",", "\"\<eds\>\""}], "]"}], 
   " ", "=", " ", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"1", ",", "6", ",", "2"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"2", ",", "7", ",", "3"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"3", ",", "8", ",", "4"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"4", ",", "9", ",", "5"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"1", ",", "5", ",", "10"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"6", ",", "11", ",", "12"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"7", ",", "13", ",", "14"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"8", ",", "15", ",", "16"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"9", ",", "17", ",", "18"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"10", ",", "19", ",", "20"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"11", ",", "20", ",", "21"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"12", ",", "22", ",", "13"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"14", ",", "23", ",", "15"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"16", ",", "24", ",", "17"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"18", ",", "25", ",", "19"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"21", ",", "30", ",", "26"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"22", ",", "26", ",", "27"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"23", ",", "27", ",", "28"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"24", ",", "28", ",", "29"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"25", ",", "29", ",", "30"}], "}"}]}], "}"}]}], ";"}]], "Input",\

 CellLabel->
  "In[324]:=",ExpressionUUID->"863682bf-5996-4de7-b299-333ac2b9453d"],

Cell[BoxData[
 RowBox[{
  RowBox[{"checkallpairs", "[", 
   RowBox[{"t_", ",", "f_"}], "]"}], " ", ":=", " ", 
  RowBox[{"{", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{
      RowBox[{"f", "[", 
       RowBox[{"t", ",", "\"\<vts\>\"", ",", "\"\<eds\>\""}], "]"}], ",", 
      RowBox[{"f", "[", 
       RowBox[{"t", ",", "\"\<eds\>\"", ",", "\"\<vts\>\""}], "]"}]}], "}"}], 
    ",", 
    RowBox[{"{", 
     RowBox[{
      RowBox[{"f", "[", 
       RowBox[{"t", ",", "\"\<vts\>\"", ",", "\"\<fcs\>\""}], "]"}], ",", 
      RowBox[{"f", "[", 
       RowBox[{"t", ",", "\"\<fcs\>\"", ",", "\"\<vts\>\""}], "]"}]}], "}"}], 
    ",", 
    RowBox[{"{", 
     RowBox[{
      RowBox[{"f", "[", 
       RowBox[{"t", ",", "\"\<eds\>\"", ",", "\"\<fcs\>\""}], "]"}], ",", 
      RowBox[{"f", "[", 
       RowBox[{"t", ",", "\"\<fcs\>\"", ",", "\"\<eds\>\""}], "]"}]}], 
     "}"}]}], "}"}]}]], "Input",
 CellLabel->
  "In[325]:=",ExpressionUUID->"b717a5c5-290b-495f-b31e-4593cebd6243"],

Cell[BoxData[
 RowBox[{
  RowBox[{"checksizes", "[", "t_", "]"}], " ", ":=", " ", 
  RowBox[{"Map", "[", 
   RowBox[{"Dimensions", ",", 
    RowBox[{"checkallpairs", "[", 
     RowBox[{"t", ",", "igrf"}], "]"}], ",", 
    RowBox[{"{", "2", "}"}]}], "]"}]}]], "Input",
 CellLabel->
  "In[326]:=",ExpressionUUID->"a6953dfe-de0b-40c3-8e80-b9cdc039edbc"],

Cell[BoxData[
 RowBox[{
  RowBox[{"checkptiglens", "[", 
   RowBox[{"t_", ",", "t1_", ",", "t2_"}], "]"}], " ", ":=", " ", 
  RowBox[{"Module", "[", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{"p1", ",", "p2", ",", "ig"}], "}"}], ",", "\[IndentingNewLine]", 
    
    RowBox[{
     RowBox[{"p1", " ", "=", " ", 
      RowBox[{"pts", "[", 
       RowBox[{"t", ",", "t1"}], "]"}]}], ";", " ", 
     RowBox[{"p2", " ", "=", " ", 
      RowBox[{"pts", "[", 
       RowBox[{"t", ",", "t2"}], "]"}]}], ";", " ", 
     RowBox[{"ig", " ", "=", " ", 
      RowBox[{"igrf", "[", 
       RowBox[{"t", ",", "t1", ",", "t2"}], "]"}]}], ";", 
     "\[IndentingNewLine]", 
     RowBox[{"Table", "[", 
      RowBox[{
       RowBox[{
        RowBox[{
         RowBox[{"abssqr", "[", 
          RowBox[{
           RowBox[{"p1", "[", 
            RowBox[{"[", "k", "]"}], "]"}], " ", "-", " ", "#"}], "]"}], 
         "&"}], " ", "/@", " ", 
        RowBox[{"Table", "[", 
         RowBox[{
          RowBox[{"p2", "[", 
           RowBox[{"[", "m", "]"}], "]"}], ",", 
          RowBox[{"{", 
           RowBox[{"m", ",", 
            RowBox[{"ig", "[", 
             RowBox[{"[", "k", "]"}], "]"}]}], "}"}]}], "]"}]}], ",", 
       RowBox[{"{", 
        RowBox[{"k", ",", 
         RowBox[{"Length", "[", "ig", "]"}]}], "}"}]}], "]"}]}]}], 
   "\[IndentingNewLine]", "]"}]}]], "Input",
 CellLabel->
  "In[327]:=",ExpressionUUID->"13f3ee40-90ce-492d-951d-3b2511cdb81a"],

Cell[BoxData[
 RowBox[{
  RowBox[{"checkptiglens", "[", "t_", "]"}], " ", ":=", " ", 
  RowBox[{"checkallpairs", "[", 
   RowBox[{"t", ",", "checkptiglens"}], "]"}]}]], "Input",
 CellLabel->
  "In[328]:=",ExpressionUUID->"c35efa1d-ed49-46e5-b1d4-a4505b22ba7e"],

Cell[BoxData[
 RowBox[{
  RowBox[{"checkptigangs", "[", 
   RowBox[{"t_", ",", "t1_", ",", "t2_"}], "]"}], " ", ":=", "  ", 
  RowBox[{"Module", "[", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{"p1", ",", "p2", ",", "ig", ",", "ige", ",", "igel"}], "}"}], 
    ",", "\[IndentingNewLine]", 
    RowBox[{
     RowBox[{"p1", " ", "=", " ", 
      RowBox[{"pts", "[", 
       RowBox[{"t", ",", "t1"}], "]"}]}], ";", " ", 
     RowBox[{"p2", " ", "=", " ", 
      RowBox[{"pts", "[", 
       RowBox[{"t", ",", "t2"}], "]"}]}], ";", " ", 
     RowBox[{"ig", " ", "=", " ", 
      RowBox[{"igrf", "[", 
       RowBox[{"t", ",", "t1", ",", "t2"}], "]"}]}], ";", 
     "\[IndentingNewLine]", 
     RowBox[{"Table", "[", 
      RowBox[{
       RowBox[{
        RowBox[{"ige", " ", "=", " ", 
         RowBox[{"ig", "[", 
          RowBox[{"[", "k", "]"}], "]"}]}], ";", " ", 
        RowBox[{"igel", " ", "=", " ", 
         RowBox[{"Length", "[", "ige", "]"}]}], ";", "\[IndentingNewLine]", 
        RowBox[{
         RowBox[{"Table", "[", 
          RowBox[{
           RowBox[{"Cross", "[", 
            RowBox[{
             RowBox[{"p2", "[", 
              RowBox[{"[", 
               RowBox[{"ige", "[", 
                RowBox[{"[", "m", "]"}], "]"}], "]"}], "]"}], ",", 
             RowBox[{"p2", "[", 
              RowBox[{"[", 
               RowBox[{"ige", "[", 
                RowBox[{"[", 
                 RowBox[{
                  RowBox[{"Mod", "[", 
                   RowBox[{"m", ",", "igel"}], "]"}], "+", "1"}], "]"}], 
                "]"}], "]"}], "]"}]}], "]"}], ",", 
           RowBox[{"{", 
            RowBox[{"m", ",", "igel"}], "}"}]}], "]"}], ".", 
         RowBox[{"p1", "[", 
          RowBox[{"[", "k", "]"}], "]"}]}]}], ",", 
       RowBox[{"{", 
        RowBox[{"k", ",", 
         RowBox[{"Length", "[", "ig", "]"}]}], "}"}]}], "]"}]}]}], 
   "\[IndentingNewLine]", "]"}]}]], "Input",
 CellLabel->
  "In[329]:=",ExpressionUUID->"0e6079bb-5e12-43ab-ad9c-4d0aa963f67d"],

Cell[BoxData[
 RowBox[{
  RowBox[{"checkptigangs", "[", "t_", "]"}], " ", ":=", " ", 
  RowBox[{"{", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{
      RowBox[{"checkptiglens", "[", 
       RowBox[{"t", ",", "\"\<vts\>\"", ",", "\"\<eds\>\""}], "]"}], ",", 
      RowBox[{"checkptiglens", "[", 
       RowBox[{"t", ",", "\"\<eds\>\"", ",", "\"\<vts\>\""}], "]"}]}], "}"}], 
    ",", 
    RowBox[{"{", 
     RowBox[{
      RowBox[{"checkptiglens", "[", 
       RowBox[{"t", ",", "\"\<vts\>\"", ",", "\"\<fcs\>\""}], "]"}], ",", 
      RowBox[{"checkptiglens", "[", 
       RowBox[{"t", ",", "\"\<fcs\>\"", ",", "\"\<vts\>\""}], "]"}]}], "}"}], 
    ",", 
    RowBox[{"{", 
     RowBox[{
      RowBox[{"checkptiglens", "[", 
       RowBox[{"t", ",", "\"\<eds\>\"", ",", "\"\<fcs\>\""}], "]"}], ",", 
      RowBox[{"checkptiglens", "[", 
       RowBox[{"t", ",", "\"\<fcs\>\"", ",", "\"\<eds\>\""}], "]"}]}], 
     "}"}]}], "}"}]}]], "Input",
 CellLabel->
  "In[330]:=",ExpressionUUID->"e35c3f03-d694-4427-b9f4-5c1fc482f96b"],

Cell[BoxData[
 RowBox[{
  RowBox[{"checkptigangs", "[", "t_", "]"}], " ", ":=", " ", 
  RowBox[{"checkallpairs", "[", 
   RowBox[{"t", ",", "checkptigangs"}], "]"}]}]], "Input",
 CellLabel->
  "In[331]:=",ExpressionUUID->"f6f1ef74-34d7-4280-bff8-efb4d2ade03a"],

Cell[BoxData[
 RowBox[{
  RowBox[{"checkptig", "[", "t_", "]"}], " ", ":=", " ", 
  RowBox[{"{", 
   RowBox[{
    RowBox[{"checkptiglens", "[", "t", "]"}], ",", 
    RowBox[{"checkptigangs", "[", "t", "]"}]}], "}"}]}]], "Input",
 CellLabel->
  "In[332]:=",ExpressionUUID->"b5c214b4-5686-4d04-8588-1b679f037e98"],

Cell[BoxData[
 RowBox[{"checksizes", "[", "\"\<tet\>\"", "]"}]], "Input",
 CellLabel->
  "In[333]:=",ExpressionUUID->"90d0279b-036b-44aa-a733-cc4d7abd5735"],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{
    RowBox[{
     RowBox[{
      RowBox[{"checkptig", "[", "\"\<tet\>\"", "]"}], " ", "-", " ", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"{", 
         RowBox[{
          RowBox[{
           RowBox[{"(", 
            RowBox[{"2", "/", "3"}], ")"}], 
           RowBox[{"(", 
            RowBox[{"3", "-", 
             RowBox[{"Sqrt", "[", "3", "]"}]}], ")"}]}], ",", 
          RowBox[{"4", "/", "3"}], ",", 
          RowBox[{
           RowBox[{"(", 
            RowBox[{"2", "/", "3"}], ")"}], 
           RowBox[{"(", 
            RowBox[{"3", "-", 
             RowBox[{"Sqrt", "[", "3", "]"}]}], ")"}]}]}], "}"}], ",", 
        RowBox[{"{", 
         RowBox[{
          RowBox[{"{", 
           RowBox[{
            RowBox[{"1", "/", 
             RowBox[{"Sqrt", "[", "3", "]"}]}], ",", "0"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"4", "/", 
             RowBox[{"(", 
              RowBox[{"3", 
               RowBox[{"Sqrt", "[", "3", "]"}]}], ")"}]}], ",", 
            RowBox[{"4", "/", 
             RowBox[{"(", 
              RowBox[{"3", 
               RowBox[{"Sqrt", "[", "3", "]"}]}], ")"}]}]}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{"0", ",", 
            RowBox[{"1", "/", 
             RowBox[{"Sqrt", "[", "3", "]"}]}]}], "}"}]}], "}"}]}], "}"}]}], 
     " ", "//", " ", "Expand"}], " ", "//", " ", "Factor"}], " ", "//", " ", 
   "Flatten"}], " ", "//", " ", "Union"}]], "Input",
 CellLabel->
  "In[334]:=",ExpressionUUID->"d8f7ddd2-666b-4b1a-b13c-8fe7567bb19d"],

Cell[BoxData[
 RowBox[{"checksizes", "[", "\"\<oct\>\"", "]"}]], "Input",
 CellLabel->
  "In[335]:=",ExpressionUUID->"d3977466-d916-42b9-b2ee-2fa2ffe2c061"],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{
    RowBox[{
     RowBox[{
      RowBox[{"checkptig", "[", "\"\<oct\>\"", "]"}], " ", "-", " ", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"{", 
         RowBox[{
          RowBox[{"2", "-", 
           RowBox[{"Sqrt", "[", "2", "]"}]}], ",", 
          RowBox[{
           RowBox[{"(", 
            RowBox[{"2", "/", "3"}], ")"}], 
           RowBox[{"(", 
            RowBox[{"3", "-", 
             RowBox[{"Sqrt", "[", "3", "]"}]}], ")"}]}], ",", 
          RowBox[{
           RowBox[{"(", 
            RowBox[{"2", "/", "3"}], ")"}], 
           RowBox[{"(", 
            RowBox[{"3", "-", 
             RowBox[{"Sqrt", "[", "6", "]"}]}], ")"}]}]}], "}"}], ",", 
        RowBox[{"{", 
         RowBox[{
          RowBox[{"{", 
           RowBox[{
            RowBox[{"1", "/", "2"}], ",", "0"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"2", "/", "3"}], ",", 
            RowBox[{"1", "/", 
             RowBox[{"Sqrt", "[", "3", "]"}]}]}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{"0", ",", 
            RowBox[{"1", "/", 
             RowBox[{"(", 
              RowBox[{"2", 
               RowBox[{"Sqrt", "[", "3", "]"}]}], ")"}]}]}], "}"}]}], "}"}]}],
        "}"}]}], " ", "//", " ", "Expand"}], " ", "//", " ", "Factor"}], " ", 
   "//", " ", "Flatten"}], " ", "//", " ", "Union"}]], "Input",
 CellLabel->
  "In[336]:=",ExpressionUUID->"5e57e84a-9891-4b11-bff2-dabda9aba623"],

Cell[BoxData[
 RowBox[{"checksizes", "[", "\"\<ico\>\"", "]"}]], "Input",
 CellLabel->
  "In[337]:=",ExpressionUUID->"9cfb1a89-ec3d-43b3-958d-fc9dae1a7416"],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{
    RowBox[{
     RowBox[{
      RowBox[{"checkptig", "[", "\"\<ico\>\"", "]"}], " ", "-", " ", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"{", 
         RowBox[{
          RowBox[{"2", 
           RowBox[{"(", 
            RowBox[{"1", "-", 
             RowBox[{
              RowBox[{"Sqrt", "[", 
               RowBox[{"5", "+", 
                RowBox[{"Sqrt", "[", "5", "]"}]}], "]"}], "/", 
              RowBox[{"Sqrt", "[", "10", "]"}]}]}], ")"}]}], ",", 
          RowBox[{"2", 
           RowBox[{"(", 
            RowBox[{"1", "-", 
             RowBox[{
              RowBox[{"Sqrt", "[", 
               RowBox[{"5", "+", 
                RowBox[{"2", 
                 RowBox[{"Sqrt", "[", "5", "]"}]}]}], "]"}], "/", 
              RowBox[{"Sqrt", "[", "15", "]"}]}]}], ")"}]}], ",", 
          RowBox[{"2", "-", 
           RowBox[{
            RowBox[{"(", 
             RowBox[{
              RowBox[{"Sqrt", "[", "5", "]"}], "+", "1"}], ")"}], "/", 
            RowBox[{"Sqrt", "[", "3", "]"}]}]}]}], "}"}], ",", 
        RowBox[{"{", 
         RowBox[{
          RowBox[{"{", 
           RowBox[{
            RowBox[{
             RowBox[{"Sqrt", "[", 
              RowBox[{"5", "-", 
               RowBox[{"Sqrt", "[", "5", "]"}]}], "]"}], "/", 
             RowBox[{"(", 
              RowBox[{"2", 
               RowBox[{"Sqrt", "[", "10", "]"}]}], ")"}]}], ",", "0"}], "}"}],
           ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{
             RowBox[{"(", 
              RowBox[{
               RowBox[{"Sqrt", "[", "2", "]"}], "*", 
               RowBox[{"Sqrt", "[", 
                RowBox[{"5", "-", 
                 RowBox[{"Sqrt", "[", "5", "]"}]}], "]"}]}], ")"}], "/", 
             RowBox[{"(", 
              RowBox[{"3", 
               RowBox[{"Sqrt", "[", "5", "]"}]}], ")"}]}], ",", 
            RowBox[{
             RowBox[{"(", 
              RowBox[{"5", "-", 
               RowBox[{"Sqrt", "[", "5", "]"}]}], ")"}], "/", 
             RowBox[{"(", 
              RowBox[{"5", 
               RowBox[{"Sqrt", "[", "3", "]"}]}], ")"}]}]}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{"0", ",", 
            RowBox[{
             RowBox[{"(", 
              RowBox[{"3", "-", 
               RowBox[{"Sqrt", "[", "5", "]"}]}], ")"}], "/", 
             RowBox[{"(", 
              RowBox[{"4", 
               RowBox[{"Sqrt", "[", "3", "]"}]}], ")"}]}]}], "}"}]}], "}"}]}],
        "}"}]}], " ", "//", " ", "N"}], " ", "//", " ", "Chop"}], " ", "//", 
   " ", "Flatten"}], " ", "//", " ", "Union"}]], "Input",
 CellLabel->
  "In[338]:=",ExpressionUUID->"29e98ef1-ed32-4343-9ed9-224751208ad9"],

Cell[BoxData[
 RowBox[{"(*", " ", 
  RowBox[{"Make", " ", "rhombus", " ", "faces", " ", "and", " ", "edges"}], 
  " ", "*)"}]], "Input",
 CellLabel->
  "In[339]:=",ExpressionUUID->"87208056-f78e-4a46-8d00-dca3b51765a6"],

Cell[BoxData[
 RowBox[{
  RowBox[{"makerhombfaces", "[", "t_", "]"}], " ", ":=", " ", 
  RowBox[{"Module", "[", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{"ned", ",", "v1", ",", "v2", ",", "f1", ",", "f2"}], "}"}], ",", 
    "\[IndentingNewLine]", 
    RowBox[{
     RowBox[{"ned", " ", "=", " ", 
      RowBox[{"Length", "[", 
       RowBox[{"pts", "[", 
        RowBox[{"t", ",", "\"\<eds\>\""}], "]"}], "]"}]}], ";", 
     "\[IndentingNewLine]", 
     RowBox[{"Table", "[", 
      RowBox[{
       RowBox[{
        RowBox[{
         RowBox[{"{", 
          RowBox[{"v1", ",", "v2"}], "}"}], " ", "=", " ", 
         RowBox[{
          RowBox[{"igrf", "[", 
           RowBox[{"t", ",", "\"\<eds\>\"", ",", "\"\<vts\>\""}], "]"}], "[", 
          
          RowBox[{"[", "k", "]"}], "]"}]}], ";", "\[IndentingNewLine]", 
        RowBox[{
         RowBox[{"{", 
          RowBox[{"f1", ",", "f2"}], "}"}], " ", "=", " ", 
         RowBox[{
          RowBox[{"igrf", "[", 
           RowBox[{"t", ",", "\"\<eds\>\"", ",", "\"\<fcs\>\""}], "]"}], "[", 
          
          RowBox[{"[", "k", "]"}], "]"}]}], ";", "\[IndentingNewLine]", 
        RowBox[{"If", "[", 
         RowBox[{
          RowBox[{
           RowBox[{
            RowBox[{"Cross", "[", 
             RowBox[{
              RowBox[{
               RowBox[{"pts", "[", 
                RowBox[{"t", ",", "\"\<vts\>\""}], "]"}], "[", 
               RowBox[{"[", "v1", "]"}], "]"}], ",", 
              RowBox[{
               RowBox[{"pts", "[", 
                RowBox[{"t", ",", "\"\<fcs\>\""}], "]"}], "[", 
               RowBox[{"[", "f1", "]"}], "]"}]}], "]"}], ".", 
            RowBox[{
             RowBox[{"pts", "[", 
              RowBox[{"t", ",", "\"\<eds\>\""}], "]"}], "[", 
             RowBox[{"[", "k", "]"}], "]"}]}], " ", "<", " ", "0"}], ",", 
          "\[IndentingNewLine]", 
          RowBox[{
           RowBox[{"{", 
            RowBox[{"f1", ",", "f2"}], "}"}], " ", "=", " ", 
           RowBox[{"{", 
            RowBox[{"f2", ",", "f1"}], "}"}]}]}], "]"}], ";", 
        "\[IndentingNewLine]", 
        RowBox[{"{", 
         RowBox[{"v1", ",", "f1", ",", "v2", ",", "f2"}], "}"}]}], ",", 
       RowBox[{"{", 
        RowBox[{"k", ",", "ned"}], "}"}]}], "]"}]}]}], "\[IndentingNewLine]", 
   "]"}]}]], "Input",
 CellLabel->
  "In[340]:=",ExpressionUUID->"270a0514-fb4f-4644-a99b-d069c507cbdf"],

Cell[BoxData[
 RowBox[{
  RowBox[{"makerhombedges", "[", "t_", "]"}], " ", ":=", " ", 
  RowBox[{"Module", "[", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{"rfcs", ",", "rfex", ",", "eds", ",", "edlbl"}], "}"}], ",", 
    "\[IndentingNewLine]", 
    RowBox[{
     RowBox[{"rfcs", " ", "=", " ", 
      RowBox[{"makerhombfaces", "[", "t", "]"}]}], ";", "\[IndentingNewLine]", 
     RowBox[{"rfex", " ", "=", " ", 
      RowBox[{
       RowBox[{
        RowBox[{"{", 
         RowBox[{
          RowBox[{"{", 
           RowBox[{
            RowBox[{"#", "[", 
             RowBox[{"[", "1", "]"}], "]"}], ",", 
            RowBox[{"#", "[", 
             RowBox[{"[", "2", "]"}], "]"}]}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"#", "[", 
             RowBox[{"[", "3", "]"}], "]"}], ",", 
            RowBox[{"#", "[", 
             RowBox[{"[", "2", "]"}], "]"}]}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"#", "[", 
             RowBox[{"[", "3", "]"}], "]"}], ",", 
            RowBox[{"#", "[", 
             RowBox[{"[", "4", "]"}], "]"}]}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"#", "[", 
             RowBox[{"[", "1", "]"}], "]"}], ",", 
            RowBox[{"#", "[", 
             RowBox[{"[", "4", "]"}], "]"}]}], "}"}]}], "}"}], "&"}], " ", "/@",
        " ", "rfcs"}]}], ";", "\[IndentingNewLine]", 
     RowBox[{"eds", " ", "=", " ", 
      RowBox[{"Union", " ", "@@", " ", "rfex"}]}], ";", "\[IndentingNewLine]", 
     RowBox[{"Do", "[", 
      RowBox[{
       RowBox[{
        RowBox[{"edlbl", "[", 
         RowBox[{"eds", "[", 
          RowBox[{"[", "k", "]"}], "]"}], "]"}], " ", "=", " ", "k"}], ",", 
       RowBox[{"{", 
        RowBox[{"k", ",", 
         RowBox[{"Length", "[", "eds", "]"}]}], "}"}]}], "]"}], ";", 
     "\[IndentingNewLine]", 
     RowBox[{"{", 
      RowBox[{"rfcs", ",", "eds", ",", 
       RowBox[{"Map", "[", 
        RowBox[{"edlbl", ",", "rfex", ",", 
         RowBox[{"{", "2", "}"}]}], "]"}]}], "}"}]}]}], "\[IndentingNewLine]",
    "]"}]}]], "Input",
 CellLabel->
  "In[341]:=",ExpressionUUID->"0e5fba0e-b4f3-4818-b476-08c4ef405ebc"]
}, Closed]],

Cell[CellGroupData[{

Cell["Distinct Vertices and Edges for Faces", "Section",ExpressionUUID->"7de1dbd8-6e8b-4eb9-b080-e13b185f449a"],

Cell[BoxData[
 RowBox[{"(*", " ", 
  RowBox[{
   RowBox[{"bdixs", ":", " ", 
    RowBox[{"each", " ", 
     RowBox[{"face", "'"}], "s", " ", "boundary", " ", "positions"}]}], ",", 
   " ", 
   RowBox[{"integers", " ", "from", " ", "1", " ", "to", " ", "some", " ", 
    RowBox[{"number", ".", "\[IndentingNewLine]", 
     RowBox[{"fcbdlst", ":", " ", 
      RowBox[{
      "list", " ", "of", " ", "all", " ", "sets", " ", "of", " ", "labels", 
       " ", "of", " ", "boundary", " ", 
       RowBox[{"positions", ".", " ", "\[IndentingNewLine]", "Done"}], " ", 
       "this", " ", "way", " ", "to", " ", "allow", " ", "reduced", " ", 
       "symmetry"}]}]}]}], ",", " ", 
   RowBox[{"like", " ", "for", " ", 
    RowBox[{"rhombuses", "."}]}]}], "\[IndentingNewLine]", "*)"}]], "Input",
 CellLabel->
  "In[342]:=",ExpressionUUID->"15d4128d-8257-4cd5-8f47-1ff1149ae662"],

Cell[BoxData[
 RowBox[{
  RowBox[{"FindBdryLbls", "[", 
   RowBox[{"bdixs_", ",", "fcbdlst_"}], "]"}], " ", ":=", " ", 
  RowBox[{"Module", "[", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{
     "nfcs", ",", "nbdfcs", ",", "nbds", ",", "fcix", ",", "bdix", ",", 
      "bdpres", ",", "bdvals", ",", "ix", ",", "bxs", ",", "lbls", ",", 
      "lblslst", ",", "bifc", ",", "prfc", ",", "vlfc", ",", "vlfcpres", ",", 
      "fbdxpres", ",", "fbxp", ",", "nwbdpres", ",", "nwbdvals", ",", "res", 
      ",", "dontuse", ",", "cmplt"}], "}"}], ",", "\[IndentingNewLine]", 
    RowBox[{"(*", " ", "Dimensions", " ", "*)"}], "\[IndentingNewLine]", 
    RowBox[{
     RowBox[{
      RowBox[{"{", 
       RowBox[{"nfcs", ",", "nbdfcs"}], "}"}], " ", "=", " ", 
      RowBox[{"Dimensions", "[", "bdixs", "]"}]}], ";", "\[IndentingNewLine]", 
     RowBox[{"nbds", " ", "=", " ", 
      RowBox[{"Max", "[", 
       RowBox[{"Flatten", "[", "bdixs", "]"}], "]"}]}], ";", 
     "\[IndentingNewLine]", 
     RowBox[{"(*", " ", 
      RowBox[{
       RowBox[{"Label", " ", "data", " ", "structure"}], ",", " ", 
       RowBox[{
       "for", " ", "speeding", " ", "up", " ", "and", " ", "convenience"}]}], 
      " ", "*)"}], "\[IndentingNewLine]", 
     RowBox[{"bdpres", " ", "=", " ", 
      RowBox[{"ConstantArray", "[", 
       RowBox[{"False", ",", "nbds"}], "]"}]}], ";", "\[IndentingNewLine]", 
     RowBox[{"bdvals", " ", "=", " ", 
      RowBox[{"ConstantArray", "[", 
       RowBox[{"Null", ",", "nbds"}], "]"}]}], ";", "\[IndentingNewLine]", 
     RowBox[{"(*", " ", 
      RowBox[{"Initial", " ", "labeling"}], " ", "*)"}], 
     "\[IndentingNewLine]", 
     RowBox[{"fcix", " ", "=", " ", "1"}], ";", "\[IndentingNewLine]", 
     RowBox[{"bxs", " ", "=", " ", 
      RowBox[{"bdixs", "[", 
       RowBox[{"[", "fcix", "]"}], "]"}]}], ";", "\[IndentingNewLine]", 
     RowBox[{
      RowBox[{"bdpres", "[", 
       RowBox[{"[", "bxs", "]"}], "]"}], " ", "=", " ", 
      RowBox[{"ConstantArray", "[", 
       RowBox[{"True", ",", "nbdfcs"}], "]"}]}], ";", "\[IndentingNewLine]", 
     RowBox[{
      RowBox[{"bdvals", "[", 
       RowBox[{"[", "bxs", "]"}], "]"}], " ", "=", " ", 
      RowBox[{"First", "[", "fcbdlst", "]"}]}], ";", "\[IndentingNewLine]", 
     RowBox[{"(*", " ", 
      RowBox[{
       RowBox[{"Data", " ", 
        RowBox[{"format", ":", " ", 
         RowBox[{"which", " ", "faces", " ", "are", " ", "filled"}]}]}], ",", 
       " ", 
       RowBox[{"which", " ", "boundaries", " ", "have", " ", "labels"}], ",", 
       " ", 
       RowBox[{"labels", " ", "of", " ", "boundaries"}]}], " ", "*)"}], 
     "\[IndentingNewLine]", 
     RowBox[{"lbls", " ", "=", " ", 
      RowBox[{"{", 
       RowBox[{"fcix", ",", "bdpres", ",", "bdvals"}], "}"}]}], ";", 
     "\[IndentingNewLine]", 
     RowBox[{"(*", " ", 
      RowBox[{"Only", " ", "one", " ", "of", " ", "them"}], " ", "*)"}], 
     "\[IndentingNewLine]", 
     RowBox[{"lblslst", " ", "=", " ", 
      RowBox[{"{", "lbls", "}"}]}], ";", "\[IndentingNewLine]", 
     RowBox[{"(*", " ", 
      RowBox[{"Fill", " ", "out"}], " ", "*)"}], "\[IndentingNewLine]", 
     RowBox[{"cmplt", " ", "=", " ", 
      RowBox[{"{", "}"}]}], ";", "\[IndentingNewLine]", 
     RowBox[{"While", "[", 
      RowBox[{"True", ",", "\[IndentingNewLine]", 
       RowBox[{
        RowBox[{"res", " ", "=", " ", 
         RowBox[{"Reap", "[", "\[IndentingNewLine]", 
          RowBox[{"Do", "[", "\[IndentingNewLine]", 
           RowBox[{
            RowBox[{
             RowBox[{
              RowBox[{"{", 
               RowBox[{"fcix", ",", "bdpres", ",", "bdvals"}], "}"}], " ", 
              "=", " ", "lbls"}], ";", "\[IndentingNewLine]", 
             RowBox[{"dontuse", " ", "=", " ", "False"}], ";", 
             "\[IndentingNewLine]", 
             RowBox[{"While", "[", 
              RowBox[{"True", ",", "\[IndentingNewLine]", 
               RowBox[{
                RowBox[{"fcix", "++"}], ";", "\[IndentingNewLine]", 
                RowBox[{"(*", " ", 
                 RowBox[{"Complete", "?"}], " ", "*)"}], 
                "\[IndentingNewLine]", 
                RowBox[{"If", "[", 
                 RowBox[{
                  RowBox[{"fcix", " ", ">", " ", "nfcs"}], ",", 
                  "\[IndentingNewLine]", 
                  RowBox[{
                   RowBox[{"AppendTo", "[", 
                    RowBox[{"cmplt", ",", "bdvals"}], "]"}], ";", 
                   "\[IndentingNewLine]", 
                   RowBox[{"dontuse", " ", "=", " ", "True"}], ";", 
                   "\[IndentingNewLine]", 
                   RowBox[{"Break", "[", "]"}], ";"}]}], 
                 "\[IndentingNewLine]", "]"}], ";", "\[IndentingNewLine]", 
                RowBox[{"(*", " ", 
                 RowBox[{"Is", " ", "the", " ", "face", " ", 
                  RowBox[{"filled", "?", " ", "Filled"}], " ", 
                  RowBox[{"correctly", "?"}]}], " ", "*)"}], 
                "\[IndentingNewLine]", 
                RowBox[{"bifc", " ", "=", " ", 
                 RowBox[{"bdixs", "[", 
                  RowBox[{"[", "fcix", "]"}], "]"}]}], ";", 
                "\[IndentingNewLine]", 
                RowBox[{"prfc", " ", "=", " ", 
                 RowBox[{"bdpres", "[", 
                  RowBox[{"[", "bifc", "]"}], "]"}]}], ";", 
                "\[IndentingNewLine]", 
                RowBox[{"vlfc", " ", "=", " ", 
                 RowBox[{"bdvals", "[", 
                  RowBox[{"[", "bifc", "]"}], "]"}]}], ";", 
                "\[IndentingNewLine]", 
                RowBox[{"If", "[", 
                 RowBox[{
                  RowBox[{"And", " ", "@@", " ", "prfc"}], ",", 
                  "\[IndentingNewLine]", 
                  RowBox[{"If", "[", 
                   RowBox[{
                    RowBox[{"MemberQ", "[", 
                    RowBox[{"fcbdlst", ",", "vlfc"}], "]"}], ",", 
                    "\[IndentingNewLine]", 
                    RowBox[{"Continue", "[", "]"}], ",", 
                    "\[IndentingNewLine]", 
                    RowBox[{
                    RowBox[{"dontuse", " ", "=", " ", "True"}], ";", 
                    "\[IndentingNewLine]", 
                    RowBox[{"Break", "[", "]"}]}]}], "\[IndentingNewLine]", 
                   "]"}], ",", "\[IndentingNewLine]", 
                  RowBox[{"(*", " ", 
                   RowBox[{"Not", " ", 
                    RowBox[{"filled", ".", " ", "Continue"}], " ", "with", 
                    " ", "filling", " ", "in"}], " ", "*)"}], 
                  "\[IndentingNewLine]", 
                  RowBox[{
                   RowBox[{"dontuse", " ", "=", " ", "False"}], ";", 
                   "\[IndentingNewLine]", 
                   RowBox[{"Break", "[", "]"}]}]}], "\[IndentingNewLine]", 
                 "]"}]}]}], "\[IndentingNewLine]", "]"}], ";", 
             "\[IndentingNewLine]", 
             RowBox[{"(*", " ", 
              RowBox[{
               RowBox[{
               "If", " ", "all", " ", "full", " ", "or", " ", "a", " ", 
                "face", " ", "not", " ", "valid"}], ",", " ", 
               RowBox[{
               "then", " ", "go", " ", "to", " ", "the", " ", "next", " ", 
                "one"}]}], " ", "*)"}], "\[IndentingNewLine]", 
             RowBox[{"If", "[", 
              RowBox[{"dontuse", ",", 
               RowBox[{"Continue", "[", "]"}]}], "]"}], ";", 
             "\[IndentingNewLine]", 
             RowBox[{"(*", " ", 
              RowBox[{
               RowBox[{
               "Find", " ", "all", " ", "valid", " ", "fillings", " ", "of", 
                " ", 
                RowBox[{"faces", ".", " ", "If"}], " ", "none"}], ",", " ", 
               RowBox[{
               "then", " ", "go", " ", "to", " ", "the", " ", "next", " ", 
                "one"}]}], " ", "*)"}], "\[IndentingNewLine]", 
             RowBox[{"vlfcpres", " ", "=", " ", 
              RowBox[{"Pick", "[", 
               RowBox[{"vlfc", ",", "prfc"}], "]"}]}], ";", 
             "\[IndentingNewLine]", 
             RowBox[{"fbdxpres", " ", "=", " ", 
              RowBox[{"Select", "[", 
               RowBox[{"fcbdlst", ",", 
                RowBox[{
                 RowBox[{
                  RowBox[{"Pick", "[", 
                   RowBox[{"#", ",", "prfc"}], "]"}], " ", "===", " ", 
                  "vlfcpres"}], "&"}]}], "]"}]}], ";", "\[IndentingNewLine]", 
             
             RowBox[{"If", "[", 
              RowBox[{
               RowBox[{
                RowBox[{"Length", "[", "fbdxpres", "]"}], "\[Equal]", "0"}], 
               ",", 
               RowBox[{"Continue", "[", "]"}]}], "]"}], ";", 
             "\[IndentingNewLine]", 
             RowBox[{"(*", " ", 
              RowBox[{
              "Fill", " ", "in", " ", "for", " ", "the", " ", "next", " ", 
               "pass"}], " ", "*)"}], "\[IndentingNewLine]", 
             RowBox[{"Do", "[", "\[IndentingNewLine]", 
              RowBox[{
               RowBox[{
                RowBox[{"nwbdpres", " ", "=", " ", "bdpres"}], ";", 
                "\[IndentingNewLine]", 
                RowBox[{"nwbdvals", " ", "=", " ", "bdvals"}], ";", 
                "\[IndentingNewLine]", 
                RowBox[{
                 RowBox[{"nwbdpres", "[", 
                  RowBox[{"[", "bifc", "]"}], "]"}], " ", "=", " ", 
                 RowBox[{"ConstantArray", "[", 
                  RowBox[{"True", ",", "nbdfcs"}], "]"}]}], ";", 
                "\[IndentingNewLine]", 
                RowBox[{
                 RowBox[{"nwbdvals", "[", 
                  RowBox[{"[", "bifc", "]"}], "]"}], " ", "=", " ", "fbxp"}], 
                ";", "\[IndentingNewLine]", 
                RowBox[{"Sow", "[", 
                 RowBox[{"{", 
                  RowBox[{"fcix", ",", "nwbdpres", ",", "nwbdvals"}], "}"}], 
                 "]"}]}], ",", "\[IndentingNewLine]", 
               RowBox[{"{", 
                RowBox[{"fbxp", ",", "fbdxpres"}], "}"}]}], "]"}]}], ",", 
            "\[IndentingNewLine]", 
            RowBox[{"{", 
             RowBox[{"lbls", ",", "lblslst"}], "}"}]}], "]"}], 
          "\[IndentingNewLine]", "]"}]}], ";", "\[IndentingNewLine]", 
        RowBox[{"(*", " ", 
         RowBox[{"Cannot", " ", "proceed", " ", 
          RowBox[{"further", " ", "--"}], " ", "all", " ", "done"}], " ", 
         "*)"}], "\[IndentingNewLine]", 
        RowBox[{"If", "[", 
         RowBox[{
          RowBox[{
           RowBox[{"Length", "[", 
            RowBox[{"res", "[", 
             RowBox[{"[", "2", "]"}], "]"}], "]"}], "\[Equal]", "0"}], ",", 
          RowBox[{"Break", "[", "]"}]}], "]"}], ";", "\[IndentingNewLine]", 
        RowBox[{"(*", " ", 
         RowBox[{"Next", " ", "iteration"}], " ", "*)"}], 
        "\[IndentingNewLine]", 
        RowBox[{"lblslst", " ", "=", " ", 
         RowBox[{"Union", "[", 
          RowBox[{"res", "[", 
           RowBox[{"[", 
            RowBox[{"2", ",", "1"}], "]"}], "]"}], "]"}]}], ";"}]}], 
      "\[IndentingNewLine]", "]"}], ";", "\[IndentingNewLine]", 
     RowBox[{"Union", "[", "cmplt", "]"}]}]}], "\[IndentingNewLine]", 
   "]"}]}]], "Input",
 CellLabel->
  "In[343]:=",ExpressionUUID->"d9efdf03-fd15-4fb4-81ff-15fb63aed852"],

Cell[BoxData[
 RowBox[{"(*", " ", 
  RowBox[{
  "Makes", " ", "all", " ", "rotations", " ", "and", " ", "reflections", " ", 
   "of", " ", "some", " ", "values"}], " ", "*)"}]], "Input",
 CellLabel->
  "In[344]:=",ExpressionUUID->"54762bc2-befa-433f-9c92-2fdeb01117e9"],

Cell[BoxData[
 RowBox[{
  RowBox[{"rotrfl", "[", "xlst_", "]"}], " ", ":=", " ", 
  RowBox[{"Module", "[", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{"xll", ",", "xrot", ",", "xrfl"}], "}"}], ",", 
    "\[IndentingNewLine]", 
    RowBox[{
     RowBox[{"xll", " ", "=", " ", 
      RowBox[{"Length", "[", "xlst", "]"}]}], ";", "\[IndentingNewLine]", 
     RowBox[{"xrot", " ", "=", "  ", 
      RowBox[{"NestList", "[", 
       RowBox[{"RotateLeft", ",", "xlst", ",", 
        RowBox[{"xll", "-", "1"}]}], "]"}]}], ";", "\[IndentingNewLine]", 
     RowBox[{"xrfl", " ", "=", " ", 
      RowBox[{"Reverse", " ", "/@", " ", "xrot"}]}], ";", 
     "\[IndentingNewLine]", 
     RowBox[{"Union", "[", 
      RowBox[{"xrot", ",", "xrfl"}], "]"}]}]}], "\[IndentingNewLine]", 
   "]"}]}]], "Input",
 CellLabel->
  "In[345]:=",ExpressionUUID->"043f095d-f0c9-4ad4-8c46-26eb5b064482"],

Cell[BoxData[
 RowBox[{"(*", " ", 
  RowBox[{
   RowBox[{"Skipped", " ", "version"}], ",", " ", 
   RowBox[{"for", " ", "the", " ", "rhombic", " ", "case"}]}], " ", 
  "*)"}]], "Input",
 CellLabel->
  "In[346]:=",ExpressionUUID->"7b004022-b549-45fa-ae34-42f12eec13fd"],

Cell[BoxData[
 RowBox[{
  RowBox[{"rotrfl", "[", 
   RowBox[{"xlst_", ",", "skip_", ",", 
    RowBox[{"rflphase_:", "0"}]}], "]"}], " ", ":=", " ", 
  RowBox[{"Module", "[", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{"xll", ",", "xrot", ",", "xrfl"}], "}"}], ",", 
    "\[IndentingNewLine]", 
    RowBox[{
     RowBox[{"xll", " ", "=", " ", 
      RowBox[{"Length", "[", "xlst", "]"}]}], ";", "\[IndentingNewLine]", 
     RowBox[{"xrot", " ", "=", "  ", 
      RowBox[{"NestList", "[", 
       RowBox[{
        RowBox[{
         RowBox[{"RotateLeft", "[", 
          RowBox[{"#", ",", "skip"}], "]"}], "&"}], ",", "xlst", ",", 
        RowBox[{"xll", "-", "1"}]}], "]"}]}], ";", "\[IndentingNewLine]", 
     RowBox[{"xrfl", " ", "=", " ", 
      RowBox[{
       RowBox[{
        RowBox[{"RotateLeft", "[", 
         RowBox[{"#", ",", "rflphase"}], "]"}], "&"}], " ", "/@", " ", 
       RowBox[{"(", 
        RowBox[{"Reverse", " ", "/@", " ", "xrot"}], ")"}]}]}], ";", 
     "\[IndentingNewLine]", 
     RowBox[{"Union", "[", 
      RowBox[{"xrot", ",", "xrfl"}], "]"}]}]}], "\[IndentingNewLine]", 
   "]"}]}]], "Input",
 CellLabel->
  "In[347]:=",ExpressionUUID->"0472c9be-82f3-4653-974f-8527c33044f7"],

Cell[BoxData[
 RowBox[{"rotrfl", "[", 
  RowBox[{"{", 
   RowBox[{"1", ",", "2", ",", "3", ",", "4"}], "}"}], "]"}]], "Input",
 CellLabel->
  "In[348]:=",ExpressionUUID->"e2308afb-b1b6-4e60-b9e4-438cfb05008b"],

Cell[BoxData[
 RowBox[{"rotrfl", "[", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{"1", ",", "2", ",", "3", ",", "4"}], "}"}], ",", "2"}], 
  "]"}]], "Input",
 CellLabel->
  "In[349]:=",ExpressionUUID->"f32fb43e-d6c6-4953-8ffa-00d12a7583e6"],

Cell[BoxData[
 RowBox[{"rotrfl", "[", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{"1", ",", "2", ",", "3", ",", "4"}], "}"}], ",", "2", ",", "1"}], 
  "]"}]], "Input",
 CellLabel->
  "In[350]:=",ExpressionUUID->"e6f16ce0-3678-4c6e-bf98-bfdcbc77459d"],

Cell[BoxData[
 RowBox[{
  RowBox[{"FindBdryLblsRR", "[", 
   RowBox[{"bdixs_", ",", "fbcd_"}], "]"}], " ", ":=", " ", 
  RowBox[{"FindBdryLbls", "[", 
   RowBox[{"bdixs", ",", 
    RowBox[{"rotrfl", "[", "fbcd", "]"}]}], "]"}]}]], "Input",
 CellLabel->
  "In[351]:=",ExpressionUUID->"b5c3c762-2df6-4fb9-9473-87fbc12c2209"]
}, Closed]],

Cell[CellGroupData[{

Cell["Extra Solutions", "Section",ExpressionUUID->"fc964487-100d-4d87-881f-73c05b18395d"],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"verts", "[", "\"\<tetalt\>\"", "]"}], " ", "=", " ", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"1", ",", "1", ",", "1"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"1", ",", 
       RowBox[{"-", "1"}], ",", 
       RowBox[{"-", "1"}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"-", "1"}], ",", "1", ",", 
       RowBox[{"-", "1"}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"-", "1"}], ",", 
       RowBox[{"-", "1"}], ",", "1"}], "}"}]}], "}"}]}], ";"}]], "Input",
 CellLabel->
  "In[352]:=",ExpressionUUID->"6fa3e87c-af0a-49ea-bd74-35c7adb9cc3c"],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"verts", "[", "\"\<octbase\>\"", "]"}], " ", "=", " ", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"0", ",", "0", ",", "1"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"1", ",", "0", ",", "0"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"0", ",", "1", ",", "0"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"0", ",", 
       RowBox[{"-", "1"}], ",", "0"}], "}"}]}], "}"}]}], ";"}]], "Input",
 CellLabel->
  "In[353]:=",ExpressionUUID->"7c3b5c2a-60ff-4b9e-8c5d-29b667a2422a"],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"verts", "[", "\"\<obfaces\>\"", "]"}], " ", "=", " ", 
   RowBox[{
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{"Mean", "[", 
        RowBox[{"#", "[", 
         RowBox[{"[", 
          RowBox[{"{", 
           RowBox[{"1", ",", "2", ",", "3"}], "}"}], "]"}], "]"}], "]"}], ",", 
       RowBox[{"Mean", "[", 
        RowBox[{"#", "[", 
         RowBox[{"[", 
          RowBox[{"{", 
           RowBox[{"1", ",", "2", ",", "4"}], "}"}], "]"}], "]"}], "]"}]}], 
      "}"}], "&"}], " ", "@", " ", 
    RowBox[{"verts", "[", "\"\<octbase\>\"", "]"}]}]}], ";"}]], "Input",
 CellLabel->
  "In[354]:=",ExpressionUUID->"1dbf0db0-a241-4abb-a050-373e88825558"],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"verts", "[", "\"\<cubalt\>\"", "]"}], " ", "=", " ", 
   RowBox[{
    RowBox[{"Sqrt", "[", "3", "]"}], "*", 
    RowBox[{"pts", "[", 
     RowBox[{"\"\<oct\>\"", ",", "\"\<fcs\>\""}], "]"}]}]}], ";"}]], "Input",
 CellLabel->
  "In[355]:=",ExpressionUUID->"55104476-0caf-4b92-b046-a8177ba50577"],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"verts", "[", "\"\<tetalt\>\"", "]"}], "-", 
   RowBox[{
    RowBox[{"Sqrt", "[", "3", "]"}], "*", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{
       RowBox[{"(", 
        RowBox[{
         RowBox[{"{", 
          RowBox[{
           RowBox[{"{", 
            RowBox[{
             RowBox[{
              RowBox[{"Sqrt", "[", "2", "]"}], "/", 
              RowBox[{"Sqrt", "[", "3", "]"}]}], ",", "0", ",", 
             RowBox[{"1", "/", 
              RowBox[{"Sqrt", "[", "3", "]"}]}]}], "}"}], ",", 
           RowBox[{"{", 
            RowBox[{
             RowBox[{
              RowBox[{"-", "1"}], "/", 
              RowBox[{"Sqrt", "[", "6", "]"}]}], ",", 
             RowBox[{"1", "/", 
              RowBox[{"Sqrt", "[", "2", "]"}]}], ",", 
             RowBox[{"1", "/", 
              RowBox[{"Sqrt", "[", "3", "]"}]}]}], "}"}], ",", 
           RowBox[{"{", 
            RowBox[{
             RowBox[{
              RowBox[{"-", "1"}], "/", 
              RowBox[{"Sqrt", "[", "6", "]"}]}], ",", 
             RowBox[{
              RowBox[{"-", "1"}], "/", 
              RowBox[{"Sqrt", "[", "2", "]"}]}], ",", 
             RowBox[{"1", "/", 
              RowBox[{"Sqrt", "[", "3", "]"}]}]}], "}"}]}], "}"}], ".", "#"}],
         ")"}], "&"}], " ", "/@", " ", 
      RowBox[{"pts", "[", 
       RowBox[{"\"\<tet\>\"", ",", "\"\<vts\>\""}], "]"}]}], ")"}]}]}], " ", "//",
   " ", "Expand"}]], "Input",
 CellLabel->
  "In[356]:=",ExpressionUUID->"8560d2c6-b491-4db1-b8e5-04158f4c4ecd"],

Cell[BoxData[
 RowBox[{
  RowBox[{"planarity", "[", "pts_", "]"}], " ", ":=", " ", 
  RowBox[{"Det", " ", "/@", " ", 
   RowBox[{"Partition", "[", 
    RowBox[{
     RowBox[{
      RowBox[{
       RowBox[{"(", 
        RowBox[{"#", " ", "-", " ", 
         RowBox[{"First", "[", "pts", "]"}]}], ")"}], "&"}], " ", "/@", " ", 
      RowBox[{"Rest", "[", "pts", "]"}]}], ",", "3", ",", "1"}], 
    "]"}]}]}]], "Input",
 CellLabel->
  "In[357]:=",ExpressionUUID->"2e97fe63-6eee-443c-abb8-cc9c21eb5a1a"],

Cell[BoxData[
 RowBox[{
  RowBox[{"vtlens", "[", "pts_", "]"}], " ", ":=", " ", 
  RowBox[{"abssqr", " ", "/@", " ", "pts"}]}]], "Input",
 CellLabel->
  "In[358]:=",ExpressionUUID->"4412cd2f-e6f1-44ea-8b89-3d66f729cc6b"],

Cell[BoxData[
 RowBox[{
  RowBox[{"edlens", "[", "pts_", "]"}], " ", ":=", " ", 
  RowBox[{"abssqr", " ", "/@", " ", 
   RowBox[{"(", 
    RowBox[{
     RowBox[{"RotateLeft", "[", "pts", "]"}], " ", "-", " ", "pts"}], 
    ")"}]}]}]], "Input",
 CellLabel->
  "In[359]:=",ExpressionUUID->"24591010-30f3-4a27-936b-8df252698288"],

Cell[BoxData[
 RowBox[{
  RowBox[{"csang", "[", "pts_", "]"}], " ", ":=", " ", 
  RowBox[{"Module", "[", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{"p1", ",", "p2", ",", "p3", ",", "p21", ",", "p23"}], "}"}], ",",
     "\[IndentingNewLine]", 
    RowBox[{
     RowBox[{
      RowBox[{"{", 
       RowBox[{"p1", ",", "p2", ",", "p3"}], "}"}], " ", "=", " ", "pts"}], 
     ";", "\[IndentingNewLine]", 
     RowBox[{"p21", " ", "=", " ", 
      RowBox[{"p2", " ", "-", " ", "p1"}]}], ";", " ", 
     RowBox[{"p23", " ", "=", " ", 
      RowBox[{"p2", " ", "-", " ", "p3"}]}], ";", "\[IndentingNewLine]", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{"p21", ".", "p23"}], ")"}], "/", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{"Sqrt", "[", 
         RowBox[{"abssqr", "[", "p21", "]"}], "]"}], "*", 
        RowBox[{"Sqrt", "[", 
         RowBox[{"abssqr", "[", "p23", "]"}], "]"}]}], ")"}]}]}]}], 
   "\[IndentingNewLine]", "]"}]}]], "Input",
 CellLabel->
  "In[360]:=",ExpressionUUID->"20e62bfa-e295-4dd7-b18b-76436a6057f0"],

Cell[BoxData[
 RowBox[{
  RowBox[{"vtcsangs", "[", "pts_", "]"}], " ", ":=", " ", 
  RowBox[{"csang", " ", "/@", " ", 
   RowBox[{"Transpose", "[", 
    RowBox[{"{", 
     RowBox[{
      RowBox[{"RotateRight", "[", "pts", "]"}], ",", "pts", ",", 
      RowBox[{"RotateLeft", "[", "pts", "]"}]}], "}"}], "]"}]}]}]], "Input",
 CellLabel->
  "In[361]:=",ExpressionUUID->"835efbe3-42ff-45dd-85d5-9f2d1581aa2e"],

Cell[BoxData[
 RowBox[{"(*", " ", 
  RowBox[{"Cube", "-", 
   RowBox[{"vertex", " ", "/", " ", "octahedron"}], "-", 
   RowBox[{"face", " ", "parity", " ", "illustration"}]}], " ", 
  "*)"}]], "Input",
 CellLabel->
  "In[362]:=",ExpressionUUID->"98aaa63b-fb1e-4076-9564-4a43068e8d16"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"Graphics3D", "[", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{"PointSize", "[", "Large", "]"}], ",", 
       RowBox[{
        RowBox[{
         RowBox[{"{", 
          RowBox[{
           RowBox[{"If", "[", 
            RowBox[{
             RowBox[{
              RowBox[{"(", 
               RowBox[{"Times", " ", "@@", " ", "#"}], ")"}], 
              "\[GreaterEqual]", "0"}], ",", "Red", ",", "Blue"}], "]"}], ",", 
           RowBox[{"Point", "[", "#", "]"}]}], "}"}], "&"}], " ", "/@", " ", 
        RowBox[{"Tuples", "[", 
         RowBox[{
          RowBox[{"{", 
           RowBox[{
            RowBox[{"-", "1"}], ",", "1"}], "}"}], ",", "3"}], "]"}]}]}], 
      "}"}], ",", 
     RowBox[{"SphericalRegion", "\[Rule]", "True"}]}], "]"}], ",", 
   RowBox[{"Graphics3D", "[", 
    RowBox[{
     RowBox[{"GraphicsComplex", "[", 
      RowBox[{
       RowBox[{"pts", "[", 
        RowBox[{"\"\<oct\>\"", ",", "\"\<vts\>\""}], "]"}], ",", 
       RowBox[{"Transpose", "[", 
        RowBox[{"{", 
         RowBox[{
          RowBox[{"{", 
           RowBox[{
           "Red", ",", "Blue", ",", "Red", ",", "Blue", ",", "Blue", ",", 
            "Red", ",", "Blue", ",", "Red"}], "}"}], ",", 
          RowBox[{"Polygon", " ", "/@", " ", 
           RowBox[{"igrf", "[", 
            RowBox[{"\"\<oct\>\"", ",", "\"\<fcs\>\"", ",", "\"\<vts\>\""}], 
            "]"}]}]}], "}"}], "]"}]}], "]"}], ",", 
     RowBox[{"SphericalRegion", "\[Rule]", "True"}]}], "]"}]}], 
  "}"}]], "Input",
 CellLabel->
  "In[363]:=",ExpressionUUID->"bdb42a26-bf57-4b2f-a0a8-25f7117dedc0"],

Cell[CellGroupData[{

Cell["Scalene Tetrahedron - arbitrary-shape triangles", "Subsection",ExpressionUUID->"98f5c1d7-266f-4f01-91cd-81ce9479cc2c"],

Cell[BoxData[
 RowBox[{
  RowBox[{"dists", "[", 
   RowBox[{"pt_", ",", "edinc_"}], "]"}], " ", ":=", " ", 
  RowBox[{"Table", "[", 
   RowBox[{
    RowBox[{"abssqr", "[", 
     RowBox[{
      RowBox[{"pt", "[", 
       RowBox[{"[", 
        RowBox[{"ed", "[", 
         RowBox[{"[", "1", "]"}], "]"}], "]"}], "]"}], "-", 
      RowBox[{"pt", "[", 
       RowBox[{"[", 
        RowBox[{"ed", "[", 
         RowBox[{"[", "2", "]"}], "]"}], "]"}], "]"}]}], "]"}], ",", 
    RowBox[{"{", 
     RowBox[{"ed", ",", "edinc"}], "}"}]}], "]"}]}]], "Input",
 CellLabel->
  "In[364]:=",ExpressionUUID->"a6d7ca0f-1304-4f5b-bc89-0ddcea24563d"],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"verts", "[", "\"\<scaltet\>\"", "]"}], " ", "=", " ", 
   RowBox[{
    RowBox[{
     RowBox[{
      RowBox[{"{", 
       RowBox[{"c1", ",", "c2", ",", "c3"}], "}"}], "*", "#"}], "&"}], " ", "/@",
     " ", 
    RowBox[{"verts", "[", "\"\<tetalt\>\"", "]"}]}]}], ";"}]], "Input",
 CellLabel->
  "In[365]:=",ExpressionUUID->"2be0205a-2fce-42f6-833b-01121f941c2c"],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"dists", "[", 
    RowBox[{
     RowBox[{"verts", "[", "\"\<scaltet\>\"", "]"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"1", ",", "2"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"1", ",", "3"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"1", ",", "4"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"2", ",", "3"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"2", ",", "4"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"3", ",", "4"}], "}"}]}], "}"}]}], "]"}], " ", "-", " ", 
   RowBox[{"4", 
    RowBox[{"{", 
     RowBox[{
      RowBox[{
       RowBox[{"c2", "^", "2"}], "+", 
       RowBox[{"c3", "^", "2"}]}], ",", 
      RowBox[{
       RowBox[{"c1", "^", "2"}], "+", 
       RowBox[{"c3", "^", "2"}]}], ",", 
      RowBox[{
       RowBox[{"c1", "^", "2"}], "+", 
       RowBox[{"c2", "^", "2"}]}], ",", 
      RowBox[{
       RowBox[{"c1", "^", "2"}], "+", 
       RowBox[{"c2", "^", "2"}]}], ",", 
      RowBox[{
       RowBox[{"c1", "^", "2"}], "+", 
       RowBox[{"c3", "^", "2"}]}], ",", 
      RowBox[{
       RowBox[{"c2", "^", "2"}], "+", 
       RowBox[{"c3", "^", "2"}]}]}], "}"}]}]}], " ", "//", " ", 
  "Factor"}]], "Input",
 CellLabel->
  "In[366]:=",ExpressionUUID->"5c7e8f61-b9d1-4017-895c-82ddf2549849"]
}, Closed]],

Cell[CellGroupData[{

Cell["Pentagonal Dodecahedron- pentagons on tetrahedron", "Subsection",ExpressionUUID->"300eebda-cd04-4aeb-9c53-e0550029252e"],

Cell[BoxData[
 RowBox[{
  RowBox[{"tetpent", "[", "cx_", "]"}], ":=", " ", 
  RowBox[{"Module", "[", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{
     "c01", ",", "c02", ",", "c11", ",", "c12", ",", "c13", ",", "p1", ",", 
      "p2", ",", "p3", ",", "p4", ",", "pf"}], "}"}], ",", 
    "\[IndentingNewLine]", 
    RowBox[{
     RowBox[{
      RowBox[{"{", 
       RowBox[{"c01", ",", "c02", ",", "c11", ",", "c12", ",", "c13"}], "}"}],
       " ", "=", " ", "cx"}], ";", "\[IndentingNewLine]", 
     RowBox[{
      RowBox[{"{", 
       RowBox[{"p1", ",", "p2", ",", "p3", ",", "p4"}], "}"}], " ", "=", " ", 
      
      RowBox[{"pts", "[", 
       RowBox[{"\"\<tet\>\"", ",", "\"\<vts\>\""}], "]"}]}], ";", 
     "\[IndentingNewLine]", 
     RowBox[{"pf", " ", "=", " ", 
      RowBox[{"Normalize", "[", 
       RowBox[{"p1", "+", "p2", "+", "p3"}], "]"}]}], ";", 
     "\[IndentingNewLine]", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"c01", "*", "p1"}], ",", 
       RowBox[{
        RowBox[{"c11", "*", "p1"}], "+", 
        RowBox[{"c12", "*", "p2"}], "+", 
        RowBox[{"c13", "*", "p3"}]}], ",", 
       RowBox[{"c02", "*", "pf"}], ",", 
       RowBox[{
        RowBox[{"c11", "*", "p3"}], "+", 
        RowBox[{"c12", "*", "p1"}], "+", 
        RowBox[{"c13", "*", "p2"}]}], ",", 
       RowBox[{
        RowBox[{"c11", "*", "p1"}], "+", 
        RowBox[{"c12", "*", "p3"}], "+", 
        RowBox[{"c13", "*", "p4"}]}]}], "}"}]}]}], "\[IndentingNewLine]", 
   "]"}]}]], "Input",
 CellLabel->
  "In[367]:=",ExpressionUUID->"91aae1a2-cb18-4f40-b1fa-6d2a88672232"],

Cell[BoxData[
 RowBox[{
  RowBox[{"tpparams", "[", "cx_", "]"}], " ", ":=", " ", 
  RowBox[{"Module", "[", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{"c1", ",", "c2", ",", "c"}], "}"}], ",", "\[IndentingNewLine]", 
    RowBox[{
     RowBox[{
      RowBox[{"{", 
       RowBox[{"c1", ",", "c2", ",", "c"}], "}"}], " ", "=", " ", "cx"}], ";",
      "\[IndentingNewLine]", 
     RowBox[{"{", 
      RowBox[{"c1", ",", "c2", ",", 
       RowBox[{
        RowBox[{"(", 
         RowBox[{"c1", "*", "c", "*", 
          RowBox[{"(", 
           RowBox[{
            RowBox[{"6", "*", 
             RowBox[{"c2", "^", "2"}]}], "-", 
            RowBox[{"4", "*", "c1", "*", "c2", "*", "c"}], "-", 
            RowBox[{"4", "*", 
             RowBox[{"c2", "^", "2"}], "*", "c"}], "+", 
            RowBox[{
             RowBox[{"c1", "^", "2"}], "*", 
             RowBox[{"c", "^", "2"}]}], "+", 
            RowBox[{
             RowBox[{"c2", "^", "2"}], "*", 
             RowBox[{"c", "^", "2"}]}]}], ")"}]}], ")"}], "/", 
        RowBox[{"(", 
         RowBox[{
          RowBox[{"4", "*", 
           RowBox[{"c2", "^", "2"}]}], "-", 
          RowBox[{"2", "*", "c1", "*", "c2", "*", "c"}], "-", 
          RowBox[{"2", "*", 
           RowBox[{"c2", "^", "2"}], "*", "c"}], "+", 
          RowBox[{
           RowBox[{"c1", "^", "2"}], "*", 
           RowBox[{"c", "^", "2"}]}], "-", 
          RowBox[{"2", "*", "c1", "*", "c2", "*", 
           RowBox[{"c", "^", "2"}]}], "+", 
          RowBox[{
           RowBox[{"c2", "^", "2"}], "*", 
           RowBox[{"c", "^", "2"}]}]}], ")"}]}], ",", 
       RowBox[{
        RowBox[{"(", 
         RowBox[{"c1", "*", "c2", "*", 
          RowBox[{"(", 
           RowBox[{
            RowBox[{"-", "1"}], "+", "c"}], ")"}], "*", "c", "*", 
          RowBox[{"(", 
           RowBox[{
            RowBox[{
             RowBox[{"-", "2"}], "*", "c2"}], "-", 
            RowBox[{"c1", "*", "c"}], "+", 
            RowBox[{"c2", "*", "c"}]}], ")"}]}], ")"}], "/", 
        RowBox[{"(", 
         RowBox[{
          RowBox[{"4", "*", 
           RowBox[{"c2", "^", "2"}]}], "-", 
          RowBox[{"2", "*", "c1", "*", "c2", "*", "c"}], "-", 
          RowBox[{"2", "*", 
           RowBox[{"c2", "^", "2"}], "*", "c"}], "+", 
          RowBox[{
           RowBox[{"c1", "^", "2"}], "*", 
           RowBox[{"c", "^", "2"}]}], "-", 
          RowBox[{"2", "*", "c1", "*", "c2", "*", 
           RowBox[{"c", "^", "2"}]}], "+", 
          RowBox[{
           RowBox[{"c2", "^", "2"}], "*", 
           RowBox[{"c", "^", "2"}]}]}], ")"}]}], ",", 
       RowBox[{
        RowBox[{"(", 
         RowBox[{"c1", "*", "c2", "*", 
          RowBox[{"(", 
           RowBox[{
            RowBox[{"-", "1"}], "+", "c"}], ")"}], "*", "c", "*", 
          RowBox[{"(", 
           RowBox[{
            RowBox[{
             RowBox[{"-", "4"}], "*", "c2"}], "+", 
            RowBox[{"c1", "*", "c"}], "+", 
            RowBox[{"c2", "*", "c"}]}], ")"}]}], ")"}], "/", 
        RowBox[{"(", 
         RowBox[{
          RowBox[{"4", "*", 
           RowBox[{"c2", "^", "2"}]}], "-", 
          RowBox[{"2", "*", "c1", "*", "c2", "*", "c"}], "-", 
          RowBox[{"2", "*", 
           RowBox[{"c2", "^", "2"}], "*", "c"}], "+", 
          RowBox[{
           RowBox[{"c1", "^", "2"}], "*", 
           RowBox[{"c", "^", "2"}]}], "-", 
          RowBox[{"2", "*", "c1", "*", "c2", "*", 
           RowBox[{"c", "^", "2"}]}], "+", 
          RowBox[{
           RowBox[{"c2", "^", "2"}], "*", 
           RowBox[{"c", "^", "2"}]}]}], ")"}]}]}], "}"}]}]}], 
   "\[IndentingNewLine]", "]"}]}]], "Input",
 CellLabel->
  "In[368]:=",ExpressionUUID->"aa96aeac-e041-4760-a955-0a810daf258b"],

Cell[BoxData[
 RowBox[{
  RowBox[{"tpverts", " ", "=", " ", 
   RowBox[{
    RowBox[{"tetpent", "[", 
     RowBox[{"tpparams", "[", 
      RowBox[{"{", 
       RowBox[{"c1", ",", "c2", ",", "c"}], "}"}], "]"}], "]"}], " ", "//", 
    " ", "Factor"}]}], ";"}]], "Input",
 CellLabel->
  "In[369]:=",ExpressionUUID->"94d93561-d648-4fde-8239-770ef7076e08"],

Cell[BoxData[
 RowBox[{"planarity", "[", "tpverts", "]"}]], "Input",
 CellLabel->
  "In[370]:=",ExpressionUUID->"8a66e595-2770-4444-bda3-8a9ecdabad96"],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"{", 
    RowBox[{
     RowBox[{
      RowBox[{"#", "[", 
       RowBox[{"[", "1", "]"}], "]"}], "===", 
      RowBox[{"c1", "^", "2"}]}], ",", 
     RowBox[{
      RowBox[{"#", "[", 
       RowBox[{"[", "3", "]"}], "]"}], "===", 
      RowBox[{"c2", "^", "2"}]}], ",", 
     RowBox[{
      RowBox[{"#", "[", 
       RowBox[{"[", "4", "]"}], "]"}], "===", 
      RowBox[{"#", "[", 
       RowBox[{"[", "2", "]"}], "]"}]}], ",", 
     RowBox[{
      RowBox[{"#", "[", 
       RowBox[{"[", "5", "]"}], "]"}], "===", 
      RowBox[{"#", "[", 
       RowBox[{"[", "2", "]"}], "]"}]}]}], "}"}], "&"}], " ", "@", " ", 
  RowBox[{"Factor", "[", 
   RowBox[{"vtlens", "[", "tpverts", "]"}], "]"}]}]], "Input",
 CellLabel->
  "In[371]:=",ExpressionUUID->"2dd06cd3-bba6-4a3f-b69f-af35b144304f"],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"{", 
    RowBox[{
     RowBox[{
      RowBox[{"#", "[", 
       RowBox[{"[", "3", "]"}], "]"}], "===", 
      RowBox[{"#", "[", 
       RowBox[{"[", "2", "]"}], "]"}]}], ",", 
     RowBox[{
      RowBox[{"#", "[", 
       RowBox[{"[", "5", "]"}], "]"}], "===", 
      RowBox[{"#", "[", 
       RowBox[{"[", "1", "]"}], "]"}]}]}], "}"}], "&"}], " ", "@", " ", 
  RowBox[{"Factor", "[", 
   RowBox[{"edlens", "[", "tpverts", "]"}], "]"}]}]], "Input",
 CellLabel->
  "In[372]:=",ExpressionUUID->"d46f038a-fdac-4ab7-a2e9-1a3bcb829b35"],

Cell[BoxData[
 RowBox[{
  RowBox[{"tpeqverts", " ", "=", " ", 
   RowBox[{
    RowBox[{"tetpent", "[", 
     RowBox[{"tpparams", "[", 
      RowBox[{"{", 
       RowBox[{"1", ",", "1", ",", "c"}], "}"}], "]"}], "]"}], " ", "//", " ",
     "Factor"}]}], ";"}]], "Input",
 CellLabel->
  "In[373]:=",ExpressionUUID->"318cdd17-7c50-4912-b8be-d9b9c48f6f91"],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"{", 
    RowBox[{
     RowBox[{
      RowBox[{"#", "[", 
       RowBox[{"[", "1", "]"}], "]"}], "\[Equal]", "1"}], ",", 
     RowBox[{
      RowBox[{"#", "[", 
       RowBox[{"[", "3", "]"}], "]"}], "\[Equal]", "1"}], ",", 
     RowBox[{
      RowBox[{"#", "[", 
       RowBox[{"[", "4", "]"}], "]"}], "===", 
      RowBox[{"#", "[", 
       RowBox[{"[", "2", "]"}], "]"}]}], ",", 
     RowBox[{
      RowBox[{"#", "[", 
       RowBox[{"[", "5", "]"}], "]"}], "===", 
      RowBox[{"#", "[", 
       RowBox[{"[", "2", "]"}], "]"}]}]}], "}"}], "&"}], " ", "@", " ", 
  RowBox[{"Factor", "[", 
   RowBox[{"vtlens", "[", "tpeqverts", "]"}], "]"}]}]], "Input",
 CellLabel->
  "In[374]:=",ExpressionUUID->"339d606b-28dd-4196-a038-c7eda998c9e9"],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"{", 
    RowBox[{
     RowBox[{
      RowBox[{"#", "[", 
       RowBox[{"[", "2", "]"}], "]"}], "===", 
      RowBox[{"#", "[", 
       RowBox[{"[", "1", "]"}], "]"}]}], ",", 
     RowBox[{
      RowBox[{"#", "[", 
       RowBox[{"[", "3", "]"}], "]"}], "===", 
      RowBox[{"#", "[", 
       RowBox[{"[", "1", "]"}], "]"}]}], ",", 
     RowBox[{
      RowBox[{"#", "[", 
       RowBox[{"[", "5", "]"}], "]"}], "===", 
      RowBox[{"#", "[", 
       RowBox[{"[", "1", "]"}], "]"}]}]}], "}"}], "&"}], " ", "@", " ", 
  RowBox[{"Factor", "[", 
   RowBox[{"edlens", "[", "tpeqverts", "]"}], "]"}]}]], "Input",
 CellLabel->
  "In[375]:=",ExpressionUUID->"8c547733-6f4a-4ba7-8842-a0c74446d1fd"],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"{", 
    RowBox[{
     RowBox[{
      RowBox[{"#", "[", 
       RowBox[{"[", "3", "]"}], "]"}], "===", 
      RowBox[{"#", "[", 
       RowBox[{"[", "1", "]"}], "]"}]}], ",", 
     RowBox[{
      RowBox[{"#", "[", 
       RowBox[{"[", "5", "]"}], "]"}], "===", 
      RowBox[{"#", "[", 
       RowBox[{"[", "4", "]"}], "]"}]}]}], "}"}], "&"}], " ", "@", " ", 
  RowBox[{"Factor", "[", 
   RowBox[{"Refine", "[", 
    RowBox[{
     RowBox[{"MapAll", "[", 
      RowBox[{"Factor", ",", 
       RowBox[{"vtcsangs", "[", "tpeqverts", "]"}]}], "]"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"c", ">", "0"}], ",", 
       RowBox[{"c", "<", "2"}]}], "}"}]}], "]"}], "]"}]}]], "Input",
 CellLabel->
  "In[376]:=",ExpressionUUID->"3f321b49-1aab-4d2c-a166-05d5285180c3"],

Cell[BoxData[
 RowBox[{
  RowBox[{"tpregvtparams", " ", "=", " ", 
   RowBox[{"{", 
    RowBox[{"1", ",", "1", ",", 
     RowBox[{
      RowBox[{"Sqrt", "[", "5", "]"}], "/", "2"}], ",", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{
        RowBox[{"Sqrt", "[", "5", "]"}], "+", "1"}], ")"}], "/", "4"}], ",", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{
        RowBox[{"Sqrt", "[", "5", "]"}], "-", "1"}], ")"}], "/", "4"}]}], 
    "}"}]}], ";"}]], "Input",
 CellLabel->
  "In[377]:=",ExpressionUUID->"1b189441-578b-4620-b0c8-06bfaf968f5a"],

Cell[BoxData[
 RowBox[{
  RowBox[{"tpregvtparams", " ", "-", " ", 
   RowBox[{"tpparams", "[", 
    RowBox[{"{", 
     RowBox[{"1", ",", "1", ",", 
      RowBox[{
       RowBox[{"(", 
        RowBox[{
         RowBox[{"Sqrt", "[", "5", "]"}], "+", "1"}], ")"}], "/", "2"}]}], 
     "}"}], "]"}]}], " ", "//", " ", "Factor"}]], "Input",
 CellLabel->
  "In[378]:=",ExpressionUUID->"993bbc46-a553-4212-8d1e-449516ad0979"],

Cell[BoxData[
 RowBox[{
  RowBox[{"tpregvts", " ", "=", " ", 
   RowBox[{
    RowBox[{
     RowBox[{"tetpent", "[", "tpregvtparams", "]"}], " ", "//", " ", 
     "Expand"}], " ", "//", " ", "Factor"}]}], ";"}]], "Input",
 CellLabel->
  "In[379]:=",ExpressionUUID->"792407f0-3847-4a58-9640-3ea87bfaf2f9"],

Cell[BoxData[
 RowBox[{"Factor", "[", 
  RowBox[{
   RowBox[{"vtlens", "[", "tpregvts", "]"}], " ", "-", " ", "1"}], 
  "]"}]], "Input",
 CellLabel->
  "In[380]:=",ExpressionUUID->"f64902c2-208a-4b37-9b58-bd8d53474289"],

Cell[BoxData[
 RowBox[{"Factor", "[", 
  RowBox[{
   RowBox[{"edlens", "[", "tpregvts", "]"}], " ", "-", " ", 
   RowBox[{
    RowBox[{"(", 
     RowBox[{"2", "/", "3"}], ")"}], 
    RowBox[{"(", 
     RowBox[{"3", "-", 
      RowBox[{"Sqrt", "[", "5", "]"}]}], ")"}]}]}], "]"}]], "Input",
 CellLabel->
  "In[381]:=",ExpressionUUID->"722d51f0-a063-471f-94b8-3747508e94df"],

Cell[BoxData[
 RowBox[{"Factor", "[", 
  RowBox[{
   RowBox[{"MapAll", "[", 
    RowBox[{
     RowBox[{
      RowBox[{"Factor", "[", 
       RowBox[{"#", ",", 
        RowBox[{"Extension", "\[Rule]", 
         RowBox[{"Sqrt", "[", "5", "]"}]}]}], "]"}], "&"}], ",", 
     RowBox[{"vtcsangs", "[", "tpregvts", "]"}]}], "]"}], " ", "-", " ", 
   RowBox[{"Cos", "[", 
    RowBox[{"3", 
     RowBox[{"Pi", "/", "5"}]}], "]"}]}], "]"}]], "Input",
 CellLabel->
  "In[382]:=",ExpressionUUID->"b486562e-2cff-45e2-9148-7c49612040f8"],

Cell[BoxData[
 RowBox[{"(*", " ", 
  RowBox[{
  "Try", " ", "to", " ", "find", " ", "some", " ", "more", " ", "symmetric", 
   " ", "formulation"}], " ", "*)"}]], "Input",
 CellLabel->
  "In[483]:=",ExpressionUUID->"3544618a-78b9-4828-8d3f-ce55a5989dd3"],

Cell[BoxData[
 RowBox[{"Module", "[", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{"p1", ",", "p2", ",", "p3", ",", "p4", ",", "pf"}], "}"}], ",", 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{
     RowBox[{"{", 
      RowBox[{"p1", ",", "p2", ",", "p3", ",", "p4"}], "}"}], " ", "=", "  ", 
     
     RowBox[{"pts", "[", 
      RowBox[{"\"\<tet\>\"", ",", "\"\<vts\>\""}], "]"}]}], ";", 
    "\[IndentingNewLine]", 
    RowBox[{"pf", " ", "=", " ", 
     RowBox[{"Normalize", "[", 
      RowBox[{"p1", "+", "p2", "+", "p3"}], "]"}]}], ";", 
    "\[IndentingNewLine]", 
    RowBox[{
     RowBox[{
      RowBox[{"(", 
       RowBox[{
        RowBox[{
         RowBox[{"(", 
          RowBox[{"d1", "+", "d2"}], ")"}], "*", "p1"}], "+", 
        RowBox[{
         RowBox[{"(", 
          RowBox[{"d2", "-", 
           RowBox[{"d3", "/", 
            RowBox[{"Sqrt", "[", "3", "]"}]}]}], ")"}], "*", "p2"}], "+", 
        RowBox[{
         RowBox[{"(", 
          RowBox[{"d2", "+", 
           RowBox[{"d3", "/", 
            RowBox[{"Sqrt", "[", "3", "]"}]}]}], ")"}], "*", "p3"}]}], ")"}], 
      " ", "-", " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{"d1", "*", "p1"}], "+", 
        RowBox[{"d2", "*", "pf"}], "+", 
        RowBox[{"d3", "*", 
         RowBox[{"Cross", "[", 
          RowBox[{"p1", ",", "pf"}], "]"}]}]}], ")"}]}], " ", "//", " ", 
     "Expand"}]}]}], "\[IndentingNewLine]", "]"}]], "Input",
 CellLabel->
  "In[474]:=",ExpressionUUID->"0b8de537-6d49-45d3-aecd-5cb9b3c8220c"],

Cell[BoxData[
 RowBox[{
  RowBox[{"planarity", "[", 
   RowBox[{"tetpent", "[", 
    RowBox[{"{", 
     RowBox[{"c01", ",", "c02", ",", 
      RowBox[{"d1", "+", "d2"}], ",", 
      RowBox[{"d2", "-", "d3"}], ",", 
      RowBox[{"d2", "+", "d3"}]}], "}"}], "]"}], "]"}], " ", "//", " ", 
  "Factor"}]], "Input",
 CellLabel->
  "In[482]:=",ExpressionUUID->"85d77be6-d731-41e6-8c5f-088775c7a217"],

Cell[BoxData[
 RowBox[{
  RowBox[{"planarity", "[", 
   RowBox[{"tetpent", "[", 
    RowBox[{"{", 
     RowBox[{"1", ",", "1", ",", 
      RowBox[{"d1", "+", "d2"}], ",", 
      RowBox[{"d2", "-", "d3"}], ",", 
      RowBox[{"d2", "+", "d3"}]}], "}"}], "]"}], "]"}], " ", "//", " ", 
  "Factor"}]], "Input",
 CellLabel->
  "In[491]:=",ExpressionUUID->"772ace73-8ddd-4f40-b913-3b7fe64c8645"],

Cell[BoxData[
 RowBox[{
  RowBox[{"planarity", "[", 
   RowBox[{"tetpent", "[", 
    RowBox[{"{", 
     RowBox[{"1", ",", "1", ",", 
      RowBox[{"2", "d2"}], ",", 
      RowBox[{"d2", "-", "d3"}], ",", 
      RowBox[{"d2", "+", "d3"}]}], "}"}], "]"}], "]"}], " ", "//", " ", 
  "Factor"}]], "Input",
 CellLabel->
  "In[492]:=",ExpressionUUID->"202445e4-3ba2-4e5b-ac50-e6b23767f945"]
}, Closed]],

Cell[CellGroupData[{

Cell["Rhombic Dodecahedron - rhombi on octahedron", "Subsection",ExpressionUUID->"828a4b79-e584-4187-a1d6-d73f42c2335c"],

Cell[BoxData[
 RowBox[{"(*", " ", 
  RowBox[{
   RowBox[{"The", " ", "3"}], "-", 
   RowBox[{
   "vertices", " ", "alternate", " ", "in", " ", "length", " ", "with", " ", 
    "each", " ", "parity", " ", "having", " ", "one", " ", 
    RowBox[{"length", "."}]}]}], "\[IndentingNewLine]", " ", "*)"}]], "Input",\

 CellLabel->
  "In[383]:=",ExpressionUUID->"61d61756-5e1f-47da-bc1e-f3be3fff4406"],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"verts", "[", "\"\<rhmbddc\>\"", "]"}], " ", "=", " ", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{
      RowBox[{"verts", "[", "\"\<octbase\>\"", "]"}], "[", 
      RowBox[{"[", "1", "]"}], "]"}], ",", 
     RowBox[{
      RowBox[{
       RowBox[{"(", 
        RowBox[{"3", "/", "2"}], ")"}], "/", 
       RowBox[{"(", 
        RowBox[{"1", "+", "f"}], ")"}]}], "*", 
      RowBox[{
       RowBox[{"verts", "[", "\"\<obfaces\>\"", "]"}], "[", 
       RowBox[{"[", "1", "]"}], "]"}]}], ",", 
     RowBox[{
      RowBox[{"verts", "[", "\"\<octbase\>\"", "]"}], "[", 
      RowBox[{"[", "2", "]"}], "]"}], ",", 
     RowBox[{
      RowBox[{
       RowBox[{"(", 
        RowBox[{"3", "/", "2"}], ")"}], "/", 
       RowBox[{"(", 
        RowBox[{"1", "-", "f"}], ")"}]}], "*", 
      RowBox[{
       RowBox[{"verts", "[", "\"\<obfaces\>\"", "]"}], "[", 
       RowBox[{"[", "2", "]"}], "]"}]}]}], "}"}]}], ";"}]], "Input",
 CellLabel->
  "In[384]:=",ExpressionUUID->"7c89359c-c4af-41d1-81da-952535f4ada9"],

Cell[BoxData[
 RowBox[{
  RowBox[{"planarity", "[", 
   RowBox[{"verts", "[", "\"\<rhmbddc\>\"", "]"}], "]"}], " ", "//", " ", 
  "Factor"}]], "Input",
 CellLabel->
  "In[385]:=",ExpressionUUID->"7f54a53e-4a0f-442e-87f5-508dba6eb5bc"],

Cell[BoxData[
 RowBox[{
  RowBox[{"vtlens", "[", 
   RowBox[{"verts", "[", "\"\<rhmbddc\>\"", "]"}], "]"}], " ", "//", " ", 
  "Factor"}]], "Input",
 CellLabel->
  "In[386]:=",ExpressionUUID->"db16d364-0f87-44c9-b123-bcb9baafb50a"],

Cell[BoxData[
 RowBox[{
  RowBox[{"edlens", "[", 
   RowBox[{"verts", "[", "\"\<rhmbddc\>\"", "]"}], "]"}], " ", "//", " ", 
  "Factor"}]], "Input",
 CellLabel->
  "In[387]:=",ExpressionUUID->"4ded1941-97b5-4f08-90ac-013f8911f45d"],

Cell[BoxData[
 RowBox[{
  RowBox[{"Refine", "[", 
   RowBox[{
    RowBox[{"MapAll", "[", 
     RowBox[{"Factor", ",", 
      RowBox[{"vtcsangs", "[", 
       RowBox[{"verts", "[", "\"\<rhmbddc\>\"", "]"}], "]"}]}], "]"}], ",", 
    RowBox[{"f", ">", "1"}]}], "]"}], " ", "//", " ", "Factor"}]], "Input",
 CellLabel->
  "In[388]:=",ExpressionUUID->"54ea3216-d433-4925-a34a-fa669c51a05f"]
}, Closed]],

Cell[CellGroupData[{

Cell["Deltoidal Icositetrahedron - kites on octahedron", "Subsection",ExpressionUUID->"4e9e941d-e56c-4356-8785-e443d087c632"],

Cell[BoxData[
 RowBox[{"(*", " ", 
  RowBox[{
   RowBox[{
   "The", " ", "shifts", " ", "along", " ", "the", " ", "edges", " ", 
    "alternate"}], ",", " ", 
   RowBox[{
    RowBox[{
    "making", " ", "the", " ", "edges", " ", "to", " ", "the", " ", "oct"}], 
    "-", 
    RowBox[{
    "face", " ", "centers", " ", "alternate", " ", "between", " ", "being", 
     " ", "clockwise", " ", "and", " ", "being", " ", "counterclockwise", " ",
      "according", " ", "to", " ", "the", " ", 
     RowBox[{"faces", "'"}], " ", 
     RowBox[{"parities", "."}]}]}]}], " ", "*)"}]], "Input",
 CellLabel->
  "In[389]:=",ExpressionUUID->"b0606c18-412e-4626-8894-c9250ffd2092"],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"verts", "[", "\"\<dltith\>\"", "]"}], " ", "=", " ", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{
      RowBox[{"verts", "[", "\"\<octbase\>\"", "]"}], "[", 
      RowBox[{"[", "1", "]"}], "]"}], ",", 
     RowBox[{
      RowBox[{
       RowBox[{"(", 
        RowBox[{"c1", "+", "c2"}], ")"}], "*", 
       RowBox[{
        RowBox[{"verts", "[", "\"\<octbase\>\"", "]"}], "[", 
        RowBox[{"[", "1", "]"}], "]"}]}], "+", 
      RowBox[{
       RowBox[{"(", 
        RowBox[{"c1", "-", "c2"}], ")"}], "*", 
       RowBox[{
        RowBox[{"verts", "[", "\"\<octbase\>\"", "]"}], "[", 
        RowBox[{"[", "2", "]"}], "]"}]}]}], ",", 
     RowBox[{"c3", "*", 
      RowBox[{
       RowBox[{"verts", "[", "\"\<obfaces\>\"", "]"}], "[", 
       RowBox[{"[", "1", "]"}], "]"}]}], ",", 
     RowBox[{
      RowBox[{
       RowBox[{"(", 
        RowBox[{"c1", "-", "c2"}], ")"}], "*", 
       RowBox[{
        RowBox[{"verts", "[", "\"\<octbase\>\"", "]"}], "[", 
        RowBox[{"[", "1", "]"}], "]"}]}], "+", 
      RowBox[{
       RowBox[{"(", 
        RowBox[{"c1", "+", "c2"}], ")"}], "*", 
       RowBox[{
        RowBox[{"verts", "[", "\"\<octbase\>\"", "]"}], "[", 
        RowBox[{"[", "3", "]"}], "]"}]}]}]}], "}"}]}], ";"}]], "Input",
 CellLabel->
  "In[390]:=",ExpressionUUID->"03ded2a7-080a-42f4-a4ee-a229ac38e820"],

Cell[BoxData[
 RowBox[{
  RowBox[{"planarity", "[", 
   RowBox[{"verts", "[", "\"\<dltith\>\"", "]"}], "]"}], " ", "//", " ", 
  "Factor"}]], "Input",
 CellLabel->
  "In[391]:=",ExpressionUUID->"c83ee3a5-5a3f-4bb0-a588-a82ed4780e81"],

Cell[BoxData[
 RowBox[{"MapAll", "[", 
  RowBox[{"Factor", ",", 
   RowBox[{"Solve", "[", 
    RowBox[{
     RowBox[{"%", "\[Equal]", "0"}], ",", "c3"}], "]"}]}], "]"}]], "Input",
 CellLabel->
  "In[392]:=",ExpressionUUID->"334b393e-52e0-4118-a9dc-23477196309e"],

Cell[BoxData[
 RowBox[{
  RowBox[{"%%", " ", "/.", 
   RowBox[{"c2", "\[Rule]", "0"}]}], " ", "//", " ", "Factor"}]], "Input",
 CellLabel->
  "In[393]:=",ExpressionUUID->"e4c1d3d6-e1fa-487e-9bdb-10731c7235a1"],

Cell[BoxData[
 RowBox[{"MapAll", "[", 
  RowBox[{"Factor", ",", 
   RowBox[{"Solve", "[", 
    RowBox[{
     RowBox[{"%", "\[Equal]", "0"}], ",", "c3"}], "]"}]}], "]"}]], "Input",
 CellLabel->
  "In[394]:=",ExpressionUUID->"836784bd-26b0-47a5-a81e-98891dc56386"],

Cell[BoxData[
 RowBox[{
  RowBox[{"vtlens", "[", 
   RowBox[{"verts", "[", "\"\<dltith\>\"", "]"}], "]"}], " ", "//", " ", 
  "Factor"}]], "Input",
 CellLabel->
  "In[395]:=",ExpressionUUID->"dbb97ef5-0352-466f-89a6-6450c9fd80a1"],

Cell[BoxData[
 RowBox[{
  RowBox[{"edlens", "[", 
   RowBox[{"verts", "[", "\"\<dltith\>\"", "]"}], "]"}], " ", "//", " ", 
  "Factor"}]], "Input",
 CellLabel->
  "In[396]:=",ExpressionUUID->"56bd1c59-a860-4ac4-a1a8-588395db3720"]
}, Closed]],

Cell[CellGroupData[{

Cell["Tetrakis hexahedron - pyramids on cube", "Subsection",ExpressionUUID->"13ec7b83-b2da-45cc-8bf9-e4885f6ce269"],

Cell[BoxData[
 RowBox[{"(*", " ", 
  RowBox[{
   RowBox[{"Do", " ", "offsets"}], ",", " ", 
   RowBox[{
   "because", " ", "that", " ", "is", " ", "relatively", " ", "easy"}]}], " ",
   "*)"}]], "Input",
 CellLabel->
  "In[397]:=",ExpressionUUID->"77e9b705-2e8c-4b48-add8-84ec69e32cac"],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"verts", "[", "\"\<dfcubalt\>\"", "]"}], " ", "=", " ", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{
        RowBox[{"x", "[", 
         RowBox[{"4", ",", "2"}], "]"}], "-", 
        RowBox[{"x", "[", 
         RowBox[{"6", ",", "3"}], "]"}], "-", 
        RowBox[{"x", "[", 
         RowBox[{"7", ",", "3"}], "]"}], "+", 
        RowBox[{"x", "[", 
         RowBox[{"8", ",", "1"}], "]"}], "+", 
        RowBox[{"x", "[", 
         RowBox[{"8", ",", "2"}], "]"}]}], ",", 
       RowBox[{"x", "[", 
        RowBox[{"4", ",", "2"}], "]"}], ",", 
       RowBox[{
        RowBox[{"-", 
         RowBox[{"x", "[", 
          RowBox[{"6", ",", "3"}], "]"}]}], "-", 
        RowBox[{"x", "[", 
         RowBox[{"7", ",", "3"}], "]"}], "-", 
        RowBox[{"x", "[", 
         RowBox[{"8", ",", "3"}], "]"}]}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{
        RowBox[{"x", "[", 
         RowBox[{"4", ",", "2"}], "]"}], "-", 
        RowBox[{"x", "[", 
         RowBox[{"6", ",", "3"}], "]"}], "-", 
        RowBox[{"x", "[", 
         RowBox[{"7", ",", "3"}], "]"}], "+", 
        RowBox[{"x", "[", 
         RowBox[{"8", ",", "1"}], "]"}], "+", 
        RowBox[{"x", "[", 
         RowBox[{"8", ",", "2"}], "]"}]}], ",", 
       RowBox[{
        RowBox[{"-", 
         RowBox[{"x", "[", 
          RowBox[{"4", ",", "2"}], "]"}]}], "-", 
        RowBox[{"x", "[", 
         RowBox[{"7", ",", "3"}], "]"}], "-", 
        RowBox[{"x", "[", 
         RowBox[{"8", ",", "3"}], "]"}]}], ",", 
       RowBox[{"x", "[", 
        RowBox[{"6", ",", "3"}], "]"}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{
        RowBox[{"-", 
         RowBox[{"x", "[", 
          RowBox[{"4", ",", "2"}], "]"}]}], "-", 
        RowBox[{"x", "[", 
         RowBox[{"8", ",", "1"}], "]"}], "-", 
        RowBox[{"x", "[", 
         RowBox[{"8", ",", "2"}], "]"}]}], ",", 
       RowBox[{
        RowBox[{"-", 
         RowBox[{"x", "[", 
          RowBox[{"4", ",", "2"}], "]"}]}], "-", 
        RowBox[{"x", "[", 
         RowBox[{"7", ",", "3"}], "]"}], "-", 
        RowBox[{"x", "[", 
         RowBox[{"8", ",", "3"}], "]"}]}], ",", 
       RowBox[{"x", "[", 
        RowBox[{"7", ",", "3"}], "]"}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{
        RowBox[{"-", 
         RowBox[{"x", "[", 
          RowBox[{"4", ",", "2"}], "]"}]}], "-", 
        RowBox[{"x", "[", 
         RowBox[{"8", ",", "1"}], "]"}], "-", 
        RowBox[{"x", "[", 
         RowBox[{"8", ",", "2"}], "]"}]}], ",", 
       RowBox[{"x", "[", 
        RowBox[{"4", ",", "2"}], "]"}], ",", 
       RowBox[{"x", "[", 
        RowBox[{"8", ",", "3"}], "]"}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{
        RowBox[{"x", "[", 
         RowBox[{"6", ",", "3"}], "]"}], "+", 
        RowBox[{"x", "[", 
         RowBox[{"7", ",", "3"}], "]"}], "-", 
        RowBox[{"x", "[", 
         RowBox[{"8", ",", "1"}], "]"}]}], ",", 
       RowBox[{"x", "[", 
        RowBox[{"8", ",", "2"}], "]"}], ",", 
       RowBox[{
        RowBox[{"-", 
         RowBox[{"x", "[", 
          RowBox[{"6", ",", "3"}], "]"}]}], "-", 
        RowBox[{"x", "[", 
         RowBox[{"7", ",", "3"}], "]"}], "-", 
        RowBox[{"x", "[", 
         RowBox[{"8", ",", "3"}], "]"}]}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{
        RowBox[{"x", "[", 
         RowBox[{"6", ",", "3"}], "]"}], "+", 
        RowBox[{"x", "[", 
         RowBox[{"7", ",", "3"}], "]"}], "-", 
        RowBox[{"x", "[", 
         RowBox[{"8", ",", "1"}], "]"}]}], ",", 
       RowBox[{
        RowBox[{"x", "[", 
         RowBox[{"7", ",", "3"}], "]"}], "-", 
        RowBox[{"x", "[", 
         RowBox[{"8", ",", "2"}], "]"}], "+", 
        RowBox[{"x", "[", 
         RowBox[{"8", ",", "3"}], "]"}]}], ",", 
       RowBox[{"x", "[", 
        RowBox[{"6", ",", "3"}], "]"}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"x", "[", 
        RowBox[{"8", ",", "1"}], "]"}], ",", 
       RowBox[{
        RowBox[{"x", "[", 
         RowBox[{"7", ",", "3"}], "]"}], "-", 
        RowBox[{"x", "[", 
         RowBox[{"8", ",", "2"}], "]"}], "+", 
        RowBox[{"x", "[", 
         RowBox[{"8", ",", "3"}], "]"}]}], ",", 
       RowBox[{"x", "[", 
        RowBox[{"7", ",", "3"}], "]"}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"x", "[", 
        RowBox[{"8", ",", "1"}], "]"}], ",", 
       RowBox[{"x", "[", 
        RowBox[{"8", ",", "2"}], "]"}], ",", 
       RowBox[{"x", "[", 
        RowBox[{"8", ",", "3"}], "]"}]}], "}"}]}], "}"}]}], ";"}]], "Input",
 CellLabel->
  "In[398]:=",ExpressionUUID->"eb8c274d-281a-4af2-acc0-82fa2f8fa83d"],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"verts", "[", "\"\<dfcubaltsol\>\"", "]"}], " ", "=", " ", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0", ",", 
         RowBox[{"-", 
          RowBox[{"x", "[", 
           RowBox[{"8", ",", "3"}], "]"}]}], ",", "0"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"0", ",", "0", ",", 
         RowBox[{"-", 
          RowBox[{"x", "[", 
           RowBox[{"8", ",", "3"}], "]"}]}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"x", "[", 
          RowBox[{"8", ",", "3"}], "]"}], ",", "0", ",", "0"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"x", "[", 
          RowBox[{"8", ",", "3"}], "]"}], ",", 
         RowBox[{"-", 
          RowBox[{"x", "[", 
           RowBox[{"8", ",", "3"}], "]"}]}], ",", 
         RowBox[{"x", "[", 
          RowBox[{"8", ",", "3"}], "]"}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", 
          RowBox[{"x", "[", 
           RowBox[{"8", ",", "3"}], "]"}]}], ",", "0", ",", "0"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", 
          RowBox[{"x", "[", 
           RowBox[{"8", ",", "3"}], "]"}]}], ",", 
         RowBox[{"x", "[", 
          RowBox[{"8", ",", "3"}], "]"}], ",", 
         RowBox[{"-", 
          RowBox[{"x", "[", 
           RowBox[{"8", ",", "3"}], "]"}]}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"0", ",", 
         RowBox[{"x", "[", 
          RowBox[{"8", ",", "3"}], "]"}], ",", "0"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"0", ",", "0", ",", 
         RowBox[{"x", "[", 
          RowBox[{"8", ",", "3"}], "]"}]}], "}"}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
         RowBox[{
          RowBox[{"2", "/", "3"}], " ", 
          RowBox[{"x", "[", 
           RowBox[{"8", ",", "3"}], "]"}]}], ",", "0", ",", 
         RowBox[{
          RowBox[{"-", 
           RowBox[{"(", 
            RowBox[{"1", "/", "3"}], ")"}]}], " ", 
          RowBox[{"x", "[", 
           RowBox[{"8", ",", "3"}], "]"}]}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{
          RowBox[{"2", "/", "3"}], " ", 
          RowBox[{"x", "[", 
           RowBox[{"8", ",", "3"}], "]"}]}], ",", 
         RowBox[{
          RowBox[{"-", 
           RowBox[{"(", 
            RowBox[{"2", "/", "3"}], ")"}]}], " ", 
          RowBox[{"x", "[", 
           RowBox[{"8", ",", "3"}], "]"}]}], ",", 
         RowBox[{
          RowBox[{"-", 
           RowBox[{"(", 
            RowBox[{"1", "/", "3"}], ")"}]}], " ", 
          RowBox[{"x", "[", 
           RowBox[{"8", ",", "3"}], "]"}]}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"0", ",", 
         RowBox[{
          RowBox[{"-", 
           RowBox[{"(", 
            RowBox[{"2", "/", "3"}], ")"}]}], " ", 
          RowBox[{"x", "[", 
           RowBox[{"8", ",", "3"}], "]"}]}], ",", 
         RowBox[{
          RowBox[{"-", 
           RowBox[{"(", 
            RowBox[{"1", "/", "3"}], ")"}]}], " ", 
          RowBox[{"x", "[", 
           RowBox[{"8", ",", "3"}], "]"}]}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"0", ",", "0", ",", 
         RowBox[{"x", "[", 
          RowBox[{"8", ",", "3"}], "]"}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{
          RowBox[{"-", 
           RowBox[{"(", 
            RowBox[{"2", "/", "3"}], ")"}]}], " ", 
          RowBox[{"x", "[", 
           RowBox[{"8", ",", "3"}], "]"}]}], ",", "0", ",", 
         RowBox[{
          RowBox[{"-", 
           RowBox[{"(", 
            RowBox[{"1", "/", "3"}], ")"}]}], " ", 
          RowBox[{"x", "[", 
           RowBox[{"8", ",", "3"}], "]"}]}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{
          RowBox[{"-", 
           RowBox[{"(", 
            RowBox[{"2", "/", "3"}], ")"}]}], " ", 
          RowBox[{"x", "[", 
           RowBox[{"8", ",", "3"}], "]"}]}], ",", 
         RowBox[{
          RowBox[{"2", "/", "3"}], " ", 
          RowBox[{"x", "[", 
           RowBox[{"8", ",", "3"}], "]"}]}], ",", 
         RowBox[{
          RowBox[{"-", 
           RowBox[{"(", 
            RowBox[{"1", "/", "3"}], ")"}]}], " ", 
          RowBox[{"x", "[", 
           RowBox[{"8", ",", "3"}], "]"}]}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"0", ",", 
         RowBox[{
          RowBox[{"2", "/", "3"}], " ", 
          RowBox[{"x", "[", 
           RowBox[{"8", ",", "3"}], "]"}]}], ",", 
         RowBox[{
          RowBox[{"-", 
           RowBox[{"(", 
            RowBox[{"1", "/", "3"}], ")"}]}], " ", 
          RowBox[{"x", "[", 
           RowBox[{"8", ",", "3"}], "]"}]}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"0", ",", "0", ",", 
         RowBox[{"x", "[", 
          RowBox[{"8", ",", "3"}], "]"}]}], "}"}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
         RowBox[{
          RowBox[{"1", "/", "2"}], " ", 
          RowBox[{"x", "[", 
           RowBox[{"8", ",", "3"}], "]"}]}], ",", 
         RowBox[{"-", 
          RowBox[{"x", "[", 
           RowBox[{"8", ",", "3"}], "]"}]}], ",", "0"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{
          RowBox[{"1", "/", "2"}], " ", 
          RowBox[{"x", "[", 
           RowBox[{"8", ",", "3"}], "]"}]}], ",", 
         RowBox[{"x", "[", 
          RowBox[{"8", ",", "3"}], "]"}], ",", "0"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{
          RowBox[{"1", "/", "2"}], " ", 
          RowBox[{"x", "[", 
           RowBox[{"8", ",", "3"}], "]"}]}], ",", 
         RowBox[{"x", "[", 
          RowBox[{"8", ",", "3"}], "]"}], ",", 
         RowBox[{"-", 
          RowBox[{"x", "[", 
           RowBox[{"8", ",", "3"}], "]"}]}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{
          RowBox[{"1", "/", "2"}], " ", 
          RowBox[{"x", "[", 
           RowBox[{"8", ",", "3"}], "]"}]}], ",", 
         RowBox[{"-", 
          RowBox[{"x", "[", 
           RowBox[{"8", ",", "3"}], "]"}]}], ",", 
         RowBox[{"x", "[", 
          RowBox[{"8", ",", "3"}], "]"}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{
          RowBox[{"-", 
           RowBox[{"(", 
            RowBox[{"3", "/", "2"}], ")"}]}], " ", 
          RowBox[{"x", "[", 
           RowBox[{"8", ",", "3"}], "]"}]}], ",", "0", ",", "0"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{
          RowBox[{"-", 
           RowBox[{"(", 
            RowBox[{"3", "/", "2"}], ")"}]}], " ", 
          RowBox[{"x", "[", 
           RowBox[{"8", ",", "3"}], "]"}]}], ",", "0", ",", "0"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{
          RowBox[{"1", "/", "2"}], " ", 
          RowBox[{"x", "[", 
           RowBox[{"8", ",", "3"}], "]"}]}], ",", "0", ",", 
         RowBox[{"-", 
          RowBox[{"x", "[", 
           RowBox[{"8", ",", "3"}], "]"}]}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{
          RowBox[{"1", "/", "2"}], " ", 
          RowBox[{"x", "[", 
           RowBox[{"8", ",", "3"}], "]"}]}], ",", "0", ",", 
         RowBox[{"x", "[", 
          RowBox[{"8", ",", "3"}], "]"}]}], "}"}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0", ",", "0", ",", 
         RowBox[{
          RowBox[{"-", "3"}], " ", 
          RowBox[{"x", "[", 
           RowBox[{"8", ",", "3"}], "]"}]}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"0", ",", 
         RowBox[{
          RowBox[{"-", "2"}], " ", 
          RowBox[{"x", "[", 
           RowBox[{"8", ",", "3"}], "]"}]}], ",", 
         RowBox[{"x", "[", 
          RowBox[{"8", ",", "3"}], "]"}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{
          RowBox[{"-", "2"}], " ", 
          RowBox[{"x", "[", 
           RowBox[{"8", ",", "3"}], "]"}]}], ",", 
         RowBox[{
          RowBox[{"-", "2"}], " ", 
          RowBox[{"x", "[", 
           RowBox[{"8", ",", "3"}], "]"}]}], ",", 
         RowBox[{"x", "[", 
          RowBox[{"8", ",", "3"}], "]"}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{
          RowBox[{"-", "2"}], " ", 
          RowBox[{"x", "[", 
           RowBox[{"8", ",", "3"}], "]"}]}], ",", "0", ",", 
         RowBox[{"x", "[", 
          RowBox[{"8", ",", "3"}], "]"}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"0", ",", "0", ",", 
         RowBox[{
          RowBox[{"-", "3"}], " ", 
          RowBox[{"x", "[", 
           RowBox[{"8", ",", "3"}], "]"}]}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"0", ",", 
         RowBox[{"2", " ", 
          RowBox[{"x", "[", 
           RowBox[{"8", ",", "3"}], "]"}]}], ",", 
         RowBox[{"x", "[", 
          RowBox[{"8", ",", "3"}], "]"}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"2", " ", 
          RowBox[{"x", "[", 
           RowBox[{"8", ",", "3"}], "]"}]}], ",", 
         RowBox[{"2", " ", 
          RowBox[{"x", "[", 
           RowBox[{"8", ",", "3"}], "]"}]}], ",", 
         RowBox[{"x", "[", 
          RowBox[{"8", ",", "3"}], "]"}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"2", " ", 
          RowBox[{"x", "[", 
           RowBox[{"8", ",", "3"}], "]"}]}], ",", "0", ",", 
         RowBox[{"x", "[", 
          RowBox[{"8", ",", "3"}], "]"}]}], "}"}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
         RowBox[{"2", " ", 
          RowBox[{"x", "[", 
           RowBox[{"8", ",", "3"}], "]"}]}], ",", 
         RowBox[{"2", " ", 
          RowBox[{"x", "[", 
           RowBox[{"8", ",", "3"}], "]"}]}], ",", 
         RowBox[{"x", "[", 
          RowBox[{"8", ",", "3"}], "]"}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"2", " ", 
          RowBox[{"x", "[", 
           RowBox[{"8", ",", "3"}], "]"}]}], ",", "0", ",", 
         RowBox[{"x", "[", 
          RowBox[{"8", ",", "3"}], "]"}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"0", ",", "0", ",", 
         RowBox[{
          RowBox[{"-", "3"}], " ", 
          RowBox[{"x", "[", 
           RowBox[{"8", ",", "3"}], "]"}]}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"0", ",", 
         RowBox[{"2", " ", 
          RowBox[{"x", "[", 
           RowBox[{"8", ",", "3"}], "]"}]}], ",", 
         RowBox[{"x", "[", 
          RowBox[{"8", ",", "3"}], "]"}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{
          RowBox[{"-", "2"}], " ", 
          RowBox[{"x", "[", 
           RowBox[{"8", ",", "3"}], "]"}]}], ",", 
         RowBox[{
          RowBox[{"-", "2"}], " ", 
          RowBox[{"x", "[", 
           RowBox[{"8", ",", "3"}], "]"}]}], ",", 
         RowBox[{"x", "[", 
          RowBox[{"8", ",", "3"}], "]"}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{
          RowBox[{"-", "2"}], " ", 
          RowBox[{"x", "[", 
           RowBox[{"8", ",", "3"}], "]"}]}], ",", "0", ",", 
         RowBox[{"x", "[", 
          RowBox[{"8", ",", "3"}], "]"}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"0", ",", "0", ",", 
         RowBox[{
          RowBox[{"-", "3"}], " ", 
          RowBox[{"x", "[", 
           RowBox[{"8", ",", "3"}], "]"}]}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"0", ",", 
         RowBox[{
          RowBox[{"-", "2"}], " ", 
          RowBox[{"x", "[", 
           RowBox[{"8", ",", "3"}], "]"}]}], ",", 
         RowBox[{"x", "[", 
          RowBox[{"8", ",", "3"}], "]"}]}], "}"}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", 
          RowBox[{"x", "[", 
           RowBox[{"8", ",", "3"}], "]"}]}], ",", 
         RowBox[{
          RowBox[{"-", 
           RowBox[{"(", 
            RowBox[{"1", "/", "2"}], ")"}]}], " ", 
          RowBox[{"x", "[", 
           RowBox[{"8", ",", "3"}], "]"}]}], ",", 
         RowBox[{"-", 
          RowBox[{"x", "[", 
           RowBox[{"8", ",", "3"}], "]"}]}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", 
          RowBox[{"x", "[", 
           RowBox[{"8", ",", "3"}], "]"}]}], ",", 
         RowBox[{
          RowBox[{"-", 
           RowBox[{"(", 
            RowBox[{"1", "/", "2"}], ")"}]}], " ", 
          RowBox[{"x", "[", 
           RowBox[{"8", ",", "3"}], "]"}]}], ",", "0"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"x", "[", 
          RowBox[{"8", ",", "3"}], "]"}], ",", 
         RowBox[{
          RowBox[{"-", 
           RowBox[{"(", 
            RowBox[{"1", "/", "2"}], ")"}]}], " ", 
          RowBox[{"x", "[", 
           RowBox[{"8", ",", "3"}], "]"}]}], ",", "0"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"x", "[", 
          RowBox[{"8", ",", "3"}], "]"}], ",", 
         RowBox[{
          RowBox[{"-", 
           RowBox[{"(", 
            RowBox[{"1", "/", "2"}], ")"}]}], " ", 
          RowBox[{"x", "[", 
           RowBox[{"8", ",", "3"}], "]"}]}], ",", 
         RowBox[{"x", "[", 
          RowBox[{"8", ",", "3"}], "]"}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"0", ",", 
         RowBox[{
          RowBox[{"-", 
           RowBox[{"(", 
            RowBox[{"1", "/", "2"}], ")"}]}], " ", 
          RowBox[{"x", "[", 
           RowBox[{"8", ",", "3"}], "]"}]}], ",", 
         RowBox[{"-", 
          RowBox[{"x", "[", 
           RowBox[{"8", ",", "3"}], "]"}]}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"0", ",", 
         RowBox[{
          RowBox[{"3", "/", "2"}], " ", 
          RowBox[{"x", "[", 
           RowBox[{"8", ",", "3"}], "]"}]}], ",", "0"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"0", ",", 
         RowBox[{
          RowBox[{"3", "/", "2"}], " ", 
          RowBox[{"x", "[", 
           RowBox[{"8", ",", "3"}], "]"}]}], ",", "0"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"0", ",", 
         RowBox[{
          RowBox[{"-", 
           RowBox[{"(", 
            RowBox[{"1", "/", "2"}], ")"}]}], " ", 
          RowBox[{"x", "[", 
           RowBox[{"8", ",", "3"}], "]"}]}], ",", 
         RowBox[{"x", "[", 
          RowBox[{"8", ",", "3"}], "]"}]}], "}"}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0", ",", 
         RowBox[{
          RowBox[{"1", "/", "2"}], " ", 
          RowBox[{"x", "[", 
           RowBox[{"8", ",", "3"}], "]"}]}], ",", 
         RowBox[{"-", 
          RowBox[{"x", "[", 
           RowBox[{"8", ",", "3"}], "]"}]}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"0", ",", 
         RowBox[{
          RowBox[{"-", 
           RowBox[{"(", 
            RowBox[{"3", "/", "2"}], ")"}]}], " ", 
          RowBox[{"x", "[", 
           RowBox[{"8", ",", "3"}], "]"}]}], ",", "0"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"0", ",", 
         RowBox[{
          RowBox[{"-", 
           RowBox[{"(", 
            RowBox[{"3", "/", "2"}], ")"}]}], " ", 
          RowBox[{"x", "[", 
           RowBox[{"8", ",", "3"}], "]"}]}], ",", "0"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"0", ",", 
         RowBox[{
          RowBox[{"1", "/", "2"}], " ", 
          RowBox[{"x", "[", 
           RowBox[{"8", ",", "3"}], "]"}]}], ",", 
         RowBox[{"x", "[", 
          RowBox[{"8", ",", "3"}], "]"}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"x", "[", 
          RowBox[{"8", ",", "3"}], "]"}], ",", 
         RowBox[{
          RowBox[{"1", "/", "2"}], " ", 
          RowBox[{"x", "[", 
           RowBox[{"8", ",", "3"}], "]"}]}], ",", 
         RowBox[{"-", 
          RowBox[{"x", "[", 
           RowBox[{"8", ",", "3"}], "]"}]}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"x", "[", 
          RowBox[{"8", ",", "3"}], "]"}], ",", 
         RowBox[{
          RowBox[{"1", "/", "2"}], " ", 
          RowBox[{"x", "[", 
           RowBox[{"8", ",", "3"}], "]"}]}], ",", "0"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", 
          RowBox[{"x", "[", 
           RowBox[{"8", ",", "3"}], "]"}]}], ",", 
         RowBox[{
          RowBox[{"1", "/", "2"}], " ", 
          RowBox[{"x", "[", 
           RowBox[{"8", ",", "3"}], "]"}]}], ",", "0"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", 
          RowBox[{"x", "[", 
           RowBox[{"8", ",", "3"}], "]"}]}], ",", 
         RowBox[{
          RowBox[{"1", "/", "2"}], " ", 
          RowBox[{"x", "[", 
           RowBox[{"8", ",", "3"}], "]"}]}], ",", 
         RowBox[{"x", "[", 
          RowBox[{"8", ",", "3"}], "]"}]}], "}"}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
         RowBox[{"x", "[", 
          RowBox[{"8", ",", "3"}], "]"}], ",", "0", ",", "0"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"x", "[", 
          RowBox[{"8", ",", "3"}], "]"}], ",", 
         RowBox[{"-", 
          RowBox[{"x", "[", 
           RowBox[{"8", ",", "3"}], "]"}]}], ",", 
         RowBox[{"-", 
          RowBox[{"x", "[", 
           RowBox[{"8", ",", "3"}], "]"}]}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"0", ",", 
         RowBox[{"-", 
          RowBox[{"x", "[", 
           RowBox[{"8", ",", "3"}], "]"}]}], ",", "0"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"0", ",", "0", ",", 
         RowBox[{"x", "[", 
          RowBox[{"8", ",", "3"}], "]"}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"0", ",", 
         RowBox[{"x", "[", 
          RowBox[{"8", ",", "3"}], "]"}], ",", "0"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"0", ",", "0", ",", 
         RowBox[{"-", 
          RowBox[{"x", "[", 
           RowBox[{"8", ",", "3"}], "]"}]}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", 
          RowBox[{"x", "[", 
           RowBox[{"8", ",", "3"}], "]"}]}], ",", "0", ",", "0"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", 
          RowBox[{"x", "[", 
           RowBox[{"8", ",", "3"}], "]"}]}], ",", 
         RowBox[{"x", "[", 
          RowBox[{"8", ",", "3"}], "]"}], ",", 
         RowBox[{"x", "[", 
          RowBox[{"8", ",", "3"}], "]"}]}], "}"}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", 
          RowBox[{"x", "[", 
           RowBox[{"8", ",", "3"}], "]"}]}], ",", 
         RowBox[{"-", 
          RowBox[{"x", "[", 
           RowBox[{"8", ",", "3"}], "]"}]}], ",", 
         RowBox[{"-", 
          RowBox[{"x", "[", 
           RowBox[{"8", ",", "3"}], "]"}]}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", 
          RowBox[{"x", "[", 
           RowBox[{"8", ",", "3"}], "]"}]}], ",", 
         RowBox[{"x", "[", 
          RowBox[{"8", ",", "3"}], "]"}], ",", 
         RowBox[{"x", "[", 
          RowBox[{"8", ",", "3"}], "]"}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"x", "[", 
          RowBox[{"8", ",", "3"}], "]"}], ",", 
         RowBox[{"x", "[", 
          RowBox[{"8", ",", "3"}], "]"}], ",", 
         RowBox[{"-", 
          RowBox[{"x", "[", 
           RowBox[{"8", ",", "3"}], "]"}]}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"x", "[", 
          RowBox[{"8", ",", "3"}], "]"}], ",", 
         RowBox[{"-", 
          RowBox[{"x", "[", 
           RowBox[{"8", ",", "3"}], "]"}]}], ",", 
         RowBox[{"x", "[", 
          RowBox[{"8", ",", "3"}], "]"}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"x", "[", 
          RowBox[{"8", ",", "3"}], "]"}], ",", 
         RowBox[{"x", "[", 
          RowBox[{"8", ",", "3"}], "]"}], ",", 
         RowBox[{"-", 
          RowBox[{"x", "[", 
           RowBox[{"8", ",", "3"}], "]"}]}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"x", "[", 
          RowBox[{"8", ",", "3"}], "]"}], ",", 
         RowBox[{"-", 
          RowBox[{"x", "[", 
           RowBox[{"8", ",", "3"}], "]"}]}], ",", 
         RowBox[{"x", "[", 
          RowBox[{"8", ",", "3"}], "]"}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", 
          RowBox[{"x", "[", 
           RowBox[{"8", ",", "3"}], "]"}]}], ",", 
         RowBox[{"-", 
          RowBox[{"x", "[", 
           RowBox[{"8", ",", "3"}], "]"}]}], ",", 
         RowBox[{"-", 
          RowBox[{"x", "[", 
           RowBox[{"8", ",", "3"}], "]"}]}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", 
          RowBox[{"x", "[", 
           RowBox[{"8", ",", "3"}], "]"}]}], ",", 
         RowBox[{"x", "[", 
          RowBox[{"8", ",", "3"}], "]"}], ",", 
         RowBox[{"x", "[", 
          RowBox[{"8", ",", "3"}], "]"}]}], "}"}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
         RowBox[{
          RowBox[{"3", "/", "2"}], " ", 
          RowBox[{"x", "[", 
           RowBox[{"8", ",", "3"}], "]"}]}], ",", "0", ",", "0"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{
          RowBox[{"3", "/", "2"}], " ", 
          RowBox[{"x", "[", 
           RowBox[{"8", ",", "3"}], "]"}]}], ",", "0", ",", "0"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{
          RowBox[{"-", 
           RowBox[{"(", 
            RowBox[{"1", "/", "2"}], ")"}]}], " ", 
          RowBox[{"x", "[", 
           RowBox[{"8", ",", "3"}], "]"}]}], ",", "0", ",", 
         RowBox[{"-", 
          RowBox[{"x", "[", 
           RowBox[{"8", ",", "3"}], "]"}]}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{
          RowBox[{"-", 
           RowBox[{"(", 
            RowBox[{"1", "/", "2"}], ")"}]}], " ", 
          RowBox[{"x", "[", 
           RowBox[{"8", ",", "3"}], "]"}]}], ",", "0", ",", 
         RowBox[{"x", "[", 
          RowBox[{"8", ",", "3"}], "]"}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{
          RowBox[{"-", 
           RowBox[{"(", 
            RowBox[{"1", "/", "2"}], ")"}]}], " ", 
          RowBox[{"x", "[", 
           RowBox[{"8", ",", "3"}], "]"}]}], ",", 
         RowBox[{"x", "[", 
          RowBox[{"8", ",", "3"}], "]"}], ",", "0"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{
          RowBox[{"-", 
           RowBox[{"(", 
            RowBox[{"1", "/", "2"}], ")"}]}], " ", 
          RowBox[{"x", "[", 
           RowBox[{"8", ",", "3"}], "]"}]}], ",", 
         RowBox[{"-", 
          RowBox[{"x", "[", 
           RowBox[{"8", ",", "3"}], "]"}]}], ",", "0"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{
          RowBox[{"-", 
           RowBox[{"(", 
            RowBox[{"1", "/", "2"}], ")"}]}], " ", 
          RowBox[{"x", "[", 
           RowBox[{"8", ",", "3"}], "]"}]}], ",", 
         RowBox[{"-", 
          RowBox[{"x", "[", 
           RowBox[{"8", ",", "3"}], "]"}]}], ",", 
         RowBox[{"-", 
          RowBox[{"x", "[", 
           RowBox[{"8", ",", "3"}], "]"}]}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{
          RowBox[{"-", 
           RowBox[{"(", 
            RowBox[{"1", "/", "2"}], ")"}]}], " ", 
          RowBox[{"x", "[", 
           RowBox[{"8", ",", "3"}], "]"}]}], ",", 
         RowBox[{"x", "[", 
          RowBox[{"8", ",", "3"}], "]"}], ",", 
         RowBox[{"x", "[", 
          RowBox[{"8", ",", "3"}], "]"}]}], "}"}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0", ",", 
         RowBox[{
          RowBox[{"-", "2"}], " ", 
          RowBox[{"x", "[", 
           RowBox[{"8", ",", "3"}], "]"}]}], ",", 
         RowBox[{"x", "[", 
          RowBox[{"8", ",", "3"}], "]"}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"0", ",", "0", ",", 
         RowBox[{
          RowBox[{"-", "3"}], " ", 
          RowBox[{"x", "[", 
           RowBox[{"8", ",", "3"}], "]"}]}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"2", " ", 
          RowBox[{"x", "[", 
           RowBox[{"8", ",", "3"}], "]"}]}], ",", "0", ",", 
         RowBox[{"x", "[", 
          RowBox[{"8", ",", "3"}], "]"}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"2", " ", 
          RowBox[{"x", "[", 
           RowBox[{"8", ",", "3"}], "]"}]}], ",", 
         RowBox[{
          RowBox[{"-", "2"}], " ", 
          RowBox[{"x", "[", 
           RowBox[{"8", ",", "3"}], "]"}]}], ",", 
         RowBox[{"x", "[", 
          RowBox[{"8", ",", "3"}], "]"}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"0", ",", 
         RowBox[{"2", " ", 
          RowBox[{"x", "[", 
           RowBox[{"8", ",", "3"}], "]"}]}], ",", 
         RowBox[{"x", "[", 
          RowBox[{"8", ",", "3"}], "]"}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"0", ",", "0", ",", 
         RowBox[{
          RowBox[{"-", "3"}], " ", 
          RowBox[{"x", "[", 
           RowBox[{"8", ",", "3"}], "]"}]}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{
          RowBox[{"-", "2"}], " ", 
          RowBox[{"x", "[", 
           RowBox[{"8", ",", "3"}], "]"}]}], ",", "0", ",", 
         RowBox[{"x", "[", 
          RowBox[{"8", ",", "3"}], "]"}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{
          RowBox[{"-", "2"}], " ", 
          RowBox[{"x", "[", 
           RowBox[{"8", ",", "3"}], "]"}]}], ",", 
         RowBox[{"2", " ", 
          RowBox[{"x", "[", 
           RowBox[{"8", ",", "3"}], "]"}]}], ",", 
         RowBox[{"x", "[", 
          RowBox[{"8", ",", "3"}], "]"}]}], "}"}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
         RowBox[{
          RowBox[{"2", "/", "3"}], " ", 
          RowBox[{"x", "[", 
           RowBox[{"8", ",", "2"}], "]"}]}], ",", 
         RowBox[{
          RowBox[{"-", 
           RowBox[{"(", 
            RowBox[{"1", "/", "3"}], ")"}]}], " ", 
          RowBox[{"x", "[", 
           RowBox[{"8", ",", "2"}], "]"}]}], ",", "0"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{
          RowBox[{"2", "/", "3"}], " ", 
          RowBox[{"x", "[", 
           RowBox[{"8", ",", "2"}], "]"}]}], ",", 
         RowBox[{
          RowBox[{"-", 
           RowBox[{"(", 
            RowBox[{"1", "/", "3"}], ")"}]}], " ", 
          RowBox[{"x", "[", 
           RowBox[{"8", ",", "2"}], "]"}]}], ",", 
         RowBox[{
          RowBox[{"-", 
           RowBox[{"(", 
            RowBox[{"2", "/", "3"}], ")"}]}], " ", 
          RowBox[{"x", "[", 
           RowBox[{"8", ",", "2"}], "]"}]}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{
          RowBox[{"-", 
           RowBox[{"(", 
            RowBox[{"2", "/", "3"}], ")"}]}], " ", 
          RowBox[{"x", "[", 
           RowBox[{"8", ",", "2"}], "]"}]}], ",", 
         RowBox[{
          RowBox[{"-", 
           RowBox[{"(", 
            RowBox[{"1", "/", "3"}], ")"}]}], " ", 
          RowBox[{"x", "[", 
           RowBox[{"8", ",", "2"}], "]"}]}], ",", 
         RowBox[{
          RowBox[{"2", "/", "3"}], " ", 
          RowBox[{"x", "[", 
           RowBox[{"8", ",", "2"}], "]"}]}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{
          RowBox[{"-", 
           RowBox[{"(", 
            RowBox[{"2", "/", "3"}], ")"}]}], " ", 
          RowBox[{"x", "[", 
           RowBox[{"8", ",", "2"}], "]"}]}], ",", 
         RowBox[{
          RowBox[{"-", 
           RowBox[{"(", 
            RowBox[{"1", "/", "3"}], ")"}]}], " ", 
          RowBox[{"x", "[", 
           RowBox[{"8", ",", "2"}], "]"}]}], ",", "0"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"0", ",", 
         RowBox[{"x", "[", 
          RowBox[{"8", ",", "2"}], "]"}], ",", "0"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"0", ",", 
         RowBox[{
          RowBox[{"-", 
           RowBox[{"(", 
            RowBox[{"1", "/", "3"}], ")"}]}], " ", 
          RowBox[{"x", "[", 
           RowBox[{"8", ",", "2"}], "]"}]}], ",", 
         RowBox[{
          RowBox[{"-", 
           RowBox[{"(", 
            RowBox[{"2", "/", "3"}], ")"}]}], " ", 
          RowBox[{"x", "[", 
           RowBox[{"8", ",", "2"}], "]"}]}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"0", ",", 
         RowBox[{
          RowBox[{"-", 
           RowBox[{"(", 
            RowBox[{"1", "/", "3"}], ")"}]}], " ", 
          RowBox[{"x", "[", 
           RowBox[{"8", ",", "2"}], "]"}]}], ",", 
         RowBox[{
          RowBox[{"2", "/", "3"}], " ", 
          RowBox[{"x", "[", 
           RowBox[{"8", ",", "2"}], "]"}]}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"0", ",", 
         RowBox[{"x", "[", 
          RowBox[{"8", ",", "2"}], "]"}], ",", "0"}], "}"}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0", ",", "0", ",", 
         RowBox[{"-", 
          RowBox[{"x", "[", 
           RowBox[{"8", ",", "2"}], "]"}]}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"0", ",", 
         RowBox[{"-", 
          RowBox[{"x", "[", 
           RowBox[{"8", ",", "2"}], "]"}]}], ",", "0"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", 
          RowBox[{"x", "[", 
           RowBox[{"8", ",", "2"}], "]"}]}], ",", 
         RowBox[{"-", 
          RowBox[{"x", "[", 
           RowBox[{"8", ",", "2"}], "]"}]}], ",", 
         RowBox[{"x", "[", 
          RowBox[{"8", ",", "2"}], "]"}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", 
          RowBox[{"x", "[", 
           RowBox[{"8", ",", "2"}], "]"}]}], ",", "0", ",", "0"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"x", "[", 
          RowBox[{"8", ",", "2"}], "]"}], ",", 
         RowBox[{"x", "[", 
          RowBox[{"8", ",", "2"}], "]"}], ",", 
         RowBox[{"-", 
          RowBox[{"x", "[", 
           RowBox[{"8", ",", "2"}], "]"}]}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"x", "[", 
          RowBox[{"8", ",", "2"}], "]"}], ",", "0", ",", "0"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"0", ",", "0", ",", 
         RowBox[{"x", "[", 
          RowBox[{"8", ",", "2"}], "]"}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"0", ",", 
         RowBox[{"x", "[", 
          RowBox[{"8", ",", "2"}], "]"}], ",", "0"}], "}"}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
         RowBox[{
          RowBox[{"1", "/", "2"}], " ", 
          RowBox[{"x", "[", 
           RowBox[{"8", ",", "2"}], "]"}]}], ",", "0", ",", 
         RowBox[{"-", 
          RowBox[{"x", "[", 
           RowBox[{"8", ",", "2"}], "]"}]}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{
          RowBox[{"1", "/", "2"}], " ", 
          RowBox[{"x", "[", 
           RowBox[{"8", ",", "2"}], "]"}]}], ",", "0", ",", 
         RowBox[{"x", "[", 
          RowBox[{"8", ",", "2"}], "]"}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{
          RowBox[{"-", 
           RowBox[{"(", 
            RowBox[{"3", "/", "2"}], ")"}]}], " ", 
          RowBox[{"x", "[", 
           RowBox[{"8", ",", "2"}], "]"}]}], ",", "0", ",", "0"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{
          RowBox[{"-", 
           RowBox[{"(", 
            RowBox[{"3", "/", "2"}], ")"}]}], " ", 
          RowBox[{"x", "[", 
           RowBox[{"8", ",", "2"}], "]"}]}], ",", "0", ",", "0"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{
          RowBox[{"1", "/", "2"}], " ", 
          RowBox[{"x", "[", 
           RowBox[{"8", ",", "2"}], "]"}]}], ",", 
         RowBox[{"x", "[", 
          RowBox[{"8", ",", "2"}], "]"}], ",", 
         RowBox[{"-", 
          RowBox[{"x", "[", 
           RowBox[{"8", ",", "2"}], "]"}]}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{
          RowBox[{"1", "/", "2"}], " ", 
          RowBox[{"x", "[", 
           RowBox[{"8", ",", "2"}], "]"}]}], ",", 
         RowBox[{"-", 
          RowBox[{"x", "[", 
           RowBox[{"8", ",", "2"}], "]"}]}], ",", 
         RowBox[{"x", "[", 
          RowBox[{"8", ",", "2"}], "]"}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{
          RowBox[{"1", "/", "2"}], " ", 
          RowBox[{"x", "[", 
           RowBox[{"8", ",", "2"}], "]"}]}], ",", 
         RowBox[{"-", 
          RowBox[{"x", "[", 
           RowBox[{"8", ",", "2"}], "]"}]}], ",", "0"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{
          RowBox[{"1", "/", "2"}], " ", 
          RowBox[{"x", "[", 
           RowBox[{"8", ",", "2"}], "]"}]}], ",", 
         RowBox[{"x", "[", 
          RowBox[{"8", ",", "2"}], "]"}], ",", "0"}], "}"}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0", ",", 
         RowBox[{
          RowBox[{"-", "3"}], " ", 
          RowBox[{"x", "[", 
           RowBox[{"8", ",", "2"}], "]"}]}], ",", "0"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"0", ",", 
         RowBox[{"x", "[", 
          RowBox[{"8", ",", "2"}], "]"}], ",", 
         RowBox[{
          RowBox[{"-", "2"}], " ", 
          RowBox[{"x", "[", 
           RowBox[{"8", ",", "2"}], "]"}]}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"0", ",", 
         RowBox[{"x", "[", 
          RowBox[{"8", ",", "2"}], "]"}], ",", 
         RowBox[{"2", " ", 
          RowBox[{"x", "[", 
           RowBox[{"8", ",", "2"}], "]"}]}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"0", ",", 
         RowBox[{
          RowBox[{"-", "3"}], " ", 
          RowBox[{"x", "[", 
           RowBox[{"8", ",", "2"}], "]"}]}], ",", "0"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{
          RowBox[{"-", "2"}], " ", 
          RowBox[{"x", "[", 
           RowBox[{"8", ",", "2"}], "]"}]}], ",", 
         RowBox[{"x", "[", 
          RowBox[{"8", ",", "2"}], "]"}], ",", "0"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{
          RowBox[{"-", "2"}], " ", 
          RowBox[{"x", "[", 
           RowBox[{"8", ",", "2"}], "]"}]}], ",", 
         RowBox[{"x", "[", 
          RowBox[{"8", ",", "2"}], "]"}], ",", 
         RowBox[{
          RowBox[{"-", "2"}], " ", 
          RowBox[{"x", "[", 
           RowBox[{"8", ",", "2"}], "]"}]}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"2", " ", 
          RowBox[{"x", "[", 
           RowBox[{"8", ",", "2"}], "]"}]}], ",", 
         RowBox[{"x", "[", 
          RowBox[{"8", ",", "2"}], "]"}], ",", 
         RowBox[{"2", " ", 
          RowBox[{"x", "[", 
           RowBox[{"8", ",", "2"}], "]"}]}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"2", " ", 
          RowBox[{"x", "[", 
           RowBox[{"8", ",", "2"}], "]"}]}], ",", 
         RowBox[{"x", "[", 
          RowBox[{"8", ",", "2"}], "]"}], ",", "0"}], "}"}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
         RowBox[{
          RowBox[{"-", 
           RowBox[{"(", 
            RowBox[{"1", "/", "3"}], ")"}]}], " ", 
          RowBox[{"x", "[", 
           RowBox[{"8", ",", "1"}], "]"}]}], ",", 
         RowBox[{
          RowBox[{"-", 
           RowBox[{"(", 
            RowBox[{"2", "/", "3"}], ")"}]}], " ", 
          RowBox[{"x", "[", 
           RowBox[{"8", ",", "1"}], "]"}]}], ",", 
         RowBox[{
          RowBox[{"-", 
           RowBox[{"(", 
            RowBox[{"2", "/", "3"}], ")"}]}], " ", 
          RowBox[{"x", "[", 
           RowBox[{"8", ",", "1"}], "]"}]}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{
          RowBox[{"-", 
           RowBox[{"(", 
            RowBox[{"1", "/", "3"}], ")"}]}], " ", 
          RowBox[{"x", "[", 
           RowBox[{"8", ",", "1"}], "]"}]}], ",", 
         RowBox[{
          RowBox[{"2", "/", "3"}], " ", 
          RowBox[{"x", "[", 
           RowBox[{"8", ",", "1"}], "]"}]}], ",", 
         RowBox[{
          RowBox[{"2", "/", "3"}], " ", 
          RowBox[{"x", "[", 
           RowBox[{"8", ",", "1"}], "]"}]}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{
          RowBox[{"-", 
           RowBox[{"(", 
            RowBox[{"1", "/", "3"}], ")"}]}], " ", 
          RowBox[{"x", "[", 
           RowBox[{"8", ",", "1"}], "]"}]}], ",", 
         RowBox[{
          RowBox[{"2", "/", "3"}], " ", 
          RowBox[{"x", "[", 
           RowBox[{"8", ",", "1"}], "]"}]}], ",", "0"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{
          RowBox[{"-", 
           RowBox[{"(", 
            RowBox[{"1", "/", "3"}], ")"}]}], " ", 
          RowBox[{"x", "[", 
           RowBox[{"8", ",", "1"}], "]"}]}], ",", 
         RowBox[{
          RowBox[{"-", 
           RowBox[{"(", 
            RowBox[{"2", "/", "3"}], ")"}]}], " ", 
          RowBox[{"x", "[", 
           RowBox[{"8", ",", "1"}], "]"}]}], ",", "0"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{
          RowBox[{"-", 
           RowBox[{"(", 
            RowBox[{"1", "/", "3"}], ")"}]}], " ", 
          RowBox[{"x", "[", 
           RowBox[{"8", ",", "1"}], "]"}]}], ",", "0", ",", 
         RowBox[{
          RowBox[{"-", 
           RowBox[{"(", 
            RowBox[{"2", "/", "3"}], ")"}]}], " ", 
          RowBox[{"x", "[", 
           RowBox[{"8", ",", "1"}], "]"}]}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{
          RowBox[{"-", 
           RowBox[{"(", 
            RowBox[{"1", "/", "3"}], ")"}]}], " ", 
          RowBox[{"x", "[", 
           RowBox[{"8", ",", "1"}], "]"}]}], ",", "0", ",", 
         RowBox[{
          RowBox[{"2", "/", "3"}], " ", 
          RowBox[{"x", "[", 
           RowBox[{"8", ",", "1"}], "]"}]}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"x", "[", 
          RowBox[{"8", ",", "1"}], "]"}], ",", "0", ",", "0"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"x", "[", 
          RowBox[{"8", ",", "1"}], "]"}], ",", "0", ",", "0"}], "}"}]}], 
      "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", 
          RowBox[{"x", "[", 
           RowBox[{"8", ",", "1"}], "]"}]}], ",", 
         RowBox[{"-", 
          RowBox[{"x", "[", 
           RowBox[{"8", ",", "1"}], "]"}]}], ",", 
         RowBox[{"-", 
          RowBox[{"x", "[", 
           RowBox[{"8", ",", "1"}], "]"}]}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", 
          RowBox[{"x", "[", 
           RowBox[{"8", ",", "1"}], "]"}]}], ",", "0", ",", "0"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"0", ",", "0", ",", 
         RowBox[{"x", "[", 
          RowBox[{"8", ",", "1"}], "]"}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"0", ",", 
         RowBox[{"-", 
          RowBox[{"x", "[", 
           RowBox[{"8", ",", "1"}], "]"}]}], ",", "0"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"0", ",", "0", ",", 
         RowBox[{"-", 
          RowBox[{"x", "[", 
           RowBox[{"8", ",", "1"}], "]"}]}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"0", ",", 
         RowBox[{"x", "[", 
          RowBox[{"8", ",", "1"}], "]"}], ",", "0"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"x", "[", 
          RowBox[{"8", ",", "1"}], "]"}], ",", 
         RowBox[{"x", "[", 
          RowBox[{"8", ",", "1"}], "]"}], ",", 
         RowBox[{"x", "[", 
          RowBox[{"8", ",", "1"}], "]"}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"x", "[", 
          RowBox[{"8", ",", "1"}], "]"}], ",", "0", ",", "0"}], "}"}]}], 
      "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0", ",", "0", ",", "0"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"0", ",", "0", ",", "0"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"0", ",", "0", ",", "0"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"0", ",", "0", ",", "0"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"0", ",", "0", ",", "0"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"0", ",", "0", ",", "0"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"0", ",", "0", ",", "0"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"0", ",", "0", ",", "0"}], "}"}]}], "}"}]}], "}"}]}], 
  ";"}]], "Input",
 CellLabel->
  "In[399]:=",ExpressionUUID->"5a2fdef1-be5a-4fb7-8c7a-7c2352c37196"],

Cell[BoxData[
 RowBox[{
  RowBox[{"ixlnsq", "[", 
   RowBox[{"vts_", ",", "ix1_", ",", "ix2_"}], "]"}], " ", ":=", " ", 
  RowBox[{"abssqr", "[", 
   RowBox[{
    RowBox[{"vts", "[", 
     RowBox[{"[", "ix1", "]"}], "]"}], "-", 
    RowBox[{"vts", "[", 
     RowBox[{"[", "ix2", "]"}], "]"}]}], "]"}]}]], "Input",
 CellLabel->
  "In[400]:=",ExpressionUUID->"05dd602b-b8c5-4998-b453-4216c06ff72d"],

Cell[BoxData[
 RowBox[{
  RowBox[{"ixlnsq", "[", 
   RowBox[{"vts_", ",", "ix12_"}], "]"}], " ", ":=", " ", 
  RowBox[{"ixlnsq", "[", 
   RowBox[{"vts", ",", 
    RowBox[{"ix12", "[", 
     RowBox[{"[", "1", "]"}], "]"}], ",", 
    RowBox[{"ix12", "[", 
     RowBox[{"[", "2", "]"}], "]"}]}], "]"}]}]], "Input",
 CellLabel->
  "In[401]:=",ExpressionUUID->"a7c11fd1-7b56-44e5-ba4e-df752078ea0d"],

Cell[BoxData[
 RowBox[{
  RowBox[{"cbvtofsttest", "[", "dvts_", "]"}], " ", ":=", " ", 
  RowBox[{"Module", "[", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{
     "e", ",", "vts", ",", "lens", ",", "ofsts", ",", "rots", ",", "scale", 
      ",", "diags", ",", "angs", ",", "plnr"}], "}"}], ",", 
    "\[IndentingNewLine]", 
    RowBox[{
     RowBox[{"vts", " ", "=", " ", 
      RowBox[{"verts", "[", "\"\<cubalt\>\"", "]"}]}], ";", 
     "\[IndentingNewLine]", 
     RowBox[{"lens", " ", "=", " ", 
      RowBox[{"Factor", "[", 
       RowBox[{
        RowBox[{"D", "[", 
         RowBox[{
          RowBox[{
           RowBox[{
            RowBox[{"ixlnsq", "[", 
             RowBox[{
              RowBox[{"vts", "+", 
               RowBox[{"e", "*", "dvts"}]}], ",", "#"}], "]"}], "&"}], "/@", 
           " ", 
           RowBox[{"igrf", "[", 
            RowBox[{"\"\<oct\>\"", ",", "\"\<eds\>\"", ",", "\"\<fcs\>\""}], 
            "]"}]}], ",", "e"}], "]"}], " ", "/.", " ", 
        RowBox[{"e", "\[Rule]", "0"}]}], " ", "]"}]}], ";", 
     "\[IndentingNewLine]", 
     RowBox[{"ofsts", " ", "=", " ", 
      RowBox[{"Factor", "[", 
       RowBox[{"Total", "[", "dvts", "]"}], "]"}]}], ";", 
     "\[IndentingNewLine]", 
     RowBox[{"rots", " ", "=", " ", 
      RowBox[{"Factor", "[", 
       RowBox[{"Total", "[", 
        RowBox[{
         RowBox[{
          RowBox[{"Cross", "[", 
           RowBox[{
            RowBox[{"#", "[", 
             RowBox[{"[", "1", "]"}], "]"}], ",", 
            RowBox[{"#", "[", 
             RowBox[{"[", "2", "]"}], "]"}]}], "]"}], "&"}], " ", "/@", " ", 
         RowBox[{"Transpose", "[", 
          RowBox[{"{", 
           RowBox[{"vts", ",", "dvts"}], "}"}], "]"}]}], "]"}], "]"}]}], ";", 
     "\[IndentingNewLine]", 
     RowBox[{"scale", " ", "=", " ", 
      RowBox[{"Factor", "[", 
       RowBox[{"Total", "[", 
        RowBox[{
         RowBox[{
          RowBox[{"Dot", "[", 
           RowBox[{
            RowBox[{"#", "[", 
             RowBox[{"[", "1", "]"}], "]"}], ",", 
            RowBox[{"#", "[", 
             RowBox[{"[", "2", "]"}], "]"}]}], "]"}], "&"}], " ", "/@", " ", 
         RowBox[{"Transpose", "[", 
          RowBox[{"{", 
           RowBox[{"vts", ",", "dvts"}], "}"}], "]"}]}], "]"}], "]"}]}], ";", 
     "\[IndentingNewLine]", 
     RowBox[{"diags", " ", "=", " ", 
      RowBox[{"Factor", "[", 
       RowBox[{
        RowBox[{"D", "[", 
         RowBox[{
          RowBox[{"{", 
           RowBox[{
            RowBox[{
             RowBox[{
              RowBox[{"ixlnsq", "[", 
               RowBox[{
                RowBox[{"vts", "+", 
                 RowBox[{"e", "*", "dvts"}]}], ",", 
                RowBox[{"#", "[", 
                 RowBox[{"[", "1", "]"}], "]"}], ",", 
                RowBox[{"#", "[", 
                 RowBox[{"[", "3", "]"}], "]"}]}], "]"}], "&"}], " ", "/@", 
             " ", 
             RowBox[{"igrf", "[", 
              RowBox[{"\"\<oct\>\"", ",", "\"\<vts\>\"", ",", "\"\<fcs\>\""}],
               "]"}]}], ",", 
            RowBox[{
             RowBox[{
              RowBox[{"ixlnsq", "[", 
               RowBox[{
                RowBox[{"vts", "+", 
                 RowBox[{"e", "*", "dvts"}]}], ",", 
                RowBox[{"#", "[", 
                 RowBox[{"[", "2", "]"}], "]"}], ",", 
                RowBox[{"#", "[", 
                 RowBox[{"[", "4", "]"}], "]"}]}], "]"}], "&"}], " ", "/@", 
             " ", 
             RowBox[{"igrf", "[", 
              RowBox[{"\"\<oct\>\"", ",", "\"\<vts\>\"", ",", "\"\<fcs\>\""}],
               "]"}]}]}], "}"}], ",", "e"}], "]"}], " ", "/.", " ", 
        RowBox[{"e", "\[Rule]", "0"}]}], "]"}]}], ";", "\[IndentingNewLine]", 
     
     RowBox[{"angs", " ", "=", " ", 
      RowBox[{"Factor", "[", 
       RowBox[{
        RowBox[{"D", "[", 
         RowBox[{
          RowBox[{
           RowBox[{
            RowBox[{"vtcsangs", "[", 
             RowBox[{
              RowBox[{"vts", "[", 
               RowBox[{"[", "#", "]"}], "]"}], "+", 
              RowBox[{"e", "*", 
               RowBox[{"dvts", "[", 
                RowBox[{"[", "#", "]"}], "]"}]}]}], "]"}], "&"}], " ", "/@", 
           " ", 
           RowBox[{"igrf", "[", 
            RowBox[{"\"\<oct\>\"", ",", "\"\<vts\>\"", ",", "\"\<fcs\>\""}], 
            "]"}]}], ",", "e"}], "]"}], " ", "/.", " ", 
        RowBox[{"e", "\[Rule]", "0"}]}], "]"}]}], ";", "\[IndentingNewLine]", 
     
     RowBox[{"plnr", " ", "=", " ", 
      RowBox[{"Factor", "[", 
       RowBox[{
        RowBox[{"D", "[", 
         RowBox[{
          RowBox[{
           RowBox[{
            RowBox[{"planarity", "[", 
             RowBox[{
              RowBox[{"vts", "[", 
               RowBox[{"[", "#", "]"}], "]"}], "+", 
              RowBox[{"e", "*", 
               RowBox[{"dvts", "[", 
                RowBox[{"[", "#", "]"}], "]"}]}]}], "]"}], "&"}], " ", "/@", 
           " ", 
           RowBox[{"igrf", "[", 
            RowBox[{"\"\<oct\>\"", ",", "\"\<vts\>\"", ",", "\"\<fcs\>\""}], 
            "]"}]}], ",", "e"}], "]"}], " ", "/.", " ", 
        RowBox[{"e", "\[Rule]", "0"}]}], "]"}]}], ";", "\[IndentingNewLine]", 
     
     RowBox[{"{", 
      RowBox[{
      "lens", ",", "ofsts", ",", "rots", ",", "scale", ",", "diags", ",", 
       "angs", ",", "plnr"}], "}"}]}]}], "\[IndentingNewLine]", 
   "]"}]}]], "Input",
 CellLabel->
  "In[402]:=",ExpressionUUID->"0bfc9a58-66c3-4a66-9625-1506d68468e7"],

Cell[BoxData[
 RowBox[{
  RowBox[{"dfsqrlst", "[", "xlst_", "]"}], " ", ":=", " ", 
  RowBox[{
   RowBox[{"Rest", "[", "xlst", "]"}], "-", 
   RowBox[{"First", "[", "xlst", "]"}]}]}]], "Input",
 CellLabel->
  "In[403]:=",ExpressionUUID->"8f1818d6-e6de-47aa-9246-1f2f74adb796"],

Cell[BoxData[
 RowBox[{
  RowBox[{"cbvtofsttstx", "[", "dvts_", "]"}], " ", ":=", " ", 
  RowBox[{
   RowBox[{
    RowBox[{"{", 
     RowBox[{
      RowBox[{"#", "[", 
       RowBox[{"[", "1", "]"}], "]"}], ",", 
      RowBox[{"#", "[", 
       RowBox[{"[", "2", "]"}], "]"}], ",", 
      RowBox[{"#", "[", 
       RowBox[{"[", "3", "]"}], "]"}], ",", 
      RowBox[{"#", "[", 
       RowBox[{"[", "4", "]"}], "]"}], ",", 
      RowBox[{"dfsqrlst", "[", 
       RowBox[{"Flatten", "[", 
        RowBox[{
         RowBox[{"#", "[", 
          RowBox[{"[", "5", "]"}], "]"}], "^", "2"}], "]"}], "]"}], ",", 
      RowBox[{"dfsqrlst", "[", 
       RowBox[{"Flatten", "[", 
        RowBox[{
         RowBox[{"#", "[", 
          RowBox[{"[", "6", "]"}], "]"}], "^", "2"}], "]"}], "]"}], ",", 
      RowBox[{"dfsqrlst", "[", 
       RowBox[{"Flatten", "[", 
        RowBox[{
         RowBox[{"#", "[", 
          RowBox[{"[", "7", "]"}], "]"}], "^", "2"}], "]"}], "]"}]}], "}"}], 
    "&"}], "  ", "@", " ", 
   RowBox[{"cbvtofsttest", "[", "dvts", "]"}]}]}]], "Input",
 CellLabel->
  "In[404]:=",ExpressionUUID->"2b115125-9145-4778-8c6d-55b9d56fb974"],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{
    RowBox[{"cbvtofsttstx", " ", "/@", " ", 
     RowBox[{"verts", "[", "\"\<dfcubaltsol\>\"", "]"}]}], " ", "//", " ", 
    "Factor"}], " ", "//", " ", "Flatten"}], " ", "//", " ", 
  "Union"}]], "Input",
 CellLabel->
  "In[405]:=",ExpressionUUID->"00125ba0-80f5-4495-8b6c-61197fbca1cd"],

Cell[BoxData[
 RowBox[{
  RowBox[{"dyad", "[", 
   RowBox[{"x_", ",", "y_"}], "]"}], " ", ":=", " ", 
  RowBox[{"Outer", "[", 
   RowBox[{"Times", ",", "x", ",", "y"}], "]"}]}]], "Input",
 CellLabel->
  "In[406]:=",ExpressionUUID->"1b4a5abc-48e6-46ba-8b32-210a604336ca"],

Cell[BoxData[
 RowBox[{
  RowBox[{"dyadsum", "[", 
   RowBox[{"xlst_", ",", "ylst_"}], "]"}], " ", ":=", " ", 
  RowBox[{"Total", "[", 
   RowBox[{
    RowBox[{
     RowBox[{"(", 
      RowBox[{"dyad", " ", "@@", " ", "#"}], ")"}], "&"}], " ", "/@", " ", 
    RowBox[{"Transpose", "[", 
     RowBox[{"{", 
      RowBox[{"xlst", ",", "ylst"}], "}"}], "]"}]}], "]"}]}]], "Input",
 CellLabel->
  "In[407]:=",ExpressionUUID->"2cf8586a-1f3a-424a-a5e5-6dc67ee92b5d"],

Cell[BoxData[
 RowBox[{"TableForm", "[", 
  RowBox[{
   RowBox[{
    RowBox[{"Map", "[", 
     RowBox[{
      RowBox[{
       RowBox[{"Union", "[", 
        RowBox[{"Flatten", "[", "#", "]"}], "]"}], "&"}], ",", "#", ",", 
      RowBox[{"{", "1", "}"}]}], "]"}], "&"}], " ", "/@", " ", 
   RowBox[{"(", 
    RowBox[{
     RowBox[{
      RowBox[{"Drop", "[", 
       RowBox[{"#", ",", "4"}], "]"}], "&"}], " ", "/@", " ", 
     RowBox[{"(", 
      RowBox[{"cbvtofsttest", " ", "/@", " ", 
       RowBox[{"verts", "[", "\"\<dfcubaltsol\>\"", "]"}]}], ")"}]}], ")"}]}],
   "]"}]], "Input",
 CellLabel->
  "In[408]:=",ExpressionUUID->"6d1c867e-40ab-4869-8dc0-b46a29f83b52"],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"MatrixForm", "[", 
    RowBox[{"dyadsum", "[", 
     RowBox[{
      RowBox[{"verts", "[", "\"\<cubalt\>\"", "]"}], ",", "#"}], "]"}], "]"}],
    "&"}], " ", "/@", " ", 
  RowBox[{"verts", "[", "\"\<dfcubaltsol\>\"", "]"}]}]], "Input",
 CellLabel->
  "In[409]:=",ExpressionUUID->"3e197411-e72b-40a5-b8de-797b32587ca5"],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"MatrixForm", "[", 
    RowBox[{"dyadsum", "[", 
     RowBox[{"#", ",", "#"}], "]"}], "]"}], "&"}], " ", "/@", " ", 
  RowBox[{"verts", "[", "\"\<dfcubaltsol\>\"", "]"}]}]], "Input",
 CellLabel->
  "In[410]:=",ExpressionUUID->"9416b9bf-e23f-4037-8dc7-292df51aeb81"]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{

Cell["Plots", "Section",ExpressionUUID->"0c022035-182f-4b91-b097-8fc282ba69cd"],

Cell[BoxData[
 RowBox[{
  RowBox[{"piplot", "[", 
   RowBox[{"t_", ",", "tf_", ",", "tv_"}], "]"}], ":=", 
  RowBox[{"Graphics3D", "[", 
   RowBox[{
    RowBox[{"GraphicsComplex", "[", 
     RowBox[{
      RowBox[{"pts", "[", 
       RowBox[{"t", ",", "tv"}], "]"}], ",", 
      RowBox[{"Polygon", "/@", 
       RowBox[{"igrf", "[", 
        RowBox[{"t", ",", "tf", ",", "tv"}], "]"}]}]}], "]"}], ",", 
    RowBox[{"SphericalRegion", "\[Rule]", "True"}]}], "]"}]}]], "Input",
 CellLabel->
  "In[411]:=",ExpressionUUID->"c32f333f-90f6-4ebd-9c03-23c33853f0cd"],

Cell[BoxData[
 RowBox[{"(*", " ", 
  RowBox[{
   RowBox[{
   "Currently", " ", "specialized", " ", "for", " ", "the", " ", "Platonic", 
    " ", 
    RowBox[{"solids", " ", "--"}], " ", "make", " ", "them", " ", "general"}],
    ",", " ", 
   RowBox[{"like", " ", "for", " ", "the", " ", "rhombic", " ", "case"}]}], 
  " ", "*)"}]], "Input",
 CellLabel->
  "In[412]:=",ExpressionUUID->"9312772d-f349-4397-b766-a83ae3d948b2"],

Cell[BoxData[
 RowBox[{
  RowBox[{"ptsplot", "[", 
   RowBox[{"vts_", ",", "lnixs_", ",", "colors_"}], "]"}], " ", ":=", " ", 
  RowBox[{"Graphics3D", "[", 
   RowBox[{
    RowBox[{"GraphicsComplex", "[", 
     RowBox[{"vts", ",", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"Line", "[", "lnixs", "]"}], ",", 
        RowBox[{"PointSize", "[", "Large", "]"}], ",", 
        RowBox[{"Transpose", "[", 
         RowBox[{"{", 
          RowBox[{"colors", ",", 
           RowBox[{"Point", " ", "/@", " ", 
            RowBox[{"Range", "[", 
             RowBox[{"Length", "[", "vts", "]"}], "]"}]}]}], "}"}], "]"}]}], 
       "}"}]}], "]"}], ",", 
    RowBox[{"SphericalRegion", "\[Rule]", "True"}]}], "]"}]}]], "Input",
 CellLabel->
  "In[413]:=",ExpressionUUID->"b9a1e6bb-99de-40d1-9e1b-4284cf5d9d9d"],

Cell[BoxData[
 RowBox[{
  RowBox[{"edsplot", "[", 
   RowBox[{"vts_", ",", "lnixs_", ",", "colors_"}], "]"}], " ", ":=", " ", 
  RowBox[{"Graphics3D", "[", 
   RowBox[{
    RowBox[{"GraphicsComplex", "[", 
     RowBox[{"vts", ",", 
      RowBox[{"Transpose", "[", 
       RowBox[{"{", 
        RowBox[{"colors", ",", 
         RowBox[{"Line", " ", "/@", " ", "lnixs"}]}], "}"}], "]"}]}], "]"}], 
    ",", 
    RowBox[{"SphericalRegion", "\[Rule]", "True"}]}], "]"}]}]], "Input",
 CellLabel->
  "In[414]:=",ExpressionUUID->"aa60dff4-8c16-40b4-96a5-43a202d43e86"],

Cell[BoxData[
 RowBox[{
  RowBox[{"ptxlblplot", "[", 
   RowBox[{"t_", ",", "flipped_", ",", "colors_"}], "]"}], " ", ":=", " ", 
  RowBox[{"Module", "[", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{"tv", ",", "tf"}], "}"}], ",", "\[IndentingNewLine]", 
    RowBox[{
     RowBox[{"tv", " ", "=", " ", 
      RowBox[{"If", "[", 
       RowBox[{"flipped", ",", "\"\<fcs\>\"", ",", "\"\<vts\>\""}], "]"}]}], 
     ";", "\[IndentingNewLine]", 
     RowBox[{"tf", " ", "=", " ", 
      RowBox[{"If", "[", 
       RowBox[{"flipped", ",", "\"\<vts\>\"", ",", "\"\<fcs\>\""}], "]"}]}], 
     ";", "\[IndentingNewLine]", 
     RowBox[{
      RowBox[{
       RowBox[{"ptsplot", "[", 
        RowBox[{
         RowBox[{"pts", "[", 
          RowBox[{"t", ",", "tv"}], "]"}], ",", 
         RowBox[{"igrf", "[", 
          RowBox[{"t", ",", "\"\<eds\>\"", ",", "tv"}], "]"}], ",", "#"}], 
        " ", "]"}], "&"}], " ", "/@", " ", 
      RowBox[{"FindBdryLblsRR", "[", 
       RowBox[{
        RowBox[{"igrf", "[", 
         RowBox[{"t", ",", "tf", ",", "tv"}], "]"}], ",", "colors"}], 
       "]"}]}]}]}], "\[IndentingNewLine]", "]"}]}]], "Input",
 CellLabel->
  "In[415]:=",ExpressionUUID->"4823ddb5-cbad-4c70-b5e9-c993214fb9b4"],

Cell[BoxData[
 RowBox[{
  RowBox[{"edxlblplot", "[", 
   RowBox[{"t_", ",", "flipped_", ",", "colors_"}], "]"}], " ", ":=", "  ", 
  RowBox[{"Module", "[", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{"tv", ",", "tf"}], "}"}], ",", "\[IndentingNewLine]", 
    RowBox[{
     RowBox[{"tv", " ", "=", " ", 
      RowBox[{"If", "[", 
       RowBox[{"flipped", ",", "\"\<fcs\>\"", ",", "\"\<vts\>\""}], "]"}]}], 
     ";", "\[IndentingNewLine]", 
     RowBox[{"tf", " ", "=", " ", 
      RowBox[{"If", "[", 
       RowBox[{"flipped", ",", "\"\<vts\>\"", ",", "\"\<fcs\>\""}], "]"}]}], 
     ";", 
     RowBox[{
      RowBox[{
       RowBox[{"edsplot", "[", 
        RowBox[{
         RowBox[{"pts", "[", 
          RowBox[{"t", ",", "tv"}], "]"}], ",", 
         RowBox[{"igrf", "[", 
          RowBox[{"t", ",", "\"\<eds\>\"", ",", "tv"}], "]"}], ",", "#"}], 
        " ", "]"}], "&"}], " ", "/@", " ", 
      RowBox[{"FindBdryLblsRR", "[", 
       RowBox[{
        RowBox[{"igrf", "[", 
         RowBox[{"t", ",", "tf", ",", "\"\<eds\>\""}], "]"}], ",", "colors"}],
        "]"}]}]}]}], "\[IndentingNewLine]", "]"}]}]], "Input",
 CellLabel->
  "In[416]:=",ExpressionUUID->"454e9118-1295-4817-af65-47978b9dde3c"],

Cell[BoxData[
 RowBox[{
  RowBox[{"ptsrmbplot", "[", 
   RowBox[{"t_", ",", "colors_"}], "]"}], " ", ":=", " ", 
  RowBox[{"Module", "[", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{
     "pv", ",", "pf", ",", "rfc", ",", "red", ",", "rfced", ",", "px"}], 
     "}"}], ",", "\[IndentingNewLine]", 
    RowBox[{
     RowBox[{"pv", " ", "=", " ", 
      RowBox[{"pts", "[", 
       RowBox[{"t", ",", "\"\<vts\>\""}], "]"}]}], ";", "\[IndentingNewLine]", 
     RowBox[{"pf", " ", "=", " ", 
      RowBox[{"pts", "[", 
       RowBox[{"t", ",", "\"\<fcs\>\""}], "]"}]}], ";", "\[IndentingNewLine]", 
     RowBox[{
      RowBox[{"{", 
       RowBox[{"rfc", ",", "red", ",", "rfced"}], "}"}], " ", "=", " ", 
      RowBox[{"makerhombedges", "[", "t", "]"}]}], ";", "\[IndentingNewLine]", 
     RowBox[{"px", " ", "=", " ", 
      RowBox[{"Join", "[", 
       RowBox[{"pv", ",", "pf"}], "]"}]}], ";", "\[IndentingNewLine]", 
     RowBox[{"Graphics3D", "[", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
         RowBox[{
          RowBox[{
           RowBox[{"Line", "[", 
            RowBox[{"{", 
             RowBox[{
              RowBox[{"pv", "[", 
               RowBox[{"[", 
                RowBox[{"#", "[", 
                 RowBox[{"[", "1", "]"}], "]"}], "]"}], "]"}], ",", 
              RowBox[{"pf", "[", 
               RowBox[{"[", 
                RowBox[{"#", "[", 
                 RowBox[{"[", "2", "]"}], "]"}], "]"}], "]"}]}], "}"}], "]"}],
            "&"}], " ", "/@", " ", "red"}], ",", 
         RowBox[{"PointSize", "[", "Large", "]"}], ",", 
         RowBox[{"Transpose", "[", 
          RowBox[{"{", 
           RowBox[{"colors", ",", 
            RowBox[{"Point", " ", "/@", " ", "px"}]}], "}"}], "]"}]}], "}"}], 
       ",", 
       RowBox[{"SphericalRegion", "\[Rule]", "True"}]}], "]"}]}]}], 
   "\[IndentingNewLine]", "]"}]}]], "Input",
 CellLabel->
  "In[417]:=",ExpressionUUID->"0d5d9e16-7644-4289-b1cf-a03adfdb60d4"],

Cell[BoxData[
 RowBox[{
  RowBox[{"edsrmbplot", "[", 
   RowBox[{"t_", ",", "colors_"}], "]"}], " ", ":=", " ", 
  RowBox[{"Module", "[", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{"pv", ",", "pf", ",", "rfc", ",", "red", ",", "rfced"}], "}"}], 
    ",", "\[IndentingNewLine]", 
    RowBox[{
     RowBox[{"pv", " ", "=", " ", 
      RowBox[{"pts", "[", 
       RowBox[{"t", ",", "\"\<vts\>\""}], "]"}]}], ";", "\[IndentingNewLine]", 
     RowBox[{"pf", " ", "=", " ", 
      RowBox[{"pts", "[", 
       RowBox[{"t", ",", "\"\<fcs\>\""}], "]"}]}], ";", "\[IndentingNewLine]", 
     RowBox[{
      RowBox[{"{", 
       RowBox[{"rfc", ",", "red", ",", "rfced"}], "}"}], " ", "=", " ", 
      RowBox[{"makerhombedges", "[", "t", "]"}]}], ";", "\[IndentingNewLine]", 
     RowBox[{"Graphics3D", "[", 
      RowBox[{
       RowBox[{"Transpose", "[", 
        RowBox[{"{", 
         RowBox[{"colors", ",", 
          RowBox[{
           RowBox[{
            RowBox[{"Line", "[", 
             RowBox[{"{", 
              RowBox[{
               RowBox[{"pv", "[", 
                RowBox[{"[", 
                 RowBox[{"#", "[", 
                  RowBox[{"[", "1", "]"}], "]"}], "]"}], "]"}], ",", 
               RowBox[{"pf", "[", 
                RowBox[{"[", 
                 RowBox[{"#", "[", 
                  RowBox[{"[", "2", "]"}], "]"}], "]"}], "]"}]}], "}"}], 
             "]"}], "&"}], " ", "/@", " ", "red"}]}], "}"}], "]"}], ",", 
       RowBox[{"SphericalRegion", "\[Rule]", "True"}]}], "]"}]}]}], 
   "\[IndentingNewLine]", "]"}]}]], "Input",
 CellLabel->
  "In[418]:=",ExpressionUUID->"c48c7610-794e-4cc2-936e-4b282ac697b4"],

Cell[BoxData[
 RowBox[{
  RowBox[{"ptxrhblblplot", "[", 
   RowBox[{"t_", ",", "colors_"}], "]"}], " ", ":=", " ", 
  RowBox[{"Module", "[", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{
     "pv", ",", "pf", ",", "rfc", ",", "red", ",", "rfced", ",", "n", ",", 
      "rfcx"}], "}"}], ",", "\[IndentingNewLine]", 
    RowBox[{
     RowBox[{"pv", " ", "=", " ", 
      RowBox[{"pts", "[", 
       RowBox[{"t", ",", "\"\<vts\>\""}], "]"}]}], ";", "\[IndentingNewLine]", 
     RowBox[{"pf", " ", "=", " ", 
      RowBox[{"pts", "[", 
       RowBox[{"t", ",", "\"\<fcs\>\""}], "]"}]}], ";", "\[IndentingNewLine]", 
     RowBox[{
      RowBox[{"{", 
       RowBox[{"rfc", ",", "red", ",", "rfced"}], "}"}], " ", "=", " ", 
      RowBox[{"makerhombedges", "[", "t", "]"}]}], ";", "\[IndentingNewLine]", 
     RowBox[{"n", " ", "=", " ", 
      RowBox[{"Length", "[", "pv", "]"}]}], ";", "\[IndentingNewLine]", 
     RowBox[{"rfcx", " ", "=", " ", 
      RowBox[{
       RowBox[{
        RowBox[{"(", 
         RowBox[{
          RowBox[{"{", 
           RowBox[{"0", ",", "n", ",", "0", ",", "n"}], "}"}], "+", "#"}], 
         ")"}], "&"}], " ", "/@", " ", "rfc"}]}], ";", "\[IndentingNewLine]", 
     
     RowBox[{
      RowBox[{
       RowBox[{"ptsrmbplot", "[", 
        RowBox[{"t", ",", "#"}], "]"}], "&"}], " ", "/@", " ", 
      RowBox[{"FindBdryLbls", "[", 
       RowBox[{"rfcx", ",", 
        RowBox[{"rotrfl", "[", 
         RowBox[{"colors", ",", "2", ",", "1"}], "]"}]}], "]"}]}]}]}], 
   "\[IndentingNewLine]", "]"}]}]], "Input",
 CellLabel->
  "In[419]:=",ExpressionUUID->"7c034144-7ac8-42ad-98cb-9f6272a48b31"],

Cell[BoxData[
 RowBox[{
  RowBox[{"edxrhblblplot", "[", 
   RowBox[{"t_", ",", "colors_"}], "]"}], " ", ":=", " ", 
  RowBox[{"Module", "[", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{"rfc", ",", "red", ",", "rfced"}], "}"}], ",", 
    "\[IndentingNewLine]", 
    RowBox[{
     RowBox[{
      RowBox[{"{", 
       RowBox[{"rfc", ",", "red", ",", "rfced"}], "}"}], " ", "=", " ", 
      RowBox[{"makerhombedges", "[", "t", "]"}]}], ";", "\[IndentingNewLine]", 
     RowBox[{
      RowBox[{
       RowBox[{"edsrmbplot", "[", 
        RowBox[{"t", ",", "#"}], "]"}], "&"}], " ", "/@", " ", 
      RowBox[{"FindBdryLbls", "[", 
       RowBox[{"rfced", ",", 
        RowBox[{"rotrfl", "[", 
         RowBox[{"colors", ",", "2"}], "]"}]}], "]"}]}]}]}], 
   "\[IndentingNewLine]", "]"}]}]], "Input",
 CellLabel->
  "In[420]:=",ExpressionUUID->"42fe9301-a78f-4a8b-b315-37006cb971ec"],

Cell[BoxData[
 RowBox[{
  RowBox[{"gatherwith", "[", 
   RowBox[{"xs_", ",", "ixs_"}], "]"}], " ", ":=", " ", 
  RowBox[{"Map", "[", 
   RowBox[{"First", ",", 
    RowBox[{"Gather", "[", 
     RowBox[{
      RowBox[{"Transpose", "[", 
       RowBox[{"{", 
        RowBox[{"xs", ",", "ixs"}], "}"}], "]"}], ",", 
      RowBox[{
       RowBox[{
        RowBox[{"Last", "[", "#1", "]"}], "===", 
        RowBox[{"Last", "[", "#2", "]"}]}], "&"}]}], "]"}], ",", 
    RowBox[{"{", "2", "}"}]}], "]"}]}]], "Input",
 CellLabel->
  "In[421]:=",ExpressionUUID->"1de168c5-e2e9-4df6-9992-ee901b1c204e"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"piplot", "[", 
    RowBox[{"\"\<oct\>\"", ",", "\"\<fcs\>\"", ",", "\"\<vts\>\""}], "]"}], 
   ",", 
   RowBox[{"piplot", "[", 
    RowBox[{"\"\<oct\>\"", ",", "\"\<vts\>\"", ",", "\"\<fcs\>\""}], "]"}], 
   ",", 
   RowBox[{"piplot", "[", 
    RowBox[{"\"\<oct\>\"", ",", "\"\<vts\>\"", ",", "\"\<eds\>\""}], "]"}], 
   ",", 
   RowBox[{"piplot", "[", 
    RowBox[{"\"\<oct\>\"", ",", "\"\<fcs\>\"", ",", "\"\<eds\>\""}], "]"}]}], 
  "}"}]], "Input",
 CellLabel->
  "In[422]:=",ExpressionUUID->"d4be83a9-df29-4a37-a452-96719eac735b"],

Cell[CellGroupData[{

Cell["Tetrahedron", "Subsection",ExpressionUUID->"f3731d7b-bdc7-42e4-92da-5489985f0767"],

Cell[BoxData[
 RowBox[{"edxlblplot", "[", 
  RowBox[{"\"\<tet\>\"", ",", "False", ",", 
   RowBox[{"{", 
    RowBox[{"Red", ",", "Red", ",", "Blue"}], "}"}]}], "]"}]], "Input",
 CellLabel->
  "In[423]:=",ExpressionUUID->"e57e5afd-0f4a-4611-998e-5b16a8edd7fe"],

Cell[BoxData[
 RowBox[{"edxlblplot", "[", 
  RowBox[{"\"\<tet\>\"", ",", "False", ",", 
   RowBox[{"{", 
    RowBox[{"Red", ",", 
     RowBox[{"Darker", "[", "Green", "]"}], ",", "Blue"}], "}"}]}], 
  "]"}]], "Input",
 CellLabel->
  "In[424]:=",ExpressionUUID->"0d4c1c92-180b-42c1-8289-c023735dbc46"],

Cell[BoxData[
 RowBox[{" ", 
  RowBox[{
   RowBox[{"bdlbls", "[", 
    RowBox[{"\"\<tet\>\"", ",", "\"\<eds\>\"", ",", "2"}], "]"}], " ", "=", 
   " ", 
   RowBox[{"FindBdryLblsRR", "[", 
    RowBox[{
     RowBox[{"igrf", "[", 
      RowBox[{"\"\<tet\>\"", ",", "\"\<fcs\>\"", ",", "\"\<eds\>\""}], "]"}], 
     ",", 
     RowBox[{"{", 
      RowBox[{"1", ",", "1", ",", "3"}], "}"}]}], "]"}]}]}]], "Input",
 CellLabel->
  "In[425]:=",ExpressionUUID->"00c8b0e9-ed63-4787-a023-87cbac8d4a5a"],

Cell[BoxData[
 RowBox[{"  ", 
  RowBox[{
   RowBox[{"bdlbls", "[", 
    RowBox[{"\"\<tet\>\"", ",", "\"\<eds\>\"", ",", "3"}], "]"}], " ", "=", 
   " ", 
   RowBox[{"FindBdryLblsRR", "[", 
    RowBox[{
     RowBox[{"igrf", "[", 
      RowBox[{"\"\<tet\>\"", ",", "\"\<fcs\>\"", ",", "\"\<eds\>\""}], "]"}], 
     ",", 
     RowBox[{"{", 
      RowBox[{"1", ",", "2", ",", "3"}], "}"}]}], "]"}]}]}]], "Input",
 CellLabel->
  "In[426]:=",ExpressionUUID->"bf604dbc-e580-4a0f-ab21-ac6989d7b7a3"],

Cell[BoxData[
 RowBox[{" ", 
  RowBox[{
   RowBox[{"bdlbls", "[", 
    RowBox[{"\"\<tet\>\"", ",", "\"\<eds\>\"", ",", "2"}], "]"}], "===", 
   RowBox[{"(", 
    RowBox[{
     RowBox[{"bdlbls", "[", 
      RowBox[{"\"\<tet\>\"", ",", "\"\<eds\>\"", ",", "3"}], "]"}], " ", "/.",
      " ", 
     RowBox[{"2", "\[Rule]", "1"}]}], ")"}]}]}]], "Input",
 CellLabel->
  "In[427]:=",ExpressionUUID->"5fe3bab3-514f-4547-9cd4-0bac0cbaef69"],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"(", 
    RowBox[{"Total", " ", "/@", " ", 
     RowBox[{"gatherwith", "[", 
      RowBox[{
       RowBox[{"pts", "[", 
        RowBox[{"\"\<tet\>\"", ",", "\"\<eds\>\""}], "]"}], ",", "#"}], 
      "]"}]}], ")"}], "&"}], "  ", "/@", " ", 
  RowBox[{"bdlbls", "[", 
   RowBox[{"\"\<tet\>\"", ",", "\"\<eds\>\"", ",", "3"}], "]"}]}]], "Input",
 CellLabel->
  "In[428]:=",ExpressionUUID->"edadf389-2254-401d-ac4a-2512cc16bd77"],

Cell[BoxData[
 RowBox[{"(*", " ", 
  RowBox[{"Opposite", " ", "sides"}], " ", "*)"}]], "Input",
 CellLabel->
  "In[429]:=",ExpressionUUID->"51dec439-a163-4118-9efc-5842292933b0"]
}, Closed]],

Cell[CellGroupData[{

Cell["Octahedron", "Subsection",ExpressionUUID->"52c91f63-30ed-4380-8295-916353686b51"],

Cell[BoxData[
 RowBox[{"ptxlblplot", "[", 
  RowBox[{"\"\<oct\>\"", ",", "False", ",", 
   RowBox[{"{", 
    RowBox[{"Red", ",", "Red", ",", "Blue"}], "}"}]}], "]"}]], "Input",
 CellLabel->
  "In[430]:=",ExpressionUUID->"f69c2cbd-302c-4297-81cb-e21c0c61c093"],

Cell[BoxData[
 RowBox[{"ptxlblplot", "[", 
  RowBox[{"\"\<oct\>\"", ",", "False", ",", 
   RowBox[{"{", 
    RowBox[{"Red", ",", 
     RowBox[{"Darker", "[", "Green", "]"}], ",", "Blue"}], "}"}]}], 
  "]"}]], "Input",
 CellLabel->
  "In[431]:=",ExpressionUUID->"fb4a87d7-0b33-4bbe-be84-049b3d1b483d"],

Cell[BoxData[
 RowBox[{" ", 
  RowBox[{
   RowBox[{"bdlbls", "[", 
    RowBox[{"\"\<oct\>\"", ",", "\"\<vts\>\"", ",", "2"}], "]"}], " ", "=", 
   " ", 
   RowBox[{"FindBdryLblsRR", "[", 
    RowBox[{
     RowBox[{"igrf", "[", 
      RowBox[{"\"\<oct\>\"", ",", "\"\<fcs\>\"", ",", "\"\<vts\>\""}], "]"}], 
     ",", 
     RowBox[{"{", 
      RowBox[{"1", ",", "1", ",", "3"}], "}"}]}], "]"}]}]}]], "Input",
 CellLabel->
  "In[432]:=",ExpressionUUID->"fb940cfa-9c5c-4b96-9080-7c9eaab65e34"],

Cell[BoxData[
 RowBox[{" ", 
  RowBox[{
   RowBox[{"bdlbls", "[", 
    RowBox[{"\"\<oct\>\"", ",", "\"\<vts\>\"", ",", "3"}], "]"}], " ", "=", 
   " ", 
   RowBox[{"FindBdryLblsRR", "[", 
    RowBox[{
     RowBox[{"igrf", "[", 
      RowBox[{"\"\<oct\>\"", ",", "\"\<fcs\>\"", ",", "\"\<vts\>\""}], "]"}], 
     ",", 
     RowBox[{"{", 
      RowBox[{"1", ",", "2", ",", "3"}], "}"}]}], "]"}]}]}]], "Input",
 CellLabel->
  "In[433]:=",ExpressionUUID->"4fb9b830-4dd2-4216-a41c-8e9847a3c534"],

Cell[BoxData[
 RowBox[{" ", 
  RowBox[{
   RowBox[{"bdlbls", "[", 
    RowBox[{"\"\<oct\>\"", ",", "\"\<vts\>\"", ",", "2"}], "]"}], "===", 
   RowBox[{"(", 
    RowBox[{
     RowBox[{"bdlbls", "[", 
      RowBox[{"\"\<oct\>\"", ",", "\"\<vts\>\"", ",", "3"}], "]"}], " ", "/.",
      " ", 
     RowBox[{"2", "\[Rule]", "1"}]}], ")"}]}]}]], "Input",
 CellLabel->
  "In[434]:=",ExpressionUUID->"78a416c6-3d70-4251-9f17-51132390109f"],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"(", 
    RowBox[{"Total", " ", "/@", " ", 
     RowBox[{"gatherwith", "[", 
      RowBox[{
       RowBox[{"pts", "[", 
        RowBox[{"\"\<oct\>\"", ",", "\"\<vts\>\""}], "]"}], ",", "#"}], 
      "]"}]}], ")"}], "&"}], "  ", "/@", " ", 
  RowBox[{"bdlbls", "[", 
   RowBox[{"\"\<oct\>\"", ",", "\"\<vts\>\"", ",", "3"}], "]"}]}]], "Input",
 CellLabel->
  "In[435]:=",ExpressionUUID->"80169392-b1fc-458e-a3e7-40fea9f619d4"],

Cell[BoxData[
 RowBox[{"edxlblplot", "[", 
  RowBox[{"\"\<oct\>\"", ",", "False", ",", 
   RowBox[{"{", 
    RowBox[{"Red", ",", "Red", ",", "Blue"}], "}"}]}], "]"}]], "Input",
 CellLabel->
  "In[436]:=",ExpressionUUID->"45997b41-7603-4725-8038-e1c72c829a0c"],

Cell[BoxData[
 RowBox[{"edxlblplot", "[", 
  RowBox[{"\"\<oct\>\"", ",", "False", ",", 
   RowBox[{"{", 
    RowBox[{"Red", ",", 
     RowBox[{"Darker", "[", "Green", "]"}], ",", "Blue"}], "}"}]}], 
  "]"}]], "Input",
 CellLabel->
  "In[437]:=",ExpressionUUID->"a7cab8ac-f0f9-4cdb-b9dc-bd758487498f"],

Cell[BoxData[
 RowBox[{
  RowBox[{"bdlbls", "[", 
   RowBox[{"\"\<oct\>\"", ",", "\"\<eds\>\"", ",", "2"}], "]"}], " ", "=", 
  " ", 
  RowBox[{"FindBdryLblsRR", "[", 
   RowBox[{
    RowBox[{"igrf", "[", 
     RowBox[{"\"\<oct\>\"", ",", "\"\<fcs\>\"", ",", "\"\<eds\>\""}], "]"}], 
    ",", 
    RowBox[{"{", 
     RowBox[{"1", ",", "1", ",", "3"}], "}"}]}], "]"}]}]], "Input",
 CellLabel->
  "In[438]:=",ExpressionUUID->"3e55e29e-60b6-4241-b7a2-04aea9924b72"],

Cell[BoxData[
 RowBox[{
  RowBox[{"bdlbls", "[", 
   RowBox[{"\"\<oct\>\"", ",", "\"\<eds\>\"", ",", "3"}], "]"}], " ", "=", 
  " ", 
  RowBox[{"FindBdryLblsRR", "[", 
   RowBox[{
    RowBox[{"igrf", "[", 
     RowBox[{"\"\<oct\>\"", ",", "\"\<fcs\>\"", ",", "\"\<eds\>\""}], "]"}], 
    ",", 
    RowBox[{"{", 
     RowBox[{"1", ",", "2", ",", "3"}], "}"}]}], "]"}]}]], "Input",
 CellLabel->
  "In[439]:=",ExpressionUUID->"d37404fc-a820-4c1d-b58f-ed09101f52ad"],

Cell[BoxData[
 RowBox[{" ", 
  RowBox[{
   RowBox[{"Union", "[", 
    RowBox[{"bdlbls", "[", 
     RowBox[{"\"\<oct\>\"", ",", "\"\<eds\>\"", ",", "2"}], "]"}], "]"}], "===", 
   RowBox[{"Union", "[", 
    RowBox[{
     RowBox[{"bdlbls", "[", 
      RowBox[{"\"\<oct\>\"", ",", "\"\<eds\>\"", ",", "3"}], "]"}], " ", "/.",
      " ", 
     RowBox[{"2", "\[Rule]", "1"}]}], "]"}]}]}]], "Input",
 CellLabel->
  "In[440]:=",ExpressionUUID->"4b7143ac-e831-447d-8f91-069fb53d733d"],

Cell[BoxData[
 RowBox[{
  RowBox[{"tenstotal", "[", "xvs_", "]"}], " ", ":=", " ", 
  RowBox[{"Total", "[", 
   RowBox[{
    RowBox[{
     RowBox[{"Outer", "[", 
      RowBox[{"Times", ",", "#", ",", "#"}], "]"}], "&"}], " ", "/@", " ", 
    "xvs"}], "]"}]}]], "Input",
 CellLabel->
  "In[441]:=",ExpressionUUID->"1d3e77de-083a-492a-b40e-5af43a9f1a0d"],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{
    RowBox[{"(", 
     RowBox[{"tenstotal", " ", "/@", " ", 
      RowBox[{"gatherwith", "[", 
       RowBox[{
        RowBox[{"pts", "[", 
         RowBox[{"\"\<oct\>\"", ",", "\"\<eds\>\""}], "]"}], ",", "#"}], 
       "]"}]}], ")"}], "&"}], "  ", "/@", " ", 
   RowBox[{"bdlbls", "[", 
    RowBox[{"\"\<oct\>\"", ",", "\"\<eds\>\"", ",", "3"}], "]"}]}], " ", "//",
   " ", "TableForm"}]], "Input",
 CellLabel->
  "In[442]:=",ExpressionUUID->"cde18afb-d56a-4ec4-967e-fec292233223"]
}, Closed]],

Cell[CellGroupData[{

Cell["Cube", "Subsection",ExpressionUUID->"63b9f30f-c873-48f7-8278-323aea11fad4"],

Cell[BoxData[
 RowBox[{"ptxlblplot", "[", 
  RowBox[{"\"\<oct\>\"", ",", "True", ",", 
   RowBox[{"{", 
    RowBox[{"Red", ",", "Red", ",", "Red", ",", "Blue"}], "}"}]}], 
  "]"}]], "Input",
 CellLabel->
  "In[443]:=",ExpressionUUID->"aac127f0-ab12-4358-a109-e713e51c868e"],

Cell[BoxData[
 RowBox[{"ptxlblplot", "[", 
  RowBox[{"\"\<oct\>\"", ",", "True", ",", 
   RowBox[{"{", 
    RowBox[{"Red", ",", "Blue", ",", "Red", ",", "Blue"}], "}"}]}], 
  "]"}]], "Input",
 CellLabel->
  "In[444]:=",ExpressionUUID->"284ecadf-3a8e-4fc9-bd23-abf9512ee8fa"],

Cell[BoxData[
 RowBox[{" ", 
  RowBox[{
   RowBox[{"bdlbls", "[", 
    RowBox[{"\"\<cub\>\"", ",", "\"\<vts\>\"", ",", "1"}], "]"}], " ", "=", 
   " ", 
   RowBox[{"FindBdryLblsRR", "[", 
    RowBox[{
     RowBox[{"igrf", "[", 
      RowBox[{"\"\<oct\>\"", ",", "\"\<vts\>\"", ",", "\"\<fcs\>\""}], "]"}], 
     ",", 
     RowBox[{"{", 
      RowBox[{"1", ",", "1", ",", "1", ",", "2"}], "}"}]}], 
    "]"}]}]}]], "Input",
 CellLabel->
  "In[445]:=",ExpressionUUID->"e356db54-4ab7-42da-ba7b-d12b87e1f3a2"],

Cell[BoxData[
 RowBox[{" ", 
  RowBox[{
   RowBox[{"bdlbls", "[", 
    RowBox[{"\"\<cub\>\"", ",", "\"\<vts\>\"", ",", "2"}], "]"}], " ", "=", 
   " ", 
   RowBox[{"FindBdryLblsRR", "[", 
    RowBox[{
     RowBox[{"igrf", "[", 
      RowBox[{"\"\<oct\>\"", ",", "\"\<vts\>\"", ",", "\"\<fcs\>\""}], "]"}], 
     ",", 
     RowBox[{"{", 
      RowBox[{"1", ",", "2", ",", "1", ",", "2"}], "}"}]}], 
    "]"}]}]}]], "Input",
 CellLabel->
  "In[446]:=",ExpressionUUID->"552ab294-f03c-450e-92cd-1277d150dabe"],

Cell[BoxData[
 RowBox[{"edxlblplot", "[", 
  RowBox[{"\"\<oct\>\"", ",", "True", ",", 
   RowBox[{"{", 
    RowBox[{"Red", ",", "Red", ",", "Red", ",", "Blue"}], "}"}]}], 
  "]"}]], "Input",
 CellLabel->
  "In[447]:=",ExpressionUUID->"b5a968ec-7f75-4d79-98b4-b6e98176ff2b"],

Cell[BoxData[
 RowBox[{"edxlblplot", "[", 
  RowBox[{"\"\<oct\>\"", ",", "True", ",", 
   RowBox[{"{", 
    RowBox[{"Red", ",", "Red", ",", "Blue", ",", "Blue"}], "}"}]}], 
  "]"}]], "Input",
 CellLabel->
  "In[448]:=",ExpressionUUID->"9ab1677a-15eb-4bbf-8f00-27ca56568b0a"],

Cell[BoxData[
 RowBox[{"edxlblplot", "[", 
  RowBox[{"\"\<oct\>\"", ",", "True", ",", 
   RowBox[{"{", 
    RowBox[{"Red", ",", "Red", ",", 
     RowBox[{"Darker", "[", "Green", "]"}], ",", "Blue"}], "}"}]}], 
  "]"}]], "Input",
 CellLabel->
  "In[449]:=",ExpressionUUID->"407174ee-49bf-40cf-92e3-2c0fdb1df98e"],

Cell[BoxData[
 RowBox[{" ", 
  RowBox[{
   RowBox[{"bdlbls", "[", 
    RowBox[{"\"\<cub\>\"", ",", "\"\<eds\>\"", ",", "1"}], "]"}], " ", "=", 
   " ", 
   RowBox[{"FindBdryLblsRR", "[", 
    RowBox[{
     RowBox[{"igrf", "[", 
      RowBox[{"\"\<oct\>\"", ",", "\"\<vts\>\"", ",", "\"\<eds\>\""}], "]"}], 
     ",", 
     RowBox[{"{", 
      RowBox[{"1", ",", "1", ",", "1", ",", "3"}], "}"}]}], 
    "]"}]}]}]], "Input",
 CellLabel->
  "In[450]:=",ExpressionUUID->"8e06523c-0196-4bd9-af8e-f79c0e4c57c9"],

Cell[BoxData[
 RowBox[{" ", 
  RowBox[{
   RowBox[{"bdlbls", "[", 
    RowBox[{"\"\<cub\>\"", ",", "\"\<eds\>\"", ",", "2"}], "]"}], " ", "=", 
   " ", 
   RowBox[{"FindBdryLblsRR", "[", 
    RowBox[{
     RowBox[{"igrf", "[", 
      RowBox[{"\"\<oct\>\"", ",", "\"\<vts\>\"", ",", "\"\<eds\>\""}], "]"}], 
     ",", 
     RowBox[{"{", 
      RowBox[{"1", ",", "1", ",", "3", ",", "3"}], "}"}]}], 
    "]"}]}]}]], "Input",
 CellLabel->
  "In[451]:=",ExpressionUUID->"86c6ef6a-2dcd-4669-979d-c2a74dd3863b"],

Cell[BoxData[
 RowBox[{" ", 
  RowBox[{
   RowBox[{"bdlbls", "[", 
    RowBox[{"\"\<cub\>\"", ",", "\"\<eds\>\"", ",", "3"}], "]"}], " ", "=", 
   " ", 
   RowBox[{"FindBdryLblsRR", "[", 
    RowBox[{
     RowBox[{"igrf", "[", 
      RowBox[{"\"\<oct\>\"", ",", "\"\<vts\>\"", ",", "\"\<eds\>\""}], "]"}], 
     ",", 
     RowBox[{"{", 
      RowBox[{"1", ",", "1", ",", "2", ",", "3"}], "}"}]}], 
    "]"}]}]}]], "Input",
 CellLabel->
  "In[452]:=",ExpressionUUID->"70a65c6d-245c-4985-9100-38080633ca39"]
}, Closed]],

Cell[CellGroupData[{

Cell["Rhombic Dodecahedron", "Subsection",ExpressionUUID->"cf551330-7dc5-42d7-b337-eb690a479fa8"],

Cell[BoxData[
 RowBox[{"ptxrhblblplot", "[", 
  RowBox[{"\"\<oct\>\"", ",", 
   RowBox[{"{", 
    RowBox[{"Red", ",", 
     RowBox[{"Darker", "[", "Green", "]"}], ",", "Red", ",", "Blue"}], 
    "}"}]}], "]"}]], "Input",
 CellLabel->
  "In[453]:=",ExpressionUUID->"6b5abfe2-dbd9-4efa-aa62-dc7c77d79e4e"],

Cell[BoxData[
 RowBox[{"edxrhblblplot", "[", 
  RowBox[{"\"\<oct\>\"", ",", 
   RowBox[{"{", 
    RowBox[{"Red", ",", "Red", ",", "Blue", ",", "Blue"}], "}"}]}], 
  "]"}]], "Input",
 CellLabel->
  "In[454]:=",ExpressionUUID->"00abbb14-4e7f-4195-9376-f5e75be1cdb8"]
}, Closed]],

Cell[CellGroupData[{

Cell["Icosahedron", "Subsection",ExpressionUUID->"0e8206df-5659-41df-bff4-fce21e6606e4"],

Cell[BoxData[
 RowBox[{"edxlblplot", "[", 
  RowBox[{"\"\<ico\>\"", ",", "False", ",", 
   RowBox[{"{", 
    RowBox[{"Red", ",", "Red", ",", "Blue"}], "}"}]}], "]"}]], "Input",
 CellLabel->
  "In[455]:=",ExpressionUUID->"11301920-d699-4d55-8982-2dfe2475d815"],

Cell[BoxData[
 RowBox[{"edxlblplot", "[", 
  RowBox[{"\"\<ico\>\"", ",", "False", ",", 
   RowBox[{"{", 
    RowBox[{"Red", ",", 
     RowBox[{"Darker", "[", "Green", "]"}], ",", "Blue"}], "}"}]}], 
  "]"}]], "Input",
 CellLabel->
  "In[456]:=",ExpressionUUID->"d710e345-b89b-481d-a350-f56fc29a3f1f"]
}, Closed]],

Cell[CellGroupData[{

Cell["Dodecahedron", "Subsection",ExpressionUUID->"49dcb14d-e194-4655-8061-e67749211210"],

Cell[BoxData[
 RowBox[{"ptxlblplot", "[", 
  RowBox[{"\"\<ico\>\"", ",", "True", ",", 
   RowBox[{"{", 
    RowBox[{"Red", ",", "Red", ",", 
     RowBox[{"Darker", "[", "Green", "]"}], ",", "Red", ",", "Blue"}], 
    "}"}]}], "]"}]], "Input",
 CellLabel->
  "In[457]:=",ExpressionUUID->"d7d0f6ed-60a5-4400-b2ca-201de9ef5373"],

Cell[BoxData[
 RowBox[{"edxlblplot", "[", 
  RowBox[{"\"\<ico\>\"", ",", "True", ",", 
   RowBox[{"{", 
    RowBox[{"Red", ",", "Red", ",", "Red", ",", "Red", ",", "Blue"}], "}"}]}],
   "]"}]], "Input",
 CellLabel->
  "In[458]:=",ExpressionUUID->"54bb51ed-882a-430c-9b58-62a34ee5de1a"],

Cell[BoxData[
 RowBox[{"edxlblplot", "[", 
  RowBox[{"\"\<ico\>\"", ",", "True", ",", 
   RowBox[{"{", 
    RowBox[{"Red", ",", "Red", ",", "Red", ",", "Blue", ",", "Blue"}], 
    "}"}]}], "]"}]], "Input",
 CellLabel->
  "In[459]:=",ExpressionUUID->"d3b92801-690d-4277-be79-ac0a3cf5b692"],

Cell[BoxData[
 RowBox[{
  RowBox[{"vtixsel", "[", 
   RowBox[{"vtixs_", ",", "ix_", ",", "n_"}], "]"}], " ", ":=", " ", 
  RowBox[{"Pick", "[", 
   RowBox[{
    RowBox[{"Range", "[", "n", "]"}], ",", "vtixs", ",", "ix"}], 
   "]"}]}]], "Input",
 CellLabel->
  "In[460]:=",ExpressionUUID->"6b22ae79-3d3b-4de5-ba30-db9955fb5c90"],

Cell[BoxData[
 RowBox[{
  RowBox[{"vtsel", "[", 
   RowBox[{"vtixs_", ",", "ix_", ",", "px_"}], "]"}], " ", ":=", " ", 
  RowBox[{"px", "[", 
   RowBox[{"[", 
    RowBox[{"vtixsel", "[", 
     RowBox[{"vtixs", ",", "ix", ",", 
      RowBox[{"Length", "[", "px", "]"}]}], "]"}], "]"}], "]"}]}]], "Input",
 CellLabel->
  "In[461]:=",ExpressionUUID->"6e6224cd-3288-485e-94f6-c18996525308"],

Cell[BoxData[
 RowBox[{
  RowBox[{"vtsprd", "[", "px_", "]"}], " ", ":=", " ", 
  RowBox[{
   RowBox[{
    RowBox[{"px", ".", 
     RowBox[{"Transpose", "[", "px", "]"}]}], " ", "//", " ", "Expand"}], " ",
    "//", " ", "Factor"}]}]], "Input",
 CellLabel->
  "In[462]:=",ExpressionUUID->"000825ef-2573-423e-b0a9-c2f6797a22e9"],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"Table", "[", 
    RowBox[{
     RowBox[{"vtsprd", "[", 
      RowBox[{"vtsel", "[", 
       RowBox[{"#", ",", "ix", ",", 
        RowBox[{"pts", "[", 
         RowBox[{"\"\<ico\>\"", ",", "\"\<fcs\>\""}], "]"}]}], "]"}], "]"}], 
     ",", 
     RowBox[{"{", 
      RowBox[{"ix", ",", 
       RowBox[{"{", 
        RowBox[{"2", ",", "3"}], "}"}]}], "}"}]}], "]"}], "&"}], " ", "/@", 
  " ", 
  RowBox[{"FindBdryLblsRR", "[", 
   RowBox[{
    RowBox[{"igrf", "[", 
     RowBox[{"\"\<ico\>\"", ",", "\"\<vts\>\"", ",", "\"\<fcs\>\""}], "]"}], 
    ",", 
    RowBox[{"{", 
     RowBox[{"1", ",", "1", ",", "2", ",", "1", ",", "3"}], "}"}]}], 
   "]"}]}]], "Input",
 CellLabel->
  "In[463]:=",ExpressionUUID->"d259a9f8-cde9-4140-81bc-34102ec486bb"],

Cell[BoxData[
 RowBox[{
  RowBox[{"sharedpts", "[", 
   RowBox[{"vtixs_", ",", "ix_", ",", "n_", ",", "nngbr_", ",", "ngbrix_"}], 
   "]"}], " ", ":=", " ", 
  RowBox[{"Union", " ", "@@", " ", 
   RowBox[{"Map", "[", 
    RowBox[{
     RowBox[{
      RowBox[{"Intersection", " ", "@@", " ", "#"}], "&"}], ",", 
     RowBox[{"Map", "[", 
      RowBox[{
       RowBox[{
        RowBox[{"ngbrix", "[", 
         RowBox[{"[", "#", "]"}], "]"}], "&"}], ",", 
       RowBox[{"Subsets", "[", 
        RowBox[{
         RowBox[{"vtixsel", "[", 
          RowBox[{"vtixs", ",", "ix", ",", "n"}], "]"}], ",", 
         RowBox[{"{", "nngbr", "}"}]}], "]"}], ",", 
       RowBox[{"{", "2", "}"}]}], "]"}]}], "]"}]}]}]], "Input",
 CellLabel->
  "In[464]:=",ExpressionUUID->"32ad54d7-6236-4dcb-9d44-40eff9171612"],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"vtsprd", "[", 
    RowBox[{
     RowBox[{
      RowBox[{
       RowBox[{"pts", "[", 
        RowBox[{"\"\<ico\>\"", ",", "\"\<fcs\>\""}], "]"}], "[", 
       RowBox[{"[", "#", "]"}], "]"}], "&"}], " ", "/@", " ", 
     RowBox[{"sharedpts", "[", 
      RowBox[{"#", ",", "2", ",", 
       RowBox[{"Length", "[", 
        RowBox[{"pts", "[", 
         RowBox[{"\"\<ico\>\"", ",", "\"\<eds\>\""}], "]"}], "]"}], ",", "3", 
       ",", 
       RowBox[{"igrf", "[", 
        RowBox[{"\"\<ico\>\"", ",", "\"\<eds\>\"", ",", "\"\<fcs\>\""}], 
        "]"}]}], "]"}]}], "]"}], "&"}], " ", "/@", " ", 
  RowBox[{"FindBdryLblsRR", "[", 
   RowBox[{
    RowBox[{"igrf", "[", 
     RowBox[{"\"\<ico\>\"", ",", "\"\<vts\>\"", ",", "\"\<eds\>\""}], "]"}], 
    ",", 
    RowBox[{"{", 
     RowBox[{"1", ",", "1", ",", "1", ",", "2", ",", "2"}], "}"}]}], 
   "]"}]}]], "Input",
 CellLabel->
  "In[465]:=",ExpressionUUID->"020b29e6-2e8b-430a-92fc-82b1325297af"]
}, Closed]]
}, Closed]]
},
WindowSize->{808, 778},
WindowMargins->{{Automatic, 16}, {Automatic, 27}},
FrontEndVersion->"11.3 for Mac OS X x86 (32-bit, 64-bit Kernel) (March 5, \
2018)",
StyleDefinitions->"Default.nb"
]
(* End of Notebook Content *)

(* Internal cache information *)
(*CellTagsOutline
CellTagsIndex->{}
*)
(*CellTagsIndex
CellTagsIndex->{}
*)
(*NotebookFileOutline
Notebook[{
Cell[558, 20, 1223, 37, 702, "Text",ExpressionUUID->"09b02b91-3da4-44fc-aee9-4a7f6b8ff7a1"],
Cell[CellGroupData[{
Cell[1806, 61, 85, 0, 67, "Section",ExpressionUUID->"7d1e88bb-9c9f-443d-adf4-1adbf81a1d42"],
Cell[1894, 63, 200, 5, 30, "Input",ExpressionUUID->"491cc2dd-6af0-4640-a671-e6ffbe9ba9d5"]
}, Closed]],
Cell[CellGroupData[{
Cell[2131, 73, 108, 0, 53, "Section",ExpressionUUID->"98632e64-564b-44c2-90df-34d432ef769b"],
Cell[2242, 75, 398, 13, 30, "Input",ExpressionUUID->"0344b144-685e-4714-b103-7c416bbeed76"],
Cell[2643, 90, 330, 9, 30, "Input",ExpressionUUID->"458e1eed-5f36-4e75-bff7-57570a6e2e1e"],
Cell[CellGroupData[{
Cell[2998, 103, 86, 0, 54, "Subsection",ExpressionUUID->"0ed4dba5-c768-4a69-8bff-9d4f41bcc3c6"],
Cell[3087, 105, 333, 8, 30, "Input",ExpressionUUID->"c47c153a-6d5d-47f0-8709-0af9baffd27a"],
Cell[3423, 115, 562, 16, 30, "Input",ExpressionUUID->"1e2d53b8-2bf2-43ff-94eb-3b0e95dc34c0"],
Cell[3988, 133, 1153, 36, 73, "Input",ExpressionUUID->"8f56246d-d3f6-4b99-afb4-5664184a94af"],
Cell[5144, 171, 1153, 36, 73, "Input",ExpressionUUID->"5d10ba48-4270-408a-9a80-cdb2e7600b1a"],
Cell[6300, 209, 229, 6, 30, "Input",ExpressionUUID->"4b8f5214-235e-46e9-8075-7a0c8d92ed1a"]
}, Open  ]],
Cell[CellGroupData[{
Cell[6566, 220, 90, 0, 54, "Subsection",ExpressionUUID->"31bab8ae-0f4c-4afb-85a3-298c2ae47e87"],
Cell[6659, 222, 336, 8, 30, "Input",ExpressionUUID->"87c0e3b5-f9be-4b75-a32d-714bacd033f5"],
Cell[6998, 232, 571, 16, 30, "Input",ExpressionUUID->"5a1bf640-9631-44d8-b32c-2987244553e1"],
Cell[7572, 250, 705, 22, 52, "Input",ExpressionUUID->"4634fe46-9887-4529-b471-17f06469a1d5"]
}, Open  ]]
}, Closed]],
Cell[CellGroupData[{
Cell[8326, 278, 80, 0, 53, "Section",ExpressionUUID->"49a0a8c6-ee33-464e-9656-78f83e0d37d5"],
Cell[8409, 280, 462, 14, 30, "Input",ExpressionUUID->"32e28f85-8aad-4eb5-99eb-74f62140cefa"],
Cell[8874, 296, 555, 16, 30, "Input",ExpressionUUID->"800bfaf1-3fd2-49d3-a872-d51c2ab9023c"],
Cell[9432, 314, 351, 10, 30, "Input",ExpressionUUID->"77d1d7ba-d25a-42fe-8892-5851d9eee599"],
Cell[9786, 326, 625, 19, 30, "Input",ExpressionUUID->"c09da90c-441f-4ccf-b37e-acaaadce9375"],
Cell[10414, 347, 875, 26, 52, "Input",ExpressionUUID->"d8f537a8-05fc-4088-a4ce-7e18a98ceec3"],
Cell[11292, 375, 650, 20, 30, "Input",ExpressionUUID->"207c3d42-01d9-480e-bd29-bce3307b8b9c"],
Cell[11945, 397, 584, 17, 30, "Input",ExpressionUUID->"bcc05416-c5b8-4edb-a19b-9977afd145bc"],
Cell[12532, 416, 890, 27, 52, "Input",ExpressionUUID->"7e071110-74f4-4652-a8b8-9e5b376f2bd1"],
Cell[13425, 445, 897, 26, 52, "Input",ExpressionUUID->"bd3ab846-f6eb-48b5-b45a-a42f3cb129e5"],
Cell[14325, 473, 998, 30, 73, "Input",ExpressionUUID->"f46bb0bb-93da-4bc6-9d54-57ef09f424b0"],
Cell[15326, 505, 2285, 64, 115, "Input",ExpressionUUID->"d0c4038b-3a07-4595-a996-b220bf5616ad"],
Cell[17614, 571, 2406, 70, 115, "Input",ExpressionUUID->"4c159c18-34f9-410c-a87c-d3abb5df687d"],
Cell[20023, 643, 852, 24, 52, "Input",ExpressionUUID->"6dbf652a-1eb4-4952-9c9c-1c21948ba7ea"]
}, Closed]],
Cell[CellGroupData[{
Cell[20912, 672, 90, 0, 53, "Section",ExpressionUUID->"f9f85292-e5d4-4cfc-b915-7d1b5f10e2e8"],
Cell[21005, 674, 582, 17, 30, "Input",ExpressionUUID->"a422fa16-67ef-4fc7-8f50-6bc3a6f8724a"],
Cell[21590, 693, 582, 17, 30, "Input",ExpressionUUID->"248da275-6906-46d9-b14d-fe9a22fe520d"],
Cell[22175, 712, 668, 21, 30, "Input",ExpressionUUID->"3ebef03e-81e5-4516-a434-1dda1a14ad07"],
Cell[22846, 735, 668, 21, 30, "Input",ExpressionUUID->"3aa94d71-53f0-44df-890d-e2ff58fb1ab9"],
Cell[23517, 758, 582, 17, 30, "Input",ExpressionUUID->"81f1997f-e54d-484c-8cd6-73a4573b4700"],
Cell[24102, 777, 582, 17, 30, "Input",ExpressionUUID->"f51dbef9-9638-4564-8fa6-ac1627ff708d"],
Cell[24687, 796, 797, 22, 52, "Input",ExpressionUUID->"5a7c009d-8f22-41ce-8fd1-bb3f45c4ccb2"],
Cell[25487, 820, 791, 22, 52, "Input",ExpressionUUID->"b81d44ce-f140-4b63-99dd-31fdda3a4d68"],
Cell[26281, 844, 1046, 33, 52, "Input",ExpressionUUID->"a6c882fb-9f10-48e7-bed9-6e304912f3e2"],
Cell[27330, 879, 1046, 33, 52, "Input",ExpressionUUID->"1045b627-1f17-4895-9e4e-e7c7718ca40c"],
Cell[28379, 914, 874, 25, 52, "Input",ExpressionUUID->"bc24a8cd-f250-469d-a4fa-ca28d3f8c2c1"],
Cell[29256, 941, 880, 25, 52, "Input",ExpressionUUID->"bdafb605-6afd-4da0-ad59-2565aaa175e2"],
Cell[30139, 968, 1483, 39, 94, "Input",ExpressionUUID->"2828d8ee-4586-4176-9ecc-5b80ca607856"],
Cell[31625, 1009, 1450, 35, 94, "Input",ExpressionUUID->"5fda78d3-3d52-4a73-8205-b9b656471940"],
Cell[33078, 1046, 2195, 69, 94, "Input",ExpressionUUID->"ace90b56-54e8-4f10-8d13-49b225feb249"],
Cell[35276, 1117, 2213, 69, 94, "Input",ExpressionUUID->"63bce83c-64f4-4280-b786-fb8a6c969a5f"],
Cell[37492, 1188, 1767, 50, 94, "Input",ExpressionUUID->"f73c27ee-e495-4ddb-980a-97bb9172e9d3"],
Cell[39262, 1240, 1794, 50, 94, "Input",ExpressionUUID->"863682bf-5996-4de7-b299-333ac2b9453d"],
Cell[41059, 1292, 975, 28, 52, "Input",ExpressionUUID->"b717a5c5-290b-495f-b31e-4593cebd6243"],
Cell[42037, 1322, 350, 9, 30, "Input",ExpressionUUID->"a6953dfe-de0b-40c3-8e80-b9cdc039edbc"],
Cell[42390, 1333, 1452, 42, 94, "Input",ExpressionUUID->"13f3ee40-90ce-492d-951d-3b2511cdb81a"],
Cell[43845, 1377, 260, 6, 30, "Input",ExpressionUUID->"c35efa1d-ed49-46e5-b1d4-a4505b22ba7e"],
Cell[44108, 1385, 2000, 54, 136, "Input",ExpressionUUID->"0e6079bb-5e12-43ab-ad9c-4d0aa963f67d"],
Cell[46111, 1441, 1022, 27, 73, "Input",ExpressionUUID->"e35c3f03-d694-4427-b9f4-5c1fc482f96b"],
Cell[47136, 1470, 260, 6, 30, "Input",ExpressionUUID->"f6f1ef74-34d7-4280-bff8-efb4d2ade03a"],
Cell[47399, 1478, 311, 8, 30, "Input",ExpressionUUID->"b5c214b4-5686-4d04-8588-1b679f037e98"],
Cell[47713, 1488, 156, 3, 30, "Input",ExpressionUUID->"90d0279b-036b-44aa-a733-cc4d7abd5735"],
Cell[47872, 1493, 1605, 47, 73, "Input",ExpressionUUID->"d8f7ddd2-666b-4b1a-b13c-8fe7567bb19d"],
Cell[49480, 1542, 156, 3, 30, "Input",ExpressionUUID->"d3977466-d916-42b9-b2ee-2fa2ffe2c061"],
Cell[49639, 1547, 1497, 44, 73, "Input",ExpressionUUID->"5e57e84a-9891-4b11-bff2-dabda9aba623"],
Cell[51139, 1593, 156, 3, 30, "Input",ExpressionUUID->"9cfb1a89-ec3d-43b3-958d-fc9dae1a7416"],
Cell[51298, 1598, 2737, 77, 115, "Input",ExpressionUUID->"29e98ef1-ed32-4343-9ed9-224751208ad9"],
Cell[54038, 1677, 219, 5, 30, "Input",ExpressionUUID->"87208056-f78e-4a46-8d00-dca3b51765a6"],
Cell[54260, 1684, 2392, 64, 178, "Input",ExpressionUUID->"270a0514-fb4f-4644-a99b-d069c507cbdf"],
Cell[56655, 1750, 2199, 60, 178, "Input",ExpressionUUID->"0e5fba0e-b4f3-4818-b476-08c4ef405ebc"]
}, Closed]],
Cell[CellGroupData[{
Cell[58891, 1815, 111, 0, 53, "Section",ExpressionUUID->"7de1dbd8-6e8b-4eb9-b080-e13b185f449a"],
Cell[59005, 1817, 870, 19, 94, "Input",ExpressionUUID->"15d4128d-8257-4cd5-8f47-1ff1149ae662"],
Cell[59878, 1838, 11251, 246, 1522, "Input",ExpressionUUID->"d9efdf03-fd15-4fb4-81ff-15fb63aed852"],
Cell[71132, 2086, 269, 6, 30, "Input",ExpressionUUID->"54762bc2-befa-433f-9c92-2fdeb01117e9"],
Cell[71404, 2094, 873, 22, 136, "Input",ExpressionUUID->"043f095d-f0c9-4ad4-8c46-26eb5b064482"],
Cell[72280, 2118, 268, 7, 30, "Input",ExpressionUUID->"7b004022-b549-45fa-ae34-42f12eec13fd"],
Cell[72551, 2127, 1204, 32, 136, "Input",ExpressionUUID->"0472c9be-82f3-4653-974f-8527c33044f7"],
Cell[73758, 2161, 209, 5, 30, "Input",ExpressionUUID->"e2308afb-b1b6-4e60-b9e4-438cfb05008b"],
Cell[73970, 2168, 237, 7, 30, "Input",ExpressionUUID->"f32fb43e-d6c6-4953-8ffa-00d12a7583e6"],
Cell[74210, 2177, 247, 7, 30, "Input",ExpressionUUID->"e6f16ce0-3678-4c6e-bf98-bfdcbc77459d"],
Cell[74460, 2186, 322, 8, 30, "Input",ExpressionUUID->"b5c3c762-2df6-4fb9-9473-87fbc12c2209"]
}, Closed]],
Cell[CellGroupData[{
Cell[74819, 2199, 89, 0, 53, "Section",ExpressionUUID->"fc964487-100d-4d87-881f-73c05b18395d"],
Cell[74911, 2201, 665, 21, 30, "Input",ExpressionUUID->"6fa3e87c-af0a-49ea-bd74-35c7adb9cc3c"],
Cell[75579, 2224, 551, 16, 30, "Input",ExpressionUUID->"7c3b5c2a-60ff-4b9e-8c5d-29b667a2422a"],
Cell[76133, 2242, 715, 21, 30, "Input",ExpressionUUID->"1dbf0db0-a241-4abb-a050-373e88825558"],
Cell[76851, 2265, 341, 9, 30, "Input",ExpressionUUID->"55104476-0caf-4b92-b046-a8177ba50577"],
Cell[77195, 2276, 1554, 44, 115, "Input",ExpressionUUID->"8560d2c6-b491-4db1-b8e5-04158f4c4ecd"],
Cell[78752, 2322, 499, 14, 30, "Input",ExpressionUUID->"2e97fe63-6eee-443c-abb8-cc9c21eb5a1a"],
Cell[79254, 2338, 220, 5, 30, "Input",ExpressionUUID->"4412cd2f-e6f1-44ea-8b89-3d66f729cc6b"],
Cell[79477, 2345, 326, 9, 30, "Input",ExpressionUUID->"24591010-30f3-4a27-936b-8df252698288"],
Cell[79806, 2356, 1038, 28, 115, "Input",ExpressionUUID->"20e62bfa-e295-4dd7-b18b-76436a6057f0"],
Cell[80847, 2386, 406, 10, 30, "Input",ExpressionUUID->"835efbe3-42ff-45dd-85d5-9f2d1581aa2e"],
Cell[81256, 2398, 284, 7, 30, "Input",ExpressionUUID->"98aaa63b-fb1e-4076-9564-4a43068e8d16"],
Cell[81543, 2407, 1645, 46, 136, "Input",ExpressionUUID->"bdb42a26-bf57-4b2f-a0a8-25f7117dedc0"],
Cell[CellGroupData[{
Cell[83213, 2457, 124, 0, 54, "Subsection",ExpressionUUID->"98f5c1d7-266f-4f01-91cd-81ce9479cc2c"],
Cell[83340, 2459, 631, 19, 30, "Input",ExpressionUUID->"a6d7ca0f-1304-4f5b-bc89-0ddcea24563d"],
Cell[83974, 2480, 408, 12, 30, "Input",ExpressionUUID->"2be0205a-2fce-42f6-833b-01121f941c2c"],
Cell[84385, 2494, 1346, 43, 73, "Input",ExpressionUUID->"5c7e8f61-b9d1-4017-895c-82ddf2549849"]
}, Closed]],
Cell[CellGroupData[{
Cell[85768, 2542, 126, 0, 38, "Subsection",ExpressionUUID->"300eebda-cd04-4aeb-9c53-e0550029252e"],
Cell[85897, 2544, 1579, 44, 157, "Input",ExpressionUUID->"91aae1a2-cb18-4f40-b1fa-6d2a88672232"],
Cell[87479, 2590, 3718, 101, 199, "Input",ExpressionUUID->"aa96aeac-e041-4760-a955-0a810daf258b"],
Cell[91200, 2693, 352, 10, 30, "Input",ExpressionUUID->"94d93561-d648-4fde-8239-770ef7076e08"],
Cell[91555, 2705, 151, 3, 30, "Input",ExpressionUUID->"8a66e595-2770-4444-bda3-8a9ecdabad96"],
Cell[91709, 2710, 830, 26, 52, "Input",ExpressionUUID->"2dd06cd3-bba6-4a3f-b69f-af35b144304f"],
Cell[92542, 2738, 578, 18, 30, "Input",ExpressionUUID->"d46f038a-fdac-4ab7-a2e9-1a3bcb829b35"],
Cell[93123, 2758, 352, 10, 30, "Input",ExpressionUUID->"318cdd17-7c50-4912-b8be-d9b9c48f6f91"],
Cell[93478, 2770, 786, 24, 52, "Input",ExpressionUUID->"339d606b-28dd-4196-a038-c7eda998c9e9"],
Cell[94267, 2796, 738, 23, 30, "Input",ExpressionUUID->"8c547733-6f4a-4ba7-8842-a0c74446d1fd"],
Cell[95008, 2821, 822, 26, 52, "Input",ExpressionUUID->"3f321b49-1aab-4d2c-a166-05d5285180c3"],
Cell[95833, 2849, 553, 17, 30, "Input",ExpressionUUID->"1b189441-578b-4620-b0c8-06bfaf968f5a"],
Cell[96389, 2868, 418, 12, 30, "Input",ExpressionUUID->"993bbc46-a553-4212-8d1e-449516ad0979"],
Cell[96810, 2882, 303, 8, 30, "Input",ExpressionUUID->"792407f0-3847-4a58-9640-3ea87bfaf2f9"],
Cell[97116, 2892, 219, 6, 30, "Input",ExpressionUUID->"f64902c2-208a-4b37-9b58-bd8d53474289"],
Cell[97338, 2900, 372, 11, 30, "Input",ExpressionUUID->"722d51f0-a063-471f-94b8-3747508e94df"],
Cell[97713, 2913, 524, 15, 30, "Input",ExpressionUUID->"b486562e-2cff-45e2-9148-7c49612040f8"],
Cell[98240, 2930, 254, 6, 30, "Input",ExpressionUUID->"3544618a-78b9-4828-8d3f-ce55a5989dd3"],
Cell[98497, 2938, 1512, 45, 136, "Input",ExpressionUUID->"0b8de537-6d49-45d3-aecd-5cb9b3c8220c"],
Cell[100012, 2985, 394, 11, 30, "Input",ExpressionUUID->"85d77be6-d731-41e6-8c5f-088775c7a217"],
Cell[100409, 2998, 390, 11, 30, "Input",ExpressionUUID->"772ace73-8ddd-4f40-b913-3b7fe64c8645"],
Cell[100802, 3011, 384, 11, 30, "Input",ExpressionUUID->"202445e4-3ba2-4e5b-ac50-e6b23767f945"]
}, Closed]],
Cell[CellGroupData[{
Cell[101223, 3027, 120, 0, 38, "Subsection",ExpressionUUID->"828a4b79-e584-4187-a1d6-d73f42c2335c"],
Cell[101346, 3029, 395, 10, 52, "Input",ExpressionUUID->"61d61756-5e1f-47da-bc1e-f3be3fff4406"],
Cell[101744, 3041, 1048, 31, 52, "Input",ExpressionUUID->"7c89359c-c4af-41d1-81da-952535f4ada9"],
Cell[102795, 3074, 234, 6, 30, "Input",ExpressionUUID->"7f54a53e-4a0f-442e-87f5-508dba6eb5bc"],
Cell[103032, 3082, 231, 6, 30, "Input",ExpressionUUID->"db16d364-0f87-44c9-b123-bcb9baafb50a"],
Cell[103266, 3090, 231, 6, 30, "Input",ExpressionUUID->"4ded1941-97b5-4f08-90ac-013f8911f45d"],
Cell[103500, 3098, 386, 10, 30, "Input",ExpressionUUID->"54ea3216-d433-4925-a34a-fa669c51a05f"]
}, Closed]],
Cell[CellGroupData[{
Cell[103923, 3113, 125, 0, 38, "Subsection",ExpressionUUID->"4e9e941d-e56c-4356-8785-e443d087c632"],
Cell[104051, 3115, 667, 17, 94, "Input",ExpressionUUID->"b0606c18-412e-4626-8894-c9250ffd2092"],
Cell[104721, 3134, 1373, 40, 94, "Input",ExpressionUUID->"03ded2a7-080a-42f4-a4ee-a229ac38e820"],
Cell[106097, 3176, 233, 6, 30, "Input",ExpressionUUID->"c83ee3a5-5a3f-4bb0-a588-a82ed4780e81"],
Cell[106333, 3184, 262, 7, 30, "Input",ExpressionUUID->"334b393e-52e0-4118-a9dc-23477196309e"],
Cell[106598, 3193, 209, 5, 30, "Input",ExpressionUUID->"e4c1d3d6-e1fa-487e-9bdb-10731c7235a1"],
Cell[106810, 3200, 262, 7, 30, "Input",ExpressionUUID->"836784bd-26b0-47a5-a81e-98891dc56386"],
Cell[107075, 3209, 230, 6, 30, "Input",ExpressionUUID->"dbb97ef5-0352-466f-89a6-6450c9fd80a1"],
Cell[107308, 3217, 230, 6, 30, "Input",ExpressionUUID->"56bd1c59-a860-4ac4-a1a8-588395db3720"]
}, Closed]],
Cell[CellGroupData[{
Cell[107575, 3228, 115, 0, 38, "Subsection",ExpressionUUID->"13ec7b83-b2da-45cc-8bf9-e4885f6ce269"],
Cell[107693, 3230, 286, 8, 30, "Input",ExpressionUUID->"77e9b705-2e8c-4b48-add8-84ec69e32cac"],
Cell[107982, 3240, 4777, 145, 178, "Input",ExpressionUUID->"eb8c274d-281a-4af2-acc0-82fa2f8fa83d"],
Cell[112762, 3387, 41005, 1242, 1186, "Input",ExpressionUUID->"5a2fdef1-be5a-4fb7-8c7a-7c2352c37196"],
Cell[153770, 4631, 396, 11, 30, "Input",ExpressionUUID->"05dd602b-b8c5-4998-b453-4216c06ff72d"],
Cell[154169, 4644, 394, 11, 30, "Input",ExpressionUUID->"a7c11fd1-7b56-44e5-ba4e-df752078ea0d"],
Cell[154566, 4657, 5481, 148, 367, "Input",ExpressionUUID->"0bfc9a58-66c3-4a66-9625-1506d68468e7"],
Cell[160050, 4807, 276, 7, 30, "Input",ExpressionUUID->"8f1818d6-e6de-47aa-9246-1f2f74adb796"],
Cell[160329, 4816, 1147, 33, 73, "Input",ExpressionUUID->"2b115125-9145-4778-8c6d-55b9d56fb974"],
Cell[161479, 4851, 335, 9, 30, "Input",ExpressionUUID->"00125ba0-80f5-4495-8b6c-61197fbca1cd"],
Cell[161817, 4862, 270, 7, 30, "Input",ExpressionUUID->"1b4a5abc-48e6-46ba-8b32-210a604336ca"],
Cell[162090, 4871, 460, 13, 30, "Input",ExpressionUUID->"2cf8586a-1f3a-424a-a5e5-6dc67ee92b5d"],
Cell[162553, 4886, 669, 20, 52, "Input",ExpressionUUID->"6d1c867e-40ab-4869-8dc0-b46a29f83b52"],
Cell[163225, 4908, 364, 10, 30, "Input",ExpressionUUID->"3e197411-e72b-40a5-b8de-797b32587ca5"],
Cell[163592, 4920, 311, 8, 30, "Input",ExpressionUUID->"9416b9bf-e23f-4037-8dc7-292df51aeb81"]
}, Closed]]
}, Closed]],
Cell[CellGroupData[{
Cell[163952, 4934, 79, 0, 53, "Section",ExpressionUUID->"0c022035-182f-4b91-b097-8fc282ba69cd"],
Cell[164034, 4936, 558, 15, 52, "Input",ExpressionUUID->"c32f333f-90f6-4ebd-9c03-23c33853f0cd"],
Cell[164595, 4953, 424, 11, 52, "Input",ExpressionUUID->"9312772d-f349-4397-b766-a83ae3d948b2"],
Cell[165022, 4966, 809, 21, 94, "Input",ExpressionUUID->"b9a1e6bb-99de-40d1-9e1b-4284cf5d9d9d"],
Cell[165834, 4989, 561, 15, 73, "Input",ExpressionUUID->"aa60dff4-8c16-40b4-96a5-43a202d43e86"],
Cell[166398, 5006, 1220, 32, 115, "Input",ExpressionUUID->"4823ddb5-cbad-4c70-b5e9-c993214fb9b4"],
Cell[167621, 5040, 1207, 32, 136, "Input",ExpressionUUID->"454e9118-1295-4817-af65-47978b9dde3c"],
Cell[168831, 5074, 1955, 51, 178, "Input",ExpressionUUID->"0d5d9e16-7644-4289-b1cf-a03adfdb60d4"],
Cell[170789, 5127, 1640, 42, 157, "Input",ExpressionUUID->"c48c7610-794e-4cc2-936e-4b282ac697b4"],
Cell[172432, 5171, 1622, 42, 178, "Input",ExpressionUUID->"7c034144-7ac8-42ad-98cb-9f6272a48b31"],
Cell[174057, 5215, 876, 24, 94, "Input",ExpressionUUID->"42fe9301-a78f-4a8b-b315-37006cb971ec"],
Cell[174936, 5241, 591, 17, 52, "Input",ExpressionUUID->"1de168c5-e2e9-4df6-9992-ee901b1c204e"],
Cell[175530, 5260, 586, 16, 52, "Input",ExpressionUUID->"d4be83a9-df29-4a37-a452-96719eac735b"],
Cell[CellGroupData[{
Cell[176141, 5280, 88, 0, 54, "Subsection",ExpressionUUID->"f3731d7b-bdc7-42e4-92da-5489985f0767"],
Cell[176232, 5282, 259, 6, 30, "Input",ExpressionUUID->"e57e5afd-0f4a-4611-998e-5b16a8edd7fe"],
Cell[176494, 5290, 300, 8, 30, "Input",ExpressionUUID->"0d4c1c92-180b-42c1-8289-c023735dbc46"],
Cell[176797, 5300, 490, 14, 30, "Input",ExpressionUUID->"00c8b0e9-ed63-4787-a023-87cbac8d4a5a"],
Cell[177290, 5316, 491, 14, 30, "Input",ExpressionUUID->"bf604dbc-e580-4a0f-ab21-ac6989d7b7a3"],
Cell[177784, 5332, 432, 12, 30, "Input",ExpressionUUID->"5fe3bab3-514f-4547-9cd4-0bac0cbaef69"],
Cell[178219, 5346, 471, 13, 30, "Input",ExpressionUUID->"edadf389-2254-401d-ac4a-2512cc16bd77"],
Cell[178693, 5361, 178, 4, 30, "Input",ExpressionUUID->"51dec439-a163-4118-9efc-5842292933b0"]
}, Closed]],
Cell[CellGroupData[{
Cell[178908, 5370, 87, 0, 38, "Subsection",ExpressionUUID->"52c91f63-30ed-4380-8295-916353686b51"],
Cell[178998, 5372, 259, 6, 30, "Input",ExpressionUUID->"f69c2cbd-302c-4297-81cb-e21c0c61c093"],
Cell[179260, 5380, 300, 8, 30, "Input",ExpressionUUID->"fb4a87d7-0b33-4bbe-be84-049b3d1b483d"],
Cell[179563, 5390, 490, 14, 30, "Input",ExpressionUUID->"fb940cfa-9c5c-4b96-9080-7c9eaab65e34"],
Cell[180056, 5406, 490, 14, 30, "Input",ExpressionUUID->"4fb9b830-4dd2-4216-a41c-8e9847a3c534"],
Cell[180549, 5422, 432, 12, 30, "Input",ExpressionUUID->"78a416c6-3d70-4251-9f17-51132390109f"],
Cell[180984, 5436, 471, 13, 30, "Input",ExpressionUUID->"80169392-b1fc-458e-a3e7-40fea9f619d4"],
Cell[181458, 5451, 259, 6, 30, "Input",ExpressionUUID->"45997b41-7603-4725-8038-e1c72c829a0c"],
Cell[181720, 5459, 300, 8, 30, "Input",ExpressionUUID->"a7cab8ac-f0f9-4cdb-b9dc-bd758487498f"],
Cell[182023, 5469, 462, 13, 30, "Input",ExpressionUUID->"3e55e29e-60b6-4241-b7a2-04aea9924b72"],
Cell[182488, 5484, 462, 13, 30, "Input",ExpressionUUID->"d37404fc-a820-4c1d-b58f-ed09101f52ad"],
Cell[182953, 5499, 476, 13, 30, "Input",ExpressionUUID->"4b7143ac-e831-447d-8f91-069fb53d733d"],
Cell[183432, 5514, 352, 10, 30, "Input",ExpressionUUID->"1d3e77de-083a-492a-b40e-5af43a9f1a0d"],
Cell[183787, 5526, 530, 15, 52, "Input",ExpressionUUID->"cde18afb-d56a-4ec4-967e-fec292233223"]
}, Closed]],
Cell[CellGroupData[{
Cell[184354, 5546, 81, 0, 38, "Subsection",ExpressionUUID->"63b9f30f-c873-48f7-8278-323aea11fad4"],
Cell[184438, 5548, 273, 7, 30, "Input",ExpressionUUID->"aac127f0-ab12-4358-a109-e713e51c868e"],
Cell[184714, 5557, 274, 7, 30, "Input",ExpressionUUID->"284ecadf-3a8e-4fc9-bd23-abf9512ee8fa"],
Cell[184991, 5566, 505, 15, 30, "Input",ExpressionUUID->"e356db54-4ab7-42da-ba7b-d12b87e1f3a2"],
Cell[185499, 5583, 505, 15, 30, "Input",ExpressionUUID->"552ab294-f03c-450e-92cd-1277d150dabe"],
Cell[186007, 5600, 273, 7, 30, "Input",ExpressionUUID->"b5a968ec-7f75-4d79-98b4-b6e98176ff2b"],
Cell[186283, 5609, 274, 7, 30, "Input",ExpressionUUID->"9ab1677a-15eb-4bbf-8f00-27ca56568b0a"],
Cell[186560, 5618, 311, 8, 30, "Input",ExpressionUUID->"407174ee-49bf-40cf-92e3-2c0fdb1df98e"],
Cell[186874, 5628, 505, 15, 30, "Input",ExpressionUUID->"8e06523c-0196-4bd9-af8e-f79c0e4c57c9"],
Cell[187382, 5645, 505, 15, 30, "Input",ExpressionUUID->"86c6ef6a-2dcd-4669-979d-c2a74dd3863b"],
Cell[187890, 5662, 505, 15, 30, "Input",ExpressionUUID->"70a65c6d-245c-4985-9100-38080633ca39"]
}, Closed]],
Cell[CellGroupData[{
Cell[188432, 5682, 97, 0, 38, "Subsection",ExpressionUUID->"cf551330-7dc5-42d7-b337-eb690a479fa8"],
Cell[188532, 5684, 303, 8, 30, "Input",ExpressionUUID->"6b5abfe2-dbd9-4efa-aa62-dc7c77d79e4e"],
Cell[188838, 5694, 264, 7, 30, "Input",ExpressionUUID->"00abbb14-4e7f-4195-9376-f5e75be1cdb8"]
}, Closed]],
Cell[CellGroupData[{
Cell[189139, 5706, 88, 0, 38, "Subsection",ExpressionUUID->"0e8206df-5659-41df-bff4-fce21e6606e4"],
Cell[189230, 5708, 259, 6, 30, "Input",ExpressionUUID->"11301920-d699-4d55-8982-2dfe2475d815"],
Cell[189492, 5716, 300, 8, 30, "Input",ExpressionUUID->"d710e345-b89b-481d-a350-f56fc29a3f1f"]
}, Closed]],
Cell[CellGroupData[{
Cell[189829, 5729, 89, 0, 38, "Subsection",ExpressionUUID->"49dcb14d-e194-4655-8061-e67749211210"],
Cell[189921, 5731, 325, 8, 30, "Input",ExpressionUUID->"d7d0f6ed-60a5-4400-b2ca-201de9ef5373"],
Cell[190249, 5741, 285, 7, 30, "Input",ExpressionUUID->"54bb51ed-882a-430c-9b58-62a34ee5de1a"],
Cell[190537, 5750, 288, 7, 30, "Input",ExpressionUUID->"d3b92801-690d-4277-be79-ac0a3cf5b692"],
Cell[190828, 5759, 327, 9, 30, "Input",ExpressionUUID->"6b22ae79-3d3b-4de5-ba30-db9955fb5c90"],
Cell[191158, 5770, 386, 10, 30, "Input",ExpressionUUID->"6e6224cd-3288-485e-94f6-c18996525308"],
Cell[191547, 5782, 327, 9, 30, "Input",ExpressionUUID->"000825ef-2573-423e-b0a9-c2f6797a22e9"],
Cell[191877, 5793, 790, 25, 52, "Input",ExpressionUUID->"d259a9f8-cde9-4140-81bc-34102ec486bb"],
Cell[192670, 5820, 799, 22, 73, "Input",ExpressionUUID->"32ad54d7-6236-4dcb-9d44-40eff9171612"],
Cell[193472, 5844, 992, 28, 73, "Input",ExpressionUUID->"020b29e6-2e8b-430a-92fc-82b1325297af"]
}, Closed]]
}, Closed]]
}
]
*)

