(* Content-type: application/vnd.wolfram.mathematica *)

(*** Wolfram Notebook File ***)
(* http://www.wolfram.com/nb *)

(* CreatedBy='Mathematica 11.3' *)

(*CacheID: 234*)
(* Internal cache information:
NotebookFileLineBreakTest
NotebookFileLineBreakTest
NotebookDataPosition[       158,          7]
NotebookDataLength[     18044,        476]
NotebookOptionsPosition[     15013,        428]
NotebookOutlinePosition[     15367,        444]
CellTagsIndexPosition[     15324,        441]
WindowFrame->Normal*)

(* Beginning of Notebook Content *)
Notebook[{
Cell["\<\
Isohedral Dice: Face-Transitive

Each face has n vertices, with vertex i having r(i) faces at it.

Polyhedron:
(Vertices) - (Edges) + (Faces) = X
X = Euler characteristic = 2*(1-g) where g is the number of holes, or the \
number of cuts needed to make spherical topology. Two separate polyhedra mean \
a contribution of -1 to g, for a cut that must be undone.
Spherical topology: g = 0, X = 2, what we\[CloseCurlyQuote]ll use here.

How many faces per vertex: its rank. Vertices come in lookalike types, and \
there may be more than one type of vertex.
\
\>", "Text",ExpressionUUID->"0e7de373-24fb-48d9-9686-0ee0213d6ded"],

Cell[CellGroupData[{

Cell["Functions", "Section",ExpressionUUID->"318e736f-7415-4098-a279-7fa80c9c4e35"],

Cell[BoxData[
 RowBox[{
  RowBox[{"vef", "[", 
   RowBox[{"rs_", ",", 
    RowBox[{"check_:", "False"}]}], "]"}], " ", ":=", " ", 
  RowBox[{"Module", "[", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{"n", ",", "vefmult", ",", "vmsum", ",", "res"}], "}"}], ",", 
    "\[IndentingNewLine]", 
    RowBox[{
     RowBox[{"n", " ", "=", " ", 
      RowBox[{"Length", "[", "rs", "]"}]}], ";", "\[IndentingNewLine]", 
     RowBox[{"vefmult", " ", "=", " ", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"Total", "[", 
         RowBox[{"1", "/", "rs"}], "]"}], ",", 
        RowBox[{"n", "/", "2"}], ",", "1"}], "}"}]}], ";", 
     "\[IndentingNewLine]", 
     RowBox[{"vmsum", " ", "=", " ", 
      RowBox[{"vefmult", ".", 
       RowBox[{"{", 
        RowBox[{"1", ",", 
         RowBox[{"-", "1"}], ",", "1"}], "}"}]}]}], ";", 
     "\[IndentingNewLine]", 
     RowBox[{"res", " ", "=", " ", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"{", 
         RowBox[{"n", ",", "rs"}], "}"}], ",", "vmsum"}], "}"}]}], ";", 
     "\[IndentingNewLine]", 
     RowBox[{"If", "[", 
      RowBox[{"check", ",", "\[IndentingNewLine]", 
       RowBox[{"If", "[", 
        RowBox[{
         RowBox[{"vmsum", " ", "\[LessEqual]", " ", "0"}], ",", 
         RowBox[{"Return", "[", "res", "]"}]}], "]"}]}], 
      "\[IndentingNewLine]", "]"}], ";", "\[IndentingNewLine]", 
     RowBox[{"Append", "[", 
      RowBox[{"res", ",", 
       RowBox[{
        RowBox[{"(", 
         RowBox[{"2", "/", "vmsum"}], ")"}], "*", "vefmult"}]}], "]"}]}]}], 
   "\[IndentingNewLine]", "]"}]}]], "Input",
 CellLabel->"In[1]:=",ExpressionUUID->"3f21c1ae-3ee5-4210-9eaa-2a35e57e488a"],

Cell[BoxData[
 RowBox[{
  RowBox[{"veflst", "[", 
   RowBox[{"n_", ",", "rsbase_", ",", 
    RowBox[{"check_:", "False"}]}], "]"}], " ", ":=", " ", 
  RowBox[{"Module", "[", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{"r", ",", "rb", ",", "lst", ",", "rt", ",", "res", ",", "quit"}],
      "}"}], ",", "\[IndentingNewLine]", 
    RowBox[{
     RowBox[{"r", " ", "=", " ", 
      RowBox[{"Max", "[", 
       RowBox[{"rsbase", ",", "3"}], "]"}]}], ";", "\[IndentingNewLine]", 
     RowBox[{"rb", " ", "=", " ", 
      RowBox[{"ConstantArray", "[", 
       RowBox[{"1", ",", 
        RowBox[{"n", "-", 
         RowBox[{"Length", "[", "rsbase", "]"}]}]}], "]"}]}], ";", 
     "\[IndentingNewLine]", 
     RowBox[{"lst", " ", "=", " ", 
      RowBox[{"{", "}"}]}], ";", "\[IndentingNewLine]", 
     RowBox[{"quit", " ", "=", " ", "False"}], ";", "\[IndentingNewLine]", 
     RowBox[{"While", "[", 
      RowBox[{
       RowBox[{"!", "quit"}], ",", "\[IndentingNewLine]", 
       RowBox[{
        RowBox[{"rt", " ", "=", " ", 
         RowBox[{"Join", "[", 
          RowBox[{"rsbase", ",", 
           RowBox[{"r", "*", "rb"}]}], "]"}]}], ";", "\[IndentingNewLine]", 
        RowBox[{"res", " ", "=", " ", 
         RowBox[{"vef", "[", 
          RowBox[{"rt", ",", "True"}], "]"}]}], ";", "\[IndentingNewLine]", 
        RowBox[{"quit", " ", "=", " ", 
         RowBox[{
          RowBox[{"res", "[", 
           RowBox[{"[", "2", "]"}], "]"}], " ", "<", " ", "0"}]}], ";", 
        "\[IndentingNewLine]", 
        RowBox[{"r", "++"}], ";", "\[IndentingNewLine]", 
        RowBox[{"If", "[", 
         RowBox[{"check", ",", "\[IndentingNewLine]", 
          RowBox[{
           RowBox[{"If", "[", 
            RowBox[{
             RowBox[{
              RowBox[{"res", "[", 
               RowBox[{"[", "2", "]"}], "]"}], " ", ">", " ", "0"}], ",", 
             "\[IndentingNewLine]", 
             RowBox[{"If", "[", 
              RowBox[{
               RowBox[{"!", 
                RowBox[{"(", 
                 RowBox[{"And", " ", "@@", " ", 
                  RowBox[{"(", 
                   RowBox[{"IntegerQ", " ", "/@", " ", 
                    RowBox[{"res", "[", 
                    RowBox[{"[", "3", "]"}], "]"}]}], ")"}]}], ")"}]}], ",", 
               RowBox[{"Continue", "[", "]"}]}], "]"}]}], 
            "\[IndentingNewLine]", "]"}], ";", "\[IndentingNewLine]", 
           RowBox[{"If", "[", 
            RowBox[{
             RowBox[{"n", "\[Equal]", "3"}], ",", "\[IndentingNewLine]", 
             RowBox[{
              RowBox[{"If", "[", 
               RowBox[{
                RowBox[{
                 RowBox[{"rt", "[", 
                  RowBox[{"[", "1", "]"}], "]"}], "\[NotEqual]", 
                 RowBox[{"rt", "[", 
                  RowBox[{"[", "2", "]"}], "]"}]}], ",", 
                RowBox[{"If", "[", 
                 RowBox[{
                  RowBox[{"OddQ", "[", 
                   RowBox[{"rt", "[", 
                    RowBox[{"[", "3", "]"}], "]"}], "]"}], ",", 
                  RowBox[{"Continue", "[", "]"}]}], "]"}]}], "]"}], ";", 
              "\[IndentingNewLine]", 
              RowBox[{"If", "[", 
               RowBox[{
                RowBox[{
                 RowBox[{"rt", "[", 
                  RowBox[{"[", "1", "]"}], "]"}], "\[NotEqual]", 
                 RowBox[{"rt", "[", 
                  RowBox[{"[", "3", "]"}], "]"}]}], ",", 
                RowBox[{"If", "[", 
                 RowBox[{
                  RowBox[{"OddQ", "[", 
                   RowBox[{"rt", "[", 
                    RowBox[{"[", "2", "]"}], "]"}], "]"}], ",", 
                  RowBox[{"Continue", "[", "]"}]}], "]"}]}], "]"}], ";", 
              "\[IndentingNewLine]", 
              RowBox[{"If", "[", 
               RowBox[{
                RowBox[{
                 RowBox[{"rt", "[", 
                  RowBox[{"[", "2", "]"}], "]"}], "\[NotEqual]", 
                 RowBox[{"rt", "[", 
                  RowBox[{"[", "3", "]"}], "]"}]}], ",", 
                RowBox[{"If", "[", 
                 RowBox[{
                  RowBox[{"OddQ", "[", 
                   RowBox[{"rt", "[", 
                    RowBox[{"[", "1", "]"}], "]"}], "]"}], ",", 
                  RowBox[{"Continue", "[", "]"}]}], "]"}]}], "]"}], ";"}]}], 
            "\[IndentingNewLine]", "]"}]}]}], "\[IndentingNewLine]", "]"}], 
        ";", "\[IndentingNewLine]", 
        RowBox[{"AppendTo", "[", 
         RowBox[{"lst", ",", "res"}], "]"}]}]}], "\[IndentingNewLine]", "]"}],
      ";", "\[IndentingNewLine]", "lst"}]}], "\[IndentingNewLine]", 
   "]"}]}]], "Input",
 CellLabel->"In[23]:=",ExpressionUUID->"8c032c5b-af58-4920-8ce4-6efc32b4fe6a"]
}, Closed]],

Cell[CellGroupData[{

Cell["Results", "Section",ExpressionUUID->"c61a2d8a-6d01-4f16-bbcb-8032a722e961"],

Cell[BoxData[
 RowBox[{"veflst", "[", 
  RowBox[{"3", ",", 
   RowBox[{"{", "}"}], ",", "True"}], "]"}]], "Input",
 CellLabel->"In[24]:=",ExpressionUUID->"024b69c2-21a1-4ec2-960a-3d97d6cf6975"],

Cell[BoxData[
 RowBox[{"veflst", "[", 
  RowBox[{"3", ",", 
   RowBox[{"{", 
    RowBox[{"5", ",", "5"}], "}"}], ",", "True"}], "]"}]], "Input",
 CellLabel->"In[25]:=",ExpressionUUID->"275beb37-df9d-4618-ada0-9e343aea71c8"],

Cell[BoxData[
 RowBox[{"veflst", "[", 
  RowBox[{"3", ",", 
   RowBox[{"{", 
    RowBox[{"5", ",", "6"}], "}"}], ",", "True"}], "]"}]], "Input",
 CellLabel->"In[26]:=",ExpressionUUID->"562961bf-22a1-4357-8ac3-9ed7e0844549"],

Cell[BoxData[
 RowBox[{"veflst", "[", 
  RowBox[{"3", ",", 
   RowBox[{"{", "4", "}"}], ",", "True"}], "]"}]], "Input",
 CellLabel->"In[27]:=",ExpressionUUID->"688f3929-3dc6-44b5-8330-1397a0b8c90c"],

Cell[BoxData[
 RowBox[{
  RowBox[{"vef", "[", 
   RowBox[{"{", 
    RowBox[{"4", ",", "4", ",", "r"}], "}"}], "]"}], " ", "//", " ", 
  "Factor"}]], "Input",
 CellLabel->"In[28]:=",ExpressionUUID->"b0cfa4c8-4267-40a8-a5ae-0d0d5a175b03"],

Cell[BoxData[
 RowBox[{"veflst", "[", 
  RowBox[{"3", ",", 
   RowBox[{"{", 
    RowBox[{"4", ",", "6"}], "}"}], ",", "True"}], "]"}]], "Input",
 CellLabel->"In[29]:=",ExpressionUUID->"2b47f965-6acf-4976-a4f9-ac65843638b6"],

Cell[BoxData[
 RowBox[{"veflst", "[", 
  RowBox[{"3", ",", 
   RowBox[{"{", "3", "}"}], ",", "True"}], "]"}]], "Input",
 CellLabel->"In[30]:=",ExpressionUUID->"beb64a1e-a7a2-4eed-8d31-069488340d97"],

Cell[BoxData[
 RowBox[{"veflst", "[", 
  RowBox[{"4", ",", 
   RowBox[{"{", "}"}]}], "]"}]], "Input",
 CellLabel->"In[31]:=",ExpressionUUID->"70de61c3-3082-4019-8e22-4565e6773415"],

Cell[BoxData[
 RowBox[{"veflst", "[", 
  RowBox[{"4", ",", 
   RowBox[{"{", "3", "}"}]}], "]"}]], "Input",
 CellLabel->"In[32]:=",ExpressionUUID->"886a3480-aa5b-4465-b52e-990e953d2b40"],

Cell[BoxData[
 RowBox[{"veflst", "[", 
  RowBox[{"4", ",", 
   RowBox[{"{", 
    RowBox[{"3", ",", "4"}], "}"}]}], "]"}]], "Input",
 CellLabel->"In[33]:=",ExpressionUUID->"c2cd86e4-3467-4ca7-aeee-8e358bf71289"],

Cell[BoxData[
 RowBox[{"veflst", "[", 
  RowBox[{"4", ",", 
   RowBox[{"{", 
    RowBox[{"3", ",", "4", ",", "4"}], "}"}]}], "]"}]], "Input",
 CellLabel->"In[34]:=",ExpressionUUID->"d253dbe5-3b1a-46d7-ac59-41cbbe65b624"],

Cell[BoxData[
 RowBox[{"veflst", "[", 
  RowBox[{"4", ",", 
   RowBox[{"{", 
    RowBox[{"3", ",", "3"}], "}"}]}], "]"}]], "Input",
 CellLabel->"In[35]:=",ExpressionUUID->"d135acb9-1b0d-441b-b420-fcef90d83abd"],

Cell[BoxData[
 RowBox[{
  RowBox[{"vef", "[", 
   RowBox[{"{", 
    RowBox[{"3", ",", "3", ",", "3", ",", "r"}], "}"}], "]"}], " ", "//", " ",
   "Factor"}]], "Input",
 CellLabel->"In[36]:=",ExpressionUUID->"2697ad39-4fae-4596-ba24-a5c1e2954c9f"],

Cell[BoxData[
 RowBox[{"veflst", "[", 
  RowBox[{"4", ",", 
   RowBox[{"{", 
    RowBox[{"3", ",", "3", ",", "4"}], "}"}], ",", "True"}], "]"}]], "Input",
 CellLabel->"In[37]:=",ExpressionUUID->"2c42442d-62fa-407b-b70d-06f3b9f8c9d6"],

Cell[BoxData[
 RowBox[{"veflst", "[", 
  RowBox[{"4", ",", 
   RowBox[{"{", 
    RowBox[{"3", ",", "3", ",", "5"}], "}"}], ",", "True"}], "]"}]], "Input",
 CellLabel->"In[38]:=",ExpressionUUID->"93905dd0-8c27-4d3d-9e76-ea912c2a7743"],

Cell[BoxData[
 RowBox[{"veflst", "[", 
  RowBox[{"4", ",", 
   RowBox[{"{", 
    RowBox[{"3", ",", "3", ",", "6"}], "}"}], ",", "True"}], "]"}]], "Input",
 CellLabel->"In[61]:=",ExpressionUUID->"38e01931-70a8-43a1-9a6e-da63b5dc6b59"],

Cell[BoxData[
 RowBox[{"veflst", "[", 
  RowBox[{"5", ",", 
   RowBox[{"{", "}"}]}], "]"}]], "Input",
 CellLabel->"In[39]:=",ExpressionUUID->"41dffe8b-c672-4295-86bb-3e4658bfb1fd"],

Cell[BoxData[
 RowBox[{"veflst", "[", 
  RowBox[{"5", ",", 
   RowBox[{"{", "3", "}"}]}], "]"}]], "Input",
 CellLabel->"In[40]:=",ExpressionUUID->"a07ddf90-cb00-4f9f-9368-0e9043cacd93"],

Cell[BoxData[
 RowBox[{"veflst", "[", 
  RowBox[{"5", ",", 
   RowBox[{"{", 
    RowBox[{"3", ",", "3"}], "}"}]}], "]"}]], "Input",
 CellLabel->"In[41]:=",ExpressionUUID->"eb10925e-66d2-41ba-9a61-0d13fd815918"],

Cell[BoxData[
 RowBox[{"veflst", "[", 
  RowBox[{"5", ",", 
   RowBox[{"{", 
    RowBox[{"3", ",", "3", ",", "3"}], "}"}]}], "]"}]], "Input",
 CellLabel->"In[42]:=",ExpressionUUID->"06bd7294-c52f-4ad8-8e63-9e1d9c58e8c3"],

Cell[BoxData[
 RowBox[{"veflst", "[", 
  RowBox[{"5", ",", 
   RowBox[{"{", 
    RowBox[{"3", ",", "3", ",", "3", ",", "3"}], "}"}], ",", "True"}], 
  "]"}]], "Input",
 CellLabel->"In[43]:=",ExpressionUUID->"6a67a860-5b6f-4597-9f77-f010855ca10b"]
}, Open  ]],

Cell[CellGroupData[{

Cell["Table", "Section",ExpressionUUID->"2f3362e5-514a-4e98-ad8b-5d437ccb5fcd"],

Cell[BoxData[
 RowBox[{"TableForm", "[", 
  RowBox[{
   RowBox[{
    RowBox[{"Factor", "[", 
     RowBox[{"vef", "[", 
      RowBox[{"#", ",", "True"}], "]"}], "]"}], "&"}], " ", "/@", " ", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"3", ",", "3", ",", "3", ",", "3"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"3", ",", "3", ",", "4", ",", "4"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"3", ",", "3", ",", "5", ",", "5"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"3", ",", "3", ",", "6", ",", "6"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"3", ",", "4", ",", "4", ",", "3"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"3", ",", "4", ",", "4", ",", "4"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"3", ",", "4", ",", "4", ",", "5"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"3", ",", "4", ",", "4", ",", "6"}], "}"}]}], "}"}]}], 
  "]"}]], "Input",
 CellLabel->"In[63]:=",ExpressionUUID->"d4a74e17-73aa-41e7-81ca-712d1203d041"],

Cell[BoxData[
 RowBox[{"TableForm", "[", 
  RowBox[{
   RowBox[{
    RowBox[{"Factor", "[", 
     RowBox[{"vef", "[", 
      RowBox[{"#", ",", "True"}], "]"}], "]"}], "&"}], " ", "/@", " ", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"3", ",", "3", ",", "3"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"4", ",", "4", ",", "4"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"5", ",", "5", ",", "5"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"6", ",", "6", ",", "6"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"4", ",", "4", ",", "r"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"6", ",", "6", ",", "3"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"6", ",", "6", ",", "4"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"6", ",", "6", ",", "5"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"6", ",", "6", ",", "6"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"8", ",", "8", ",", "3"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"8", ",", "8", ",", "4"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"10", ",", "10", ",", "3"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"12", ",", "12", ",", "3"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"4", ",", "6", ",", "6"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"4", ",", "6", ",", "8"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"4", ",", "6", ",", "10"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"4", ",", "6", ",", "12"}], "}"}]}], "}"}]}], "]"}]], "Input",
 CellLabel->"In[59]:=",ExpressionUUID->"1e0fa1b3-02ba-48e8-aa17-9b61f2ee51d0"]
}, Open  ]]
},
WindowSize->{808, 778},
WindowMargins->{{Automatic, 188}, {Automatic, 0}},
FrontEndVersion->"11.3 for Mac OS X x86 (32-bit, 64-bit Kernel) (March 5, \
2018)",
StyleDefinitions->"Default.nb"
]
(* End of Notebook Content *)

(* Internal cache information *)
(*CellTagsOutline
CellTagsIndex->{}
*)
(*CellTagsIndex
CellTagsIndex->{}
*)
(*NotebookFileOutline
Notebook[{
Cell[558, 20, 632, 15, 311, "Text",ExpressionUUID->"0e7de373-24fb-48d9-9686-0ee0213d6ded"],
Cell[CellGroupData[{
Cell[1215, 39, 83, 0, 67, "Section",ExpressionUUID->"318e736f-7415-4098-a279-7fa80c9c4e35"],
Cell[1301, 41, 1656, 45, 220, "Input",ExpressionUUID->"3f21c1ae-3ee5-4210-9eaa-2a35e57e488a"],
Cell[2960, 88, 4693, 111, 514, "Input",ExpressionUUID->"8c032c5b-af58-4920-8ce4-6efc32b4fe6a"]
}, Closed]],
Cell[CellGroupData[{
Cell[7690, 204, 81, 0, 53, "Section",ExpressionUUID->"c61a2d8a-6d01-4f16-bbcb-8032a722e961"],
Cell[7774, 206, 193, 4, 30, "Input",ExpressionUUID->"024b69c2-21a1-4ec2-960a-3d97d6cf6975"],
Cell[7970, 212, 223, 5, 30, "Input",ExpressionUUID->"275beb37-df9d-4618-ada0-9e343aea71c8"],
Cell[8196, 219, 223, 5, 30, "Input",ExpressionUUID->"562961bf-22a1-4357-8ac3-9ed7e0844549"],
Cell[8422, 226, 198, 4, 30, "Input",ExpressionUUID->"688f3929-3dc6-44b5-8330-1397a0b8c90c"],
Cell[8623, 232, 236, 6, 30, "Input",ExpressionUUID->"b0cfa4c8-4267-40a8-a5ae-0d0d5a175b03"],
Cell[8862, 240, 223, 5, 30, "Input",ExpressionUUID->"2b47f965-6acf-4976-a4f9-ac65843638b6"],
Cell[9088, 247, 198, 4, 30, "Input",ExpressionUUID->"beb64a1e-a7a2-4eed-8d31-069488340d97"],
Cell[9289, 253, 180, 4, 30, "Input",ExpressionUUID->"70de61c3-3082-4019-8e22-4565e6773415"],
Cell[9472, 259, 185, 4, 30, "Input",ExpressionUUID->"886a3480-aa5b-4465-b52e-990e953d2b40"],
Cell[9660, 265, 210, 5, 30, "Input",ExpressionUUID->"c2cd86e4-3467-4ca7-aeee-8e358bf71289"],
Cell[9873, 272, 220, 5, 30, "Input",ExpressionUUID->"d253dbe5-3b1a-46d7-ac59-41cbbe65b624"],
Cell[10096, 279, 210, 5, 30, "Input",ExpressionUUID->"d135acb9-1b0d-441b-b420-fcef90d83abd"],
Cell[10309, 286, 246, 6, 30, "Input",ExpressionUUID->"2697ad39-4fae-4596-ba24-a5c1e2954c9f"],
Cell[10558, 294, 233, 5, 30, "Input",ExpressionUUID->"2c42442d-62fa-407b-b70d-06f3b9f8c9d6"],
Cell[10794, 301, 233, 5, 30, "Input",ExpressionUUID->"93905dd0-8c27-4d3d-9e76-ea912c2a7743"],
Cell[11030, 308, 233, 5, 30, "Input",ExpressionUUID->"38e01931-70a8-43a1-9a6e-da63b5dc6b59"],
Cell[11266, 315, 180, 4, 30, "Input",ExpressionUUID->"41dffe8b-c672-4295-86bb-3e4658bfb1fd"],
Cell[11449, 321, 185, 4, 30, "Input",ExpressionUUID->"a07ddf90-cb00-4f9f-9368-0e9043cacd93"],
Cell[11637, 327, 210, 5, 30, "Input",ExpressionUUID->"eb10925e-66d2-41ba-9a61-0d13fd815918"],
Cell[11850, 334, 220, 5, 30, "Input",ExpressionUUID->"06bd7294-c52f-4ad8-8e63-9e1d9c58e8c3"],
Cell[12073, 341, 246, 6, 30, "Input",ExpressionUUID->"6a67a860-5b6f-4597-9f77-f010855ca10b"]
}, Open  ]],
Cell[CellGroupData[{
Cell[12356, 352, 79, 0, 67, "Section",ExpressionUUID->"2f3362e5-514a-4e98-ad8b-5d437ccb5fcd"],
Cell[12438, 354, 988, 26, 73, "Input",ExpressionUUID->"d4a74e17-73aa-41e7-81ca-712d1203d041"],
Cell[13429, 382, 1568, 43, 94, "Input",ExpressionUUID->"1e0fa1b3-02ba-48e8-aa17-9b61f2ee51d0"]
}, Open  ]]
}
]
*)

