(* Content-type: application/mathematica *)

(*** Wolfram Notebook File ***)
(* http://www.wolfram.com/nb *)

(* CreatedBy='Mathematica 7.0' *)

(*CacheID: 234*)
(* Internal cache information:
NotebookFileLineBreakTest
NotebookFileLineBreakTest
NotebookDataPosition[       145,          7]
NotebookDataLength[     88514,       2540]
NotebookOptionsPosition[     86816,       2489]
NotebookOutlinePosition[     87174,       2505]
CellTagsIndexPosition[     87131,       2502]
WindowFrame->Normal*)

(* Beginning of Notebook Content *)
Notebook[{
Cell["\<\
Isohedral Dartboards and their Isogonal Duals -- Plane Tilings

Functions are tiling[nrpt, type, extra args]
nrpt - number of repeats in each dimension
extra args: numbers

Grids used: square, hexagonal

type -- # extra args -- wallpaper symmetry group -- name(s)
sqr -- 0 -- p4m -- square t, quadrille
sqr pyr -- 0 -- p4m -- tetrakis square t, kisquadrille
sqr trunc -- 1 -- p4m -- truncated square t, truncated quadrille
sqr pntg -- 2 - p4g -- cairo pentagonal t, 4-fold pentille
sqr snub -- 2 -- p4g -- snub square t, snub quadrille
rect pntg -- 1 -- cmm -- prismatic pentagonal t, iso(4-)pentille
rect snub -- 1 -- cmm -- elongated triangular t, isosnub quadrille
hex -- 0 -- p6m -- hexagonal t, hextille
tri -- 0 -- p6m -- triangular t, deltille
tri trunc -- 1 -- p6m -- hexagonal t, hextille
tri rhomb -- 0 -- p6m -- rhombille t, rhombille
hex tri -- 0 -- p6m -- trihexagonal t, hexadeltille
tri pyr -- 0 -- p6m -- triakis triangular t, kisdeltille
hex trunc -- 1 -- p6m -- truncated hexagonal t, truncated hextille
hex kite -- 0 -- p6m -- deltoidal trihexagonal t, tetrille
hex tri rect -- 1 -- p6m -- rhombitrihexagonal t, rhombihexadetille
hex pyr -- 0 --  p6m -- kisrhombille t, kisrhombille
hex tri rect trunc -- 2 -- p6m -- truncated trihexagonal t, truncated \
hexadeltille
hex pntg -- 2 -- p6 -- floret pentagonal t, 6-fold pentille
hex snub -- 2 -- p6 -- snub hexagonal t, snub hextille

http://en.wikipedia.org/wiki/List_of_convex_uniform_tilings\
\>", "Text"],

Cell[CellGroupData[{

Cell["Formulas", "Section"],

Cell[BoxData[
 RowBox[{
  RowBox[{"show2d", "[", "x_", "]"}], " ", ":=", " ", 
  RowBox[{"Graphics", "[", "x", "]"}]}]], "Input"],

Cell[BoxData[
 RowBox[{
  RowBox[{"show2dclip", "[", 
   RowBox[{"x_", ",", "rng_"}], "]"}], " ", ":=", " ", 
  RowBox[{"Graphics", "[", 
   RowBox[{"x", ",", 
    RowBox[{"PlotRange", "\[Rule]", "rng"}], ",", 
    RowBox[{"PlotRangeClipping", "\[Rule]", "True"}]}], "]"}]}]], "Input"],

Cell[BoxData[
 RowBox[{
  RowBox[{"repeat2d", "[", 
   RowBox[{"nrpt_", ",", "ucs_", ",", "x_"}], "]"}], " ", ":=", " ", 
  RowBox[{"Table", "[", 
   RowBox[{
    RowBox[{"Translate", "[", 
     RowBox[{"x", ",", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"k1", ",", "k2"}], "}"}], ".", "ucs"}]}], "]"}], ",", 
    RowBox[{"{", 
     RowBox[{"k1", ",", "0", ",", 
      RowBox[{
       RowBox[{"nrpt", "[", 
        RowBox[{"[", "1", "]"}], "]"}], "-", "1"}]}], "}"}], ",", 
    RowBox[{"{", 
     RowBox[{"k2", ",", "0", ",", 
      RowBox[{
       RowBox[{"nrpt", "[", 
        RowBox[{"[", "2", "]"}], "]"}], "-", "1"}]}], "}"}]}], 
   "]"}]}]], "Input"],

Cell[BoxData[
 RowBox[{
  RowBox[{"repeat", "[", 
   RowBox[{"nrpt_", ",", "\"\<square\>\"", ",", "x_"}], "]"}], " ", ":=", " ", 
  RowBox[{"repeat2d", "[", 
   RowBox[{"nrpt", ",", 
    RowBox[{"IdentityMatrix", "[", "2", "]"}], ",", "x"}], "]"}]}]], "Input"],

Cell[BoxData[
 RowBox[{
  RowBox[{"repeat", "[", 
   RowBox[{"nrpt_", ",", "\"\<hex\>\"", ",", "x_"}], "]"}], " ", ":=", " ", 
  RowBox[{"repeat2d", "[", 
   RowBox[{"nrpt", ",", 
    RowBox[{"{", 
     RowBox[{
      RowBox[{"{", 
       RowBox[{"1", ",", "0"}], "}"}], ",", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"1", "/", "2"}], ",", 
        RowBox[{
         RowBox[{"Sqrt", "[", "3", "]"}], "/", "2"}]}], "}"}]}], "}"}], ",", 
    "x"}], "]"}]}]], "Input"],

Cell[BoxData[
 RowBox[{" ", 
  RowBox[{
   RowBox[{"bkgd", " ", "=", " ", 
    RowBox[{"GrayLevel", "[", 
     RowBox[{"7", "/", "8"}], "]"}]}], ";"}]}]], "Input"],

Cell[BoxData[
 RowBox[{
  RowBox[{"tiling", "[", 
   RowBox[{"nrpt_", ",", "\"\<sqr\>\""}], "]"}], " ", ":=", " ", 
  RowBox[{"repeat", "[", 
   RowBox[{"nrpt", ",", "\"\<square\>\"", ",", 
    RowBox[{"{", 
     RowBox[{
      RowBox[{"EdgeForm", "[", "Thick", "]"}], ",", "bkgd", ",", 
      RowBox[{"GraphicsComplex", "[", 
       RowBox[{
        RowBox[{"{", 
         RowBox[{
          RowBox[{"{", 
           RowBox[{"0", ",", "0"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{"1", ",", "0"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{"0", ",", "1"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{"1", ",", "1"}], "}"}]}], "}"}], ",", 
        RowBox[{"Polygon", "[", 
         RowBox[{"{", 
          RowBox[{"{", 
           RowBox[{"1", ",", "2", ",", "4", ",", "3"}], "}"}], "}"}], "]"}]}],
        "]"}]}], "}"}]}], "]"}]}]], "Input"],

Cell[BoxData[
 RowBox[{
  RowBox[{"tiling", "[", 
   RowBox[{"nrpt_", ",", "\"\<sqr pyr\>\""}], "]"}], " ", ":=", " ", 
  RowBox[{"repeat", "[", 
   RowBox[{"nrpt", ",", "\"\<square\>\"", ",", 
    RowBox[{"{", 
     RowBox[{
      RowBox[{"EdgeForm", "[", "Thick", "]"}], ",", "bkgd", ",", 
      RowBox[{"GraphicsComplex", "[", 
       RowBox[{
        RowBox[{"{", 
         RowBox[{
          RowBox[{"{", 
           RowBox[{"0", ",", "0"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"1", "/", "2"}], ",", "0"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{"1", ",", "0"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{"0", ",", 
            RowBox[{"1", "/", "2"}]}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"1", "/", "2"}], ",", 
            RowBox[{"1", "/", "2"}]}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{"1", ",", 
            RowBox[{"1", "/", "2"}]}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{"0", ",", "1"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"1", "/", "2"}], ",", "1"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{"1", ",", "1"}], "}"}]}], "}"}], ",", 
        RowBox[{"Polygon", "[", 
         RowBox[{"{", 
          RowBox[{
           RowBox[{"{", 
            RowBox[{"1", ",", "2", ",", "5"}], "}"}], ",", 
           RowBox[{"{", 
            RowBox[{"2", ",", "3", ",", "5"}], "}"}], ",", 
           RowBox[{"{", 
            RowBox[{"4", ",", "1", ",", "5"}], "}"}], ",", 
           RowBox[{"{", 
            RowBox[{"3", ",", "6", ",", "5"}], "}"}], ",", 
           RowBox[{"{", 
            RowBox[{"7", ",", "4", ",", "5"}], "}"}], ",", 
           RowBox[{"{", 
            RowBox[{"6", ",", "9", ",", "5"}], "}"}], ",", 
           RowBox[{"{", 
            RowBox[{"8", ",", "7", ",", "5"}], "}"}], ",", 
           RowBox[{"{", 
            RowBox[{"9", ",", "8", ",", "5"}], "}"}]}], "}"}], "]"}]}], 
       "]"}]}], "}"}]}], "]"}]}]], "Input"],

Cell[BoxData[
 RowBox[{
  RowBox[{"tiling", "[", 
   RowBox[{"nrpt_", ",", "\"\<sqr trunc\>\"", ",", "f1_"}], "]"}], " ", ":=", 
  " ", 
  RowBox[{"repeat", "[", 
   RowBox[{"nrpt", ",", "\"\<square\>\"", ",", 
    RowBox[{"{", 
     RowBox[{
      RowBox[{"EdgeForm", "[", "Thick", "]"}], ",", "bkgd", ",", 
      RowBox[{"GraphicsComplex", "[", 
       RowBox[{
        RowBox[{"{", 
         RowBox[{
          RowBox[{"{", 
           RowBox[{"0", ",", 
            RowBox[{
             RowBox[{"-", "f1"}], "/", "2"}]}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{
             RowBox[{"-", "f1"}], "/", "2"}], ",", "0"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"f1", "/", "2"}], ",", "0"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"1", "-", 
             RowBox[{"f1", "/", "2"}]}], ",", "0"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{"0", ",", 
            RowBox[{"f1", "/", "2"}]}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{"1", ",", 
            RowBox[{"f1", "/", "2"}]}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{"0", ",", 
            RowBox[{"1", "-", 
             RowBox[{"f1", "/", "2"}]}]}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{"1", ",", 
            RowBox[{"1", "-", 
             RowBox[{"f1", "/", "2"}]}]}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"f1", "/", "2"}], ",", "1"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"1", "-", 
             RowBox[{"f1", "/", "2"}]}], ",", "1"}], "}"}]}], "}"}], ",", 
        RowBox[{"Polygon", "[", 
         RowBox[{"{", 
          RowBox[{
           RowBox[{"{", 
            RowBox[{"1", ",", "3", ",", "5", ",", "2", ",", "1"}], "}"}], ",", 
           RowBox[{"{", 
            RowBox[{
            "3", ",", "4", ",", "6", ",", "8", ",", "10", ",", "9", ",", "7", 
             ",", "5", ",", "3"}], "}"}]}], "}"}], "]"}]}], "]"}]}], "}"}]}], 
   "]"}]}]], "Input"],

Cell[BoxData[
 RowBox[{
  RowBox[{"tiling", "[", 
   RowBox[{"nrpt_", ",", "\"\<sqr pntg\>\"", ",", "f1_"}], "]"}], " ", ":=", 
  " ", 
  RowBox[{"repeat", "[", 
   RowBox[{"nrpt", ",", "\"\<square\>\"", ",", 
    RowBox[{"{", 
     RowBox[{
      RowBox[{"EdgeForm", "[", "Thick", "]"}], ",", "bkgd", ",", 
      RowBox[{"Table", "[", 
       RowBox[{
        RowBox[{"Translate", "[", 
         RowBox[{
          RowBox[{"GraphicsComplex", "[", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{
              RowBox[{"{", 
               RowBox[{"0", ",", 
                RowBox[{
                 RowBox[{
                  RowBox[{"-", "1"}], "/", "2"}], "+", 
                 RowBox[{"f1", "/", "4"}]}]}], "}"}], ",", 
              RowBox[{"{", 
               RowBox[{
                RowBox[{
                 RowBox[{"-", "1"}], "/", "4"}], ",", 
                RowBox[{
                 RowBox[{"-", "1"}], "/", "4"}]}], "}"}], ",", 
              RowBox[{"{", 
               RowBox[{
                RowBox[{"1", "/", "4"}], ",", 
                RowBox[{
                 RowBox[{"-", "1"}], "/", "4"}]}], "}"}], ",", 
              RowBox[{"{", 
               RowBox[{
                RowBox[{
                 RowBox[{"-", "1"}], "/", "2"}], ",", 
                RowBox[{
                 RowBox[{"-", "f1"}], "/", "4"}]}], "}"}], ",", 
              RowBox[{"{", 
               RowBox[{
                RowBox[{"1", "/", "2"}], ",", 
                RowBox[{
                 RowBox[{"-", "f1"}], "/", "4"}]}], "}"}], ",", 
              RowBox[{"{", 
               RowBox[{
                RowBox[{
                 RowBox[{"-", "f1"}], "/", "4"}], ",", "0"}], "}"}], ",", 
              RowBox[{"{", 
               RowBox[{
                RowBox[{"f1", "/", "4"}], ",", "0"}], "}"}], ",", 
              RowBox[{"{", 
               RowBox[{
                RowBox[{
                 RowBox[{"-", "1"}], "/", "2"}], ",", 
                RowBox[{"f1", "/", "4"}]}], "}"}], ",", 
              RowBox[{"{", 
               RowBox[{
                RowBox[{"1", "/", "2"}], ",", 
                RowBox[{"f1", "/", "4"}]}], "}"}], ",", 
              RowBox[{"{", 
               RowBox[{
                RowBox[{
                 RowBox[{"-", "1"}], "/", "4"}], ",", 
                RowBox[{"1", "/", "4"}]}], "}"}], ",", 
              RowBox[{"{", 
               RowBox[{
                RowBox[{"1", "/", "4"}], ",", 
                RowBox[{"1", "/", "4"}]}], "}"}], ",", 
              RowBox[{"{", 
               RowBox[{"0", ",", 
                RowBox[{
                 RowBox[{"1", "/", "2"}], "-", 
                 RowBox[{"f1", "/", "4"}]}]}], "}"}]}], "}"}], ",", 
            RowBox[{"Polygon", "[", 
             RowBox[{"{", 
              RowBox[{
               RowBox[{"{", 
                RowBox[{"1", ",", "3", ",", "7", ",", "6", ",", "2"}], "}"}], 
               ",", 
               RowBox[{"{", 
                RowBox[{"2", ",", "6", ",", "10", ",", "8", ",", "4"}], "}"}],
                ",", 
               RowBox[{"{", 
                RowBox[{"3", ",", "5", ",", "9", ",", "11", ",", "7"}], "}"}],
                ",", 
               RowBox[{"{", 
                RowBox[{"6", ",", "7", ",", "11", ",", "12", ",", "10"}], 
                "}"}]}], "}"}], "]"}]}], "]"}], ",", 
          RowBox[{
           RowBox[{"(", 
            RowBox[{"k", "/", "2"}], ")"}], 
           RowBox[{"{", 
            RowBox[{"1", ",", "1"}], "}"}]}]}], "]"}], ",", 
        RowBox[{"{", 
         RowBox[{"k", ",", "0", ",", "1"}], "}"}]}], "]"}]}], "}"}]}], 
   "]"}]}]], "Input"],

Cell[BoxData[
 RowBox[{
  RowBox[{"tiling", "[", 
   RowBox[{"nrpt_", ",", "\"\<sqr snub\>\"", ",", "f1_"}], "]"}], " ", ":=", 
  " ", 
  RowBox[{"repeat", "[", 
   RowBox[{"nrpt", ",", "\"\<square\>\"", ",", 
    RowBox[{"{", 
     RowBox[{
      RowBox[{"EdgeForm", "[", "Thick", "]"}], ",", "bkgd", ",", 
      RowBox[{"GraphicsComplex", "[", 
       RowBox[{
        RowBox[{"{", 
         RowBox[{
          RowBox[{"{", 
           RowBox[{"0", ",", 
            RowBox[{
             RowBox[{"-", "f1"}], "/", "2"}]}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{"1", ",", 
            RowBox[{
             RowBox[{"-", "f1"}], "/", "2"}]}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{
             RowBox[{"1", "/", "2"}], "-", 
             RowBox[{"f1", "/", "2"}]}], ",", "0"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{
             RowBox[{"1", "/", "2"}], "+", 
             RowBox[{"f1", "/", "2"}]}], ",", "0"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{"0", ",", 
            RowBox[{"f1", "/", "2"}]}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{"1", ",", 
            RowBox[{"f1", "/", "2"}]}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"1", "/", "2"}], ",", 
            RowBox[{
             RowBox[{"1", "/", "2"}], "-", 
             RowBox[{"f1", "/", "2"}]}]}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{
             RowBox[{"-", "f1"}], "/", "2"}], ",", 
            RowBox[{"1", "/", "2"}]}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"f1", "/", "2"}], ",", 
            RowBox[{"1", "/", "2"}]}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"1", "-", 
             RowBox[{"f1", "/", "2"}]}], ",", 
            RowBox[{"1", "/", "2"}]}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"1", "/", "2"}], ",", 
            RowBox[{
             RowBox[{"1", "/", "2"}], "+", 
             RowBox[{"f1", "/", "2"}]}]}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{"0", ",", 
            RowBox[{"1", "-", 
             RowBox[{"f1", "/", "2"}]}]}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{"1", ",", 
            RowBox[{"1", "-", 
             RowBox[{"f1", "/", "2"}]}]}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{
             RowBox[{"1", "/", "2"}], "-", 
             RowBox[{"f1", "/", "2"}]}], ",", "1"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{
             RowBox[{"1", "/", "2"}], "+", 
             RowBox[{"f1", "/", "2"}]}], ",", "1"}], "}"}]}], "}"}], ",", 
        RowBox[{"Polygon", "[", 
         RowBox[{"{", 
          RowBox[{
           RowBox[{"{", 
            RowBox[{"3", ",", "7", ",", "9", ",", "5"}], "}"}], ",", 
           RowBox[{"{", 
            RowBox[{"4", ",", "6", ",", "10", ",", "7"}], "}"}], ",", 
           RowBox[{"{", 
            RowBox[{"9", ",", "11", ",", "14", ",", "12"}], "}"}], ",", 
           RowBox[{"{", 
            RowBox[{"10", ",", "13", ",", "15", ",", "11"}], "}"}], ",", 
           RowBox[{"{", 
            RowBox[{"1", ",", "3", ",", "5"}], "}"}], ",", 
           RowBox[{"{", 
            RowBox[{"2", ",", "6", ",", "4"}], "}"}], ",", 
           RowBox[{"{", 
            RowBox[{"7", ",", "11", ",", "9"}], "}"}], ",", 
           RowBox[{"{", 
            RowBox[{"7", ",", "10", ",", "11"}], "}"}], ",", 
           RowBox[{"{", 
            RowBox[{"3", ",", "4", ",", "7"}], "}"}], ",", 
           RowBox[{"{", 
            RowBox[{"11", ",", "15", ",", "14"}], "}"}], ",", 
           RowBox[{"{", 
            RowBox[{"5", ",", "9", ",", "8"}], "}"}], ",", 
           RowBox[{"{", 
            RowBox[{"8", ",", "9", ",", "12"}], "}"}]}], "}"}], "]"}]}], 
       "]"}]}], "}"}]}], "]"}]}]], "Input"],

Cell[BoxData[
 RowBox[{
  RowBox[{"tiling", "[", 
   RowBox[{"nrpt_", ",", "\"\<rect pntg\>\"", ",", "f1_"}], "]"}], " ", ":=", 
  " ", 
  RowBox[{"repeat", "[", 
   RowBox[{"nrpt", ",", "\"\<square\>\"", ",", 
    RowBox[{"{", 
     RowBox[{
      RowBox[{"EdgeForm", "[", "Thick", "]"}], ",", "bkgd", ",", 
      RowBox[{"GraphicsComplex", "[", 
       RowBox[{
        RowBox[{"{", 
         RowBox[{
          RowBox[{"{", 
           RowBox[{"0", ",", "0"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{"1", ",", "0"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{"0", ",", 
            RowBox[{
             RowBox[{"1", "/", "2"}], "-", 
             RowBox[{"f1", "/", "2"}]}]}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{"1", ",", 
            RowBox[{
             RowBox[{"1", "/", "2"}], "-", 
             RowBox[{"f1", "/", "2"}]}]}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"1", "/", "2"}], ",", 
            RowBox[{
             RowBox[{"1", "/", "2"}], "+", 
             RowBox[{"f1", "/", "2"}]}]}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"3", "/", "2"}], ",", 
            RowBox[{
             RowBox[{"1", "/", "2"}], "+", 
             RowBox[{"f1", "/", "2"}]}]}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"1", "/", "2"}], ",", "1"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"3", "/", "2"}], ",", "1"}], "}"}]}], "}"}], ",", 
        RowBox[{"Polygon", "[", 
         RowBox[{"{", 
          RowBox[{
           RowBox[{"{", 
            RowBox[{"1", ",", "2", ",", "4", ",", "5", ",", "3"}], "}"}], ",", 
           RowBox[{"{", 
            RowBox[{"4", ",", "6", ",", "8", ",", "7", ",", "5"}], "}"}]}], 
          "}"}], "]"}]}], "]"}]}], "}"}]}], "]"}]}]], "Input"],

Cell[BoxData[
 RowBox[{
  RowBox[{"tiling", "[", 
   RowBox[{"nrpt_", ",", "\"\<rect snub\>\"", ",", "f1_"}], "]"}], " ", ":=", 
  " ", 
  RowBox[{"repeat", "[", 
   RowBox[{"nrpt", ",", "\"\<square\>\"", ",", 
    RowBox[{"{", 
     RowBox[{
      RowBox[{"EdgeForm", "[", "Thick", "]"}], ",", "bkgd", ",", 
      RowBox[{"Table", "[", 
       RowBox[{
        RowBox[{"Translate", "[", 
         RowBox[{
          RowBox[{"GraphicsComplex", "[", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{
              RowBox[{"{", 
               RowBox[{"0", ",", "0"}], "}"}], ",", 
              RowBox[{"{", 
               RowBox[{"1", ",", "0"}], "}"}], ",", 
              RowBox[{"{", 
               RowBox[{"0", ",", 
                RowBox[{"f1", "/", "2"}]}], "}"}], ",", 
              RowBox[{"{", 
               RowBox[{"1", ",", 
                RowBox[{"f1", "/", "2"}]}], "}"}], ",", 
              RowBox[{"{", 
               RowBox[{
                RowBox[{"1", "/", "2"}], ",", 
                RowBox[{"1", "/", "2"}]}], "}"}], ",", 
              RowBox[{"{", 
               RowBox[{
                RowBox[{"3", "/", "2"}], ",", 
                RowBox[{"1", "/", "2"}]}], "}"}]}], "}"}], ",", 
            RowBox[{"Polygon", "[", 
             RowBox[{"{", 
              RowBox[{
               RowBox[{"{", 
                RowBox[{"1", ",", "2", ",", "4", ",", "3"}], "}"}], ",", 
               RowBox[{"{", 
                RowBox[{"3", ",", "4", ",", "5"}], "}"}], ",", 
               RowBox[{"{", 
                RowBox[{"4", ",", "6", ",", "5"}], "}"}]}], "}"}], "]"}]}], 
           "]"}], ",", 
          RowBox[{
           RowBox[{"(", 
            RowBox[{"k", "/", "2"}], ")"}], 
           RowBox[{"{", 
            RowBox[{"1", ",", "1"}], "}"}]}]}], "]"}], ",", 
        RowBox[{"{", 
         RowBox[{"k", ",", "0", ",", "1"}], "}"}]}], "]"}]}], "}"}]}], 
   "]"}]}]], "Input"],

Cell[BoxData[
 RowBox[{
  RowBox[{"tiling", "[", 
   RowBox[{"nrpt_", ",", "\"\<tri\>\""}], "]"}], " ", ":=", " ", 
  RowBox[{"repeat", "[", 
   RowBox[{"nrpt", ",", "\"\<hex\>\"", ",", 
    RowBox[{"{", 
     RowBox[{
      RowBox[{"EdgeForm", "[", "Thick", "]"}], ",", "bkgd", ",", 
      RowBox[{"GraphicsComplex", "[", 
       RowBox[{
        RowBox[{"{", 
         RowBox[{
          RowBox[{"{", 
           RowBox[{"0", ",", "0"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{"1", ",", "0"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"1", "/", "2"}], ",", 
            RowBox[{
             RowBox[{"Sqrt", "[", "3", "]"}], "/", "2"}]}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"3", "/", "2"}], ",", 
            RowBox[{
             RowBox[{"Sqrt", "[", "3", "]"}], "/", "2"}]}], "}"}]}], "}"}], 
        ",", 
        RowBox[{"Polygon", "[", 
         RowBox[{"{", 
          RowBox[{
           RowBox[{"{", 
            RowBox[{"1", ",", "2", ",", "3"}], "}"}], ",", 
           RowBox[{"{", 
            RowBox[{"2", ",", "4", ",", "3"}], "}"}]}], "}"}], "]"}]}], 
       "]"}]}], "}"}]}], "]"}]}]], "Input"],

Cell[BoxData[
 RowBox[{
  RowBox[{"tiling", "[", 
   RowBox[{"nrpt_", ",", "\"\<hex\>\""}], "]"}], " ", ":=", " ", 
  RowBox[{"repeat", "[", 
   RowBox[{"nrpt", ",", "\"\<hex\>\"", ",", 
    RowBox[{"{", 
     RowBox[{
      RowBox[{"EdgeForm", "[", "Thick", "]"}], ",", "bkgd", ",", 
      RowBox[{"GraphicsComplex", "[", 
       RowBox[{
        RowBox[{"{", 
         RowBox[{
          RowBox[{"{", 
           RowBox[{
            RowBox[{"1", "/", "2"}], ",", 
            RowBox[{
             RowBox[{"-", 
              RowBox[{"Sqrt", "[", "3", "]"}]}], "/", "6"}]}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{"0", ",", "0"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{"1", ",", "0"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{"0", ",", 
            RowBox[{
             RowBox[{"Sqrt", "[", "3", "]"}], "/", "3"}]}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{"1", ",", 
            RowBox[{
             RowBox[{"Sqrt", "[", "3", "]"}], "/", "3"}]}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"1", "/", "2"}], ",", 
            RowBox[{
             RowBox[{"Sqrt", "[", "3", "]"}], "/", "2"}]}], "}"}]}], "}"}], 
        ",", 
        RowBox[{"Polygon", "[", 
         RowBox[{"{", 
          RowBox[{"{", 
           RowBox[{"1", ",", "3", ",", "5", ",", "6", ",", "4", ",", "2"}], 
           "}"}], "}"}], "]"}]}], "]"}]}], "}"}]}], "]"}]}]], "Input"],

Cell[BoxData[
 RowBox[{
  RowBox[{"tiling", "[", 
   RowBox[{"nrpt_", ",", "\"\<tri trunc\>\"", ",", "f1_"}], "]"}], " ", ":=", 
  " ", 
  RowBox[{"repeat", "[", 
   RowBox[{"nrpt", ",", "\"\<hex\>\"", ",", 
    RowBox[{"{", 
     RowBox[{
      RowBox[{"EdgeForm", "[", "Thick", "]"}], ",", "bkgd", ",", 
      RowBox[{"GraphicsComplex", "[", 
       RowBox[{
        RowBox[{"{", 
         RowBox[{
          RowBox[{"{", 
           RowBox[{
            RowBox[{"f1", "/", "2"}], ",", "0"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"1", "-", 
             RowBox[{"f1", "/", "2"}]}], ",", "0"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"f1", "/", "4"}], ",", 
            RowBox[{"f1", "*", 
             RowBox[{
              RowBox[{"Sqrt", "[", "3", "]"}], "/", "4"}]}]}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"1", "-", 
             RowBox[{"f1", "/", "4"}]}], ",", 
            RowBox[{"f1", "*", 
             RowBox[{
              RowBox[{"Sqrt", "[", "3", "]"}], "/", "4"}]}]}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"1", "+", 
             RowBox[{"f1", "/", "4"}]}], ",", 
            RowBox[{"f1", "*", 
             RowBox[{
              RowBox[{"Sqrt", "[", "3", "]"}], "/", "4"}]}]}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{
             RowBox[{"1", "/", "2"}], "-", 
             RowBox[{"f1", "/", "4"}]}], ",", 
            RowBox[{
             RowBox[{
              RowBox[{"Sqrt", "[", "3", "]"}], "/", "2"}], "-", 
             RowBox[{"f1", "*", 
              RowBox[{
               RowBox[{"Sqrt", "[", "3", "]"}], "/", "4"}]}]}]}], "}"}], ",", 
          
          RowBox[{"{", 
           RowBox[{
            RowBox[{
             RowBox[{"1", "/", "2"}], "+", 
             RowBox[{"f1", "/", "4"}]}], ",", 
            RowBox[{
             RowBox[{
              RowBox[{"Sqrt", "[", "3", "]"}], "/", "2"}], "-", 
             RowBox[{"f1", "*", 
              RowBox[{
               RowBox[{"Sqrt", "[", "3", "]"}], "/", "4"}]}]}]}], "}"}], ",", 
          
          RowBox[{"{", 
           RowBox[{
            RowBox[{
             RowBox[{"3", "/", "2"}], "-", 
             RowBox[{"f1", "/", "4"}]}], ",", 
            RowBox[{
             RowBox[{
              RowBox[{"Sqrt", "[", "3", "]"}], "/", "2"}], "-", 
             RowBox[{"f1", "*", 
              RowBox[{
               RowBox[{"Sqrt", "[", "3", "]"}], "/", "4"}]}]}]}], "}"}], ",", 
          
          RowBox[{"{", 
           RowBox[{
            RowBox[{
             RowBox[{"1", "/", "2"}], "-", 
             RowBox[{"f1", "/", "2"}]}], ",", 
            RowBox[{
             RowBox[{"Sqrt", "[", "3", "]"}], "/", "2"}]}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{
             RowBox[{"1", "/", "2"}], "+", 
             RowBox[{"f1", "/", "2"}]}], ",", 
            RowBox[{
             RowBox[{"Sqrt", "[", "3", "]"}], "/", "2"}]}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{
             RowBox[{"3", "/", "2"}], "-", 
             RowBox[{"f1", "/", "2"}]}], ",", 
            RowBox[{
             RowBox[{"Sqrt", "[", "3", "]"}], "/", "2"}]}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{
             RowBox[{"1", "/", "2"}], "-", 
             RowBox[{"f1", "/", "4"}]}], ",", 
            RowBox[{
             RowBox[{
              RowBox[{"Sqrt", "[", "3", "]"}], "/", "2"}], "+", 
             RowBox[{"f1", "*", 
              RowBox[{
               RowBox[{"Sqrt", "[", "3", "]"}], "/", "4"}]}]}]}], "}"}], ",", 
          
          RowBox[{"{", 
           RowBox[{
            RowBox[{
             RowBox[{"1", "/", "2"}], "+", 
             RowBox[{"f1", "/", "4"}]}], ",", 
            RowBox[{
             RowBox[{
              RowBox[{"Sqrt", "[", "3", "]"}], "/", "2"}], "+", 
             RowBox[{"f1", "*", 
              RowBox[{
               RowBox[{"Sqrt", "[", "3", "]"}], "/", "4"}]}]}]}], "}"}]}], 
         "}"}], ",", 
        RowBox[{"Polygon", "[", 
         RowBox[{"{", 
          RowBox[{
           RowBox[{"{", 
            RowBox[{"1", ",", "2", ",", "4", ",", "7", ",", "6", ",", "3"}], 
            "}"}], ",", 
           RowBox[{"{", 
            RowBox[{"4", ",", "5", ",", "8", ",", "11", ",", "10", ",", "7"}],
             "}"}], ",", 
           RowBox[{"{", 
            RowBox[{
            "6", ",", "7", ",", "10", ",", "13", ",", "12", ",", "9"}], 
            "}"}]}], "}"}], "]"}]}], "]"}]}], "}"}]}], "]"}]}]], "Input"],

Cell[BoxData[
 RowBox[{
  RowBox[{"tiling", "[", 
   RowBox[{"nrpt_", ",", "\"\<tri rhomb\>\""}], "]"}], " ", ":=", " ", 
  RowBox[{"repeat", "[", 
   RowBox[{"nrpt", ",", "\"\<hex\>\"", ",", 
    RowBox[{"{", 
     RowBox[{
      RowBox[{"EdgeForm", "[", "Thick", "]"}], ",", "bkgd", ",", 
      RowBox[{"GraphicsComplex", "[", 
       RowBox[{
        RowBox[{"{", 
         RowBox[{
          RowBox[{"{", 
           RowBox[{
            RowBox[{"1", "/", "2"}], ",", 
            RowBox[{
             RowBox[{"-", 
              RowBox[{"Sqrt", "[", "3", "]"}]}], "/", "6"}]}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{"0", ",", "0"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{"1", ",", "0"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"1", "/", "2"}], ",", 
            RowBox[{
             RowBox[{"Sqrt", "[", "3", "]"}], "/", "6"}]}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{"0", ",", 
            RowBox[{
             RowBox[{"Sqrt", "[", "3", "]"}], "/", "3"}]}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{"1", ",", 
            RowBox[{
             RowBox[{"Sqrt", "[", "3", "]"}], "/", "3"}]}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"1", "/", "2"}], ",", 
            RowBox[{
             RowBox[{"Sqrt", "[", "3", "]"}], "/", "2"}]}], "}"}]}], "}"}], 
        ",", 
        RowBox[{"Polygon", "[", 
         RowBox[{"{", 
          RowBox[{
           RowBox[{"{", 
            RowBox[{"2", ",", "1", ",", "3", ",", "4"}], "}"}], ",", 
           RowBox[{"{", 
            RowBox[{"2", ",", "4", ",", "7", ",", "5"}], "}"}], ",", 
           RowBox[{"{", 
            RowBox[{"3", ",", "6", ",", "7", ",", "4"}], "}"}]}], "}"}], 
         "]"}]}], "]"}]}], "}"}]}], "]"}]}]], "Input"],

Cell[BoxData[
 RowBox[{
  RowBox[{"tiling", "[", 
   RowBox[{"nrpt_", ",", "\"\<hex tri\>\""}], "]"}], " ", ":=", " ", 
  RowBox[{"repeat", "[", 
   RowBox[{"nrpt", ",", "\"\<hex\>\"", ",", 
    RowBox[{"{", 
     RowBox[{
      RowBox[{"EdgeForm", "[", "Thick", "]"}], ",", "bkgd", ",", 
      RowBox[{"GraphicsComplex", "[", 
       RowBox[{
        RowBox[{"{", 
         RowBox[{
          RowBox[{"{", 
           RowBox[{"0", ",", "0"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"1", "/", "2"}], ",", "0"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{"1", ",", "0"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"1", "/", "4"}], ",", 
            RowBox[{
             RowBox[{"Sqrt", "[", "3", "]"}], "/", "4"}]}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"5", "/", "4"}], ",", 
            RowBox[{
             RowBox[{"Sqrt", "[", "3", "]"}], "/", "4"}]}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"1", "/", "2"}], ",", 
            RowBox[{
             RowBox[{"Sqrt", "[", "3", "]"}], "/", "2"}]}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{"1", ",", 
            RowBox[{
             RowBox[{"Sqrt", "[", "3", "]"}], "/", "2"}]}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"3", "/", "2"}], ",", 
            RowBox[{
             RowBox[{"Sqrt", "[", "3", "]"}], "/", "2"}]}], "}"}]}], "}"}], 
        ",", 
        RowBox[{"Polygon", "[", 
         RowBox[{"{", 
          RowBox[{
           RowBox[{"{", 
            RowBox[{"2", ",", "3", ",", "5", ",", "7", ",", "6", ",", "4"}], 
            "}"}], ",", 
           RowBox[{"{", 
            RowBox[{"1", ",", "2", ",", "4"}], "}"}], ",", 
           RowBox[{"{", 
            RowBox[{"5", ",", "8", ",", "7"}], "}"}]}], "}"}], "]"}]}], 
       "]"}]}], "}"}]}], "]"}]}]], "Input"],

Cell[BoxData[
 RowBox[{
  RowBox[{"tiling", "[", 
   RowBox[{"nrpt_", ",", "\"\<tri pyr\>\""}], "]"}], " ", ":=", " ", 
  RowBox[{"repeat", "[", 
   RowBox[{"nrpt", ",", "\"\<hex\>\"", ",", 
    RowBox[{"{", 
     RowBox[{
      RowBox[{"EdgeForm", "[", "Thick", "]"}], ",", "bkgd", ",", 
      RowBox[{"GraphicsComplex", "[", 
       RowBox[{
        RowBox[{"{", 
         RowBox[{
          RowBox[{"{", 
           RowBox[{"0", ",", "0"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{"1", ",", "0"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"1", "/", "2"}], ",", 
            RowBox[{
             RowBox[{"Sqrt", "[", "3", "]"}], "/", "6"}]}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{"1", ",", 
            RowBox[{
             RowBox[{"Sqrt", "[", "3", "]"}], "/", "3"}]}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"1", "/", "2"}], ",", 
            RowBox[{
             RowBox[{"Sqrt", "[", "3", "]"}], "/", "2"}]}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"3", "/", "2"}], ",", 
            RowBox[{
             RowBox[{"Sqrt", "[", "3", "]"}], "/", "2"}]}], "}"}]}], "}"}], 
        ",", 
        RowBox[{"Polygon", "[", 
         RowBox[{"{", 
          RowBox[{
           RowBox[{"{", 
            RowBox[{"1", ",", "2", ",", "3"}], "}"}], ",", 
           RowBox[{"{", 
            RowBox[{"2", ",", "5", ",", "3"}], "}"}], ",", 
           RowBox[{"{", 
            RowBox[{"1", ",", "3", ",", "5"}], "}"}], ",", 
           RowBox[{"{", 
            RowBox[{"2", ",", "4", ",", "5"}], "}"}], ",", 
           RowBox[{"{", 
            RowBox[{"2", ",", "6", ",", "4"}], "}"}], ",", 
           RowBox[{"{", 
            RowBox[{"4", ",", "6", ",", "5"}], "}"}]}], "}"}], "]"}]}], 
       "]"}]}], "}"}]}], "]"}]}]], "Input"],

Cell[BoxData[
 RowBox[{
  RowBox[{"tiling", "[", 
   RowBox[{"nrpt_", ",", "\"\<hex trunc\>\"", ",", "f1_"}], "]"}], " ", ":=", 
  " ", 
  RowBox[{"repeat", "[", 
   RowBox[{"nrpt", ",", "\"\<hex\>\"", ",", 
    RowBox[{"{", 
     RowBox[{
      RowBox[{"EdgeForm", "[", "Thick", "]"}], ",", "bkgd", ",", 
      RowBox[{"GraphicsComplex", "[", 
       RowBox[{
        RowBox[{"{", 
         RowBox[{
          RowBox[{"{", 
           RowBox[{
            RowBox[{
             RowBox[{"1", "/", "2"}], "-", 
             RowBox[{"f1", "/", "4"}]}], ",", 
            RowBox[{
             RowBox[{
              RowBox[{"-", 
               RowBox[{"Sqrt", "[", "3", "]"}]}], "/", "6"}], "+", 
             RowBox[{"f1", "*", 
              RowBox[{
               RowBox[{"Sqrt", "[", "3", "]"}], "/", "12"}]}]}]}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{
             RowBox[{"1", "/", "2"}], "+", 
             RowBox[{"f1", "/", "4"}]}], ",", 
            RowBox[{
             RowBox[{
              RowBox[{"-", 
               RowBox[{"Sqrt", "[", "3", "]"}]}], "/", "6"}], "+", 
             RowBox[{"f1", "*", 
              RowBox[{
               RowBox[{"Sqrt", "[", "3", "]"}], "/", "12"}]}]}]}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"f1", "/", "4"}], ",", 
            RowBox[{
             RowBox[{"-", "f1"}], "*", 
             RowBox[{
              RowBox[{"Sqrt", "[", "3", "]"}], "/", "12"}]}]}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"1", "-", 
             RowBox[{"f1", "/", "4"}]}], ",", 
            RowBox[{
             RowBox[{"-", "f1"}], "*", 
             RowBox[{
              RowBox[{"Sqrt", "[", "3", "]"}], "/", "12"}]}]}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{"0", ",", 
            RowBox[{"f1", "*", 
             RowBox[{
              RowBox[{"Sqrt", "[", "3", "]"}], "/", "6"}]}]}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{"1", ",", 
            RowBox[{"f1", "*", 
             RowBox[{
              RowBox[{"Sqrt", "[", "3", "]"}], "/", "6"}]}]}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{"0", ",", 
            RowBox[{
             RowBox[{
              RowBox[{"Sqrt", "[", "3", "]"}], "/", "3"}], "-", 
             RowBox[{"f1", "*", 
              RowBox[{
               RowBox[{"Sqrt", "[", "3", "]"}], "/", "6"}]}]}]}], "}"}], ",", 
          
          RowBox[{"{", 
           RowBox[{"1", ",", 
            RowBox[{
             RowBox[{
              RowBox[{"Sqrt", "[", "3", "]"}], "/", "3"}], "-", 
             RowBox[{"f1", "*", 
              RowBox[{
               RowBox[{"Sqrt", "[", "3", "]"}], "/", "6"}]}]}]}], "}"}], ",", 
          
          RowBox[{"{", 
           RowBox[{
            RowBox[{"f1", "/", "4"}], ",", 
            RowBox[{
             RowBox[{
              RowBox[{"Sqrt", "[", "3", "]"}], "/", "3"}], "+", 
             RowBox[{"f1", "*", 
              RowBox[{
               RowBox[{"Sqrt", "[", "3", "]"}], "/", "12"}]}]}]}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"1", "-", 
             RowBox[{"f1", "/", "4"}]}], ",", 
            RowBox[{
             RowBox[{
              RowBox[{"Sqrt", "[", "3", "]"}], "/", "3"}], "+", 
             RowBox[{"f1", "*", 
              RowBox[{
               RowBox[{"Sqrt", "[", "3", "]"}], "/", "12"}]}]}]}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"1", "+", 
             RowBox[{"f1", "/", "4"}]}], ",", 
            RowBox[{
             RowBox[{
              RowBox[{"Sqrt", "[", "3", "]"}], "/", "3"}], "+", 
             RowBox[{"f1", "*", 
              RowBox[{
               RowBox[{"Sqrt", "[", "3", "]"}], "/", "12"}]}]}]}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{
             RowBox[{"1", "/", "2"}], "-", 
             RowBox[{"f1", "/", "4"}]}], ",", 
            RowBox[{
             RowBox[{
              RowBox[{"Sqrt", "[", "3", "]"}], "/", "2"}], "-", 
             RowBox[{"f1", "*", 
              RowBox[{
               RowBox[{"Sqrt", "[", "3", "]"}], "/", "12"}]}]}]}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{
             RowBox[{"1", "/", "2"}], "+", 
             RowBox[{"f1", "/", "4"}]}], ",", 
            RowBox[{
             RowBox[{
              RowBox[{"Sqrt", "[", "3", "]"}], "/", "2"}], "-", 
             RowBox[{"f1", "*", 
              RowBox[{
               RowBox[{"Sqrt", "[", "3", "]"}], "/", "12"}]}]}]}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"1", "/", "2"}], ",", 
            RowBox[{
             RowBox[{
              RowBox[{"Sqrt", "[", "3", "]"}], "/", "2"}], "+", 
             RowBox[{"f1", "*", 
              RowBox[{
               RowBox[{"Sqrt", "[", "3", "]"}], "/", "6"}]}]}]}], "}"}]}], 
         "}"}], ",", 
        RowBox[{"Polygon", "[", 
         RowBox[{"{", 
          RowBox[{
           RowBox[{"{", 
            RowBox[{
            "1", ",", "2", ",", "4", ",", "6", ",", "8", ",", "10", ",", "13",
              ",", "12", ",", "9", ",", "7", ",", "5", ",", "3"}], "}"}], ",", 
           RowBox[{"{", 
            RowBox[{"8", ",", "11", ",", "10"}], "}"}], ",", 
           RowBox[{"{", 
            RowBox[{"12", ",", "13", ",", "14"}], "}"}]}], "}"}], "]"}]}], 
       "]"}]}], "}"}]}], "]"}]}]], "Input"],

Cell[BoxData[
 RowBox[{
  RowBox[{"tiling", "[", 
   RowBox[{"nrpt_", ",", "\"\<tri kite\>\""}], "]"}], " ", ":=", " ", 
  RowBox[{"repeat", "[", 
   RowBox[{"nrpt", ",", "\"\<hex\>\"", ",", 
    RowBox[{"{", 
     RowBox[{
      RowBox[{"EdgeForm", "[", "Thick", "]"}], ",", "bkgd", ",", 
      RowBox[{"GraphicsComplex", "[", 
       RowBox[{
        RowBox[{"{", 
         RowBox[{
          RowBox[{"{", 
           RowBox[{"0", ",", "0"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"1", "/", "2"}], ",", "0"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{"1", ",", "0"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"1", "/", "2"}], ",", 
            RowBox[{
             RowBox[{"Sqrt", "[", "3", "]"}], "/", "6"}]}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"1", "/", "4"}], ",", 
            RowBox[{
             RowBox[{"Sqrt", "[", "3", "]"}], "/", "4"}]}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"3", "/", "4"}], ",", 
            RowBox[{
             RowBox[{"Sqrt", "[", "3", "]"}], "/", "4"}]}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"5", "/", "4"}], ",", 
            RowBox[{
             RowBox[{"Sqrt", "[", "3", "]"}], "/", "4"}]}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{"1", ",", 
            RowBox[{
             RowBox[{"Sqrt", "[", "3", "]"}], "/", "3"}]}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"1", "/", "2"}], ",", 
            RowBox[{
             RowBox[{"Sqrt", "[", "3", "]"}], "/", "2"}]}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{"1", ",", 
            RowBox[{
             RowBox[{"Sqrt", "[", "3", "]"}], "/", "2"}]}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"3", "/", "2"}], ",", 
            RowBox[{
             RowBox[{"Sqrt", "[", "3", "]"}], "/", "2"}]}], "}"}]}], "}"}], 
        ",", 
        RowBox[{"Polygon", "[", 
         RowBox[{"{", 
          RowBox[{
           RowBox[{"{", 
            RowBox[{"1", ",", "2", ",", "4", ",", "5"}], "}"}], ",", 
           RowBox[{"{", 
            RowBox[{"2", ",", "3", ",", "6", ",", "4"}], "}"}], ",", 
           RowBox[{"{", 
            RowBox[{"4", ",", "6", ",", "9", ",", "5"}], "}"}], ",", 
           RowBox[{"{", 
            RowBox[{"3", ",", "7", ",", "8", ",", "6"}], "}"}], ",", 
           RowBox[{"{", 
            RowBox[{"6", ",", "8", ",", "10", ",", "9"}], "}"}], ",", 
           RowBox[{"{", 
            RowBox[{"7", ",", "11", ",", "10", ",", "8"}], "}"}]}], "}"}], 
         "]"}]}], "]"}]}], "}"}]}], "]"}]}]], "Input"],

Cell[BoxData[
 RowBox[{
  RowBox[{"tiling", "[", 
   RowBox[{"nrpt_", ",", "\"\<hex tri rect\>\"", ",", "f1_"}], "]"}], " ", ":=",
   " ", 
  RowBox[{"repeat", "[", 
   RowBox[{"nrpt", ",", "\"\<hex\>\"", ",", 
    RowBox[{"{", 
     RowBox[{
      RowBox[{"EdgeForm", "[", "Thick", "]"}], ",", "bkgd", ",", 
      RowBox[{"GraphicsComplex", "[", 
       RowBox[{
        RowBox[{"{", 
         RowBox[{
          RowBox[{"{", 
           RowBox[{
            RowBox[{"1", "/", "2"}], ",", 
            RowBox[{
             RowBox[{
              RowBox[{"-", 
               RowBox[{"Sqrt", "[", "3", "]"}]}], "/", "6"}], "+", 
             RowBox[{"f1", "*", 
              RowBox[{
               RowBox[{"Sqrt", "[", "3", "]"}], "/", "3"}]}]}]}], "}"}], ",", 
          
          RowBox[{"{", 
           RowBox[{
            RowBox[{"f1", "/", "2"}], ",", 
            RowBox[{"f1", "*", 
             RowBox[{
              RowBox[{"Sqrt", "[", "3", "]"}], "/", "6"}]}]}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"1", "-", 
             RowBox[{"f1", "/", "2"}]}], ",", 
            RowBox[{"f1", "*", 
             RowBox[{
              RowBox[{"Sqrt", "[", "3", "]"}], "/", "6"}]}]}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"1", "+", 
             RowBox[{"f1", "/", "2"}]}], ",", 
            RowBox[{"f1", "*", 
             RowBox[{
              RowBox[{"Sqrt", "[", "3", "]"}], "/", "6"}]}]}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"f1", "/", "2"}], ",", 
            RowBox[{
             RowBox[{
              RowBox[{"Sqrt", "[", "3", "]"}], "/", "3"}], "-", 
             RowBox[{"f1", "*", 
              RowBox[{
               RowBox[{"Sqrt", "[", "3", "]"}], "/", "6"}]}]}]}], "}"}], ",", 
          
          RowBox[{"{", 
           RowBox[{
            RowBox[{"1", "-", 
             RowBox[{"f1", "/", "2"}]}], ",", 
            RowBox[{
             RowBox[{
              RowBox[{"Sqrt", "[", "3", "]"}], "/", "3"}], "-", 
             RowBox[{"f1", "*", 
              RowBox[{
               RowBox[{"Sqrt", "[", "3", "]"}], "/", "6"}]}]}]}], "}"}], ",", 
          
          RowBox[{"{", 
           RowBox[{
            RowBox[{"1", "+", 
             RowBox[{"f1", "/", "2"}]}], ",", 
            RowBox[{
             RowBox[{
              RowBox[{"Sqrt", "[", "3", "]"}], "/", "3"}], "-", 
             RowBox[{"f1", "*", 
              RowBox[{
               RowBox[{"Sqrt", "[", "3", "]"}], "/", "6"}]}]}]}], "}"}], ",", 
          
          RowBox[{"{", 
           RowBox[{
            RowBox[{"1", "/", "2"}], ",", 
            RowBox[{
             RowBox[{
              RowBox[{"Sqrt", "[", "3", "]"}], "/", "2"}], "-", 
             RowBox[{"f1", "*", 
              RowBox[{
               RowBox[{"Sqrt", "[", "3", "]"}], "/", "3"}]}]}]}], "}"}], ",", 
          
          RowBox[{"{", 
           RowBox[{"0", ",", 
            RowBox[{
             RowBox[{
              RowBox[{"Sqrt", "[", "3", "]"}], "/", "3"}], "+", 
             RowBox[{"f1", "*", 
              RowBox[{
               RowBox[{"Sqrt", "[", "3", "]"}], "/", "3"}]}]}]}], "}"}], ",", 
          
          RowBox[{"{", 
           RowBox[{"1", ",", 
            RowBox[{
             RowBox[{
              RowBox[{"Sqrt", "[", "3", "]"}], "/", "3"}], "+", 
             RowBox[{"f1", "*", 
              RowBox[{
               RowBox[{"Sqrt", "[", "3", "]"}], "/", "3"}]}]}]}], "}"}], ",", 
          
          RowBox[{"{", 
           RowBox[{
            RowBox[{
             RowBox[{"1", "/", "2"}], "-", 
             RowBox[{"f1", "/", "2"}]}], ",", 
            RowBox[{
             RowBox[{
              RowBox[{"Sqrt", "[", "3", "]"}], "/", "2"}], "+", 
             RowBox[{"f1", "*", 
              RowBox[{
               RowBox[{"Sqrt", "[", "3", "]"}], "/", "6"}]}]}]}], "}"}], ",", 
          
          RowBox[{"{", 
           RowBox[{
            RowBox[{
             RowBox[{"1", "/", "2"}], "+", 
             RowBox[{"f1", "/", "2"}]}], ",", 
            RowBox[{
             RowBox[{
              RowBox[{"Sqrt", "[", "3", "]"}], "/", "2"}], "+", 
             RowBox[{"f1", "*", 
              RowBox[{
               RowBox[{"Sqrt", "[", "3", "]"}], "/", "6"}]}]}]}], "}"}]}], 
         "}"}], ",", 
        RowBox[{"Polygon", "[", 
         RowBox[{"{", 
          RowBox[{
           RowBox[{"{", 
            RowBox[{"1", ",", "3", ",", "6", ",", "8", ",", "5", ",", "2"}], 
            "}"}], ",", 
           RowBox[{"{", 
            RowBox[{"6", ",", "7", ",", "10"}], "}"}], ",", 
           RowBox[{"{", 
            RowBox[{"8", ",", "12", ",", "11"}], "}"}], ",", 
           RowBox[{"{", 
            RowBox[{"3", ",", "4", ",", "7", ",", "6"}], "}"}], ",", 
           RowBox[{"{", 
            RowBox[{"6", ",", "10", ",", "12", ",", "8"}], "}"}], ",", 
           RowBox[{"{", 
            RowBox[{"5", ",", "8", ",", "11", ",", "9"}], "}"}]}], "}"}], 
         "]"}]}], "]"}]}], "}"}]}], "]"}]}]], "Input"],

Cell[BoxData[
 RowBox[{
  RowBox[{"tiling", "[", 
   RowBox[{"nrpt_", ",", "\"\<hex pyr\>\""}], "]"}], " ", ":=", " ", 
  RowBox[{"repeat", "[", 
   RowBox[{"nrpt", ",", "\"\<hex\>\"", ",", 
    RowBox[{"{", 
     RowBox[{
      RowBox[{"EdgeForm", "[", "Thick", "]"}], ",", "bkgd", ",", 
      RowBox[{"GraphicsComplex", "[", 
       RowBox[{
        RowBox[{"{", 
         RowBox[{
          RowBox[{"{", 
           RowBox[{"0", ",", "0"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"1", "/", "3"}], ",", "0"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"1", "/", "2"}], ",", "0"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"2", "/", "3"}], ",", "0"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{"1", ",", "0"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"1", "/", "4"}], ",", 
            RowBox[{
             RowBox[{"Sqrt", "[", "3", "]"}], "/", "12"}]}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"3", "/", "4"}], ",", 
            RowBox[{
             RowBox[{"Sqrt", "[", "3", "]"}], "/", "12"}]}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"1", "/", "6"}], ",", 
            RowBox[{
             RowBox[{"Sqrt", "[", "3", "]"}], "/", "6"}]}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"1", "/", "2"}], ",", 
            RowBox[{
             RowBox[{"Sqrt", "[", "3", "]"}], "/", "6"}]}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"5", "/", "6"}], ",", 
            RowBox[{
             RowBox[{"Sqrt", "[", "3", "]"}], "/", "6"}]}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{"1", ",", 
            RowBox[{
             RowBox[{"Sqrt", "[", "3", "]"}], "/", "6"}]}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"7", "/", "6"}], ",", 
            RowBox[{
             RowBox[{"Sqrt", "[", "3", "]"}], "/", "6"}]}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"1", "/", "4"}], ",", 
            RowBox[{
             RowBox[{"Sqrt", "[", "3", "]"}], "/", "4"}]}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"3", "/", "4"}], ",", 
            RowBox[{
             RowBox[{"Sqrt", "[", "3", "]"}], "/", "4"}]}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"5", "/", "4"}], ",", 
            RowBox[{
             RowBox[{"Sqrt", "[", "3", "]"}], "/", "4"}]}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"1", "/", "3"}], ",", 
            RowBox[{
             RowBox[{"Sqrt", "[", "3", "]"}], "/", "3"}]}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"1", "/", "2"}], ",", 
            RowBox[{
             RowBox[{"Sqrt", "[", "3", "]"}], "/", "3"}]}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"2", "/", "3"}], ",", 
            RowBox[{
             RowBox[{"Sqrt", "[", "3", "]"}], "/", "3"}]}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{"1", ",", 
            RowBox[{
             RowBox[{"Sqrt", "[", "3", "]"}], "/", "3"}]}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"4", "/", "3"}], ",", 
            RowBox[{
             RowBox[{"Sqrt", "[", "3", "]"}], "/", "3"}]}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"3", "/", "4"}], ",", 
            RowBox[{"5", 
             RowBox[{
              RowBox[{"Sqrt", "[", "3", "]"}], "/", "12"}]}]}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"5", "/", "4"}], ",", 
            RowBox[{"5", 
             RowBox[{
              RowBox[{"Sqrt", "[", "3", "]"}], "/", "12"}]}]}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"1", "/", "2"}], ",", 
            RowBox[{
             RowBox[{"Sqrt", "[", "3", "]"}], "/", "2"}]}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"5", "/", "6"}], ",", 
            RowBox[{
             RowBox[{"Sqrt", "[", "3", "]"}], "/", "2"}]}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{"1", ",", 
            RowBox[{
             RowBox[{"Sqrt", "[", "3", "]"}], "/", "2"}]}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"7", "/", "6"}], ",", 
            RowBox[{
             RowBox[{"Sqrt", "[", "3", "]"}], "/", "2"}]}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"3", "/", "2"}], ",", 
            RowBox[{
             RowBox[{"Sqrt", "[", "3", "]"}], "/", "2"}]}], "}"}]}], "}"}], 
        ",", 
        RowBox[{"Polygon", "[", 
         RowBox[{"{", 
          RowBox[{
           RowBox[{"{", 
            RowBox[{"1", ",", "2", ",", "6"}], "}"}], ",", 
           RowBox[{"{", 
            RowBox[{"4", ",", "5", ",", "7"}], "}"}], ",", 
           RowBox[{"{", 
            RowBox[{"1", ",", "6", ",", "8"}], "}"}], ",", 
           RowBox[{"{", 
            RowBox[{"2", ",", "9", ",", "6"}], "}"}], ",", 
           RowBox[{"{", 
            RowBox[{"2", ",", "3", ",", "9"}], "}"}], ",", 
           RowBox[{"{", 
            RowBox[{"3", ",", "4", ",", "9"}], "}"}], ",", 
           RowBox[{"{", 
            RowBox[{"4", ",", "7", ",", "9"}], "}"}], ",", 
           RowBox[{"{", 
            RowBox[{"5", ",", "10", ",", "7"}], "}"}], ",", 
           RowBox[{"{", 
            RowBox[{"5", ",", "11", ",", "10"}], "}"}], ",", 
           RowBox[{"{", 
            RowBox[{"5", ",", "12", ",", "11"}], "}"}], ",", 
           RowBox[{"{", 
            RowBox[{"6", ",", "9", ",", "8"}], "}"}], ",", 
           RowBox[{"{", 
            RowBox[{"7", ",", "10", ",", "9"}], "}"}], ",", 
           RowBox[{"{", 
            RowBox[{"8", ",", "9", ",", "13"}], "}"}], ",", 
           RowBox[{"{", 
            RowBox[{"9", ",", "10", ",", "14"}], "}"}], ",", 
           RowBox[{"{", 
            RowBox[{"9", ",", "16", ",", "13"}], "}"}], ",", 
           RowBox[{"{", 
            RowBox[{"9", ",", "17", ",", "16"}], "}"}], ",", 
           RowBox[{"{", 
            RowBox[{"9", ",", "18", ",", "17"}], "}"}], ",", 
           RowBox[{"{", 
            RowBox[{"9", ",", "14", ",", "18"}], "}"}], ",", 
           RowBox[{"{", 
            RowBox[{"10", ",", "19", ",", "14"}], "}"}], ",", 
           RowBox[{"{", 
            RowBox[{"10", ",", "11", ",", "19"}], "}"}], ",", 
           RowBox[{"{", 
            RowBox[{"11", ",", "12", ",", "19"}], "}"}], ",", 
           RowBox[{"{", 
            RowBox[{"12", ",", "15", ",", "19"}], "}"}], ",", 
           RowBox[{"{", 
            RowBox[{"14", ",", "19", ",", "18"}], "}"}], ",", 
           RowBox[{"{", 
            RowBox[{"15", ",", "20", ",", "19"}], "}"}], ",", 
           RowBox[{"{", 
            RowBox[{"18", ",", "19", ",", "21"}], "}"}], ",", 
           RowBox[{"{", 
            RowBox[{"19", ",", "20", ",", "22"}], "}"}], ",", 
           RowBox[{"{", 
            RowBox[{"16", ",", "17", ",", "23"}], "}"}], ",", 
           RowBox[{"{", 
            RowBox[{"17", ",", "18", ",", "23"}], "}"}], ",", 
           RowBox[{"{", 
            RowBox[{"18", ",", "21", ",", "23"}], "}"}], ",", 
           RowBox[{"{", 
            RowBox[{"19", ",", "21", ",", "24"}], "}"}], ",", 
           RowBox[{"{", 
            RowBox[{"19", ",", "25", ",", "24"}], "}"}], ",", 
           RowBox[{"{", 
            RowBox[{"19", ",", "26", ",", "25"}], "}"}], ",", 
           RowBox[{"{", 
            RowBox[{"19", ",", "22", ",", "26"}], "}"}], ",", 
           RowBox[{"{", 
            RowBox[{"20", ",", "27", ",", "22"}], "}"}], ",", 
           RowBox[{"{", 
            RowBox[{"21", ",", "23", ",", "24"}], "}"}], ",", 
           RowBox[{"{", 
            RowBox[{"22", ",", "27", ",", "26"}], "}"}]}], "}"}], "]"}]}], 
       "]"}]}], "}"}]}], "]"}]}]], "Input"],

Cell[BoxData[
 RowBox[{
  RowBox[{"tiling", "[", 
   RowBox[{
   "nrpt_", ",", "\"\<hex tri rect trunc\>\"", ",", "f1_", ",", "f2_"}], 
   "]"}], " ", ":=", " ", 
  RowBox[{"repeat", "[", 
   RowBox[{"nrpt", ",", "\"\<hex\>\"", ",", 
    RowBox[{"{", 
     RowBox[{
      RowBox[{"EdgeForm", "[", "Thick", "]"}], ",", "bkgd", ",", 
      RowBox[{"GraphicsComplex", "[", 
       RowBox[{
        RowBox[{"{", 
         RowBox[{
          RowBox[{"{", 
           RowBox[{
            RowBox[{
             RowBox[{"f1", "/", "4"}], "+", 
             RowBox[{"f2", "/", "4"}]}], ",", 
            RowBox[{"f2", "*", 
             RowBox[{
              RowBox[{"Sqrt", "[", "3", "]"}], "/", "4"}]}]}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{
             RowBox[{"1", "/", "2"}], "-", 
             RowBox[{"f1", "/", "4"}], "-", 
             RowBox[{"f2", "/", "4"}]}], ",", 
            RowBox[{"f2", "*", 
             RowBox[{
              RowBox[{"Sqrt", "[", "3", "]"}], "/", "4"}]}]}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{
             RowBox[{
              RowBox[{"-", "f1"}], "/", "8"}], "+", 
             RowBox[{"f2", "/", "4"}]}], ",", 
            RowBox[{
             RowBox[{"f1", "*", 
              RowBox[{
               RowBox[{"Sqrt", "[", "3", "]"}], "/", "8"}]}], "+", 
             RowBox[{"f2", "*", 
              RowBox[{
               RowBox[{"Sqrt", "[", "3", "]"}], "/", "4"}]}]}]}], "}"}], ",", 
          
          RowBox[{"{", 
           RowBox[{
            RowBox[{
             RowBox[{"1", "/", "2"}], "+", 
             RowBox[{"f1", "/", "8"}], "-", 
             RowBox[{"f2", "/", "4"}]}], ",", 
            RowBox[{
             RowBox[{"f1", "*", 
              RowBox[{
               RowBox[{"Sqrt", "[", "3", "]"}], "/", "8"}]}], "+", 
             RowBox[{"f2", "*", 
              RowBox[{
               RowBox[{"Sqrt", "[", "3", "]"}], "/", "4"}]}]}]}], "}"}], ",", 
          
          RowBox[{"{", 
           RowBox[{
            RowBox[{
             RowBox[{
              RowBox[{"-", "1"}], "/", "4"}], "+", 
             RowBox[{"f1", "/", "8"}], "+", 
             RowBox[{"f2", "/", "2"}]}], ",", 
            RowBox[{
             RowBox[{
              RowBox[{"Sqrt", "[", "3", "]"}], "/", "4"}], "-", 
             RowBox[{"f1", "*", 
              RowBox[{
               RowBox[{"Sqrt", "[", "3", "]"}], "/", "8"}]}]}]}], "}"}], ",", 
          
          RowBox[{"{", 
           RowBox[{
            RowBox[{
             RowBox[{"3", "/", "4"}], "-", 
             RowBox[{"f1", "/", "8"}], "-", 
             RowBox[{"f2", "/", "2"}]}], ",", 
            RowBox[{
             RowBox[{
              RowBox[{"Sqrt", "[", "3", "]"}], "/", "4"}], "-", 
             RowBox[{"f1", "*", 
              RowBox[{
               RowBox[{"Sqrt", "[", "3", "]"}], "/", "8"}]}]}]}], "}"}], ",", 
          
          RowBox[{"{", 
           RowBox[{
            RowBox[{
             RowBox[{"3", "/", "4"}], "+", 
             RowBox[{"f1", "/", "8"}], "+", 
             RowBox[{"f2", "/", "2"}]}], ",", 
            RowBox[{
             RowBox[{
              RowBox[{"Sqrt", "[", "3", "]"}], "/", "4"}], "-", 
             RowBox[{"f1", "*", 
              RowBox[{
               RowBox[{"Sqrt", "[", "3", "]"}], "/", "8"}]}]}]}], "}"}], ",", 
          
          RowBox[{"{", 
           RowBox[{
            RowBox[{
             RowBox[{
              RowBox[{"-", "1"}], "/", "4"}], "+", 
             RowBox[{"f1", "/", "8"}], "+", 
             RowBox[{"f2", "/", "2"}]}], ",", 
            RowBox[{
             RowBox[{
              RowBox[{"Sqrt", "[", "3", "]"}], "/", "4"}], "+", 
             RowBox[{"f1", "*", 
              RowBox[{
               RowBox[{"Sqrt", "[", "3", "]"}], "/", "8"}]}]}]}], "}"}], ",", 
          
          RowBox[{"{", 
           RowBox[{
            RowBox[{
             RowBox[{"3", "/", "4"}], "-", 
             RowBox[{"f1", "/", "8"}], "-", 
             RowBox[{"f2", "/", "2"}]}], ",", 
            RowBox[{
             RowBox[{
              RowBox[{"Sqrt", "[", "3", "]"}], "/", "4"}], "+", 
             RowBox[{"f1", "*", 
              RowBox[{
               RowBox[{"Sqrt", "[", "3", "]"}], "/", "8"}]}]}]}], "}"}], ",", 
          
          RowBox[{"{", 
           RowBox[{
            RowBox[{
             RowBox[{"3", "/", "4"}], "+", 
             RowBox[{"f1", "/", "8"}], "+", 
             RowBox[{"f2", "/", "2"}]}], ",", 
            RowBox[{
             RowBox[{
              RowBox[{"Sqrt", "[", "3", "]"}], "/", "4"}], "+", 
             RowBox[{"f1", "*", 
              RowBox[{
               RowBox[{"Sqrt", "[", "3", "]"}], "/", "8"}]}]}]}], "}"}], ",", 
          
          RowBox[{"{", 
           RowBox[{
            RowBox[{
             RowBox[{
              RowBox[{"-", "f1"}], "/", "8"}], "+", 
             RowBox[{"f2", "/", "4"}]}], ",", 
            RowBox[{
             RowBox[{
              RowBox[{"Sqrt", "[", "3", "]"}], "/", "2"}], "-", 
             RowBox[{"f1", "*", 
              RowBox[{
               RowBox[{"Sqrt", "[", "3", "]"}], "/", "8"}]}], "-", 
             RowBox[{"f2", "*", 
              RowBox[{
               RowBox[{"Sqrt", "[", "3", "]"}], "/", "4"}]}]}]}], "}"}], ",", 
          
          RowBox[{"{", 
           RowBox[{
            RowBox[{
             RowBox[{"1", "/", "2"}], "+", 
             RowBox[{"f1", "/", "8"}], "-", 
             RowBox[{"f2", "/", "4"}]}], ",", 
            RowBox[{
             RowBox[{
              RowBox[{"Sqrt", "[", "3", "]"}], "/", "2"}], "-", 
             RowBox[{"f1", "*", 
              RowBox[{
               RowBox[{"Sqrt", "[", "3", "]"}], "/", "8"}]}], "-", 
             RowBox[{"f2", "*", 
              RowBox[{
               RowBox[{"Sqrt", "[", "3", "]"}], "/", "4"}]}]}]}], "}"}], ",", 
          
          RowBox[{"{", 
           RowBox[{
            RowBox[{"1", "-", 
             RowBox[{"f1", "/", "8"}], "+", 
             RowBox[{"f2", "/", "4"}]}], ",", 
            RowBox[{
             RowBox[{
              RowBox[{"Sqrt", "[", "3", "]"}], "/", "2"}], "-", 
             RowBox[{"f1", "*", 
              RowBox[{
               RowBox[{"Sqrt", "[", "3", "]"}], "/", "8"}]}], "-", 
             RowBox[{"f2", "*", 
              RowBox[{
               RowBox[{"Sqrt", "[", "3", "]"}], "/", "4"}]}]}]}], "}"}], ",", 
          
          RowBox[{"{", 
           RowBox[{
            RowBox[{
             RowBox[{"f1", "/", "4"}], "+", 
             RowBox[{"f2", "/", "4"}]}], ",", 
            RowBox[{
             RowBox[{
              RowBox[{"Sqrt", "[", "3", "]"}], "/", "2"}], "-", 
             RowBox[{"f2", "*", 
              RowBox[{
               RowBox[{"Sqrt", "[", "3", "]"}], "/", "4"}]}]}]}], "}"}], ",", 
          
          RowBox[{"{", 
           RowBox[{
            RowBox[{
             RowBox[{"1", "/", "2"}], "-", 
             RowBox[{"f1", "/", "4"}], "-", 
             RowBox[{"f2", "/", "4"}]}], ",", 
            RowBox[{
             RowBox[{
              RowBox[{"Sqrt", "[", "3", "]"}], "/", "2"}], "-", 
             RowBox[{"f2", "*", 
              RowBox[{
               RowBox[{"Sqrt", "[", "3", "]"}], "/", "4"}]}]}]}], "}"}], ",", 
          
          RowBox[{"{", 
           RowBox[{
            RowBox[{
             RowBox[{
              RowBox[{"-", "f1"}], "/", "4"}], "-", 
             RowBox[{"f2", "/", "4"}]}], ",", 
            RowBox[{
             RowBox[{
              RowBox[{"Sqrt", "[", "3", "]"}], "/", "2"}], "+", 
             RowBox[{"f2", "*", 
              RowBox[{
               RowBox[{"Sqrt", "[", "3", "]"}], "/", "4"}]}]}]}], "}"}], ",", 
          
          RowBox[{"{", 
           RowBox[{
            RowBox[{
             RowBox[{"1", "/", "2"}], "+", 
             RowBox[{"f1", "/", "4"}], "+", 
             RowBox[{"f2", "/", "4"}]}], ",", 
            RowBox[{
             RowBox[{
              RowBox[{"Sqrt", "[", "3", "]"}], "/", "2"}], "+", 
             RowBox[{"f2", "*", 
              RowBox[{
               RowBox[{"Sqrt", "[", "3", "]"}], "/", "4"}]}]}]}], "}"}], ",", 
          
          RowBox[{"{", 
           RowBox[{
            RowBox[{"1", "-", 
             RowBox[{"f1", "/", "4"}], "-", 
             RowBox[{"f2", "/", "4"}]}], ",", 
            RowBox[{
             RowBox[{
              RowBox[{"Sqrt", "[", "3", "]"}], "/", "2"}], "+", 
             RowBox[{"f2", "*", 
              RowBox[{
               RowBox[{"Sqrt", "[", "3", "]"}], "/", "4"}]}]}]}], "}"}], ",", 
          
          RowBox[{"{", 
           RowBox[{
            RowBox[{
             RowBox[{"f1", "/", "8"}], "-", 
             RowBox[{"f2", "/", "4"}]}], ",", 
            RowBox[{
             RowBox[{
              RowBox[{"Sqrt", "[", "3", "]"}], "/", "2"}], "+", 
             RowBox[{"f1", "*", 
              RowBox[{
               RowBox[{"Sqrt", "[", "3", "]"}], "/", "8"}]}], "+", 
             RowBox[{"f2", "*", 
              RowBox[{
               RowBox[{"Sqrt", "[", "3", "]"}], "/", "4"}]}]}]}], "}"}], ",", 
          
          RowBox[{"{", 
           RowBox[{
            RowBox[{
             RowBox[{"1", "/", "2"}], "-", 
             RowBox[{"f1", "/", "8"}], "+", 
             RowBox[{"f2", "/", "4"}]}], ",", 
            RowBox[{
             RowBox[{
              RowBox[{"Sqrt", "[", "3", "]"}], "/", "2"}], "+", 
             RowBox[{"f1", "*", 
              RowBox[{
               RowBox[{"Sqrt", "[", "3", "]"}], "/", "8"}]}], "+", 
             RowBox[{"f2", "*", 
              RowBox[{
               RowBox[{"Sqrt", "[", "3", "]"}], "/", "4"}]}]}]}], "}"}], ",", 
          
          RowBox[{"{", 
           RowBox[{
            RowBox[{
             RowBox[{"1", "/", "4"}], "-", 
             RowBox[{"f1", "/", "8"}], "-", 
             RowBox[{"f2", "/", "2"}]}], ",", 
            RowBox[{
             RowBox[{"3", 
              RowBox[{
               RowBox[{"Sqrt", "[", "3", "]"}], "/", "4"}]}], "-", 
             RowBox[{"f1", "*", 
              RowBox[{
               RowBox[{"Sqrt", "[", "3", "]"}], "/", "8"}]}]}]}], "}"}], ",", 
          
          RowBox[{"{", 
           RowBox[{
            RowBox[{
             RowBox[{"1", "/", "4"}], "+", 
             RowBox[{"f1", "/", "8"}], "+", 
             RowBox[{"f2", "/", "2"}]}], ",", 
            RowBox[{
             RowBox[{"3", 
              RowBox[{
               RowBox[{"Sqrt", "[", "3", "]"}], "/", "4"}]}], "-", 
             RowBox[{"f1", "*", 
              RowBox[{
               RowBox[{"Sqrt", "[", "3", "]"}], "/", "8"}]}]}]}], "}"}]}], 
         "}"}], ",", 
        RowBox[{"Polygon", "[", 
         RowBox[{"{", 
          RowBox[{
           RowBox[{"{", 
            RowBox[{
            "1", ",", "2", ",", "4", ",", "6", ",", "9", ",", "12", ",", "15",
              ",", "14", ",", "11", ",", "8", ",", "5", ",", "3"}], "}"}], 
           ",", 
           RowBox[{"{", 
            RowBox[{
            "9", ",", "10", ",", "13", ",", "18", ",", "17", ",", "12"}], 
            "}"}], ",", 
           RowBox[{"{", 
            RowBox[{
            "14", ",", "15", ",", "20", ",", "22", ",", "21", ",", "19"}], 
            "}"}], ",", 
           RowBox[{"{", 
            RowBox[{"6", ",", "7", ",", "10", ",", "9"}], "}"}], ",", 
           RowBox[{"{", 
            RowBox[{"11", ",", "14", ",", "19", ",", "16"}], "}"}], ",", 
           RowBox[{"{", 
            RowBox[{"12", ",", "17", ",", "20", ",", "15"}], "}"}]}], "}"}], 
         "]"}]}], "]"}]}], "}"}]}], "]"}]}]], "Input"],

Cell[BoxData[
 RowBox[{
  RowBox[{"tiling", "[", 
   RowBox[{"nrpt_", ",", "\"\<hex tri pntg\>\"", ",", "f1_", ",", "f2_"}], 
   "]"}], " ", ":=", " ", 
  RowBox[{"repeat", "[", 
   RowBox[{"nrpt", ",", "\"\<hex\>\"", ",", 
    RowBox[{"{", 
     RowBox[{
      RowBox[{"EdgeForm", "[", "Thick", "]"}], ",", "bkgd", ",", 
      RowBox[{"Table", "[", 
       RowBox[{
        RowBox[{"Rotate", "[", 
         RowBox[{
          RowBox[{"Polygon", "[", 
           RowBox[{"{", 
            RowBox[{
             RowBox[{"{", 
              RowBox[{"0", ",", "0"}], "}"}], ",", 
             RowBox[{"{", 
              RowBox[{
               RowBox[{
                RowBox[{"1", "/", "2"}], "-", "f1"}], ",", "f2"}], "}"}], ",", 
             RowBox[{"{", 
              RowBox[{
               RowBox[{"1", "/", "2"}], ",", 
               RowBox[{
                RowBox[{"Sqrt", "[", "3", "]"}], "/", "6"}]}], "}"}], ",", 
             RowBox[{"{", 
              RowBox[{
               RowBox[{
                RowBox[{"1", "/", "4"}], "+", 
                RowBox[{"f1", "/", "2"}], "+", 
                RowBox[{"f2", "*", 
                 RowBox[{
                  RowBox[{"Sqrt", "[", "3", "]"}], "/", "2"}]}]}], ",", 
               RowBox[{
                RowBox[{
                 RowBox[{"Sqrt", "[", "3", "]"}], "/", "4"}], "+", 
                RowBox[{"f1", "*", 
                 RowBox[{
                  RowBox[{"Sqrt", "[", "3", "]"}], "/", "2"}]}], "-", 
                RowBox[{"f2", "/", "2"}]}]}], "}"}], ",", 
             RowBox[{"{", 
              RowBox[{
               RowBox[{
                RowBox[{"1", "/", "4"}], "-", 
                RowBox[{"f1", "/", "2"}], "-", 
                RowBox[{"f2", "*", 
                 RowBox[{
                  RowBox[{"Sqrt", "[", "3", "]"}], "/", "2"}]}]}], ",", 
               RowBox[{
                RowBox[{
                 RowBox[{"Sqrt", "[", "3", "]"}], "/", "4"}], "-", 
                RowBox[{"f1", "*", 
                 RowBox[{
                  RowBox[{"Sqrt", "[", "3", "]"}], "/", "2"}]}], "+", 
                RowBox[{"f2", "/", "2"}]}]}], "}"}]}], "}"}], "]"}], ",", 
          RowBox[{"k", "*", 
           RowBox[{"Pi", "/", "3"}]}], ",", 
          RowBox[{"{", 
           RowBox[{"0", ",", "0"}], "}"}]}], "]"}], ",", 
        RowBox[{"{", 
         RowBox[{"k", ",", "0", ",", "5"}], "}"}]}], "]"}]}], "}"}]}], 
   "]"}]}]], "Input"],

Cell[BoxData[
 RowBox[{
  RowBox[{"tiling", "[", 
   RowBox[{"nrpt_", ",", "\"\<hex tri snub\>\"", ",", "f1_", ",", "f2_"}], 
   "]"}], " ", ":=", " ", 
  RowBox[{"repeat", "[", 
   RowBox[{"nrpt", ",", "\"\<hex\>\"", ",", 
    RowBox[{"{", 
     RowBox[{
      RowBox[{"EdgeForm", "[", "Thick", "]"}], ",", "bkgd", ",", 
      RowBox[{"GraphicsComplex", "[", 
       RowBox[{
        RowBox[{"{", 
         RowBox[{
          RowBox[{"{", 
           RowBox[{"f1", ",", "f2"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{
             RowBox[{"f1", "/", "2"}], "-", 
             RowBox[{"f2", "*", 
              RowBox[{
               RowBox[{"Sqrt", "[", "3", "]"}], "/", "2"}]}]}], ",", 
            RowBox[{
             RowBox[{"f1", "*", 
              RowBox[{
               RowBox[{"Sqrt", "[", "3", "]"}], "/", "2"}]}], "+", 
             RowBox[{"f2", "/", "2"}]}]}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{
             RowBox[{
              RowBox[{"-", "f1"}], "/", "2"}], "-", 
             RowBox[{"f2", "*", 
              RowBox[{
               RowBox[{"Sqrt", "[", "3", "]"}], "/", "2"}]}]}], ",", 
            RowBox[{
             RowBox[{"f1", "*", 
              RowBox[{
               RowBox[{"Sqrt", "[", "3", "]"}], "/", "2"}]}], "-", 
             RowBox[{"f2", "/", "2"}]}]}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"-", "f1"}], ",", 
            RowBox[{"-", "f2"}]}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{
             RowBox[{
              RowBox[{"-", "f1"}], "/", "2"}], "+", 
             RowBox[{"f2", "*", 
              RowBox[{
               RowBox[{"Sqrt", "[", "3", "]"}], "/", "2"}]}]}], ",", 
            RowBox[{
             RowBox[{
              RowBox[{"-", "f1"}], "*", 
              RowBox[{
               RowBox[{"Sqrt", "[", "3", "]"}], "/", "2"}]}], "-", 
             RowBox[{"f2", "/", "2"}]}]}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{
             RowBox[{"f1", "/", "2"}], "+", 
             RowBox[{"f2", "*", 
              RowBox[{
               RowBox[{"Sqrt", "[", "3", "]"}], "/", "2"}]}]}], ",", 
            RowBox[{
             RowBox[{
              RowBox[{"-", "f1"}], "*", 
              RowBox[{
               RowBox[{"Sqrt", "[", "3", "]"}], "/", "2"}]}], "+", 
             RowBox[{"f2", "/", "2"}]}]}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"1", "-", "f1"}], ",", 
            RowBox[{"-", "f2"}]}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"1", "-", 
             RowBox[{"f1", "/", "2"}], "-", 
             RowBox[{"f2", "*", 
              RowBox[{
               RowBox[{"Sqrt", "[", "3", "]"}], "/", "2"}]}]}], ",", 
            RowBox[{
             RowBox[{"f1", "*", 
              RowBox[{
               RowBox[{"Sqrt", "[", "3", "]"}], "/", "2"}]}], "-", 
             RowBox[{"f2", "/", "2"}]}]}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{
             RowBox[{"1", "/", "2"}], "-", 
             RowBox[{"f1", "/", "2"}], "+", 
             RowBox[{"f2", "*", 
              RowBox[{
               RowBox[{"Sqrt", "[", "3", "]"}], "/", "2"}]}]}], ",", 
            RowBox[{
             RowBox[{
              RowBox[{"Sqrt", "[", "3", "]"}], "/", "2"}], "-", 
             RowBox[{"f1", "*", 
              RowBox[{
               RowBox[{"Sqrt", "[", "3", "]"}], "/", "2"}]}], "-", 
             RowBox[{"f2", "/", "2"}]}]}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{
             RowBox[{"1", "/", "2"}], "-", "f1"}], ",", 
            RowBox[{
             RowBox[{
              RowBox[{"Sqrt", "[", "3", "]"}], "/", "2"}], "-", "f2"}]}], 
           "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{
             RowBox[{
              RowBox[{"-", "1"}], "/", "2"}], "+", 
             RowBox[{"f1", "/", "2"}], "+", 
             RowBox[{"f2", "*", 
              RowBox[{
               RowBox[{"Sqrt", "[", "3", "]"}], "/", "2"}]}]}], ",", 
            RowBox[{
             RowBox[{
              RowBox[{"Sqrt", "[", "3", "]"}], "/", "2"}], "-", 
             RowBox[{"f1", "*", 
              RowBox[{
               RowBox[{"Sqrt", "[", "3", "]"}], "/", "2"}]}], "+", 
             RowBox[{"f2", "/", "2"}]}]}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{
             RowBox[{
              RowBox[{"-", "1"}], "/", "2"}], "-", 
             RowBox[{"f1", "/", "2"}], "+", 
             RowBox[{"f2", "*", 
              RowBox[{
               RowBox[{"Sqrt", "[", "3", "]"}], "/", "2"}]}]}], ",", 
            RowBox[{
             RowBox[{
              RowBox[{"Sqrt", "[", "3", "]"}], "/", "2"}], "-", 
             RowBox[{"f1", "*", 
              RowBox[{
               RowBox[{"Sqrt", "[", "3", "]"}], "/", "2"}]}], "-", 
             RowBox[{"f2", "/", "2"}]}]}], "}"}]}], "}"}], ",", 
        RowBox[{"Polygon", "[", 
         RowBox[{"{", 
          RowBox[{
           RowBox[{"{", 
            RowBox[{"1", ",", "2", ",", "3", ",", "4", ",", "5", ",", "6"}], 
            "}"}], ",", 
           RowBox[{"{", 
            RowBox[{"1", ",", "8", ",", "9"}], "}"}], ",", 
           RowBox[{"{", 
            RowBox[{"2", ",", "10", ",", "11"}], "}"}], ",", 
           RowBox[{"{", 
            RowBox[{"6", ",", "7", ",", "8"}], "}"}], ",", 
           RowBox[{"{", 
            RowBox[{"6", ",", "8", ",", "1"}], "}"}], ",", 
           RowBox[{"{", 
            RowBox[{"1", ",", "9", ",", "10"}], "}"}], ",", 
           RowBox[{"{", 
            RowBox[{"1", ",", "10", ",", "2"}], "}"}], ",", 
           RowBox[{"{", 
            RowBox[{"2", ",", "11", ",", "12"}], "}"}], ",", 
           RowBox[{"{", 
            RowBox[{"2", ",", "12", ",", "3"}], "}"}]}], "}"}], "]"}]}], 
       "]"}]}], "}"}]}], "]"}]}]], "Input"],

Cell[BoxData[
 RowBox[{"show2d", "[", 
  RowBox[{"tiling", "[", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{"3", ",", "3"}], "}"}], ",", "\"\<hex tri snub\>\"", ",", 
    RowBox[{"1", "/", "4"}], ",", 
    RowBox[{"1", "/", "4"}]}], "]"}], "]"}]], "Input"]
}, Closed]],

Cell[CellGroupData[{

Cell["Displays", "Section"],

Cell[BoxData[
 RowBox[{
  RowBox[{"stdclip", "[", 
   RowBox[{"org_", ",", "rng_"}], "]"}], " ", ":=", " ", 
  RowBox[{"Transpose", "[", 
   RowBox[{"{", 
    RowBox[{"org", ",", 
     RowBox[{"org", "+", "rng"}]}], "}"}], "]"}]}]], "Input"],

Cell[BoxData[
 RowBox[{"Grid", "[", 
  RowBox[{"{", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{"\"\<sqr\>\"", ",", 
      RowBox[{"show2dclip", "[", 
       RowBox[{
        RowBox[{"tiling", "[", 
         RowBox[{
          RowBox[{"{", 
           RowBox[{"8", ",", "8"}], "}"}], ",", "\"\<sqr\>\""}], "]"}], ",", 
        RowBox[{"stdclip", "[", 
         RowBox[{
          RowBox[{"{", 
           RowBox[{
            RowBox[{"1", "/", "2"}], ",", 
            RowBox[{"1", "/", "2"}]}], "}"}], ",", "6"}], "]"}]}], "]"}], 
      ",", "\"\<sqr pyr\>\"", ",", 
      RowBox[{"show2dclip", "[", 
       RowBox[{
        RowBox[{"tiling", "[", 
         RowBox[{
          RowBox[{"{", 
           RowBox[{"8", ",", "8"}], "}"}], ",", "\"\<sqr pyr\>\""}], "]"}], 
        ",", 
        RowBox[{"stdclip", "[", 
         RowBox[{
          RowBox[{"{", 
           RowBox[{
            RowBox[{"1", "/", "4"}], ",", 
            RowBox[{"1", "/", "4"}]}], "}"}], ",", "6"}], "]"}]}], "]"}]}], 
     "}"}], ",", 
    RowBox[{"{", 
     RowBox[{"\"\<sqr trunc\>\"", ",", 
      RowBox[{"show2dclip", "[", 
       RowBox[{
        RowBox[{"tiling", "[", 
         RowBox[{
          RowBox[{"{", 
           RowBox[{"8", ",", "8"}], "}"}], ",", "\"\<sqr trunc\>\"", ",", 
          RowBox[{"1", "/", "2"}]}], "]"}], ",", 
        RowBox[{"stdclip", "[", 
         RowBox[{
          RowBox[{"{", 
           RowBox[{
            RowBox[{"1", "/", "2"}], ",", 
            RowBox[{"1", "/", "2"}]}], "}"}], ",", "6"}], "]"}]}], "]"}], 
      ",", "\"\<sqr pntg\>\"", ",", 
      RowBox[{"show2dclip", "[", 
       RowBox[{
        RowBox[{"tiling", "[", 
         RowBox[{
          RowBox[{"{", 
           RowBox[{"4", ",", "4"}], "}"}], ",", "\"\<sqr pntg\>\"", ",", 
          RowBox[{"1", "/", "3"}]}], "]"}], ",", 
        RowBox[{"stdclip", "[", 
         RowBox[{
          RowBox[{"{", 
           RowBox[{
            RowBox[{"1", "/", "2"}], ",", 
            RowBox[{"1", "/", "2"}]}], "}"}], ",", "3"}], "]"}]}], "]"}]}], 
     "}"}], ",", 
    RowBox[{"{", 
     RowBox[{"\"\<sqr snub\>\"", ",", 
      RowBox[{"show2dclip", "[", 
       RowBox[{
        RowBox[{"tiling", "[", 
         RowBox[{
          RowBox[{"{", 
           RowBox[{"4", ",", "4"}], "}"}], ",", "\"\<sqr snub\>\"", ",", 
          RowBox[{"1", "/", "3"}]}], "]"}], ",", 
        RowBox[{"stdclip", "[", 
         RowBox[{
          RowBox[{"{", 
           RowBox[{
            RowBox[{"1", "/", "2"}], ",", 
            RowBox[{"1", "/", "2"}]}], "}"}], ",", "3"}], "]"}]}], "]"}]}], 
     "}"}]}], "}"}], "]"}]], "Input"],

Cell[BoxData[
 RowBox[{"Grid", "[", 
  RowBox[{"{", 
   RowBox[{"{", 
    RowBox[{"\"\<rect pntg\>\"", ",", 
     RowBox[{"show2dclip", "[", 
      RowBox[{
       RowBox[{"tiling", "[", 
        RowBox[{
         RowBox[{"{", 
          RowBox[{"7", ",", "8"}], "}"}], ",", "\"\<rect pntg\>\"", ",", 
         RowBox[{"1", "/", "3"}]}], "]"}], ",", 
       RowBox[{"stdclip", "[", 
        RowBox[{
         RowBox[{"{", 
          RowBox[{
           RowBox[{"1", "/", "2"}], ",", 
           RowBox[{"1", "/", "2"}]}], "}"}], ",", "6"}], "]"}]}], "]"}], ",", 
     "\"\<rect snub\>\"", ",", 
     RowBox[{"show2dclip", "[", 
      RowBox[{
       RowBox[{"tiling", "[", 
        RowBox[{
         RowBox[{"{", 
          RowBox[{"5", ",", "4"}], "}"}], ",", "\"\<rect snub\>\"", ",", 
         RowBox[{"1", "/", "3"}]}], "]"}], ",", 
       RowBox[{"stdclip", "[", 
        RowBox[{
         RowBox[{"{", 
          RowBox[{
           RowBox[{"4", "/", "3"}], ",", 
           RowBox[{"1", "/", "3"}]}], "}"}], ",", "3"}], "]"}]}], "]"}]}], 
    "}"}], "}"}], "]"}]], "Input"],

Cell[BoxData[
 RowBox[{"Grid", "[", 
  RowBox[{"{", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{"\"\<tri\>\"", ",", 
      RowBox[{"show2dclip", "[", 
       RowBox[{
        RowBox[{"tiling", "[", 
         RowBox[{
          RowBox[{"{", 
           RowBox[{"12", ",", "8"}], "}"}], ",", "\"\<tri\>\""}], "]"}], ",", 
        
        RowBox[{"stdclip", "[", 
         RowBox[{
          RowBox[{"{", 
           RowBox[{
            RowBox[{"4", "+", 
             RowBox[{"1", "/", "2"}]}], ",", 
            RowBox[{"1", "/", "2"}]}], "}"}], ",", "6"}], "]"}]}], "]"}], 
      ",", "\"\<hex\>\"", ",", 
      RowBox[{"show2dclip", "[", 
       RowBox[{
        RowBox[{"tiling", "[", 
         RowBox[{
          RowBox[{"{", 
           RowBox[{"12", ",", "8"}], "}"}], ",", "\"\<hex\>\""}], "]"}], ",", 
        
        RowBox[{"stdclip", "[", 
         RowBox[{
          RowBox[{"{", 
           RowBox[{
            RowBox[{"4", "+", 
             RowBox[{"1", "/", "2"}]}], ",", 
            RowBox[{"1", "/", "2"}]}], "}"}], ",", "6"}], "]"}]}], "]"}]}], 
     "}"}], ",", 
    RowBox[{"{", 
     RowBox[{"\"\<tri trunc\>\"", ",", 
      RowBox[{"show2dclip", "[", 
       RowBox[{
        RowBox[{"tiling", "[", 
         RowBox[{
          RowBox[{"{", 
           RowBox[{"12", ",", "8"}], "}"}], ",", "\"\<tri trunc\>\"", ",", 
          RowBox[{"1", "/", "3"}]}], "]"}], ",", 
        RowBox[{"stdclip", "[", 
         RowBox[{
          RowBox[{"{", 
           RowBox[{
            RowBox[{"4", "+", 
             RowBox[{"1", "/", "2"}]}], ",", 
            RowBox[{"1", "/", "2"}]}], "}"}], ",", "6"}], "]"}]}], "]"}], 
      ",", "\"\<tri rhomb\>\"", ",", 
      RowBox[{"show2dclip", "[", 
       RowBox[{
        RowBox[{"tiling", "[", 
         RowBox[{
          RowBox[{"{", 
           RowBox[{"12", ",", "8"}], "}"}], ",", "\"\<tri rhomb\>\""}], "]"}],
         ",", 
        RowBox[{"stdclip", "[", 
         RowBox[{
          RowBox[{"{", 
           RowBox[{
            RowBox[{"4", "+", 
             RowBox[{"1", "/", "2"}]}], ",", 
            RowBox[{"1", "/", "2"}]}], "}"}], ",", "6"}], "]"}]}], "]"}]}], 
     "}"}], ",", 
    RowBox[{"{", 
     RowBox[{"\"\<hex tri\>\"", ",", 
      RowBox[{"show2dclip", "[", 
       RowBox[{
        RowBox[{"tiling", "[", 
         RowBox[{
          RowBox[{"{", 
           RowBox[{"12", ",", "8"}], "}"}], ",", "\"\<hex tri\>\""}], "]"}], 
        ",", 
        RowBox[{"stdclip", "[", 
         RowBox[{
          RowBox[{"{", 
           RowBox[{
            RowBox[{"4", "+", 
             RowBox[{"1", "/", "2"}]}], ",", 
            RowBox[{"1", "/", "2"}]}], "}"}], ",", "6"}], "]"}]}], "]"}], 
      ",", "\"\<tri pyr\>\"", ",", 
      RowBox[{"show2dclip", "[", 
       RowBox[{
        RowBox[{"tiling", "[", 
         RowBox[{
          RowBox[{"{", 
           RowBox[{"12", ",", "8"}], "}"}], ",", "\"\<tri pyr\>\""}], "]"}], 
        ",", 
        RowBox[{"stdclip", "[", 
         RowBox[{
          RowBox[{"{", 
           RowBox[{
            RowBox[{"4", "+", 
             RowBox[{"1", "/", "2"}]}], ",", 
            RowBox[{"1", "/", "2"}]}], "}"}], ",", "6"}], "]"}]}], "]"}]}], 
     "}"}], ",", 
    RowBox[{"{", 
     RowBox[{"\"\<hex trunc\>\"", ",", 
      RowBox[{"show2dclip", "[", 
       RowBox[{
        RowBox[{"tiling", "[", 
         RowBox[{
          RowBox[{"{", 
           RowBox[{"12", ",", "8"}], "}"}], ",", "\"\<hex trunc\>\"", ",", 
          RowBox[{"2", "/", "3"}]}], "]"}], ",", 
        RowBox[{"stdclip", "[", 
         RowBox[{
          RowBox[{"{", 
           RowBox[{
            RowBox[{"4", "+", 
             RowBox[{"1", "/", "2"}]}], ",", 
            RowBox[{"1", "/", "2"}]}], "}"}], ",", "6"}], "]"}]}], "]"}], 
      ",", "\"\<tri kite\>\"", ",", 
      RowBox[{"show2dclip", "[", 
       RowBox[{
        RowBox[{"tiling", "[", 
         RowBox[{
          RowBox[{"{", 
           RowBox[{"12", ",", "8"}], "}"}], ",", "\"\<tri kite\>\""}], "]"}], 
        ",", 
        RowBox[{"stdclip", "[", 
         RowBox[{
          RowBox[{"{", 
           RowBox[{
            RowBox[{"4", "+", 
             RowBox[{"1", "/", "2"}]}], ",", 
            RowBox[{"1", "/", "2"}]}], "}"}], ",", "6"}], "]"}]}], "]"}]}], 
     "}"}], ",", 
    RowBox[{"{", 
     RowBox[{"\"\<hex tri rect\>\"", ",", 
      RowBox[{"show2dclip", "[", 
       RowBox[{
        RowBox[{"tiling", "[", 
         RowBox[{
          RowBox[{"{", 
           RowBox[{"12", ",", "8"}], "}"}], ",", "\"\<hex tri rect\>\"", ",", 
          
          RowBox[{"1", "/", "3"}]}], "]"}], ",", 
        RowBox[{"stdclip", "[", 
         RowBox[{
          RowBox[{"{", 
           RowBox[{
            RowBox[{"4", "+", 
             RowBox[{"1", "/", "2"}]}], ",", 
            RowBox[{"1", "/", "2"}]}], "}"}], ",", "6"}], "]"}]}], "]"}]}], 
     "}"}], ",", 
    RowBox[{"{", 
     RowBox[{"\"\<hex pyr\>\"", ",", 
      RowBox[{"show2dclip", "[", 
       RowBox[{
        RowBox[{"tiling", "[", 
         RowBox[{
          RowBox[{"{", 
           RowBox[{"6", ",", "4"}], "}"}], ",", "\"\<hex pyr\>\""}], "]"}], 
        ",", 
        RowBox[{"stdclip", "[", 
         RowBox[{
          RowBox[{"{", 
           RowBox[{
            RowBox[{"2", "+", 
             RowBox[{"1", "/", "4"}]}], ",", 
            RowBox[{"1", "/", "4"}]}], "}"}], ",", "3"}], "]"}]}], "]"}], 
      ",", "\"\<hex tri\\nrect trunc\>\"", ",", 
      RowBox[{"show2dclip", "[", 
       RowBox[{
        RowBox[{"tiling", "[", 
         RowBox[{
          RowBox[{"{", 
           RowBox[{"6", ",", "4"}], "}"}], ",", "\"\<hex tri rect trunc\>\"", 
          ",", 
          RowBox[{"1", "/", "3"}], ",", 
          RowBox[{"1", "/", "3"}]}], "]"}], ",", 
        RowBox[{"stdclip", "[", 
         RowBox[{
          RowBox[{"{", 
           RowBox[{
            RowBox[{"2", "+", 
             RowBox[{"1", "/", "4"}]}], ",", 
            RowBox[{"1", "/", "4"}]}], "}"}], ",", "3"}], "]"}]}], "]"}]}], 
     "}"}], ",", 
    RowBox[{"{", 
     RowBox[{"\"\<hex tri pntg\>\"", ",", 
      RowBox[{"show2dclip", "[", 
       RowBox[{
        RowBox[{"tiling", "[", 
         RowBox[{
          RowBox[{"{", 
           RowBox[{"6", ",", "6"}], "}"}], ",", "\"\<hex tri pntg\>\"", ",", 
          RowBox[{"1", "/", "6"}], ",", 
          RowBox[{"1", "/", "8"}]}], "]"}], ",", 
        RowBox[{"stdclip", "[", 
         RowBox[{
          RowBox[{"{", 
           RowBox[{
            RowBox[{"2", "+", 
             RowBox[{"1", "/", "4"}]}], ",", 
            RowBox[{"1", "/", "4"}]}], "}"}], ",", "3"}], "]"}]}], "]"}], 
      ",", "\"\<hex tri snub\>\"", ",", 
      RowBox[{"show2dclip", "[", 
       RowBox[{
        RowBox[{"tiling", "[", 
         RowBox[{
          RowBox[{"{", 
           RowBox[{"6", ",", "6"}], "}"}], ",", "\"\<hex tri snub\>\"", ",", 
          RowBox[{"1", "/", "4"}], ",", 
          RowBox[{"1", "/", "4"}]}], "]"}], ",", 
        RowBox[{"stdclip", "[", 
         RowBox[{
          RowBox[{"{", 
           RowBox[{
            RowBox[{"2", "+", 
             RowBox[{"1", "/", "4"}]}], ",", 
            RowBox[{"1", "/", "4"}]}], "}"}], ",", "3"}], "]"}]}], "]"}]}], 
     "}"}]}], "}"}], "]"}]], "Input"]
}, Closed]]
},
WindowSize->{640, 696},
WindowMargins->{{Automatic, 0}, {Automatic, 11}},
FrontEndVersion->"11.0 for Mac OS X x86 (32-bit, 64-bit Kernel) (September \
21, 2016)",
StyleDefinitions->"Default.nb"
]
(* End of Notebook Content *)

(* Internal cache information *)
(*CellTagsOutline
CellTagsIndex->{}
*)
(*CellTagsIndex
CellTagsIndex->{}
*)
(*NotebookFileOutline
Notebook[{
Cell[545, 20, 1486, 33, 600, "Text"],
Cell[CellGroupData[{
Cell[2056, 57, 27, 0, 64, "Section"],
Cell[2086, 59, 129, 3, 32, "Input"],
Cell[2218, 64, 285, 7, 54, "Input"],
Cell[2506, 73, 667, 21, 75, "Input"],
Cell[3176, 96, 260, 6, 32, "Input"],
Cell[3439, 104, 476, 15, 54, "Input"],
Cell[3918, 121, 163, 5, 32, "Input"],
Cell[4084, 128, 887, 25, 117, "Input"],
Cell[4974, 155, 2062, 56, 159, "Input"],
Cell[7039, 213, 2082, 59, 159, "Input"],
Cell[9124, 274, 3653, 98, 243, "Input"],
Cell[12780, 374, 3985, 109, 243, "Input"],
Cell[16768, 485, 1881, 53, 159, "Input"],
Cell[18652, 540, 1940, 53, 180, "Input"],
Cell[20595, 595, 1207, 35, 117, "Input"],
Cell[21805, 632, 1459, 41, 138, "Input"],
Cell[23267, 675, 4704, 134, 327, "Input"],
Cell[27974, 811, 1837, 51, 159, "Input"],
Cell[29814, 864, 1955, 55, 159, "Input"],
Cell[31772, 921, 1880, 52, 159, "Input"],
Cell[33655, 975, 5501, 153, 348, "Input"],
Cell[39159, 1130, 2743, 74, 201, "Input"],
Cell[41905, 1206, 5099, 145, 306, "Input"],
Cell[47007, 1353, 8075, 211, 453, "Input"],
Cell[55085, 1566, 11709, 331, 600, "Input"],
Cell[66797, 1899, 2440, 64, 222, "Input"],
Cell[69240, 1965, 6057, 165, 390, "Input"],
Cell[75300, 2132, 256, 7, 32, "Input"]
}, Closed]],
Cell[CellGroupData[{
Cell[75593, 2144, 27, 0, 50, "Section"],
Cell[75623, 2146, 241, 7, 32, "Input"],
Cell[75867, 2155, 2611, 78, 222, "Input"],
Cell[78481, 2235, 1080, 32, 117, "Input"],
Cell[79564, 2269, 7236, 217, 579, "Input"]
}, Closed]]
}
]
*)

