(* Content-type: application/mathematica *)

(*** Wolfram Notebook File ***)
(* http://www.wolfram.com/nb *)

(* CreatedBy='Mathematica 7.0' *)

(*CacheID: 234*)
(* Internal cache information:
NotebookFileLineBreakTest
NotebookFileLineBreakTest
NotebookDataPosition[       145,          7]
NotebookDataLength[    308938,       8509]
NotebookOptionsPosition[    275557,       8096]
NotebookOutlinePosition[    275932,       8113]
CellTagsIndexPosition[    275889,       8110]
WindowFrame->Normal*)

(* Beginning of Notebook Content *)
Notebook[{

Cell[CellGroupData[{
Cell["Introduction", "Section",ExpressionUUID->"00e7d1ff-3c24-45c5-8056-6d9002a478f2"],

Cell["\<\
This is about isohedral dice and their duals, isogonal polyhedra.

http://www.fantasylibrary.com/lounge/diceprop.htm
http://en.wikipedia.org/wiki/Dice
http://www.maa.org/editorial/mathgames/mathgames_ 05 _ 16 _ 05. html
http://www.mathpuzzle.com/Fairdice.htm
http://hometown.aol.com/dicetalk/polyh.htm
http://en.wikipedia.org/wiki/Isohedral_figure - face-transitive
http://en.wikipedia.org/wiki/Isotoxal_figure - edge-transitive
http://en.wikipedia.org/wiki/Isogonal_figure - vertex-transitive
http://en.wikipedia.org/wiki/Catalan_solid
http://en.wikipedia.org/wiki/Archimedean_solid

Axial shapes:

http://en.wikipedia.org/wiki/Bipyramid - Bipyramid - Dipyramid - Triangular \
Dihedron
n-fold, no alternation: D(n,h)
2n-fold, radial alternation: D(n,h)
2n-fold, axial alternation: D(n,d)

http://en.wikipedia.org/wiki/Trapezohedron - Trapezohedron - Antidipyramid - \
Deltohedron - Trapezoidal Dihedron
n-fold, symmetric faces: D(n,d)
n-fold, general: D(n)

http://en.wikipedia.org/wiki/Prism_(geometry) - Prism
n-fold, rectangular faces: D(n,h)
2n-fold, alternating-taper faces: D(n,d)

http://en.wikipedia.org/wiki/Antiprism - Antiprism
n-fold, symmetric faces: D(n,h)
n-fold, general: D(n)

Duality:
Bipyramid - Prism
Trapezohedron - Antiprism

Quasi-spherical shapes -- duality:

Regular:
Index - Triangle-face - Dual (n-face)
3 - Tetrahedron - Tetrahedron
4 - Octahedron - Cube
5 - Icosahedron - Dodecahedron

triangle-face pyramid - truncated dual-face
dual-face pyramid - truncated triangle-face
both pyramid - truncated max
rhombus-face - truncated both
kite-face - truncated edge
pentagon-face - snub

Regular polygons made semiregular:
Tetrahedron: disphenoid
Octahedron: 4-bipyramid, 3-antiprism
Cube: 3-trapezohedron, 4-prism  (vertices all alike: rectangular cuboid)
Icosahedron: stretched/squeezed along one axis (not implemented here)
Dodecahedron: pentagon-face tetrahedron\
\>", "Text",ExpressionUUID->"92838113-268b-4ab7-ab49-5547153c9fcd"]
}, Open  ]],

Cell[CellGroupData[{

Cell["Formulas", "Section",ExpressionUUID->"7547bb61-bce4-46d9-9087-4f11a780bee6"],

Cell[CellGroupData[{

Cell["Shared", "Subsection",ExpressionUUID->"7555a5d6-6128-4aee-961c-b0eee04b2666"],

Cell[BoxData[
 RowBox[{"(*", " ", 
  RowBox[{
   RowBox[{
    RowBox[{"Don", "'"}], "t", " ", "resize", " ", "the", " ", "bounding", 
    " ", "box", " ", "when", " ", "rotating", " ", 
    RowBox[{"it", ".", " ", "Also"}]}], ",", " ", 
   RowBox[{
   "render", " ", "only", " ", "the", " ", "front", " ", "sides", " ", "of", 
    " ", "the", " ", 
    RowBox[{"polygons", "."}]}]}], " ", "*)"}]], "Input",
 CellLabel->
  "In[328]:=",ExpressionUUID->"7f9fe089-54a9-46df-8fcc-331ba0fe4773"],

Cell[BoxData[
 RowBox[{
  RowBox[{"show3d", "[", "x_", "]"}], " ", ":=", " ", 
  RowBox[{"Graphics3D", "[", 
   RowBox[{"x", ",", 
    RowBox[{"SphericalRegion", "\[Rule]", "True"}]}], "]"}]}]], "Input",
 CellLabel->
  "In[329]:=",ExpressionUUID->"4de6522c-5cd0-482e-9c79-440a76759eb5"],

Cell[BoxData[
 RowBox[{
  RowBox[{"show3dfront", "[", "x_", "]"}], " ", ":=", " ", 
  RowBox[{"show3d", "[", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"FaceForm", "[", 
      RowBox[{
       RowBox[{"{", "}"}], ",", "None"}], "]"}], ",", "x"}], "}"}], 
   "]"}]}]], "Input",
 CellLabel->
  "In[330]:=",ExpressionUUID->"f036ede8-d8a8-4bd3-bb69-6216146e2aad"],

Cell[BoxData[
 RowBox[{"(*", " ", 
  RowBox[{
  "Normal", " ", "direction", " ", "from", " ", "three", " ", "vectors", " ", 
   "in", " ", "an", " ", "array"}], " ", "*)"}]], "Input",
 CellLabel->
  "In[331]:=",ExpressionUUID->"e7771895-f02f-49fc-a50a-ce42be2fe959"],

Cell[BoxData[
 RowBox[{
  RowBox[{"normdir", "[", "x_", "]"}], " ", ":=", " ", 
  RowBox[{
   RowBox[{"Cross", "[", 
    RowBox[{
     RowBox[{
      RowBox[{"x", "[", 
       RowBox[{"[", "1", "]"}], "]"}], "-", 
      RowBox[{"x", "[", 
       RowBox[{"[", "2", "]"}], "]"}]}], ",", 
     RowBox[{
      RowBox[{"x", "[", 
       RowBox[{"[", "1", "]"}], "]"}], "-", 
      RowBox[{"x", "[", 
       RowBox[{"[", "3", "]"}], "]"}]}]}], "]"}], " ", "//", " ", 
   "Factor"}]}]], "Input",
 CellLabel->
  "In[332]:=",ExpressionUUID->"5459a704-5800-41da-a0fb-f47821e8af3f"],

Cell[BoxData[
 RowBox[{
  RowBox[{"planarity", "[", "x_", "]"}], " ", ":=", " ", 
  RowBox[{
   RowBox[{
    RowBox[{"Table", "[", 
     RowBox[{
      RowBox[{"Factor", "[", 
       RowBox[{"#", ".", 
        RowBox[{"(", 
         RowBox[{
          RowBox[{"x", "[", 
           RowBox[{"[", "k", "]"}], "]"}], "-", 
          RowBox[{"x", "[", 
           RowBox[{"[", "1", "]"}], "]"}]}], ")"}]}], "]"}], ",", 
      RowBox[{"{", 
       RowBox[{"k", ",", "4", ",", 
        RowBox[{"Length", "[", "x", "]"}]}], "}"}]}], "]"}], "&"}], " ", "@", 
   " ", 
   RowBox[{"normdir", "[", "x", "]"}]}]}]], "Input",
 CellLabel->
  "In[333]:=",ExpressionUUID->"64e1ca5f-8cc1-48a8-a8f5-37d5ac280194"],

Cell[BoxData[
 RowBox[{"(*", " ", 
  RowBox[{"Absolute", " ", "square", " ", "of", " ", "length"}], " ", 
  "*)"}]], "Input",
 CellLabel->
  "In[334]:=",ExpressionUUID->"57eb56a2-cce4-482c-8a08-baa44e99ea70"],

Cell[BoxData[
 RowBox[{
  RowBox[{"abssqr", "[", "x_", "]"}], " ", ":=", " ", 
  RowBox[{"Total", "[", 
   RowBox[{"x", "^", "2"}], "]"}]}]], "Input",
 CellLabel->
  "In[335]:=",ExpressionUUID->"9f0669e9-3a87-42f1-a921-ddce27c82334"],

Cell[BoxData[
 RowBox[{"(*", " ", 
  RowBox[{"Polygon", "-", 
   RowBox[{"side", " ", "lengths", " ", "squared"}]}], " ", "*)"}]], "Input",
 CellLabel->
  "In[336]:=",ExpressionUUID->"7aadd915-c91e-46d8-b062-2d7a35919dba"],

Cell[BoxData[
 RowBox[{
  RowBox[{"polysidelensqs", "[", "x_", "]"}], " ", ":=", " ", 
  RowBox[{"Module", "[", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{"i", ",", "j", ",", "n", ",", "xi", ",", "xj"}], "}"}], ",", 
    "\[IndentingNewLine]", 
    RowBox[{
     RowBox[{"n", " ", "=", " ", 
      RowBox[{"Length", "[", "x", "]"}]}], ";", "\[IndentingNewLine]", 
     RowBox[{"Table", "[", 
      RowBox[{
       RowBox[{
        RowBox[{"j", " ", "=", " ", 
         RowBox[{
          RowBox[{"Mod", "[", 
           RowBox[{"i", ",", "n"}], "]"}], "+", "1"}]}], ";", " ", 
        RowBox[{"xi", "=", 
         RowBox[{"x", "[", 
          RowBox[{"[", "i", "]"}], "]"}]}], ";", 
        RowBox[{"xj", "=", 
         RowBox[{"x", "[", 
          RowBox[{"[", "j", "]"}], "]"}]}], ";", 
        RowBox[{"Factor", "[", 
         RowBox[{"abssqr", "[", 
          RowBox[{"xj", "-", "xi"}], "]"}], "]"}]}], ",", 
       RowBox[{"{", 
        RowBox[{"i", ",", "n"}], "}"}]}], "]"}]}]}], "]"}]}]], "Input",
 CellLabel->
  "In[337]:=",ExpressionUUID->"e11ba3e8-021d-4383-8d22-6bde03aae587"],

Cell[BoxData[
 RowBox[{"(*", " ", 
  RowBox[{"Polygon", "-", 
   RowBox[{"side", " ", "angle", " ", "cosines"}]}], " ", "*)"}]], "Input",
 CellLabel->
  "In[338]:=",ExpressionUUID->"e1bf3b75-53dc-41da-b4e0-c5ab9798c279"],

Cell[BoxData[
 RowBox[{
  RowBox[{"polysidecosangs", "[", "x_", "]"}], " ", ":=", " ", 
  RowBox[{"Module", "[", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{
     "i", ",", "j", ",", "k", ",", "n", ",", "xi", ",", "xj", ",", "xk", ",", 
      "xji", ",", "xjk"}], "}"}], ",", "\[IndentingNewLine]", 
    RowBox[{
     RowBox[{"n", " ", "=", " ", 
      RowBox[{"Length", "[", "x", "]"}]}], ";", "\[IndentingNewLine]", 
     RowBox[{"Table", "[", 
      RowBox[{
       RowBox[{
        RowBox[{"j", "=", 
         RowBox[{
          RowBox[{"Mod", "[", 
           RowBox[{"i", ",", "n"}], "]"}], "+", "1"}]}], ";", 
        RowBox[{"k", "=", 
         RowBox[{
          RowBox[{"Mod", "[", 
           RowBox[{"j", ",", "n"}], "]"}], "+", "1"}]}], ";", 
        RowBox[{"xi", "=", 
         RowBox[{"x", "[", 
          RowBox[{"[", "i", "]"}], "]"}]}], ";", 
        RowBox[{"xj", "=", 
         RowBox[{"x", "[", 
          RowBox[{"[", "j", "]"}], "]"}]}], ";", 
        RowBox[{"xk", "=", 
         RowBox[{"x", "[", 
          RowBox[{"[", "k", "]"}], "]"}]}], ";", 
        RowBox[{"xji", " ", "=", " ", 
         RowBox[{"Factor", "[", 
          RowBox[{"xj", "-", "xi"}], "]"}]}], ";", 
        RowBox[{"xjk", "=", 
         RowBox[{"Factor", "[", 
          RowBox[{"xj", "-", "xk"}], "]"}]}], ";", 
        RowBox[{
         RowBox[{"(", 
          RowBox[{"xji", ".", "xjk"}], ")"}], "/", 
         RowBox[{"Sqrt", "[", 
          RowBox[{
           RowBox[{"abssqr", "[", "xji", "]"}], "*", 
           RowBox[{"abssqr", "[", "xjk", "]"}]}], "]"}]}]}], ",", 
       RowBox[{"{", 
        RowBox[{"i", ",", "n"}], "}"}]}], "]"}]}]}], "]"}]}]], "Input",
 CellLabel->
  "In[339]:=",ExpressionUUID->"6e6a9415-03b4-4d54-82c6-b50e9696e65f"],

Cell[BoxData[
 RowBox[{"(*", " ", 
  RowBox[{"Squares", " ", "of", " ", "those", " ", "angles"}], " ", 
  "*)"}]], "Input",
 CellLabel->
  "In[340]:=",ExpressionUUID->"7c643831-f186-403b-a3d3-a0ba55cc175c"],

Cell[BoxData[
 RowBox[{
  RowBox[{"polysidecsangsqs", "[", "x_", "]"}], " ", ":=", " ", 
  RowBox[{"Module", "[", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{
     "i", ",", "j", ",", "k", ",", "n", ",", "xi", ",", "xj", ",", "xk", ",", 
      "xji", ",", "xjk"}], "}"}], ",", "\[IndentingNewLine]", 
    RowBox[{
     RowBox[{"n", " ", "=", " ", 
      RowBox[{"Length", "[", "x", "]"}]}], ";", "\[IndentingNewLine]", 
     RowBox[{"Table", "[", 
      RowBox[{
       RowBox[{
        RowBox[{"j", "=", 
         RowBox[{
          RowBox[{"Mod", "[", 
           RowBox[{"i", ",", "n"}], "]"}], "+", "1"}]}], ";", 
        RowBox[{"k", "=", 
         RowBox[{
          RowBox[{"Mod", "[", 
           RowBox[{"j", ",", "n"}], "]"}], "+", "1"}]}], ";", 
        RowBox[{"xi", "=", 
         RowBox[{"x", "[", 
          RowBox[{"[", "i", "]"}], "]"}]}], ";", 
        RowBox[{"xj", "=", 
         RowBox[{"x", "[", 
          RowBox[{"[", "j", "]"}], "]"}]}], ";", 
        RowBox[{"xk", "=", 
         RowBox[{"x", "[", 
          RowBox[{"[", "k", "]"}], "]"}]}], ";", 
        RowBox[{"xji", " ", "=", " ", 
         RowBox[{"Factor", "[", 
          RowBox[{"xj", "-", "xi"}], "]"}]}], ";", 
        RowBox[{"xjk", "=", 
         RowBox[{"Factor", "[", 
          RowBox[{"xj", "-", "xk"}], "]"}]}], ";", 
        RowBox[{
         RowBox[{
          RowBox[{"(", 
           RowBox[{"xji", ".", "xjk"}], ")"}], "^", "2"}], "/", 
         RowBox[{"(", 
          RowBox[{
           RowBox[{"abssqr", "[", "xji", "]"}], "*", 
           RowBox[{"abssqr", "[", "xjk", "]"}]}], ")"}]}]}], ",", 
       RowBox[{"{", 
        RowBox[{"i", ",", "n"}], "}"}]}], "]"}]}]}], "]"}]}]], "Input",
 CellLabel->
  "In[341]:=",ExpressionUUID->"7797e813-8c53-4f8c-b7f0-4238a92cf456"],

Cell[BoxData[
 RowBox[{"(*", " ", 
  RowBox[{"Polygon", " ", "area", " ", "factor"}], " ", "*)"}]], "Input",
 CellLabel->
  "In[342]:=",ExpressionUUID->"37ff24c7-b581-4b8d-9bcb-39a048cde739"],

Cell[BoxData[
 RowBox[{
  RowBox[{"polyareafactor", "[", "x_", "]"}], " ", ":=", " ", 
  RowBox[{"Module", "[", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{"i", ",", "j", ",", "n", ",", "xi", ",", "xj"}], "}"}], ",", 
    "\[IndentingNewLine]", 
    RowBox[{
     RowBox[{"n", " ", "=", " ", 
      RowBox[{"Length", "[", "x", "]"}]}], ";", "\[IndentingNewLine]", 
     RowBox[{"Factor", "[", 
      RowBox[{
       RowBox[{"(", 
        RowBox[{"1", "/", "2"}], ")"}], "*", 
       RowBox[{"Sum", "[", 
        RowBox[{
         RowBox[{
          RowBox[{"j", " ", "=", " ", 
           RowBox[{
            RowBox[{"Mod", "[", 
             RowBox[{"i", ",", "n"}], "]"}], "+", "1"}]}], ";", " ", 
          RowBox[{"xi", "=", 
           RowBox[{"x", "[", 
            RowBox[{"[", "i", "]"}], "]"}]}], ";", 
          RowBox[{"xj", "=", 
           RowBox[{"x", "[", 
            RowBox[{"[", "j", "]"}], "]"}]}], ";", 
          RowBox[{"Cross", "[", 
           RowBox[{"xi", ",", "xj"}], "]"}]}], ",", 
         RowBox[{"{", 
          RowBox[{"i", ",", "n"}], "}"}]}], "]"}]}], "]"}]}]}], 
   "]"}]}]], "Input",
 CellLabel->
  "In[343]:=",ExpressionUUID->"ea18407d-3265-46d8-997a-cf1b21d84b7a"],

Cell[BoxData[
 RowBox[{"(*", " ", 
  RowBox[{"Power", " ", 
   RowBox[{"simplifiers", ":", " ", 
    RowBox[{"good", " ", "for", " ", "sqrt", 
     RowBox[{"(", 
      RowBox[{"a", "^", "2"}], ")"}], " ", "and", " ", "the", " ", 
     "like"}]}]}], " ", "*)"}]], "Input",
 CellLabel->
  "In[344]:=",ExpressionUUID->"34280628-05a1-40f6-9616-534fa1e883ce"],

Cell[BoxData[
 RowBox[{
  RowBox[{"powersimp", " ", "=", " ", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{
      RowBox[{
       RowBox[{"(", 
        RowBox[{"x_", "^", "p_"}], ")"}], "^", "q_"}], "\[Rule]", 
      RowBox[{"x", "^", 
       RowBox[{"(", 
        RowBox[{"p", "*", "q"}], ")"}]}]}], ",", " ", 
     RowBox[{
      RowBox[{
       RowBox[{"(", 
        RowBox[{"x_", "*", "y_"}], ")"}], "^", "p_"}], "\[Rule]", 
      RowBox[{
       RowBox[{"(", 
        RowBox[{"x", "^", "p"}], ")"}], "*", 
       RowBox[{"(", 
        RowBox[{"y", "^", "p"}], ")"}]}]}]}], "}"}]}], ";"}]], "Input",
 CellLabel->
  "In[345]:=",ExpressionUUID->"92ea85cc-ec17-4b2c-894d-bd180aef4b2d"],

Cell[BoxData[
 RowBox[{"(*", " ", 
  RowBox[{"Polynomial", " ", 
   RowBox[{"remainder", ":", " ", 
    RowBox[{
    "returns", " ", "last", " ", "two", " ", "results", " ", "of", " ", 
     RowBox[{"Euclid", "'"}], "s", " ", "Algorithm", " ", "before", " ", 
     "zero"}]}]}], " ", "*)"}]], "Input",
 CellLabel->
  "In[346]:=",ExpressionUUID->"10653bfe-34c6-4100-b1c0-497ecc5a35a6"],

Cell[BoxData[
 RowBox[{
  RowBox[{"polmod", "[", 
   RowBox[{"px1_", ",", "px2_", ",", "x_"}], "]"}], " ", ":=", " ", 
  RowBox[{"Module", "[", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{"p1", ",", "p2", ",", "p3"}], "}"}], ",", 
    RowBox[{
     RowBox[{"p1", "=", 
      RowBox[{"Numerator", "[", 
       RowBox[{"Factor", "[", "px1", "]"}], "]"}]}], ";", 
     RowBox[{"p2", "=", 
      RowBox[{"Numerator", "[", 
       RowBox[{"Factor", "[", "px2", "]"}], "]"}]}], ";", 
     RowBox[{"While", "[", 
      RowBox[{"True", ",", 
       RowBox[{
        RowBox[{"p3", "=", 
         RowBox[{"Numerator", "[", 
          RowBox[{"Factor", "[", 
           RowBox[{"PolynomialRemainder", "[", 
            RowBox[{"p1", ",", "p2", ",", "x"}], "]"}], "]"}], "]"}]}], ";", 
        RowBox[{"If", "[", 
         RowBox[{
          RowBox[{"p3", "===", "0"}], ",", 
          RowBox[{"Return", "[", 
           RowBox[{"{", 
            RowBox[{"p1", ",", "p2"}], "}"}], "]"}]}], "]"}], ";", 
        RowBox[{"p1", "=", "p2"}], ";", 
        RowBox[{"p2", "=", "p3"}]}]}], "]"}]}]}], "]"}]}]], "Input",
 CellLabel->
  "In[347]:=",ExpressionUUID->"c6b1c403-c3f8-4f24-8f3a-2cd8b265dffe"],

Cell[BoxData[
 RowBox[{"(*", " ", 
  RowBox[{
   RowBox[{
    RowBox[{
    "Algebraic", " ", "representation", " ", "of", " ", "trigonometric", " ", 
     
     RowBox[{"functions", ":", " ", "cos"}]}], " ", "=", " ", 
    RowBox[{"[", "0", "]"}]}], ",", " ", 
   RowBox[{"sin", " ", "=", " ", 
    RowBox[{
     RowBox[{
      RowBox[{
       RowBox[{"[", "1", "]"}], " ", "--"}], " ", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"cos", "[", "a", "]"}], ",", 
        RowBox[{"sin", "[", "a", "]"}]}], "}"}], " ", "in", " ", "terms", " ",
       "of", " ", "t"}], " ", "=", " ", 
     RowBox[{"tan", "[", 
      RowBox[{"a", "/", "2"}], "]"}]}]}]}], " ", "*)"}]], "Input",
 CellLabel->
  "In[348]:=",ExpressionUUID->"add70c81-e895-44c6-9e3e-46458ac46d0e"],

Cell[BoxData[
 RowBox[{
  RowBox[{"trgalg", "[", 
   RowBox[{"cs_", ",", "t_"}], "]"}], " ", ":=", " ", 
  RowBox[{"{", 
   RowBox[{
    RowBox[{
     RowBox[{"cs", "[", "0", "]"}], "\[Rule]", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{"1", "-", 
        RowBox[{"t", "^", "2"}]}], ")"}], "/", 
      RowBox[{"(", 
       RowBox[{"1", "+", 
        RowBox[{"t", "^", "2"}]}], ")"}]}]}], ",", 
    RowBox[{
     RowBox[{"cs", "[", "1", "]"}], "\[Rule]", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{"2", "t"}], ")"}], "/", 
      RowBox[{"(", 
       RowBox[{"1", "+", 
        RowBox[{"t", "^", "2"}]}], ")"}]}]}]}], "}"}]}]], "Input",
 CellLabel->
  "In[349]:=",ExpressionUUID->"633261fa-7f5c-40db-869a-6338e04df5a8"],

Cell[BoxData[
 RowBox[{"(*", " ", 
  RowBox[{"Tangent", " ", "addition", " ", "and", " ", "duplication"}], " ", 
  "*)"}]], "Input",
 CellLabel->
  "In[350]:=",ExpressionUUID->"e961e991-d475-4555-b097-9b7b88246f04"],

Cell[BoxData[
 RowBox[{
  RowBox[{"tanadd", "[", 
   RowBox[{"t1_", ",", "t2_"}], "]"}], " ", ":=", " ", 
  RowBox[{
   RowBox[{"(", 
    RowBox[{"t1", "+", "t2"}], ")"}], "/", 
   RowBox[{"(", 
    RowBox[{"1", "-", 
     RowBox[{"t1", "*", "t2"}]}], ")"}]}]}]], "Input",
 CellLabel->
  "In[351]:=",ExpressionUUID->"ceb05d3c-033c-4461-a8ec-82cfd9b899b9"],

Cell[BoxData[
 RowBox[{
  RowBox[{"tandup", "[", "t_", "]"}], " ", ":=", " ", 
  RowBox[{"tanadd", "[", 
   RowBox[{"t", ",", "t"}], "]"}]}]], "Input",
 CellLabel->
  "In[352]:=",ExpressionUUID->"ccb772c6-b240-429c-b30b-ce169c2d93d5"],

Cell[BoxData[
 RowBox[{"(*", " ", 
  RowBox[{
  "Subtract", " ", "the", " ", "first", " ", "member", " ", "of", " ", "a", 
   " ", "list", " ", "from", " ", "the", " ", 
   RowBox[{"others", ".", " ", "Good"}], " ", "for", " ", "testing", " ", 
   "for", " ", "equality"}], " ", "*)"}]], "Input",
 CellLabel->
  "In[353]:=",ExpressionUUID->"24d7ce60-ffcc-4c26-8acd-c281e25eca9b"],

Cell[BoxData[
 RowBox[{
  RowBox[{"subfirst", "[", "x_", "]"}], " ", ":=", " ", 
  RowBox[{"Factor", "[", 
   RowBox[{
    RowBox[{
     RowBox[{"#", " ", "-", " ", 
      RowBox[{"x", "[", 
       RowBox[{"[", "1", "]"}], "]"}]}], "&"}], " ", "/@", " ", 
    RowBox[{"Drop", "[", 
     RowBox[{"x", ",", "1"}], "]"}]}], "]"}]}]], "Input",
 CellLabel->
  "In[354]:=",ExpressionUUID->"334e302b-2aea-48c7-9bbe-c6e591ac20d7"],

Cell[BoxData[
 RowBox[{"(*", " ", 
  RowBox[{
   RowBox[{"Sums", " ", "of", " ", "powers", " ", "of", " ", "values"}], ",", 
   " ", 
   RowBox[{
   "so", " ", "as", " ", "to", " ", "test", " ", "identity", " ", "without", 
    " ", "concerning", " ", "oneself", " ", "with", " ", "permutations"}]}], 
  " ", "*)"}]], "Input",
 CellLabel->
  "In[355]:=",ExpressionUUID->"12a76a72-a7a3-4a6b-8c0c-058d550aab39"],

Cell[BoxData[
 RowBox[{
  RowBox[{"powersums", "[", "x_", "]"}], " ", ":=", " ", 
  RowBox[{"Table", "[", 
   RowBox[{
    RowBox[{"Factor", "[", 
     RowBox[{"Total", "[", 
      RowBox[{"x", "^", "k"}], "]"}], "]"}], ",", 
    RowBox[{"{", 
     RowBox[{"k", ",", 
      RowBox[{"Length", "[", "x", "]"}]}], "}"}]}], "]"}]}]], "Input",
 CellLabel->
  "In[356]:=",ExpressionUUID->"640b00e1-6492-41b0-932d-7c24f003b749"],

Cell[BoxData[
 RowBox[{"(*", " ", 
  RowBox[{
   RowBox[{"Find", " ", "dice", " ", 
    RowBox[{"condition", " ", "--"}], " ", "to", " ", "be", " ", "a", " ", 
    "good", " ", "die"}], ",", " ", 
   RowBox[{
   "the", " ", "polyhedron", " ", "must", " ", "have", " ", "maximum", " ", 
    "mechanical", " ", 
    RowBox[{"stability", ".", " ", "For"}], " ", "that"}], ",", " ", 
   RowBox[{
   "the", " ", "centroid", " ", "of", " ", "the", " ", "polyhedron", " ", 
    "must", " ", "lie", " ", "on", " ", "the", " ", "normal", " ", "vector", 
    " ", "from", " ", "the", " ", "centroid", " ", "of", " ", "each", " ", 
    "face"}]}], " ", "*)"}]], "Input",
 CellLabel->
  "In[357]:=",ExpressionUUID->"18002f9e-8b92-4b6f-ad24-1356d987d550"],

Cell[BoxData[
 RowBox[{
  RowBox[{"ctrdarnrm", "[", "vts_", "]"}], " ", ":=", " ", 
  RowBox[{"Module", "[", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{"n", ",", "k", ",", "arnrm", ",", "ctrdan"}], "}"}], ",", 
    "\[IndentingNewLine]", 
    RowBox[{
     RowBox[{"n", " ", "=", " ", 
      RowBox[{"Length", "[", "vts", "]"}]}], ";", "\[IndentingNewLine]", 
     RowBox[{"arnrm", " ", "=", " ", 
      RowBox[{
       RowBox[{
        RowBox[{"(", 
         RowBox[{"1", "/", "4"}], ")"}], "*", 
        RowBox[{"Sum", "[", 
         RowBox[{
          RowBox[{"Cross", "[", 
           RowBox[{
            RowBox[{"vts", "[", 
             RowBox[{"[", 
              RowBox[{"k", "+", "1"}], "]"}], "]"}], ",", 
            RowBox[{
             RowBox[{"vts", "[", 
              RowBox[{"[", 
               RowBox[{
                RowBox[{"Mod", "[", 
                 RowBox[{
                  RowBox[{"k", "+", "1"}], ",", "n"}], "]"}], "+", "1"}], 
               "]"}], "]"}], "-", 
             RowBox[{"vts", "[", 
              RowBox[{"[", 
               RowBox[{
                RowBox[{"Mod", "[", 
                 RowBox[{
                  RowBox[{"k", "-", "1"}], ",", "n"}], "]"}], "+", "1"}], 
               "]"}], "]"}]}]}], "]"}], ",", 
          RowBox[{"{", 
           RowBox[{"k", ",", "0", ",", 
            RowBox[{"n", "-", "1"}]}], "}"}]}], "]"}]}], " ", "//", " ", 
       "Factor"}]}], ";", "\[IndentingNewLine]", 
     RowBox[{"ctrdan", " ", "=", " ", 
      RowBox[{
       RowBox[{
        RowBox[{"(", 
         RowBox[{"1", "/", "6"}], ")"}], "*", 
        RowBox[{"Sum", "[", 
         RowBox[{
          RowBox[{
           RowBox[{"vts", "[", 
            RowBox[{"[", 
             RowBox[{"k", "+", "1"}], "]"}], "]"}], "*", 
           RowBox[{"(", 
            RowBox[{"arnrm", ".", 
             RowBox[{"Cross", "[", 
              RowBox[{
               RowBox[{"vts", "[", 
                RowBox[{"[", 
                 RowBox[{"k", "+", "1"}], "]"}], "]"}], ",", 
               RowBox[{
                RowBox[{"vts", "[", 
                 RowBox[{"[", 
                  RowBox[{
                   RowBox[{"Mod", "[", 
                    RowBox[{
                    RowBox[{"k", "+", "1"}], ",", "n"}], "]"}], "+", "1"}], 
                  "]"}], "]"}], "-", 
                RowBox[{"vts", "[", 
                 RowBox[{"[", 
                  RowBox[{
                   RowBox[{"Mod", "[", 
                    RowBox[{
                    RowBox[{"k", "-", "1"}], ",", "n"}], "]"}], "+", "1"}], 
                  "]"}], "]"}]}]}], "]"}]}], ")"}]}], ",", 
          RowBox[{"{", 
           RowBox[{"k", ",", "0", ",", 
            RowBox[{"n", "-", "1"}]}], "}"}]}], "]"}]}], " ", "//", " ", 
       "Factor"}]}], ";", "\[IndentingNewLine]", 
     RowBox[{
      RowBox[{"{", 
       RowBox[{
        RowBox[{"ctrdan", "/", 
         RowBox[{"(", 
          RowBox[{"arnrm", ".", "arnrm"}], ")"}]}], ",", "arnrm"}], "}"}], 
      " ", "//", " ", "Factor"}]}]}], "]"}]}]], "Input",
 CellLabel->
  "In[358]:=",ExpressionUUID->"28f636c8-02e1-48a9-b645-b0fa2532c505"],

Cell[BoxData[
 RowBox[{
  RowBox[{"dicecond", "[", "vts_", "]"}], " ", ":=", " ", 
  RowBox[{
   RowBox[{
    RowBox[{
     RowBox[{"Cross", "[", 
      RowBox[{
       RowBox[{"#", "[", 
        RowBox[{"[", "1", "]"}], "]"}], ",", 
       RowBox[{"#", "[", 
        RowBox[{"[", "2", "]"}], "]"}]}], "]"}], "&"}], " ", "@", " ", 
    RowBox[{"ctrdarnrm", "[", "vts", "]"}]}], " ", "//", " ", 
   "Factor"}]}]], "Input",
 CellLabel->
  "In[359]:=",ExpressionUUID->"2157763e-0c67-4e72-b099-06bbc06cf193"]
}, Closed]],

Cell[CellGroupData[{

Cell["Axial", "Subsection",ExpressionUUID->"6f305bf2-f207-4c4c-b5f3-5659799b7474"],

Cell[CellGroupData[{

Cell["Bipyramid", "Subsubsection",ExpressionUUID->"1feb8290-204c-42b6-9d27-c3f6954b3e4f"],

Cell[BoxData[
 RowBox[{
  RowBox[{"bipyrmdvts", " ", "=", " ", 
   RowBox[{
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0", ",", "0", ",", "1"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"0", ",", "0", ",", 
         RowBox[{"-", "1"}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"a", ",", "0", ",", "b"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"ax", "*", 
          RowBox[{"cst", "[", "0", "]"}]}], ",", 
         RowBox[{"ax", "*", 
          RowBox[{"cst", "[", "1", "]"}]}], ",", 
         RowBox[{"-", "b"}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"a", "*", 
          RowBox[{"cstx", "[", "0", "]"}]}], ",", 
         RowBox[{"a", "*", 
          RowBox[{"cstx", "[", "1", "]"}]}], ",", "b"}], "}"}]}], "}"}], " ", 
     "/.", 
     RowBox[{"Flatten", "[", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"trgalg", "[", 
         RowBox[{"cst", ",", "t"}], "]"}], ",", 
        RowBox[{"trgalg", "[", 
         RowBox[{"cstx", ",", 
          RowBox[{"tandup", "[", "t", "]"}]}], "]"}]}], "}"}], "]"}]}], " ", "//",
     " ", "Factor"}]}], ";"}]], "Input",
 CellLabel->
  "In[360]:=",ExpressionUUID->"33486001-908e-4b4f-8bb0-78618f973c8c"],

Cell[BoxData[
 RowBox[{
  RowBox[{"bypyrmdfcs", " ", "=", " ", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"1", ",", "3", ",", "4"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"1", ",", "4", ",", "5"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"2", ",", "4", ",", "3"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"2", ",", "5", ",", "4"}], "}"}]}], "}"}]}], ";"}]], "Input",
 CellLabel->
  "In[361]:=",ExpressionUUID->"34f3fd72-b523-4680-aabc-e741c1c98baa"],

Cell[BoxData[
 RowBox[{"(*", " ", 
  RowBox[{"Radial", " ", "displacement", " ", "only"}], " ", "*)"}]], "Input",\

 CellLabel->
  "In[362]:=",ExpressionUUID->"297f6447-2f06-4e58-9807-dd86db630baa"],

Cell[BoxData[
 RowBox[{
  RowBox[{"bipyrmdvtsrd", " ", "=", " ", 
   RowBox[{"bipyrmdvts", " ", "/.", " ", 
    RowBox[{"b", "\[Rule]", "0"}]}]}], ";"}]], "Input",
 CellLabel->
  "In[363]:=",ExpressionUUID->"5d5a77f9-4c92-47e9-9f6a-17ce8130669b"],

Cell[BoxData[
 RowBox[{"subfirst", "[", 
  RowBox[{
   RowBox[{
    RowBox[{"powersums", "[", 
     RowBox[{"polysidelensqs", "[", 
      RowBox[{"bipyrmdvtsrd", "[", 
       RowBox[{"[", "#", "]"}], "]"}], "]"}], "]"}], "&"}], " ", "/@", " ", 
   "bypyrmdfcs"}], "]"}]], "Input",
 CellLabel->
  "In[364]:=",ExpressionUUID->"ad67bfc2-2496-4a4f-bf32-610588f46393"],

Cell[BoxData[
 RowBox[{"(*", " ", 
  RowBox[{"Axial", " ", "displacement", " ", "only"}], " ", "*)"}]], "Input",
 CellLabel->
  "In[365]:=",ExpressionUUID->"6c683894-70c3-4f73-8814-18eeb5fd58fd"],

Cell[BoxData[
 RowBox[{
  RowBox[{"bipyrmdvtsax", " ", "=", " ", 
   RowBox[{"bipyrmdvts", " ", "/.", " ", 
    RowBox[{"ax", "\[Rule]", "a"}]}]}], ";"}]], "Input",
 CellLabel->
  "In[366]:=",ExpressionUUID->"4180c6bd-c888-41c3-aba3-03b63c3ad5bb"],

Cell[BoxData[
 RowBox[{"subfirst", "[", 
  RowBox[{
   RowBox[{
    RowBox[{"powersums", "[", 
     RowBox[{"polysidelensqs", "[", 
      RowBox[{"bipyrmdvtsax", "[", 
       RowBox[{"[", "#", "]"}], "]"}], "]"}], "]"}], "&"}], " ", "/@", " ", 
   "bypyrmdfcs"}], "]"}]], "Input",
 CellLabel->
  "In[367]:=",ExpressionUUID->"d70cba4a-4d9e-42df-8902-214f93bdf6fb"],

Cell[BoxData[
 RowBox[{"(*", " ", 
  RowBox[{"No", " ", "displacements"}], " ", "*)"}]], "Input",
 CellLabel->
  "In[368]:=",ExpressionUUID->"7515e263-5228-41c5-9ac3-5b221ec81adf"],

Cell[BoxData[
 RowBox[{
  RowBox[{"bipyrmdvts00", " ", "=", " ", 
   RowBox[{"bipyrmdvts", " ", "/.", " ", 
    RowBox[{"{", 
     RowBox[{
      RowBox[{"ax", "\[Rule]", "a"}], ",", 
      RowBox[{"b", "\[Rule]", "0"}]}], "}"}]}]}], ";"}]], "Input",
 CellLabel->
  "In[369]:=",ExpressionUUID->"81911c1e-f013-49f5-91c9-c423c8f43c7f"],

Cell[BoxData[
 RowBox[{"subfirst", "[", 
  RowBox[{
   RowBox[{
    RowBox[{"powersums", "[", 
     RowBox[{"polysidelensqs", "[", 
      RowBox[{"bipyrmdvts00", "[", 
       RowBox[{"[", "#", "]"}], "]"}], "]"}], "]"}], "&"}], " ", "/@", " ", 
   "bypyrmdfcs"}], "]"}]], "Input",
 CellLabel->
  "In[370]:=",ExpressionUUID->"ea18089f-202e-4356-864e-bc94e030f09e"],

Cell[BoxData[
 RowBox[{"(*", " ", 
  RowBox[{"Dice", " ", 
   RowBox[{"condition", " ", "--"}], " ", "satisfied", " ", "only", " ", 
   "for", " ", "no", " ", "displacements"}], " ", "*)"}]], "Input",
 CellLabel->
  "In[371]:=",ExpressionUUID->"5a37f5c3-9c15-46c3-81d5-e68060f0e3fe"],

Cell[BoxData[
 RowBox[{"dicecond", "[", 
  RowBox[{
   RowBox[{"bipyrmdvts00", "[", 
    RowBox[{"[", 
     RowBox[{"bypyrmdfcs", "[", 
      RowBox[{"[", "1", "]"}], "]"}], "]"}], "]"}], " ", "/.", " ", 
   RowBox[{"a", "\[Rule]", 
    RowBox[{"Sqrt", "[", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{"1", "+", 
        RowBox[{"t", "^", "2"}]}], ")"}], "/", "2"}], "]"}]}]}], 
  "]"}]], "Input",
 CellLabel->
  "In[372]:=",ExpressionUUID->"0a10b057-8073-46fa-8b2b-c1aa15d61a8a"]
}, Closed]],

Cell[CellGroupData[{

Cell["Prism", "Subsubsection",ExpressionUUID->"244af3c5-6742-4357-990e-e46dec4dba8f"],

Cell[BoxData[
 RowBox[{
  RowBox[{"prismvts", " ", "=", " ", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{
      RowBox[{"{", 
       RowBox[{"a", ",", "0", ",", "1"}], "}"}], ",", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"a", "*", 
         RowBox[{"cst1", "[", "0", "]"}]}], ",", 
        RowBox[{"a", "*", 
         RowBox[{"cst1", "[", "1", "]"}]}], ",", "1"}], "}"}], ",", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"a", "*", 
         RowBox[{"cst2", "[", "0", "]"}]}], ",", 
        RowBox[{"a", "*", 
         RowBox[{"cst2", "[", "1", "]"}]}], ",", 
        RowBox[{"-", "1"}]}], "}"}], ",", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"a", "*", 
         RowBox[{"cst3", "[", "0", "]"}]}], ",", 
        RowBox[{"a", "*", 
         RowBox[{"cst3", "[", "1", "]"}]}], ",", 
        RowBox[{"-", "1"}]}], "}"}]}], "}"}], " ", "/.", " ", 
    RowBox[{"Flatten", "[", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"trgalg", "[", 
        RowBox[{"cst1", ",", "t1"}], "]"}], ",", 
       RowBox[{"trgalg", "[", 
        RowBox[{"cst2", ",", 
         RowBox[{"tanadd", "[", 
          RowBox[{"t1", ",", 
           RowBox[{"-", "t3"}]}], "]"}]}], "]"}], ",", 
       RowBox[{"trgalg", "[", 
        RowBox[{"cst3", ",", "t3"}], "]"}]}], "}"}], "]"}]}]}], 
  ";"}]], "Input",
 CellLabel->
  "In[373]:=",ExpressionUUID->"ed8288e8-2eb1-4e7a-9f28-ef572823d16f"],

Cell[BoxData[
 RowBox[{"planarity", "[", "prismvts", "]"}]], "Input",
 CellLabel->
  "In[374]:=",ExpressionUUID->"f9131f8e-d4d1-48a0-bb80-02ca261b1db0"],

Cell[BoxData[
 RowBox[{"(*", " ", 
  RowBox[{"t3", " ", "\[NotEqual]", " ", 
   RowBox[{
    RowBox[{"0", " ", "--"}], " ", "alternating", " ", "up", " ", "and", " ", 
    
    RowBox[{"down", ":", " ", 
     RowBox[{
      RowBox[{"\\/", "\\/"}], "\\/"}]}]}]}], " ", "*)"}]], "Input",
 CellLabel->
  "In[375]:=",ExpressionUUID->"8354716e-bf62-4f6a-9daa-40734e19b211"]
}, Closed]],

Cell[CellGroupData[{

Cell["Trapezodihedron", "Subsubsection",ExpressionUUID->"987b6b7e-9c18-4ba7-94b0-f943940ab0ae"],

Cell[BoxData[
 RowBox[{
  RowBox[{"tzdhdrvts", " ", "=", " ", 
   RowBox[{
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0", ",", "0", ",", "1"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"0", ",", "0", ",", 
         RowBox[{"-", "1"}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"a", ",", "0", ",", "b"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"a", "*", 
          RowBox[{"cst1", "[", "0", "]"}]}], ",", 
         RowBox[{"a", "*", 
          RowBox[{"cst1", "[", "1", "]"}]}], ",", 
         RowBox[{"-", "b"}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"a", "*", 
          RowBox[{"cst2", "[", "0", "]"}]}], ",", 
         RowBox[{"a", "*", 
          RowBox[{"cst2", "[", "1", "]"}]}], ",", "b"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"a", "*", 
          RowBox[{"cst12", "[", "0", "]"}]}], ",", 
         RowBox[{"a", "*", 
          RowBox[{"cst12", "[", "1", "]"}]}], ",", 
         RowBox[{"-", "b"}]}], "}"}]}], "}"}], " ", "/.", " ", 
     RowBox[{"Flatten", "[", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"trgalg", "[", 
         RowBox[{"cst1", ",", "t1"}], "]"}], ",", 
        RowBox[{"trgalg", "[", 
         RowBox[{"cst2", ",", 
          RowBox[{"tanadd", "[", 
           RowBox[{"t1", ",", "t2"}], "]"}]}], "]"}], ",", 
        RowBox[{"trgalg", "[", 
         RowBox[{"cst12", ",", 
          RowBox[{"tanadd", "[", 
           RowBox[{
            RowBox[{"tanadd", "[", 
             RowBox[{"t1", ",", "t2"}], "]"}], ",", "t1"}], "]"}]}], "]"}], 
        ",", 
        RowBox[{"b", "\[Rule]", 
         RowBox[{"t1", "*", "t2"}]}]}], "}"}], "]"}]}], " ", "//", " ", 
    "Factor"}]}], ";"}]], "Input",
 CellLabel->
  "In[376]:=",ExpressionUUID->"acf67927-24b5-46db-96be-a9440d241a9d"],

Cell[BoxData[
 RowBox[{
  RowBox[{"tzdhdrfcs", " ", "=", " ", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"1", ",", "3", ",", "4", ",", "5"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"2", ",", "6", ",", "5", ",", "4"}], "}"}]}], "}"}]}], 
  ";"}]], "Input",
 CellLabel->
  "In[377]:=",ExpressionUUID->"2a38b9d6-c613-4580-a87b-40489f396d71"],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"planarity", "[", 
    RowBox[{"tzdhdrvts", "[", 
     RowBox[{"[", "#", "]"}], "]"}], "]"}], "&"}], " ", "/@", " ", 
  "tzdhdrfcs"}]], "Input",
 CellLabel->
  "In[378]:=",ExpressionUUID->"ea90714f-8333-4a0f-acdb-771a2343d27d"],

Cell[BoxData[
 RowBox[{"subfirst", "[", 
  RowBox[{
   RowBox[{
    RowBox[{"powersums", "[", 
     RowBox[{"polysidelensqs", "[", 
      RowBox[{"tzdhdrvts", "[", 
       RowBox[{"[", "#", "]"}], "]"}], "]"}], "]"}], "&"}], " ", "/@", " ", 
   "tzdhdrfcs"}], "]"}]], "Input",
 CellLabel->
  "In[379]:=",ExpressionUUID->"04e9cc9e-093d-408d-b608-4330cff5ebc8"],

Cell[BoxData[
 RowBox[{"subfirst", "[", 
  RowBox[{
   RowBox[{
    RowBox[{"powersums", "[", 
     RowBox[{"polysidecsangsqs", "[", 
      RowBox[{"tzdhdrvts", "[", 
       RowBox[{"[", "#", "]"}], "]"}], "]"}], "]"}], "&"}], " ", "/@", " ", 
   "tzdhdrfcs"}], "]"}]], "Input",
 CellLabel->
  "In[380]:=",ExpressionUUID->"075710b2-5905-40d6-919b-5e7fa623b96c"],

Cell[BoxData[
 RowBox[{"subfirst", "[", 
  RowBox[{
   RowBox[{
    RowBox[{"abssqr", "[", 
     RowBox[{"polyareafactor", "[", 
      RowBox[{"tzdhdrvts", "[", 
       RowBox[{"[", "#", "]"}], "]"}], "]"}], "]"}], "&"}], " ", "/@", " ", 
   "tzdhdrfcs"}], "]"}]], "Input",
 CellLabel->
  "In[381]:=",ExpressionUUID->"d9985734-a2b5-494a-97b9-c1e42457199a"],

Cell[BoxData[
 RowBox[{"(*", " ", 
  RowBox[{
   RowBox[{
   "All", " ", "vertices", " ", "on", " ", "a", " ", "circumscribed", " ", 
    RowBox[{"sphere", " ", "--"}], " ", "a"}], " ", "=", " ", 
   RowBox[{"Sqrt", "[", 
    RowBox[{"1", "-", 
     RowBox[{"b", "^", "2"}]}], "]"}]}], " ", "*)"}]], "Input",
 CellLabel->
  "In[382]:=",ExpressionUUID->"25dca32f-f8f5-4c64-8ccb-5ec99d7fd8b6"],

Cell[BoxData[
 RowBox[{"subfirst", "[", 
  RowBox[{"abssqr", " ", "/@", " ", 
   RowBox[{"Factor", "[", 
    RowBox[{"tzdhdrvts", " ", "/.", " ", 
     RowBox[{"{", 
      RowBox[{"a", "\[Rule]", 
       RowBox[{"Sqrt", "[", 
        RowBox[{"1", "-", 
         RowBox[{
          RowBox[{"(", 
           RowBox[{"t1", "*", "t2"}], ")"}], "^", "2"}]}], "]"}]}], "}"}]}], 
    "]"}]}], "]"}]], "Input",
 CellLabel->
  "In[383]:=",ExpressionUUID->"0b9e9b0e-465a-4bd7-9741-df2980b3d36b"]
}, Closed]],

Cell[CellGroupData[{

Cell["Antiprism", "Subsubsection",ExpressionUUID->"b69d93e7-ac9a-4ec8-b58d-72ac1c6a0ef6"],

Cell[BoxData[
 RowBox[{"(*", " ", 
  RowBox[{
   RowBox[{"Can", " ", "be", " ", 
    RowBox[{"like", " ", "\\"}]}], "|", 
   RowBox[{"\\", 
    RowBox[{"|", 
     RowBox[{"\\", 
      RowBox[{"|", " ", 
       RowBox[{"or", " ", "/"}], "|", 
       RowBox[{"/", 
        RowBox[{"|", 
         RowBox[{"/", "|"}]}]}]}]}]}]}]}], " ", "*)"}]], "Input",
 CellLabel->
  "In[384]:=",ExpressionUUID->"f5b687a0-458e-43f6-afe5-d4ec3e084ae6"]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{

Cell["Quasi-Spherical", "Subsection",ExpressionUUID->"a5336527-b40a-4980-8b15-3b92f7a8bc37"],

Cell[CellGroupData[{

Cell["Setup", "Subsubsection",ExpressionUUID->"7bd5bda4-63ab-4267-a164-4d7c09c51741"],

Cell[BoxData[
 RowBox[{"(*", " ", 
  RowBox[{
   RowBox[{"c", " ", "=", " ", 
    RowBox[{
     RowBox[{"cos", 
      RowBox[{"(", 
       RowBox[{"2", 
        RowBox[{"Pi", "/", "n"}]}], ")"}], " ", "n"}], " ", "=", " ", 
     RowBox[{"3", " ", 
      RowBox[{"(", "tetrahedron", ")"}]}]}]}], ",", " ", 
   RowBox[{"n", " ", "=", " ", 
    RowBox[{"4", " ", 
     RowBox[{"(", "octahedron", ")"}]}]}], ",", " ", 
   RowBox[{"n", " ", "=", " ", 
    RowBox[{"5", " ", 
     RowBox[{"(", "icosahedron", ")"}]}]}]}], " ", "*)"}]], "Input",
 CellLabel->
  "In[385]:=",ExpressionUUID->"440598dc-d450-4f0c-9f84-c4fec5f285aa"],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"cval", "[", "3", "]"}], " ", "=", " ", 
   RowBox[{
    RowBox[{"-", "1"}], "/", "2"}]}], ";", " ", 
  RowBox[{
   RowBox[{"cval", "[", "4", "]"}], "=", "0"}], ";", " ", 
  RowBox[{
   RowBox[{"cval", "[", "5", "]"}], "=", 
   RowBox[{
    RowBox[{"(", 
     RowBox[{
      RowBox[{"Sqrt", "[", "5", "]"}], "-", "1"}], ")"}], "/", "4"}]}], 
  ";"}]], "Input",
 CellLabel->
  "In[386]:=",ExpressionUUID->"4c9c1ca4-5899-4340-9b00-846e72436d8b"],

Cell[BoxData[
 RowBox[{
  RowBox[{"Table", "[", 
   RowBox[{
    RowBox[{
     RowBox[{"cval", "[", "n", "]"}], "-", 
     RowBox[{"Cos", "[", 
      RowBox[{"2", 
       RowBox[{"Pi", "/", "n"}]}], "]"}]}], ",", 
    RowBox[{"{", 
     RowBox[{"n", ",", "3", ",", "5"}], "}"}]}], "]"}], " ", "//", " ", 
  "Factor"}]], "Input",
 CellLabel->
  "In[387]:=",ExpressionUUID->"f931e4cd-67b8-4557-a781-522392fc8462"],

Cell[BoxData[
 RowBox[{
  RowBox[{"qsrefpts", " ", "=", " ", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"0", ",", "0", ",", "1"}], "}"}], ",", 
     RowBox[{
      RowBox[{"{", 
       RowBox[{
        RowBox[{
         RowBox[{"Sqrt", "[", 
          RowBox[{"1", "-", 
           RowBox[{"2", "c"}]}], "]"}], "*", "c"}], ",", 
        RowBox[{
         RowBox[{"-", 
          RowBox[{"Sqrt", "[", 
           RowBox[{"1", "-", 
            RowBox[{"2", "c"}]}], "]"}]}], "*", 
         RowBox[{"Sqrt", "[", 
          RowBox[{"1", "-", 
           RowBox[{"c", "^", "2"}]}], "]"}]}], ",", "c"}], "}"}], "/", 
      RowBox[{"(", 
       RowBox[{"1", "-", "c"}], ")"}]}], ",", 
     RowBox[{
      RowBox[{"{", 
       RowBox[{
        RowBox[{"Sqrt", "[", 
         RowBox[{"1", "-", 
          RowBox[{"2", "c"}]}], "]"}], ",", "0", ",", "c"}], "}"}], "/", 
      RowBox[{"(", 
       RowBox[{"1", "-", "c"}], ")"}]}], ",", 
     RowBox[{
      RowBox[{"{", 
       RowBox[{
        RowBox[{
         RowBox[{"Sqrt", "[", 
          RowBox[{"1", "-", 
           RowBox[{"2", "c"}]}], "]"}], "*", "c"}], ",", 
        RowBox[{
         RowBox[{"Sqrt", "[", 
          RowBox[{"1", "-", 
           RowBox[{"2", "c"}]}], "]"}], "*", 
         RowBox[{"Sqrt", "[", 
          RowBox[{"1", "-", 
           RowBox[{"c", "^", "2"}]}], "]"}]}], ",", "c"}], "}"}], "/", 
      RowBox[{"(", 
       RowBox[{"1", "-", "c"}], ")"}]}], ",", 
     RowBox[{
      RowBox[{"{", 
       RowBox[{
        RowBox[{
         RowBox[{"Sqrt", "[", 
          RowBox[{"1", "-", 
           RowBox[{"2", "c"}]}], "]"}], "*", 
         RowBox[{"(", 
          RowBox[{
           RowBox[{"2", 
            RowBox[{"c", "^", "2"}]}], "-", "1"}], ")"}]}], ",", 
        RowBox[{
         RowBox[{"Sqrt", "[", 
          RowBox[{"1", "-", 
           RowBox[{"2", "c"}]}], "]"}], "*", 
         RowBox[{"(", 
          RowBox[{"2", "c", "*", 
           RowBox[{"Sqrt", "[", 
            RowBox[{"1", "-", 
             RowBox[{"c", "^", "2"}]}], "]"}]}], ")"}]}], ",", "c"}], "}"}], 
      "/", 
      RowBox[{"(", 
       RowBox[{"1", "-", "c"}], ")"}]}]}], "}"}]}], ";"}]], "Input",
 CellLabel->
  "In[388]:=",ExpressionUUID->"0c6ab4c4-7ff8-4c38-80b8-4a5e7020d75d"],

Cell[BoxData[
 RowBox[{
  RowBox[{"qsrefpolys", " ", "=", " ", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"1", ",", "2", ",", "3"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"1", ",", "3", ",", "4"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"1", ",", "4", ",", "5"}], "}"}]}], "}"}]}], ";"}]], "Input",
 CellLabel->
  "In[389]:=",ExpressionUUID->"2575c46d-77b6-4a6e-bfd4-89ae7c2a97ae"],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"(", 
    RowBox[{
     RowBox[{
      RowBox[{"polysidelensqs", "[", 
       RowBox[{"qsrefpts", "[", 
        RowBox[{"[", "#", "]"}], "]"}], "]"}], "&"}], " ", "/@", " ", 
     "qsrefpolys"}], ")"}], "-", " ", 
   RowBox[{"2", 
    RowBox[{
     RowBox[{"(", 
      RowBox[{"1", "-", 
       RowBox[{"2", "c"}]}], ")"}], "/", 
     RowBox[{"(", 
      RowBox[{"1", "-", "c"}], ")"}]}]}]}], " ", "//", " ", 
  "Factor"}]], "Input",
 CellLabel->
  "In[390]:=",ExpressionUUID->"a506e481-3845-48be-bf7b-188fedb83079"],

Cell[BoxData[
 RowBox[{"qsrefedges", " ", "=", " ", 
  RowBox[{"Union", "[", 
   RowBox[{"Sort", " ", "/@", " ", 
    RowBox[{"Flatten", "[", 
     RowBox[{
      RowBox[{
       RowBox[{
        RowBox[{"Transpose", "[", 
         RowBox[{"{", 
          RowBox[{"#", ",", 
           RowBox[{"RotateLeft", "[", "#", "]"}]}], "}"}], "]"}], "&"}], " ", 
       "/@", " ", "qsrefpolys"}], ",", "1"}], "]"}]}], "]"}]}]], "Input",
 CellLabel->
  "In[391]:=",ExpressionUUID->"565c1c09-30c6-4487-b3da-7ff62503011f"],

Cell[BoxData[
 RowBox[{
  RowBox[{"qsrefedpts", " ", "=", " ", 
   RowBox[{
    RowBox[{
     RowBox[{"Mean", "[", 
      RowBox[{"qsrefpts", "[", 
       RowBox[{"[", "#", "]"}], "]"}], "]"}], "&"}], " ", "/@", " ", 
    "qsrefedges"}]}], ";"}]], "Input",
 CellLabel->
  "In[392]:=",ExpressionUUID->"a7cbe648-ad68-40cf-b71f-8cc930e792af"],

Cell[BoxData[
 RowBox[{
  RowBox[{"qsreffcpts", " ", "=", " ", 
   RowBox[{
    RowBox[{
     RowBox[{"Mean", "[", 
      RowBox[{"qsrefpts", "[", 
       RowBox[{"[", "#", "]"}], "]"}], "]"}], "&"}], " ", "/@", " ", 
    "qsrefpolys"}]}], ";"}]], "Input",
 CellLabel->
  "In[393]:=",ExpressionUUID->"a6173c46-c0b8-4835-b335-3b014647fd5e"],

Cell[BoxData[
 RowBox[{"(*", " ", "Lengths", " ", "*)"}]], "Input",
 CellLabel->
  "In[394]:=",ExpressionUUID->"7f418713-625f-4c05-ac7f-86c3cc1d53af"],

Cell[BoxData[
 RowBox[{
  RowBox[{"vtplen", " ", "=", " ", "1"}], ";", " ", 
  RowBox[{"edplen", " ", "=", " ", 
   RowBox[{"Sqrt", "[", 
    RowBox[{"1", "/", 
     RowBox[{"(", 
      RowBox[{"2", 
       RowBox[{"(", 
        RowBox[{"1", "-", "c"}], ")"}]}], ")"}]}], "]"}]}], ";", " ", 
  RowBox[{"fcplen", " ", "=", " ", 
   RowBox[{"Sqrt", "[", 
    RowBox[{
     RowBox[{"(", 
      RowBox[{"1", "+", "c"}], ")"}], "/", 
     RowBox[{"(", 
      RowBox[{"3", 
       RowBox[{"(", 
        RowBox[{"1", "-", "c"}], ")"}]}], ")"}]}], "]"}]}], ";"}]], "Input",
 CellLabel->
  "In[395]:=",ExpressionUUID->"ef9c48b2-3e04-4d2e-810f-2b881c9e87f3"],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"(", 
    RowBox[{"abssqr", " ", "/@", " ", "qsrefpts"}], ")"}], "/", 
   RowBox[{"vtplen", "^", "2"}]}], " ", "//", " ", "Factor"}]], "Input",
 CellLabel->
  "In[396]:=",ExpressionUUID->"31eb0a26-cef2-41cd-b883-5ab017da334a"],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"(", 
    RowBox[{"abssqr", " ", "/@", " ", "qsrefedpts"}], ")"}], "/", 
   RowBox[{"edplen", "^", "2"}]}], "//", " ", "Factor"}]], "Input",
 CellLabel->
  "In[397]:=",ExpressionUUID->"cc9fa01d-7dfd-4d67-85aa-03a9a7b228b9"],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"(", 
    RowBox[{"abssqr", " ", "/@", " ", "qsreffcpts"}], ")"}], " ", "/", " ", 
   RowBox[{"fcplen", "^", "2"}]}], "//", " ", "Factor"}]], "Input",
 CellLabel->
  "In[398]:=",ExpressionUUID->"ec073cbd-f7e7-4e74-8c55-88315c0103ba"]
}, Closed]],

Cell[CellGroupData[{

Cell["Triangles", "Subsubsection",ExpressionUUID->"a3480d78-5020-4349-b38f-9819ffdc39fd"],

Cell[BoxData[
 RowBox[{"(*", " ", 
  RowBox[{
   RowBox[{"triakis", " ", "triangle"}], "-", 
   RowBox[{"based", " ", "regular", " ", 
    RowBox[{"polyhedron", ":", " ", 
     RowBox[{"pyramid", " ", "on", " ", "each", " ", 
      RowBox[{"face", ":", " ", 
       RowBox[{"face", "-", "vertex", "-", "vertex"}]}]}]}]}]}], " ", 
  "*)"}]], "Input",
 CellLabel->
  "In[399]:=",ExpressionUUID->"c5a4c95f-48d9-4a84-a613-86c9e48fe7fc"],

Cell[BoxData[
 RowBox[{"(*", " ", 
  RowBox[{"n", "-", 
   RowBox[{"akis", " ", "dual"}], "-", "of", "-", "trifaced", "-", 
   RowBox[{"poly", ":", " ", 
    RowBox[{"pyramid", " ", "on", " ", "each", " ", 
     RowBox[{"face", ":", " ", 
      RowBox[{"vertex", "-", "face", "-", "face"}]}]}]}]}], " ", 
  "*)"}]], "Input",
 CellLabel->
  "In[400]:=",ExpressionUUID->"9bbfb353-3bdf-4e78-8aa3-2affbf5e57d2"],

Cell[BoxData[
 RowBox[{"(*", " ", 
  RowBox[{
   RowBox[{"hexakis", " ", "trifaced"}], "-", 
   RowBox[{"poly", " ", "or", " ", "2", "n"}], "-", 
   RowBox[{"axis", " ", "dual"}], "-", "of", "-", "trifaced", "-", 
   RowBox[{"poly", ":", " ", 
    RowBox[{"pyramid", " ", "on", " ", "each", " ", 
     RowBox[{"face", ":", " ", 
      RowBox[{"vertex", "-", "face", "-", "edge"}]}]}]}]}], " ", 
  "*)"}]], "Input",
 CellLabel->
  "In[401]:=",ExpressionUUID->"aaf4db23-3103-405b-8f04-defca3a9d55b"],

Cell[BoxData[
 RowBox[{"(*", " ", 
  RowBox[{"Dice", " ", "conditions", " ", "for", " ", "them"}], " ", 
  "*)"}]], "Input",
 CellLabel->
  "In[402]:=",ExpressionUUID->"d77e622b-19df-43dd-ac46-d54b730c1cdf"],

Cell[BoxData[
 RowBox[{
  RowBox[{"dctripyrht", "[", "c_", "]"}], " ", ":=", " ", 
  RowBox[{
   RowBox[{"(", 
    RowBox[{"1", "/", "2"}], ")"}], "*", 
   RowBox[{"Sqrt", "[", 
    RowBox[{
     RowBox[{"(", 
      RowBox[{"1", "/", "3"}], ")"}], "*", 
     RowBox[{"(", 
      RowBox[{
       RowBox[{"(", 
        RowBox[{"1", "+", "c"}], ")"}], "/", 
       RowBox[{"(", 
        RowBox[{"1", "-", "c"}], ")"}]}], ")"}]}], "]"}], "*", 
   RowBox[{"(", 
    RowBox[{
     RowBox[{"-", "1"}], "+", 
     RowBox[{"Sqrt", "[", 
      RowBox[{
       RowBox[{"(", 
        RowBox[{"13", "+", "c"}], ")"}], "/", 
       RowBox[{"(", 
        RowBox[{"1", "+", "c"}], ")"}]}], "]"}]}], ")"}]}]}]], "Input",
 CellLabel->
  "In[403]:=",ExpressionUUID->"5a8b8f9e-951c-460f-bbba-0d92518126c6"],

Cell[BoxData[
 RowBox[{"dicecond", "[", 
  RowBox[{"{", 
   RowBox[{
    RowBox[{
     RowBox[{"dctripyrht", "[", "c", "]"}], "*", 
     RowBox[{
      RowBox[{"qsreffcpts", "[", 
       RowBox[{"[", "1", "]"}], "]"}], "/", "fcplen"}]}], ",", 
    RowBox[{
     RowBox[{"qsrefpts", "[", 
      RowBox[{"[", "1", "]"}], "]"}], "/", "vtplen"}], ",", 
    RowBox[{
     RowBox[{"qsrefpts", "[", 
      RowBox[{"[", "2", "]"}], "]"}], "/", "vtplen"}]}], "}"}], 
  "]"}]], "Input",
 CellLabel->
  "In[404]:=",ExpressionUUID->"766ebe3e-d017-4c13-9c00-6d70dffa45bd"],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"dcdualpyrht", "[", "c_", "]"}], " ", ":=", " ", 
   RowBox[{
    RowBox[{"(", 
     RowBox[{"1", "/", "2"}], ")"}], "*", 
    RowBox[{"Sqrt", "[", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{"1", "/", "3"}], ")"}], "*", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{"(", 
         RowBox[{"1", "+", "c"}], ")"}], "/", 
        RowBox[{"(", 
         RowBox[{"1", "-", "c"}], ")"}]}], ")"}]}], "]"}], "*", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{"-", "1"}], "+", 
      RowBox[{"Sqrt", "[", 
       RowBox[{"17", "-", 
        RowBox[{"16", "c"}]}], "]"}]}], ")"}]}]}], ";"}]], "Input",
 CellLabel->
  "In[405]:=",ExpressionUUID->"fbe5fcbb-fd76-41f4-b964-c7a856c41326"],

Cell[BoxData[
 RowBox[{"dicecond", "[", 
  RowBox[{"{", 
   RowBox[{
    RowBox[{
     RowBox[{"dcdualpyrht", "[", "c", "]"}], "*", 
     RowBox[{
      RowBox[{"qsrefpts", "[", 
       RowBox[{"[", "1", "]"}], "]"}], "/", "vtplen"}]}], ",", 
    RowBox[{
     RowBox[{"qsreffcpts", "[", 
      RowBox[{"[", "1", "]"}], "]"}], "/", "fcplen"}], ",", 
    RowBox[{
     RowBox[{"qsreffcpts", "[", 
      RowBox[{"[", "2", "]"}], "]"}], "/", "fcplen"}]}], "}"}], 
  "]"}]], "Input",
 CellLabel->
  "In[406]:=",ExpressionUUID->"79af3e86-6eea-47d2-9abf-bccd18382bd4"],

Cell[BoxData[
 RowBox[{"(*", " ", 
  RowBox[{
   RowBox[{"For", " ", "the", " ", "third", " ", "case"}], ",", " ", 
   RowBox[{
   "one", " ", "has", " ", "to", " ", "solve", " ", "a", " ", "quartic"}]}], 
  " ", "*)"}]], "Input",
 CellLabel->
  "In[407]:=",ExpressionUUID->"89c75336-3ce4-4861-8bff-b6712692b962"],

Cell[BoxData[
 RowBox[{"dccdsplit", " ", "=", " ", 
  RowBox[{"dicecond", "[", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"qsrefpts", "[", 
      RowBox[{"[", "1", "]"}], "]"}], ",", 
     RowBox[{"q1", "*", 
      RowBox[{"qsrefedpts", "[", 
       RowBox[{"[", "1", "]"}], "]"}]}], ",", 
     RowBox[{"q2", "*", 
      RowBox[{"qsreffcpts", "[", 
       RowBox[{"[", "1", "]"}], "]"}]}]}], "}"}], "]"}]}]], "Input",
 CellLabel->
  "In[408]:=",ExpressionUUID->"985790b8-a78b-42fc-8afe-365954efb22b"],

Cell[BoxData[
 RowBox[{
  RowBox[{"dccdsplit", " ", "/.", " ", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"c", "\[Rule]", 
      RowBox[{"cval", "[", "3", "]"}]}], ",", 
     RowBox[{"q1", "\[Rule]", 
      RowBox[{
       RowBox[{"(", 
        RowBox[{"1", "/", "2"}], ")"}], 
       RowBox[{"(", 
        RowBox[{
         RowBox[{"-", "1"}], "+", 
         RowBox[{"Sqrt", "[", "17", "]"}]}], ")"}]}]}], ",", 
     RowBox[{"q2", "\[Rule]", "3"}]}], "}"}]}], " ", "//", " ", 
  "Factor"}]], "Input",
 CellLabel->
  "In[409]:=",ExpressionUUID->"7e61c093-1146-4f7e-b1fe-8e7e08ac19c2"],

Cell[BoxData[
 RowBox[{
  RowBox[{"nmsvdccdsplit", "[", "k_", "]"}], " ", ":=", " ", 
  RowBox[{"{", 
   RowBox[{
    RowBox[{"N", "[", 
     RowBox[{
      RowBox[{"vtplen", "/", 
       RowBox[{"{", 
        RowBox[{"edplen", ",", "fcplen"}], "}"}]}], " ", "/.", " ", 
      RowBox[{"c", "\[Rule]", 
       RowBox[{"Cos", "[", 
        RowBox[{"2", 
         RowBox[{"Pi", "/", "k"}]}], "]"}]}]}], "]"}], ",", 
    RowBox[{"NSolve", "[", 
     RowBox[{
      RowBox[{"Thread", "[", 
       RowBox[{
        RowBox[{"(", 
         RowBox[{"dccdsplit", " ", "/.", " ", 
          RowBox[{"c", "\[Rule]", 
           RowBox[{"Cos", "[", 
            RowBox[{"2", 
             RowBox[{"Pi", "/", "k"}]}], "]"}]}]}], ")"}], "\[Equal]", "0"}], 
       "]"}], ",", 
      RowBox[{"{", 
       RowBox[{"q1", ",", "q2"}], "}"}]}], "]"}]}], "}"}]}]], "Input",
 CellLabel->
  "In[410]:=",ExpressionUUID->"b9b1d995-5232-4f16-a965-2f01f0c9d0aa"],

Cell[BoxData[
 RowBox[{"nmsvdccdsplit", "[", "3", "]"}]], "Input",
 CellLabel->
  "In[411]:=",ExpressionUUID->"5b9f0000-5ef9-49fe-9df9-573fbc8d82b9"],

Cell[BoxData[
 RowBox[{"nmsvdccdsplit", "[", "4", "]"}]], "Input",
 CellLabel->
  "In[412]:=",ExpressionUUID->"bdc77ccf-7c27-4762-bb79-383b9a46dc63"],

Cell[BoxData[
 RowBox[{"nmsvdccdsplit", "[", "5", "]"}]], "Input",
 CellLabel->
  "In[413]:=",ExpressionUUID->"8a7cd75a-dbb3-4e40-b2bf-3eaaec91e6fb"],

Cell[BoxData[
 RowBox[{"(*", " ", 
  RowBox[{"However", ",", " ", 
   RowBox[{
    RowBox[{"the", " ", "equal"}], "-", 
    RowBox[{
    "length", " ", "approximation", " ", "is", " ", "very", " ", 
     "close"}]}]}], " ", "*)"}]], "Input",
 CellLabel->
  "In[414]:=",ExpressionUUID->"663a8928-7834-488c-a94f-48955655bd56"],

Cell[BoxData[
 RowBox[{"(*", " ", 
  RowBox[{"Irregular", " ", "isohedral", " ", "tetrahedron"}], " ", 
  "*)"}]], "Input",
 CellLabel->
  "In[415]:=",ExpressionUUID->"53ca90d4-81b9-49e9-a8f0-b9b7009a924d"],

Cell[BoxData[
 RowBox[{
  RowBox[{"irrtetvts", " ", "=", " ", 
   RowBox[{
    RowBox[{
     RowBox[{"(", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"r1", ",", "r2", ",", "r3"}], "}"}], "*", "#"}], ")"}], "&"}],
     " ", "/@", " ", 
    RowBox[{"Select", "[", 
     RowBox[{
      RowBox[{"Tuples", "[", 
       RowBox[{
        RowBox[{"{", 
         RowBox[{
          RowBox[{"-", "1"}], ",", "1"}], "}"}], ",", "3"}], "]"}], ",", 
      RowBox[{
       RowBox[{"(", 
        RowBox[{
         RowBox[{"(", 
          RowBox[{"Times", " ", "@@", " ", "#"}], ")"}], " ", ">", " ", "0"}],
         ")"}], "&"}]}], "]"}]}]}], ";"}]], "Input",
 CellLabel->
  "In[416]:=",ExpressionUUID->"59cd5fe7-5681-4724-8d21-22530ccac0de"],

Cell[BoxData[
 RowBox[{"Union", "[", 
  RowBox[{"Sort", " ", "/@", " ", 
   RowBox[{"Table", "[", 
    RowBox[{
     RowBox[{
      RowBox[{
       RowBox[{"Table", "[", 
        RowBox[{
         RowBox[{"Factor", "[", 
          RowBox[{"abssqr", "[", 
           RowBox[{
            RowBox[{"irrtetvts", "[", 
             RowBox[{"[", 
              RowBox[{"#", "[", 
               RowBox[{"[", 
                RowBox[{"l", "+", "1"}], "]"}], "]"}], "]"}], "]"}], "-", 
            RowBox[{"irrtetvts", "[", 
             RowBox[{"[", 
              RowBox[{"#", "[", 
               RowBox[{"[", "l", "]"}], "]"}], "]"}], "]"}]}], "]"}], "]"}], 
         ",", 
         RowBox[{"{", 
          RowBox[{"l", ",", "3"}], "}"}]}], "]"}], "&"}], " ", "@", " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{
         RowBox[{"Append", "[", 
          RowBox[{"#", ",", 
           RowBox[{"First", "[", "#", "]"}]}], "]"}], "&"}], " ", "@", " ", 
        RowBox[{"Most", "[", 
         RowBox[{"RotateLeft", "[", 
          RowBox[{
           RowBox[{"Range", "[", "4", "]"}], ",", "k"}], "]"}], "]"}]}], 
       ")"}]}], ",", 
     RowBox[{"{", 
      RowBox[{"k", ",", "0", ",", "3"}], "}"}]}], "]"}]}], "]"}]], "Input",
 CellLabel->
  "In[417]:=",ExpressionUUID->"364496a5-884d-4344-9bb9-df994d781290"],

Cell[BoxData[
 RowBox[{"(*", " ", 
  RowBox[{"Stellated", " ", "cases"}], " ", "*)"}]], "Input",
 CellLabel->
  "In[418]:=",ExpressionUUID->"0df022ce-e39c-4f1d-a419-df726ef931c1"],

Cell[BoxData[
 RowBox[{
  RowBox[{"stellexttri", "[", "c_", "]"}], " ", ":=", " ", 
  RowBox[{
   RowBox[{"(", 
    RowBox[{"3", "/", 
     RowBox[{"(", 
      RowBox[{"1", "+", 
       RowBox[{"4", "c"}]}], ")"}]}], ")"}], "*", 
   RowBox[{"Sqrt", "[", 
    RowBox[{
     RowBox[{"(", 
      RowBox[{"1", "/", "3"}], ")"}], "*", 
     RowBox[{"(", 
      RowBox[{
       RowBox[{"(", 
        RowBox[{"1", "+", "c"}], ")"}], "/", 
       RowBox[{"(", 
        RowBox[{"1", "-", "c"}], ")"}]}], ")"}]}], "]"}]}]}]], "Input",
 CellLabel->
  "In[419]:=",ExpressionUUID->"9ca3c1e4-7cb6-4926-b623-e3c74d0321fa"],

Cell[BoxData[
 RowBox[{
  RowBox[{"planarity", "[", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"qsrefpts", "[", 
      RowBox[{"[", "1", "]"}], "]"}], ",", 
     RowBox[{"qsrefpts", "[", 
      RowBox[{"[", "2", "]"}], "]"}], ",", 
     RowBox[{"qsrefpts", "[", 
      RowBox[{"[", "3", "]"}], "]"}], ",", 
     RowBox[{
      RowBox[{"stellexttri", "[", "c", "]"}], "*", 
      RowBox[{"(", 
       RowBox[{"vtplen", "/", "fcplen"}], ")"}], "*", 
      RowBox[{"qsreffcpts", "[", 
       RowBox[{"[", "2", "]"}], "]"}]}]}], "}"}], "]"}], " ", "//", " ", 
  "Factor"}]], "Input",
 CellLabel->
  "In[420]:=",ExpressionUUID->"815ce124-0859-495a-b5aa-8058bf1ee495"],

Cell[BoxData[
 RowBox[{
  RowBox[{"stellextdual", "[", "c_", "]"}], " ", ":=", " ", 
  RowBox[{
   RowBox[{"(", 
    RowBox[{
     RowBox[{"(", 
      RowBox[{"1", "+", "c"}], ")"}], "/", 
     RowBox[{"(", 
      RowBox[{"3", "c"}], ")"}]}], ")"}], "/", 
   RowBox[{"Sqrt", "[", 
    RowBox[{
     RowBox[{"(", 
      RowBox[{"1", "/", "3"}], ")"}], "*", 
     RowBox[{"(", 
      RowBox[{
       RowBox[{"(", 
        RowBox[{"1", "+", "c"}], ")"}], "/", 
       RowBox[{"(", 
        RowBox[{"1", "-", "c"}], ")"}]}], ")"}]}], "]"}]}]}]], "Input",
 CellLabel->
  "In[421]:=",ExpressionUUID->"7d500472-7581-4215-aac0-8ce7d0ff0e27"],

Cell[BoxData[
 RowBox[{
  RowBox[{"planarity", "[", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"qsreffcpts", "[", 
      RowBox[{"[", "1", "]"}], "]"}], ",", 
     RowBox[{"qsreffcpts", "[", 
      RowBox[{"[", "2", "]"}], "]"}], ",", 
     RowBox[{"qsreffcpts", "[", 
      RowBox[{"[", "3", "]"}], "]"}], ",", 
     RowBox[{
      RowBox[{"stellextdual", "[", "c", "]"}], "*", 
      RowBox[{"(", 
       RowBox[{"fcplen", "/", "vtplen"}], ")"}], "*", 
      RowBox[{"qsrefpts", "[", 
       RowBox[{"[", "3", "]"}], "]"}]}]}], "}"}], "]"}], " ", "//", " ", 
  "Factor"}]], "Input",
 CellLabel->
  "In[422]:=",ExpressionUUID->"6eef97b6-c09d-4892-be06-9ca1217ddae4"],

Cell[BoxData[
 RowBox[{"(*", " ", 
  RowBox[{
   RowBox[{"Pentagram", " ", "--"}], " ", "use", " ", "relative", " ", 
   "lengths", " ", "in", " ", "the", " ", "stellated", " ", "ones"}], " ", 
  "*)"}]], "Input",
 CellLabel->
  "In[423]:=",ExpressionUUID->"53bc0e14-fd89-4905-bf66-69523cc9c86c"],

Cell[BoxData[
 RowBox[{
  RowBox[{"eps2", " ", "=", " ", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"0", ",", "1"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"-", "1"}], ",", "0"}], "}"}]}], "}"}]}], ";"}]], "Input",
 CellLabel->
  "In[424]:=",ExpressionUUID->"3cfe0105-bd2e-4f4d-9e5f-c7c42e7b425d"],

Cell[BoxData[
 RowBox[{
  RowBox[{"ptpts", " ", "=", " ", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"c", ",", 
       RowBox[{"-", 
        RowBox[{"Sqrt", "[", 
         RowBox[{"1", "-", 
          RowBox[{"c", "^", "2"}]}], "]"}]}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"1", ",", "0"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"c", ",", 
       RowBox[{"Sqrt", "[", 
        RowBox[{"1", "-", 
         RowBox[{"c", "^", "2"}]}], "]"}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{
        RowBox[{"2", 
         RowBox[{"c", "^", "2"}]}], "-", "1"}], ",", 
       RowBox[{"2", "c", "*", 
        RowBox[{"Sqrt", "[", 
         RowBox[{"1", "-", 
          RowBox[{"c", "^", "2"}]}], "]"}]}]}], "}"}]}], "}"}]}], 
  ";"}]], "Input",
 CellLabel->
  "In[425]:=",ExpressionUUID->"13ed6650-83cc-42a3-b4ef-cbb58ead0c9c"],

Cell[BoxData[
 RowBox[{
  RowBox[{"ptisc", " ", "=", " ", 
   RowBox[{"c", "*", 
    RowBox[{"{", 
     RowBox[{"1", ",", 
      RowBox[{
       RowBox[{"Sqrt", "[", 
        RowBox[{"1", "-", 
         RowBox[{"c", "^", "2"}]}], "]"}], "/", 
       RowBox[{"(", 
        RowBox[{"1", "+", "c"}], ")"}]}]}], "}"}]}]}], ";"}]], "Input",
 CellLabel->
  "In[426]:=",ExpressionUUID->"845f53aa-8eba-4e47-886d-68a34bc14f4f"],

Cell[BoxData[
 RowBox[{
  RowBox[{"Table", "[", 
   RowBox[{
    RowBox[{
     RowBox[{"(", 
      RowBox[{"ptisc", " ", "-", " ", 
       RowBox[{"ptpts", "[", 
        RowBox[{"[", "k", "]"}], "]"}]}], ")"}], ".", "eps2", ".", 
     RowBox[{"(", 
      RowBox[{"ptisc", " ", "-", " ", 
       RowBox[{"ptpts", "[", 
        RowBox[{"[", 
         RowBox[{"k", "+", "2"}], "]"}], "]"}]}], ")"}]}], ",", 
    RowBox[{"{", 
     RowBox[{"k", ",", "1", ",", "2"}], "}"}]}], "]"}], " ", "//", " ", 
  "Factor"}]], "Input",
 CellLabel->
  "In[427]:=",ExpressionUUID->"552a15c7-a731-40e5-8c99-0fa10da09669"],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{
    RowBox[{
     RowBox[{"(", 
      RowBox[{"2", "c"}], ")"}], "^", "2"}], "*", 
    RowBox[{"abssqr", "[", 
     RowBox[{"ptisc", " ", "-", " ", 
      RowBox[{"ptpts", "[", 
       RowBox[{"[", "2", "]"}], "]"}]}], "]"}]}], " ", "-", " ", 
   RowBox[{
    RowBox[{"(", 
     RowBox[{"2", "*", 
      RowBox[{"ptisc", "[", 
       RowBox[{"[", "2", "]"}], "]"}]}], ")"}], "^", "2"}]}], " ", "//", " ", 
  "Factor"}]], "Input",
 CellLabel->
  "In[428]:=",ExpressionUUID->"a7859b31-2270-42e3-b057-8efdd35b4ff7"],

Cell[BoxData[
 RowBox[{"(*", " ", 
  RowBox[{
   RowBox[{"(", 
    RowBox[{"Star", "-", 
     RowBox[{"point", " ", "base"}], "-", "to", "-", "base"}], ")"}], " ", 
   "=", " ", 
   RowBox[{
    RowBox[{"(", 
     RowBox[{"2", "c"}], ")"}], " ", "*", " ", 
    RowBox[{"(", 
     RowBox[{"star", "-", 
      RowBox[{"point", " ", "base"}], "-", "to", "-", "peak"}], ")"}]}]}], 
  " ", "*)"}]], "Input",
 CellLabel->
  "In[429]:=",ExpressionUUID->"e4fbbb2f-49ef-4e62-a95a-bf47517be2d3"],

Cell[BoxData[
 RowBox[{"(*", " ", 
  RowBox[{"Small", " ", "Stellated", " ", "Dodecahedron"}], " ", 
  "*)"}]], "Input",
 CellLabel->
  "In[430]:=",ExpressionUUID->"547028a9-b62a-4708-a61b-539a2ac19837"],

Cell[BoxData[
 RowBox[{
  RowBox[{"stelloutdual", "[", "c_", "]"}], " ", ":=", " ", 
  RowBox[{
   RowBox[{"(", 
    RowBox[{
     RowBox[{"(", 
      RowBox[{"1", "+", "c"}], ")"}], "/", 
     RowBox[{"(", 
      RowBox[{"3", "c"}], ")"}]}], ")"}], "/", 
   RowBox[{"Sqrt", "[", 
    RowBox[{
     RowBox[{"(", 
      RowBox[{"1", "/", "3"}], ")"}], "*", 
     RowBox[{"(", 
      RowBox[{
       RowBox[{"(", 
        RowBox[{"1", "+", "c"}], ")"}], "/", 
       RowBox[{"(", 
        RowBox[{"1", "-", "c"}], ")"}]}], ")"}]}], "]"}]}]}]], "Input",
 CellLabel->
  "In[431]:=",ExpressionUUID->"ad869f16-404e-4a5e-8f47-02ed59f99eb2"],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{
    RowBox[{
     RowBox[{"(", 
      RowBox[{"2", "c"}], ")"}], "^", "2"}], "*", 
    RowBox[{"abssqr", "[", 
     RowBox[{
      RowBox[{
       RowBox[{"stelloutdual", "[", "c", "]"}], "*", 
       RowBox[{"(", 
        RowBox[{"fcplen", "/", "vtplen"}], ")"}], "*", 
       RowBox[{"qsrefpts", "[", 
        RowBox[{"[", "1", "]"}], "]"}]}], " ", "-", " ", 
      RowBox[{"qsreffcpts", "[", 
       RowBox[{"[", "1", "]"}], "]"}]}], "]"}]}], " ", "-", " ", 
   RowBox[{"abssqr", "[", 
    RowBox[{
     RowBox[{"qsreffcpts", "[", 
      RowBox[{"[", "2", "]"}], "]"}], " ", "-", " ", 
     RowBox[{"qsreffcpts", "[", 
      RowBox[{"[", "1", "]"}], "]"}]}], "]"}]}], " ", "//", " ", 
  "Factor"}]], "Input",
 CellLabel->
  "In[432]:=",ExpressionUUID->"87c823b8-cd7b-4ebd-822b-d913b8d78282"],

Cell[BoxData[
 RowBox[{"(*", " ", 
  RowBox[{"Great", " ", "Stellated", " ", "Dodecahedron"}], " ", 
  "*)"}]], "Input",
 CellLabel->
  "In[433]:=",ExpressionUUID->"b331d7e6-e229-4882-b77b-d3ebd4c862cc"],

Cell[BoxData[
 RowBox[{
  RowBox[{"stellouttri", "[", "c_", "]"}], " ", ":=", " ", 
  RowBox[{
   RowBox[{"(", 
    RowBox[{"1", " ", "+", " ", 
     RowBox[{
      RowBox[{"Sqrt", "[", 
       RowBox[{"2", 
        RowBox[{"(", 
         RowBox[{"3", "-", 
          RowBox[{"3", "c"}], "-", 
          RowBox[{"10", 
           RowBox[{"c", "^", "2"}]}], "+", 
          RowBox[{"4", 
           RowBox[{"c", "^", "3"}]}], "+", 
          RowBox[{"8", 
           RowBox[{"c", "^", "4"}]}]}], ")"}]}], "]"}], "/", 
      RowBox[{"(", 
       RowBox[{"2", "c", 
        RowBox[{"(", 
         RowBox[{"1", "+", "c"}], ")"}]}], ")"}]}]}], ")"}], "*", 
   RowBox[{"Sqrt", "[", 
    RowBox[{
     RowBox[{"(", 
      RowBox[{"1", "/", "3"}], ")"}], "*", 
     RowBox[{"(", 
      RowBox[{
       RowBox[{"(", 
        RowBox[{"1", "+", "c"}], ")"}], "/", 
       RowBox[{"(", 
        RowBox[{"1", "-", "c"}], ")"}]}], ")"}]}], "]"}]}]}]], "Input",
 CellLabel->
  "In[434]:=",ExpressionUUID->"835549bf-5baa-41f9-bdc9-75bb500aa060"],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{
    RowBox[{
     RowBox[{"(", 
      RowBox[{"2", "c"}], ")"}], "^", "2"}], "*", 
    RowBox[{"abssqr", "[", 
     RowBox[{
      RowBox[{
       RowBox[{"stellouttri", "[", "c", "]"}], "*", 
       RowBox[{"(", 
        RowBox[{"vtplen", "/", "fcplen"}], ")"}], "*", 
       RowBox[{"qsreffcpts", "[", 
        RowBox[{"[", "1", "]"}], "]"}]}], " ", "-", " ", 
      RowBox[{"qsrefpts", "[", 
       RowBox[{"[", "1", "]"}], "]"}]}], "]"}]}], " ", "-", " ", 
   RowBox[{"abssqr", "[", 
    RowBox[{
     RowBox[{"qsrefpts", "[", 
      RowBox[{"[", "2", "]"}], "]"}], " ", "-", " ", 
     RowBox[{"qsrefpts", "[", 
      RowBox[{"[", "1", "]"}], "]"}]}], "]"}]}], "//", " ", 
  "Factor"}]], "Input",
 CellLabel->
  "In[435]:=",ExpressionUUID->"e8ccef15-ffa5-43e2-900b-327e401d40ad"],

Cell[BoxData[
 RowBox[{"(*", " ", 
  RowBox[{"Great", " ", "Dodecahedron"}], " ", "*)"}]], "Input",
 CellLabel->
  "In[436]:=",ExpressionUUID->"9086a73f-d9ef-47f3-b401-a6ff5484805e"],

Cell[BoxData[
 RowBox[{
  RowBox[{"planarity", "[", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"qsrefpts", "[", 
      RowBox[{"[", "2", "]"}], "]"}], ",", 
     RowBox[{"qsrefpts", "[", 
      RowBox[{"[", "3", "]"}], "]"}], ",", 
     RowBox[{"qsrefpts", "[", 
      RowBox[{"[", "4", "]"}], "]"}], ",", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{
        RowBox[{"(", 
         RowBox[{"3", "c"}], ")"}], "/", 
        RowBox[{"(", 
         RowBox[{"1", "+", "c"}], ")"}]}], ")"}], "*", 
      RowBox[{"qsreffcpts", "[", 
       RowBox[{"[", "1", "]"}], "]"}]}]}], "}"}], "]"}], " ", "//", " ", 
  "Factor"}]], "Input",
 CellLabel->
  "In[437]:=",ExpressionUUID->"29f8160b-8c1c-4dd1-b1c3-447797a0cfba"],

Cell[BoxData[
 RowBox[{
  RowBox[{"stellintri", "[", "c_", "]"}], " ", ":=", " ", 
  RowBox[{
   RowBox[{"(", 
    RowBox[{
     RowBox[{"(", 
      RowBox[{"3", "c"}], ")"}], "/", 
     RowBox[{"(", 
      RowBox[{"1", "+", "c"}], ")"}]}], ")"}], "*", 
   RowBox[{"Sqrt", "[", 
    RowBox[{
     RowBox[{"(", 
      RowBox[{"1", "/", "3"}], ")"}], "*", 
     RowBox[{"(", 
      RowBox[{
       RowBox[{"(", 
        RowBox[{"1", "+", "c"}], ")"}], "/", 
       RowBox[{"(", 
        RowBox[{"1", "-", "c"}], ")"}]}], ")"}]}], "]"}]}]}]], "Input",
 CellLabel->
  "In[438]:=",ExpressionUUID->"2e3b6fc9-0b89-4d3f-9dd1-4c28325bfd62"],

Cell[BoxData[
 RowBox[{"(*", " ", 
  RowBox[{"Great", " ", "Icosahedron"}], " ", "*)"}]], "Input",
 CellLabel->
  "In[439]:=",ExpressionUUID->"acc0acf4-3be4-4c61-90bd-675520aea854"],

Cell[BoxData[
 RowBox[{"(*", " ", 
  RowBox[{"Not", " ", "isohedral"}], " ", "*)"}]], "Input",
 CellLabel->
  "In[440]:=",ExpressionUUID->"d7407db6-7f39-4507-9823-e55163667565"]
}, Closed]],

Cell[CellGroupData[{

Cell["Quads", "Subsubsection",ExpressionUUID->"c7c87f6a-2ee3-4be9-b2a1-bc7b6eafe6a2"],

Cell[BoxData[
 RowBox[{"(*", " ", 
  RowBox[{
   RowBox[{
    RowBox[{"Rhombic", " ", "--"}], " ", "vertex"}], "-", "face", "-", 
   "vertex", "-", "face"}], " ", "*)"}]], "Input",
 CellLabel->
  "In[441]:=",ExpressionUUID->"05d8552a-006d-46f0-b302-4f38096408ad"],

Cell[BoxData[
 RowBox[{
  RowBox[{"rhombfacepts", " ", "=", " ", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"qsrefpts", "[", 
      RowBox[{"[", "1", "]"}], "]"}], ",", 
     RowBox[{
      RowBox[{"3", "/", 
       RowBox[{"(", 
        RowBox[{"2", 
         RowBox[{"(", 
          RowBox[{"1", "+", "c"}], ")"}]}], ")"}]}], "*", 
      RowBox[{"qsreffcpts", "[", 
       RowBox[{"[", "1", "]"}], "]"}]}], ",", 
     RowBox[{"qsrefpts", "[", 
      RowBox[{"[", "3", "]"}], "]"}], ",", 
     RowBox[{
      RowBox[{"3", "/", 
       RowBox[{"(", 
        RowBox[{"2", 
         RowBox[{"(", 
          RowBox[{"1", "+", "c"}], ")"}]}], ")"}]}], "*", 
      RowBox[{"qsreffcpts", "[", 
       RowBox[{"[", "2", "]"}], "]"}]}]}], "}"}]}], ";"}]], "Input",
 CellLabel->
  "In[442]:=",ExpressionUUID->"57df554f-b7ab-49c5-824b-72f7eaa0f9c1"],

Cell[BoxData[
 RowBox[{
  RowBox[{"abssqr", " ", "/@", "  ", "rhombfacepts"}], " ", "//", " ", 
  "Factor"}]], "Input",
 CellLabel->
  "In[443]:=",ExpressionUUID->"3987b307-4417-44cb-a070-2f27337871aa"],

Cell[BoxData[
 RowBox[{"Solve", "[", 
  RowBox[{
   RowBox[{
    RowBox[{"%", "[", 
     RowBox[{"[", "2", "]"}], "]"}], "\[Equal]", "1"}], ",", "c"}], 
  "]"}]], "Input",
 CellLabel->
  "In[444]:=",ExpressionUUID->"fc21301a-14b2-41f3-b78a-95f399cbafd9"],

Cell[BoxData[
 RowBox[{"dicecond", "[", "rhombfacepts", "]"}]], "Input",
 CellLabel->
  "In[445]:=",ExpressionUUID->"0a06a3f4-8b9d-4a6e-9443-b1f884dbfc8d"],

Cell[BoxData[
 RowBox[{"(*", " ", 
  RowBox[{"Octahedron", ":", " ", 
   RowBox[{
   "face", " ", "points", " ", "can", " ", "have", " ", "alternating", " ", 
    "heights"}]}], " ", "*)"}]], "Input",
 CellLabel->
  "In[446]:=",ExpressionUUID->"81539b55-4d1e-4ad1-829d-2c22ba661cf7"],

Cell[BoxData[
 RowBox[{
  RowBox[{"shftrhombfacepts", " ", "=", " ", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{
      RowBox[{"qsrefpts", "[", 
       RowBox[{"[", "1", "]"}], "]"}], ",", 
      RowBox[{
       RowBox[{
        RowBox[{"(", 
         RowBox[{"3", "/", "2"}], ")"}], "/", 
        RowBox[{"(", 
         RowBox[{"1", "-", "q"}], ")"}]}], "*", 
       RowBox[{"qsreffcpts", "[", 
        RowBox[{"[", "1", "]"}], "]"}]}], ",", 
      RowBox[{"qsrefpts", "[", 
       RowBox[{"[", "3", "]"}], "]"}], ",", 
      RowBox[{
       RowBox[{
        RowBox[{"(", 
         RowBox[{"3", "/", "2"}], ")"}], "/", 
        RowBox[{"(", 
         RowBox[{"1", "+", "q"}], ")"}]}], "*", 
       RowBox[{"qsreffcpts", "[", 
        RowBox[{"[", "2", "]"}], "]"}]}]}], "}"}], " ", "/.", " ", 
    RowBox[{"{", 
     RowBox[{"c", "\[Rule]", "0"}], "}"}]}]}], ";"}]], "Input",
 CellLabel->
  "In[447]:=",ExpressionUUID->"a1a49901-66af-4b33-b680-e6753c265420"],

Cell[BoxData[
 RowBox[{"planarity", "[", "shftrhombfacepts", "]"}]], "Input",
 CellLabel->
  "In[448]:=",ExpressionUUID->"b16f1f2f-584a-499a-b7fc-92c52a412310"],

Cell[BoxData[
 RowBox[{"dicecond", "[", "shftrhombfacepts", "]"}]], "Input",
 CellLabel->
  "In[449]:=",ExpressionUUID->"8e124213-4d22-42e5-b837-c830bbc9e878"],

Cell[BoxData[
 RowBox[{"(*", " ", 
  RowBox[{"Kites", " ", "/", " ", "Deltoids"}], " ", "*)"}]], "Input",
 CellLabel->
  "In[450]:=",ExpressionUUID->"2a1499e9-8313-4b8a-b11b-fe4dabd03cd4"],

Cell[BoxData[
 RowBox[{
  RowBox[{"kitefacepts", " ", "=", " ", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"qsrefpts", "[", 
      RowBox[{"[", "1", "]"}], "]"}], ",", 
     RowBox[{"4", "*", 
      RowBox[{"q", "/", 
       RowBox[{"(", 
        RowBox[{"1", "+", "q"}], ")"}]}], "*", 
      RowBox[{"qsrefedpts", "[", 
       RowBox[{"[", "1", "]"}], "]"}]}], ",", 
     RowBox[{"3", "*", "q", "*", 
      RowBox[{"qsreffcpts", "[", 
       RowBox[{"[", "1", "]"}], "]"}]}], ",", 
     RowBox[{"4", "*", 
      RowBox[{"q", "/", 
       RowBox[{"(", 
        RowBox[{"1", "+", "q"}], ")"}]}], "*", 
      RowBox[{"qsrefedpts", "[", 
       RowBox[{"[", "2", "]"}], "]"}]}]}], "}"}]}], ";"}]], "Input",
 CellLabel->
  "In[451]:=",ExpressionUUID->"e36c6e8c-7101-49b4-998c-c76b9a2c50af"],

Cell[BoxData[
 RowBox[{"planarity", "[", "kitefacepts", "]"}]], "Input",
 CellLabel->
  "In[452]:=",ExpressionUUID->"c95d50c9-6e1e-485b-abe1-b4bde5e2730d"],

Cell[BoxData[
 RowBox[{
  RowBox[{"abssqr", " ", "/@", " ", "kitefacepts"}], " ", "//", " ", 
  "Factor"}]], "Input",
 CellLabel->
  "In[453]:=",ExpressionUUID->"68bd3bec-af3b-4908-9de2-3eaa528199d5"],

Cell[BoxData[
 RowBox[{"(*", " ", 
  RowBox[{"dicecond", "-", " ", 
   RowBox[{"a", " ", "cubic", " ", "equation", " ", "in", " ", "q"}]}], " ", 
  "*)"}]], "Input",
 CellLabel->
  "In[454]:=",ExpressionUUID->"ede92f56-9099-47ed-a8ac-f15ed801beb6"],

Cell[BoxData[
 RowBox[{"(*", " ", 
  RowBox[{"Octahedron", ":", " ", 
   RowBox[{
   "edge", " ", "points", " ", "can", " ", "have", " ", "alternating", " ", 
    "shifts", " ", "to", " ", "and", " ", "from", " ", "vertices"}]}], " ", 
  "*)"}]], "Input",
 CellLabel->
  "In[455]:=",ExpressionUUID->"6f0d9760-dd70-4b8c-bece-3912f1c59e03"],

Cell[BoxData[
 RowBox[{
  RowBox[{"shftkitefacepts", " ", "=", " ", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{
      RowBox[{"qsrefpts", "[", 
       RowBox[{"[", "1", "]"}], "]"}], ",", 
      RowBox[{"2", "*", 
       RowBox[{"q", "/", 
        RowBox[{"(", 
         RowBox[{
          RowBox[{"(", 
           RowBox[{"1", "-", 
            RowBox[{"f", "^", "2"}]}], ")"}], "+", 
          RowBox[{
           RowBox[{"(", 
            RowBox[{"1", "+", 
             RowBox[{"3", 
              RowBox[{"f", "^", "2"}]}]}], ")"}], "q"}]}], ")"}]}], 
       RowBox[{"(", 
        RowBox[{
         RowBox[{
          RowBox[{"(", 
           RowBox[{"1", "+", "f"}], ")"}], "*", 
          RowBox[{"qsrefpts", "[", 
           RowBox[{"[", "1", "]"}], "]"}]}], "+", 
         RowBox[{
          RowBox[{"(", 
           RowBox[{"1", "-", "f"}], ")"}], "*", 
          RowBox[{"qsrefpts", "[", 
           RowBox[{"[", "2", "]"}], "]"}]}]}], ")"}]}], ",", 
      RowBox[{"3", "*", "q", "*", 
       RowBox[{"qsreffcpts", "[", 
        RowBox[{"[", "1", "]"}], "]"}]}], ",", 
      RowBox[{"2", "*", 
       RowBox[{"q", "/", 
        RowBox[{"(", 
         RowBox[{
          RowBox[{"(", 
           RowBox[{"1", "-", 
            RowBox[{"f", "^", "2"}]}], ")"}], "+", 
          RowBox[{
           RowBox[{"(", 
            RowBox[{"1", "+", 
             RowBox[{"3", 
              RowBox[{"f", "^", "2"}]}]}], ")"}], "q"}]}], ")"}]}], 
       RowBox[{"(", 
        RowBox[{
         RowBox[{
          RowBox[{"(", 
           RowBox[{"1", "-", "f"}], ")"}], "*", 
          RowBox[{"qsrefpts", "[", 
           RowBox[{"[", "1", "]"}], "]"}]}], "+", 
         RowBox[{
          RowBox[{"(", 
           RowBox[{"1", "+", "f"}], ")"}], "*", 
          RowBox[{"qsrefpts", "[", 
           RowBox[{"[", "3", "]"}], "]"}]}]}], ")"}]}]}], "}"}], " ", "/.", 
    " ", 
    RowBox[{"{", 
     RowBox[{"c", "\[Rule]", "0"}], "}"}]}]}], ";"}]], "Input",
 CellLabel->
  "In[456]:=",ExpressionUUID->"b43db246-46f3-401b-8fd5-b4e507042647"],

Cell[BoxData[
 RowBox[{"planarity", "[", "shftkitefacepts", "]"}]], "Input",
 CellLabel->
  "In[457]:=",ExpressionUUID->"1c6145fb-1d82-4bb1-bc48-462c84c8d989"]
}, Closed]],

Cell[CellGroupData[{

Cell["Pentagons", "Subsubsection",ExpressionUUID->"7d3ad87e-0798-4953-a731-65d4bbe00a60"],

Cell[BoxData[
 RowBox[{"(*", " ", 
  RowBox[{
   RowBox[{
    RowBox[{
    "Pentagonal", " ", "shapes", " ", "for", " ", "trifaced", " ", 
     "polyhedra"}], ";", " ", 
    RowBox[{
     RowBox[{"these", " ", "have", " ", "two", " ", "mirror"}], "-", 
     RowBox[{"image", " ", "or", " ", "chiral", " ", "forms"}]}], ";", " ", 
    RowBox[{
     RowBox[{"what", "'"}], "s", " ", "here", " ", "is", " ", "one", " ", 
     "of", " ", 
     RowBox[{"them", ".", " ", "By"}], " ", "symmetry"}]}], ",", " ", 
   RowBox[{
   "the", " ", "fourth", " ", "point", " ", "is", " ", "in", " ", "the", " ", 
    "center", " ", "of", " ", "the", " ", "face"}]}], " ", "*)"}]], "Input",
 CellLabel->
  "In[458]:=",ExpressionUUID->"100f3d38-9f27-41f3-815c-2c097a40e538"],

Cell[BoxData[
 RowBox[{
  RowBox[{"pntgptssubs", " ", "=", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"q1", "\[Rule]", 
      RowBox[{
       RowBox[{"(", 
        RowBox[{"qx", "*", 
         RowBox[{"(", 
          RowBox[{
           RowBox[{"4", 
            RowBox[{"(", 
             RowBox[{"2", "+", "c"}], ")"}], 
            RowBox[{"q", "^", "2"}]}], "-", 
           RowBox[{"3", 
            RowBox[{"(", 
             RowBox[{"5", "+", 
              RowBox[{"2", "c"}]}], ")"}], "*", "q", "*", "qx"}], "+", 
           RowBox[{"9", 
            RowBox[{"qx", "^", "2"}]}], "-", 
           RowBox[{
            RowBox[{"(", 
             RowBox[{"3", "-", 
              RowBox[{"2", "c"}]}], ")"}], 
            RowBox[{"q", "^", "2"}], "*", "qx"}], "+", 
           RowBox[{
            RowBox[{"q", "^", "2"}], "*", 
            RowBox[{"qx", "^", "2"}]}]}], ")"}]}], ")"}], "/", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{"8", 
          RowBox[{"(", 
           RowBox[{"1", "+", "c"}], ")"}], 
          RowBox[{"q", "^", "2"}]}], "-", 
         RowBox[{"12", 
          RowBox[{"(", 
           RowBox[{"1", "+", "c"}], ")"}], "q", "*", "qx"}], "+", 
         RowBox[{"9", 
          RowBox[{"qx", "^", "2"}]}], "-", 
         RowBox[{"4", 
          RowBox[{"(", 
           RowBox[{"1", "+", "c"}], ")"}], 
          RowBox[{"q", "^", "2"}], "*", "qx"}], "-", 
         RowBox[{"3", 
          RowBox[{"(", 
           RowBox[{"1", "-", 
            RowBox[{"2", "c"}]}], ")"}], "q", "*", 
          RowBox[{"qx", "^", "2"}]}], "+", 
         RowBox[{"2", 
          RowBox[{"(", 
           RowBox[{"1", "+", "c"}], ")"}], 
          RowBox[{"q", "^", "2"}], "*", 
          RowBox[{"qx", "^", "2"}]}]}], ")"}]}]}], ",", 
     RowBox[{"q2", "\[Rule]", 
      RowBox[{
       RowBox[{"(", 
        RowBox[{"q", "*", 
         RowBox[{"(", 
          RowBox[{
           RowBox[{"-", "1"}], "+", "qx"}], ")"}], "*", "qx", "*", 
         RowBox[{"(", 
          RowBox[{
           RowBox[{"4", "c", "*", "q"}], "-", 
           RowBox[{"3", "qx"}], "+", 
           RowBox[{"q", "*", "qx"}]}], ")"}]}], ")"}], "/", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{"8", 
          RowBox[{"(", 
           RowBox[{"1", "+", "c"}], ")"}], 
          RowBox[{"q", "^", "2"}]}], "-", 
         RowBox[{"12", 
          RowBox[{"(", 
           RowBox[{"1", "+", "c"}], ")"}], "q", "*", "qx"}], "+", 
         RowBox[{"9", 
          RowBox[{"qx", "^", "2"}]}], "-", 
         RowBox[{"4", 
          RowBox[{"(", 
           RowBox[{"1", "+", "c"}], ")"}], 
          RowBox[{"q", "^", "2"}], "*", "qx"}], "-", 
         RowBox[{"3", 
          RowBox[{"(", 
           RowBox[{"1", "-", 
            RowBox[{"2", "c"}]}], ")"}], "q", "*", 
          RowBox[{"qx", "^", "2"}]}], "+", 
         RowBox[{"2", 
          RowBox[{"(", 
           RowBox[{"1", "+", "c"}], ")"}], 
          RowBox[{"q", "^", "2"}], "*", 
          RowBox[{"qx", "^", "2"}]}]}], ")"}]}]}], ",", 
     RowBox[{"q3", "\[Rule]", 
      RowBox[{
       RowBox[{"(", 
        RowBox[{"q", "*", 
         RowBox[{"(", 
          RowBox[{
           RowBox[{"-", "1"}], "+", "qx"}], ")"}], "*", "qx", "*", 
         RowBox[{"(", 
          RowBox[{
           RowBox[{
            RowBox[{"-", "4"}], "q"}], "+", 
           RowBox[{"3", "qx"}], "+", 
           RowBox[{"q", "*", "qx"}]}], ")"}]}], ")"}], "/", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{"8", 
          RowBox[{"(", 
           RowBox[{"1", "+", "c"}], ")"}], 
          RowBox[{"q", "^", "2"}]}], "-", 
         RowBox[{"12", 
          RowBox[{"(", 
           RowBox[{"1", "+", "c"}], ")"}], "q", "*", "qx"}], "+", 
         RowBox[{"9", 
          RowBox[{"qx", "^", "2"}]}], "-", 
         RowBox[{"4", 
          RowBox[{"(", 
           RowBox[{"1", "+", "c"}], ")"}], 
          RowBox[{"q", "^", "2"}], "*", "qx"}], "-", 
         RowBox[{"3", 
          RowBox[{"(", 
           RowBox[{"1", "-", 
            RowBox[{"2", "c"}]}], ")"}], "q", "*", 
          RowBox[{"qx", "^", "2"}]}], "+", 
         RowBox[{"2", 
          RowBox[{"(", 
           RowBox[{"1", "+", "c"}], ")"}], 
          RowBox[{"q", "^", "2"}], "*", 
          RowBox[{"qx", "^", "2"}]}]}], ")"}]}]}]}], "}"}]}], ";"}]], "Input",\

 CellLabel->
  "In[459]:=",ExpressionUUID->"b9a4241c-baa1-4822-b1a7-3ec31a2641ac"],

Cell[BoxData[
 RowBox[{
  RowBox[{"pntgfacepts", " ", "=", " ", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{
      RowBox[{"qsrefpts", "[", 
       RowBox[{"[", "1", "]"}], "]"}], ",", 
      RowBox[{
       RowBox[{"q1", "*", 
        RowBox[{"qsrefpts", "[", 
         RowBox[{"[", "1", "]"}], "]"}]}], "+", 
       RowBox[{"q2", "*", 
        RowBox[{"qsrefpts", "[", 
         RowBox[{"[", "2", "]"}], "]"}]}], "+", 
       RowBox[{"q3", "*", 
        RowBox[{"qsrefpts", "[", 
         RowBox[{"[", "3", "]"}], "]"}]}]}], ",", 
      RowBox[{"q", "*", 
       RowBox[{"qsreffcpts", "[", 
        RowBox[{"[", "1", "]"}], "]"}]}], ",", 
      RowBox[{
       RowBox[{"q1", "*", 
        RowBox[{"qsrefpts", "[", 
         RowBox[{"[", "3", "]"}], "]"}]}], "+", 
       RowBox[{"q2", "*", 
        RowBox[{"qsrefpts", "[", 
         RowBox[{"[", "1", "]"}], "]"}]}], "+", 
       RowBox[{"q3", "*", 
        RowBox[{"qsrefpts", "[", 
         RowBox[{"[", "2", "]"}], "]"}]}]}], ",", 
      RowBox[{
       RowBox[{"q1", "*", 
        RowBox[{"qsrefpts", "[", 
         RowBox[{"[", "1", "]"}], "]"}]}], "+", 
       RowBox[{"q2", "*", 
        RowBox[{"qsrefpts", "[", 
         RowBox[{"[", "3", "]"}], "]"}]}], "+", 
       RowBox[{"q3", "*", 
        RowBox[{"qsrefpts", "[", 
         RowBox[{"[", "4", "]"}], "]"}]}]}]}], "}"}], " ", "/.", " ", 
    "pntgptssubs"}]}], ";"}]], "Input",
 CellLabel->
  "In[460]:=",ExpressionUUID->"c278f4be-17cd-477a-80df-c768c7acd55a"],

Cell[BoxData[
 RowBox[{"planarity", "[", "pntgfacepts", "]"}]], "Input",
 CellLabel->
  "In[461]:=",ExpressionUUID->"8992c98c-783c-44b6-8178-c07df4d46425"],

Cell[BoxData[
 RowBox[{"(*", " ", 
  RowBox[{
   RowBox[{"Side", "-", 
    RowBox[{"length", " ", 
     RowBox[{"squared", ":", " ", 
      RowBox[{"1", "-", "2"}]}]}]}], ",", " ", 
   RowBox[{"2", "-", "3"}], ",", " ", 
   RowBox[{"3", "-", "4"}], ",", " ", 
   RowBox[{"4", "-", "5"}], ",", " ", 
   RowBox[{"5", "-", "1"}]}], " ", "*)"}]], "Input",
 CellLabel->
  "In[462]:=",ExpressionUUID->"0ab23921-23ac-4c15-9f56-2c2f99fe5da5"],

Cell[BoxData[
 RowBox[{
  RowBox[{"pntgsdlnsqs", " ", "=", " ", 
   RowBox[{"polysidelensqs", "[", "pntgfacepts", "]"}]}], ";"}]], "Input",
 CellLabel->
  "In[463]:=",ExpressionUUID->"b8ca592c-e74e-41ad-bf9a-625500a7df47"],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"pntgsdlnsqs", "[", 
    RowBox[{"[", "5", "]"}], "]"}], "-", 
   RowBox[{"pntgsdlnsqs", "[", 
    RowBox[{"[", "1", "]"}], "]"}]}], "//", " ", "Factor"}]], "Input",
 CellLabel->
  "In[464]:=",ExpressionUUID->"7d096c03-898e-4ec2-8043-52d76189d403"],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"pntgsdlnsqs", "[", 
    RowBox[{"[", "3", "]"}], "]"}], "-", 
   RowBox[{"pntgsdlnsqs", "[", 
    RowBox[{"[", "2", "]"}], "]"}]}], "//", " ", "Factor"}]], "Input",
 CellLabel->
  "In[465]:=",ExpressionUUID->"a5775247-330f-4b19-a335-90564f213357"],

Cell[BoxData[
 RowBox[{"(*", " ", 
  RowBox[{
   RowBox[{"Side", "-", 
    RowBox[{"angle", " ", 
     RowBox[{"squared", ":", " ", 
      RowBox[{"1", "-", "2", "-", "3"}]}]}]}], ",", " ", 
   RowBox[{"2", "-", "3", "-", "4"}], ",", " ", 
   RowBox[{"3", "-", "4", "-", "5"}], ",", " ", 
   RowBox[{"4", "-", "5", "-", "1"}], ",", " ", 
   RowBox[{"5", "-", "1", "-", "2"}]}], " ", "*)"}]], "Input",
 CellLabel->
  "In[466]:=",ExpressionUUID->"30ca033b-77e6-4bcb-bb16-54e95046722d"],

Cell[BoxData[
 RowBox[{
  RowBox[{"pntgangsqs", " ", "=", " ", 
   RowBox[{"polysidecsangsqs", "[", "pntgfacepts", "]"}]}], ";"}]], "Input",
 CellLabel->
  "In[467]:=",ExpressionUUID->"c6d74392-5c25-4fad-bf7c-ec0ccc7fa62a"],

Cell[BoxData[
 RowBox[{"(*", " ", 
  RowBox[{
  "For", " ", "making", " ", "center", " ", "points", " ", "the", " ", "same",
    " ", "lengths", " ", "as", " ", "the", " ", "vertices"}], " ", 
  "*)"}]], "Input",
 CellLabel->
  "In[468]:=",ExpressionUUID->"115999e8-f4f0-41bb-a2c5-4963f6c2b18e"],

Cell[BoxData[
 RowBox[{
  RowBox[{"fcctoq", "[", "c_", "]"}], " ", ":=", " ", 
  RowBox[{
   RowBox[{"Sqrt", "[", "3", "]"}], "*", 
   RowBox[{"Sqrt", "[", 
    RowBox[{
     RowBox[{"(", 
      RowBox[{"1", "-", "c"}], ")"}], "/", 
     RowBox[{"(", 
      RowBox[{"1", "+", "c"}], ")"}]}], "]"}]}]}]], "Input",
 CellLabel->
  "In[469]:=",ExpressionUUID->"6fe91eed-d3a7-4d41-999e-2e33a21dc924"],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"fcqtoc", "[", "q_", "]"}], " ", ":=", " ", 
   RowBox[{
    RowBox[{"(", 
     RowBox[{"3", "-", 
      RowBox[{"q", "^", "2"}]}], ")"}], "/", 
    RowBox[{"(", 
     RowBox[{"3", "+", 
      RowBox[{"q", "^", "2"}]}], ")"}]}]}], ";"}]], "Input",
 CellLabel->
  "In[470]:=",ExpressionUUID->"602fcee0-ed1d-4dbd-b909-96791395705e"],

Cell[BoxData[
 RowBox[{"Refine", "[", 
  RowBox[{
   RowBox[{
    RowBox[{"fcctoq", "[", 
     RowBox[{"fcqtoc", "[", "q", "]"}], "]"}], " ", "//", " ", "Factor"}], 
   ",", 
   RowBox[{"q", ">", "0"}]}], "]"}]], "Input",
 CellLabel->
  "In[471]:=",ExpressionUUID->"6f2bbff9-47c1-4aaa-b2e9-7060e148f94b"],

Cell[BoxData[
 RowBox[{
  RowBox[{"fcqtoc", "[", 
   RowBox[{"fcctoq", "[", "c", "]"}], "]"}], " ", "//", " ", 
  "Factor"}]], "Input",
 CellLabel->
  "In[472]:=",ExpressionUUID->"b6b684ca-ac4a-4fa7-b81f-2f6cd3f567e6"],

Cell[BoxData[
 RowBox[{"(*", " ", 
  RowBox[{
  "All", " ", "vertices", " ", "with", " ", "the", " ", "same", " ", 
   "distance"}], " ", "*)"}]], "Input",
 CellLabel->
  "In[473]:=",ExpressionUUID->"b20200a6-bee7-4a88-a04e-670f8dd2e302"],

Cell[BoxData[
 RowBox[{"Union", "[", 
  RowBox[{"subfirst", "[", 
   RowBox[{"abssqr", " ", "/@", " ", 
    RowBox[{"(", 
     RowBox[{"pntgfacepts", " ", "/.", " ", 
      RowBox[{"c", "\[Rule]", 
       RowBox[{"fcqtoc", "[", "q", "]"}]}]}], ")"}]}], "]"}], "]"}]], "Input",\

 CellLabel->
  "In[474]:=",ExpressionUUID->"2a2b5870-09c4-4c3a-90e2-5d110fa941ee"],

Cell[BoxData[
 RowBox[{"pntgqxsols", " ", "=", " ", 
  RowBox[{"MapAll", "[", 
   RowBox[{"Factor", ",", 
    RowBox[{"Refine", "[", 
     RowBox[{
      RowBox[{"MapAll", "[", 
       RowBox[{"Factor", ",", 
        RowBox[{"Solve", "[", 
         RowBox[{
          RowBox[{
           RowBox[{"%", "[", 
            RowBox[{"[", "2", "]"}], "]"}], "\[Equal]", "0"}], ",", "qx"}], 
         "]"}]}], "]"}], ",", 
      RowBox[{"q", ">", "1"}]}], "]"}]}], "]"}]}]], "Input",
 CellLabel->
  "In[475]:=",ExpressionUUID->"4efe30f8-9296-43ed-9121-6025f673a932"],

Cell[BoxData[
 RowBox[{"Table", "[", 
  RowBox[{
   RowBox[{
    RowBox[{"(", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{
        RowBox[{"(", 
         RowBox[{
          RowBox[{"{", 
           RowBox[{
            RowBox[{"q", "*", 
             RowBox[{"fcplen", "/", "vtplen"}]}], ",", "q1", ",", "q2", ",", 
            "q3"}], "}"}], " ", "/.", " ", "pntgptssubs"}], ")"}], " ", "/.", 
        " ", 
        RowBox[{"Last", "[", "pntgqxsols", "]"}]}], ")"}], " ", "/.", " ", 
      RowBox[{"q", "->", 
       RowBox[{"fcctoq", "[", "c", "]"}]}]}], ")"}], " ", "/.", " ", 
    RowBox[{"c", "\[Rule]", 
     RowBox[{"N", "[", 
      RowBox[{"cval", "[", "k", "]"}], "]"}]}]}], ",", 
   RowBox[{"{", 
    RowBox[{"k", ",", "3", ",", "5"}], "}"}]}], "]"}]], "Input",
 CellLabel->
  "In[476]:=",ExpressionUUID->"58df900c-7c19-4aca-b288-0f6f2b103f59"],

Cell[BoxData[
 RowBox[{"(*", " ", 
  RowBox[{
  "The", " ", "last", " ", "two", " ", "solutions", " ", "are", " ", "the", 
   " ", "desired", " ", "ones"}], " ", "*)"}]], "Input",
 CellLabel->
  "In[477]:=",ExpressionUUID->"ce47993e-9cc7-46d2-9991-77fd8210803a"],

Cell[BoxData[
 RowBox[{"(*", " ", 
  RowBox[{
   RowBox[{"Tetrahedron", "-", "based"}], ",", " ", 
   RowBox[{"face", " ", "centers"}], ",", " ", 
   RowBox[{"vertices", " ", "equal", " ", "length"}]}], " ", "*)"}]], "Input",\

 CellLabel->
  "In[478]:=",ExpressionUUID->"64092e54-47df-483a-b784-d7d8e11fffc7"],

Cell[BoxData[
 RowBox[{
  RowBox[{"ttpntgsdlnsqs", " ", "=", " ", 
   RowBox[{
    RowBox[{"pntgsdlnsqs", " ", "/.", " ", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"c", "\[Rule]", 
        RowBox[{
         RowBox[{"-", "1"}], "/", "2"}]}], ",", 
       RowBox[{"q", "\[Rule]", "3"}]}], "}"}]}], " ", "//", " ", "Factor"}]}],
   ";"}]], "Input",
 CellLabel->
  "In[479]:=",ExpressionUUID->"3317885c-7aca-4e46-beba-a243ad85e303"],

Cell[BoxData[
 RowBox[{
  RowBox[{"ttpntgangsqs", " ", "=", " ", 
   RowBox[{
    RowBox[{"pntgangsqs", " ", "/.", " ", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"c", "\[Rule]", 
        RowBox[{
         RowBox[{"-", "1"}], "/", "2"}]}], ",", 
       RowBox[{"q", "\[Rule]", "3"}]}], "}"}]}], " ", "//", " ", "Factor"}]}],
   ";"}]], "Input",
 CellLabel->
  "In[480]:=",ExpressionUUID->"c40944fb-b6ba-4bb5-bbda-dfdef8dfd592"],

Cell[BoxData["ttpntgsdlnsqs"], "Input",
 CellLabel->
  "In[481]:=",ExpressionUUID->"11dfc007-d62f-49cf-b0ac-adb3f6da5bd5"],

Cell[BoxData["ttpntgangsqs"], "Input",
 CellLabel->
  "In[482]:=",ExpressionUUID->"34ec589d-dd0f-41ce-a644-79e15d85e684"],

Cell[BoxData[
 RowBox[{"(*", " ", 
  RowBox[{
   RowBox[{
    RowBox[{"Degenerate", " ", 
     RowBox[{"case", ":", " ", "pentagon"}]}], " ", "\[Rule]", " ", 
    RowBox[{"half", " ", "a", " ", "square"}]}], ",", " ", 
   RowBox[{"making", " ", "a", " ", "cube"}]}], " ", "*)"}]], "Input",
 CellLabel->
  "In[483]:=",ExpressionUUID->"da9e5f9f-b7eb-4b03-9278-ccf5d2fdacb5"],

Cell[BoxData[
 RowBox[{"ttpntgsdlnsqs", " ", "/.", " ", 
  RowBox[{"qx", "\[Rule]", "1"}]}]], "Input",
 CellLabel->
  "In[484]:=",ExpressionUUID->"8e7db5b8-a048-47a5-a5d0-495458bcc8e8"],

Cell[BoxData[
 RowBox[{"ttpntgangsqs", " ", "/.", " ", 
  RowBox[{"qx", "\[Rule]", "1"}]}]], "Input",
 CellLabel->
  "In[485]:=",ExpressionUUID->"42905a22-c06c-432e-9e11-de1715586f5e"],

Cell[BoxData[
 RowBox[{"(*", " ", 
  RowBox[{
   RowBox[{
    RowBox[{"Degenerate", " ", "case"}], " ", "\[Rule]", " ", 
    RowBox[{"pentagon", " ", "is", " ", "regular"}]}], ",", " ", 
   RowBox[{"making", " ", "a", " ", "regular", " ", "dodecahedron"}]}], " ", 
  "*)"}]], "Input",
 CellLabel->
  "In[486]:=",ExpressionUUID->"68cb4233-8eae-4716-a44a-ecc6e9e235ff"],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"ttpntgsdlnsqs", "[", 
    RowBox[{"[", "4", "]"}], "]"}], "-", 
   RowBox[{"ttpntgsdlnsqs", "[", 
    RowBox[{"[", "1", "]"}], "]"}]}], " ", "//", " ", "Factor"}]], "Input",
 CellLabel->
  "In[487]:=",ExpressionUUID->"3ce030e7-6b09-49c6-b352-918f86b0b5fc"],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"ttpntgangsqs", "[", 
    RowBox[{"[", "3", "]"}], "]"}], "-", 
   RowBox[{"ttpntgangsqs", "[", 
    RowBox[{"[", "2", "]"}], "]"}]}], " ", "//", " ", "Factor"}]], "Input",
 CellLabel->
  "In[488]:=",ExpressionUUID->"55ad127b-9dac-4781-ac0c-a0c2e11b9d1d"],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"ttpntgangsqs", "[", 
    RowBox[{"[", "3", "]"}], "]"}], "-", 
   RowBox[{"ttpntgangsqs", "[", 
    RowBox[{"[", "1", "]"}], "]"}]}], " ", "//", " ", "Factor"}]], "Input",
 CellLabel->
  "In[489]:=",ExpressionUUID->"01a68f4b-feee-4c13-80ad-bb6d47c1dbb5"],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"ttpntgangsqs", "[", 
    RowBox[{"[", "2", "]"}], "]"}], "-", 
   RowBox[{"ttpntgangsqs", "[", 
    RowBox[{"[", "1", "]"}], "]"}]}], " ", "//", " ", "Factor"}]], "Input",
 CellLabel->
  "In[490]:=",ExpressionUUID->"bae6da94-5d67-46c4-9f75-3f42c4558c22"],

Cell[BoxData[
 RowBox[{"Reduce", "[", 
  RowBox[{
   RowBox[{
    RowBox[{"-", "1"}], "-", "qx", "+", 
    RowBox[{"qx", "^", "2"}]}], "\[Equal]", "0"}], "]"}]], "Input",
 CellLabel->
  "In[491]:=",ExpressionUUID->"a54913ec-1a8c-4345-ae21-794454ba3e7f"]
}, Closed]]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{

Cell["Models", "Section",ExpressionUUID->"594baf13-3cb0-4d5d-a40e-e1ad023467ff"],

Cell[CellGroupData[{

Cell["Axial", "Subsection",ExpressionUUID->"9563e888-e8a1-432c-8408-61b66528730b"],

Cell[CellGroupData[{

Cell["Bipyramid - Tri Faces", "Subsubsection",ExpressionUUID->"02135073-646d-49d6-bff3-37891dbc10dd"],

Cell[BoxData[
 RowBox[{"(*", " ", 
  RowBox[{
   RowBox[{"Vertices", ":", " ", 
    RowBox[{"north", " ", "pole"}]}], ",", " ", 
   RowBox[{"then", " ", "south", " ", "pole"}], ",", " ", 
   RowBox[{"then", " ", "equatorial", " ", 
    RowBox[{"belt", ".", " ", 
     RowBox[{"Faces", ":", " ", "northern"}]}]}], ",", " ", 
   RowBox[{"southern", "."}]}], " ", "*)"}]], "Input",
 CellLabel->
  "In[492]:=",ExpressionUUID->"d29a79ab-bf90-49ce-bd5e-ce3e3ddb753a"],

Cell[BoxData[
 RowBox[{
  RowBox[{"mdlpolys", "[", 
   RowBox[{"\"\<bipyr\>\"", ",", "n_"}], "]"}], " ", ":=", " ", 
  RowBox[{"Module", "[", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{"k", ",", "kx"}], "}"}], ",", 
    RowBox[{"Join", "[", 
     RowBox[{
      RowBox[{"Table", "[", 
       RowBox[{
        RowBox[{
         RowBox[{"kx", " ", "=", " ", 
          RowBox[{"Mod", "[", 
           RowBox[{
            RowBox[{"k", "+", "1"}], ",", "n"}], "]"}]}], ";", " ", 
         RowBox[{"Polygon", "[", 
          RowBox[{"{", 
           RowBox[{"1", ",", 
            RowBox[{"3", "+", "k"}], ",", 
            RowBox[{"3", "+", "kx"}]}], "}"}], "]"}]}], ",", 
        RowBox[{"{", 
         RowBox[{"k", ",", "0", ",", 
          RowBox[{"n", "-", "1"}]}], "}"}]}], "]"}], ",", 
      RowBox[{"Table", "[", 
       RowBox[{
        RowBox[{
         RowBox[{"kx", " ", "=", " ", 
          RowBox[{"Mod", "[", 
           RowBox[{
            RowBox[{"k", "+", "1"}], ",", "n"}], "]"}]}], ";", " ", 
         RowBox[{"Polygon", "[", 
          RowBox[{"{", 
           RowBox[{"2", ",", 
            RowBox[{"3", "+", "kx"}], ",", 
            RowBox[{"3", "+", "k"}]}], "}"}], "]"}]}], ",", 
        RowBox[{"{", 
         RowBox[{"k", ",", "0", ",", 
          RowBox[{"n", "-", "1"}]}], "}"}]}], "]"}]}], "]"}]}], 
   "\[IndentingNewLine]", "]"}]}]], "Input",
 CellLabel->
  "In[493]:=",ExpressionUUID->"4ddaf949-bb6d-486f-a63b-b51370e2ca8e"],

Cell[BoxData[
 RowBox[{
  RowBox[{"model", "[", 
   RowBox[{"\"\<bipyr\>\"", ",", "n_", ",", "r_", ",", "z_"}], "]"}], " ", ":=",
   " ", 
  RowBox[{"Module", "[", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{"k", ",", "a"}], "}"}], ",", 
    RowBox[{"GraphicsComplex", "[", 
     RowBox[{
      RowBox[{"Join", "[", 
       RowBox[{
        RowBox[{"{", 
         RowBox[{
          RowBox[{"{", 
           RowBox[{"0", ",", "0", ",", "z"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{"0", ",", "0", ",", 
            RowBox[{"-", "z"}]}], "}"}]}], "}"}], ",", 
        RowBox[{"Table", "[", 
         RowBox[{
          RowBox[{
           RowBox[{"a", " ", "=", " ", 
            RowBox[{"2", "Pi", "*", 
             RowBox[{"k", "/", "n"}]}]}], ";", " ", 
           RowBox[{"r", "*", 
            RowBox[{"{", 
             RowBox[{
              RowBox[{"Cos", "[", "a", "]"}], ",", 
              RowBox[{"Sin", "[", "a", "]"}], ",", "0"}], "}"}]}]}], ",", 
          RowBox[{"{", 
           RowBox[{"k", ",", "0", ",", 
            RowBox[{"n", "-", "1"}]}], "}"}]}], "]"}]}], "]"}], ",", 
      RowBox[{"mdlpolys", "[", 
       RowBox[{"\"\<bipyr\>\"", ",", "n"}], "]"}]}], "]"}]}], 
   "\[IndentingNewLine]", "]"}]}]], "Input",
 CellLabel->
  "In[494]:=",ExpressionUUID->"d08ccdbc-7e37-4ed4-9d31-ad2da954d988"],

Cell[BoxData[
 RowBox[{
  RowBox[{"model", "[", 
   RowBox[{"\"\<bipyr\>\"", ",", "n_", ",", "r_"}], "]"}], " ", ":=", " ", 
  RowBox[{"model", "[", 
   RowBox[{"\"\<bipyr\>\"", ",", "n", ",", "r", ",", "r"}], "]"}]}]], "Input",\

 CellLabel->
  "In[495]:=",ExpressionUUID->"b23885b4-811a-43d9-b9e2-d61bba4d1cd5"],

Cell[BoxData[
 RowBox[{
  RowBox[{"model", "[", 
   RowBox[{
   "\"\<bipyr rad\>\"", ",", "n_", ",", "r1_", ",", "r2_", ",", "z_"}], "]"}],
   " ", ":=", " ", 
  RowBox[{"Module", "[", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{"k", ",", "a"}], "}"}], ",", 
    RowBox[{"GraphicsComplex", "[", 
     RowBox[{
      RowBox[{"Join", "[", 
       RowBox[{
        RowBox[{"{", 
         RowBox[{
          RowBox[{"{", 
           RowBox[{"0", ",", "0", ",", "z"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{"0", ",", "0", ",", 
            RowBox[{"-", "z"}]}], "}"}]}], "}"}], ",", 
        RowBox[{"Table", "[", 
         RowBox[{
          RowBox[{
           RowBox[{"a", " ", "=", " ", 
            RowBox[{"Pi", "*", 
             RowBox[{"k", "/", "n"}]}]}], ";", " ", 
           RowBox[{
            RowBox[{"If", "[", 
             RowBox[{
              RowBox[{"EvenQ", "[", "k", "]"}], ",", "r1", ",", "r2"}], "]"}],
             "*", 
            RowBox[{"{", 
             RowBox[{
              RowBox[{"Cos", "[", "a", "]"}], ",", 
              RowBox[{"Sin", "[", "a", "]"}], ",", "0"}], "}"}]}]}], ",", 
          RowBox[{"{", 
           RowBox[{"k", ",", "0", ",", 
            RowBox[{
             RowBox[{"2", "n"}], "-", "1"}]}], "}"}]}], "]"}]}], "]"}], ",", 
      RowBox[{"mdlpolys", "[", 
       RowBox[{"\"\<bipyr\>\"", ",", 
        RowBox[{"2", "n"}]}], "]"}]}], "]"}]}], "\[IndentingNewLine]", 
   "]"}]}]], "Input",
 CellLabel->
  "In[496]:=",ExpressionUUID->"d04345ba-e390-4b66-8891-3111a723ab91"],

Cell[BoxData[
 RowBox[{
  RowBox[{"model", "[", 
   RowBox[{"\"\<bipyr axl\>\"", ",", "n_", ",", "r_", ",", "rz_", ",", "z_"}],
    "]"}], " ", ":=", " ", 
  RowBox[{"Module", "[", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{"k", ",", "a"}], "}"}], ",", 
    RowBox[{"GraphicsComplex", "[", 
     RowBox[{
      RowBox[{"Join", "[", 
       RowBox[{
        RowBox[{"{", 
         RowBox[{
          RowBox[{"{", 
           RowBox[{"0", ",", "0", ",", "z"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{"0", ",", "0", ",", 
            RowBox[{"-", "z"}]}], "}"}]}], "}"}], ",", 
        RowBox[{"Table", "[", 
         RowBox[{
          RowBox[{
           RowBox[{"a", " ", "=", " ", 
            RowBox[{"Pi", "*", 
             RowBox[{"k", "/", "n"}]}]}], ";", 
           RowBox[{"{", 
            RowBox[{
             RowBox[{"r", "*", 
              RowBox[{"Cos", "[", "a", "]"}]}], ",", 
             RowBox[{"r", "*", 
              RowBox[{"Sin", "[", "a", "]"}]}], ",", 
             RowBox[{"rz", "*", 
              RowBox[{"If", "[", 
               RowBox[{
                RowBox[{"EvenQ", "[", "k", "]"}], ",", "1", ",", 
                RowBox[{"-", "1"}]}], "]"}]}]}], "}"}]}], ",", 
          RowBox[{"{", 
           RowBox[{"k", ",", "0", ",", 
            RowBox[{
             RowBox[{"2", "n"}], "-", "1"}]}], "}"}]}], "]"}]}], "]"}], ",", 
      RowBox[{"mdlpolys", "[", 
       RowBox[{"\"\<bipyr\>\"", ",", 
        RowBox[{"2", "n"}]}], "]"}]}], "]"}]}], "\[IndentingNewLine]", 
   "]"}]}]], "Input",
 CellLabel->
  "In[497]:=",ExpressionUUID->"2891504a-b570-4f7a-9e46-9a2502edc6a2"],

Cell[BoxData[
 RowBox[{
  RowBox[{"model", "[", 
   RowBox[{"\"\<bipyr axl\>\"", ",", "n_", ",", "r_", ",", "rz_"}], "]"}], 
  " ", ":=", " ", 
  RowBox[{"model", "[", 
   RowBox[{"\"\<bipyr axl\>\"", ",", "n", ",", "r", ",", "rz", ",", 
    RowBox[{"Sqrt", "[", 
     RowBox[{
      RowBox[{"r", "^", "2"}], "+", 
      RowBox[{"rz", "^", "2"}]}], "]"}]}], "]"}]}]], "Input",
 CellLabel->
  "In[498]:=",ExpressionUUID->"1a53ac45-3d17-4e67-9ee6-cd21ba988eb5"]
}, Closed]],

Cell[CellGroupData[{

Cell["Trapezohedron - Quad Faces", "Subsubsection",ExpressionUUID->"696ef0d8-a346-4efe-9e66-8302d2ded5dc"],

Cell[BoxData[
 RowBox[{"(*", " ", 
  RowBox[{
   RowBox[{"Vertices", ":", " ", 
    RowBox[{"north", " ", "pole"}]}], ",", " ", 
   RowBox[{"then", " ", "south", " ", "pole"}], ",", " ", 
   RowBox[{"then", " ", "northern", " ", "belt"}], ",", " ", 
   RowBox[{"then", " ", "southern", " ", 
    RowBox[{"belt", ".", " ", 
     RowBox[{"Faces", ":", " ", "northern"}]}]}], ",", " ", 
   RowBox[{"southern", "."}]}], " ", "*)"}]], "Input",
 CellLabel->
  "In[499]:=",ExpressionUUID->"046d0ad5-a026-47ad-b357-bdb30791f46d"],

Cell[BoxData[
 RowBox[{
  RowBox[{"mdlpolys", "[", 
   RowBox[{"\"\<tpzdh\>\"", ",", "n_"}], "]"}], " ", ":=", 
  RowBox[{"Module", "[", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{"k", ",", "kx"}], "}"}], ",", 
    RowBox[{"Join", "[", 
     RowBox[{
      RowBox[{"Table", "[", 
       RowBox[{
        RowBox[{
         RowBox[{"kx", " ", "=", " ", 
          RowBox[{"Mod", "[", 
           RowBox[{
            RowBox[{"k", "+", "1"}], ",", "n"}], "]"}]}], ";", " ", 
         RowBox[{"Polygon", "[", 
          RowBox[{"{", 
           RowBox[{"1", ",", 
            RowBox[{"3", "+", "k"}], ",", 
            RowBox[{"n", "+", "3", "+", "k"}], ",", 
            RowBox[{"3", "+", "kx"}]}], "}"}], "]"}]}], ",", 
        RowBox[{"{", 
         RowBox[{"k", ",", "0", ",", 
          RowBox[{"n", "-", "1"}]}], "}"}]}], "]"}], ",", 
      RowBox[{"Table", "[", 
       RowBox[{
        RowBox[{
         RowBox[{"kx", " ", "=", " ", 
          RowBox[{"Mod", "[", 
           RowBox[{
            RowBox[{"k", "+", "1"}], ",", "n"}], "]"}]}], ";", " ", 
         RowBox[{"Polygon", "[", 
          RowBox[{"{", 
           RowBox[{"2", ",", 
            RowBox[{"n", "+", "3", "+", "kx"}], ",", 
            RowBox[{"3", "+", "kx"}], ",", 
            RowBox[{"n", "+", "3", "+", "k"}]}], "}"}], "]"}]}], ",", 
        RowBox[{"{", 
         RowBox[{"k", ",", "0", ",", 
          RowBox[{"n", "-", "1"}]}], "}"}]}], "]"}]}], "]"}]}], 
   "\[IndentingNewLine]", "]"}]}]], "Input",
 CellLabel->
  "In[500]:=",ExpressionUUID->"082839f8-8e12-463d-b4a4-82df89f397d1"],

Cell[BoxData[
 RowBox[{
  RowBox[{"model", "[", 
   RowBox[{"\"\<tpzdh skw\>\"", ",", "n_", ",", "r_", ",", "z_", ",", "f_"}], 
   "]"}], " ", ":=", " ", 
  RowBox[{"Module", "[", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{"k", ",", "a", ",", "rz"}], "}"}], ",", "\[IndentingNewLine]", 
    RowBox[{
     RowBox[{"rz", " ", "=", " ", 
      RowBox[{"z", "*", 
       RowBox[{"Tan", "[", 
        RowBox[{
         RowBox[{"(", 
          RowBox[{"1", "+", "f"}], ")"}], 
         RowBox[{"Pi", "/", 
          RowBox[{"(", 
           RowBox[{"2", "n"}], ")"}]}]}], "]"}], "*", 
       RowBox[{"Tan", "[", 
        RowBox[{
         RowBox[{"(", 
          RowBox[{"1", "-", "f"}], ")"}], 
         RowBox[{"Pi", "/", 
          RowBox[{"(", 
           RowBox[{"2", "n"}], ")"}]}]}], "]"}]}]}], ";", 
     "\[IndentingNewLine]", 
     RowBox[{"GraphicsComplex", "[", 
      RowBox[{
       RowBox[{"Join", "[", 
        RowBox[{
         RowBox[{"{", 
          RowBox[{
           RowBox[{"{", 
            RowBox[{"0", ",", "0", ",", "z"}], "}"}], ",", 
           RowBox[{"{", 
            RowBox[{"0", ",", "0", ",", 
             RowBox[{"-", "z"}]}], "}"}]}], "}"}], ",", 
         RowBox[{"Table", "[", 
          RowBox[{
           RowBox[{
            RowBox[{"a", "=", 
             RowBox[{"2", "Pi", "*", 
              RowBox[{"k", "/", "n"}]}]}], ";", 
            RowBox[{"{", 
             RowBox[{
              RowBox[{"r", "*", 
               RowBox[{"Cos", "[", "a", "]"}]}], ",", 
              RowBox[{"r", "*", 
               RowBox[{"Sin", "[", "a", "]"}]}], ",", "rz"}], "}"}]}], ",", 
           RowBox[{"{", 
            RowBox[{"k", ",", "0", ",", 
             RowBox[{"n", "-", "1"}]}], "}"}]}], "]"}], ",", 
         RowBox[{"Table", "[", 
          RowBox[{
           RowBox[{
            RowBox[{"a", "=", 
             RowBox[{"2", "Pi", "*", 
              RowBox[{
               RowBox[{"(", 
                RowBox[{"k", "+", 
                 RowBox[{
                  RowBox[{"(", 
                   RowBox[{"1", "+", "f"}], ")"}], "/", "2"}]}], ")"}], "/", 
               "n"}]}]}], ";", 
            RowBox[{"{", 
             RowBox[{
              RowBox[{"r", "*", 
               RowBox[{"Cos", "[", "a", "]"}]}], ",", 
              RowBox[{"r", "*", 
               RowBox[{"Sin", "[", "a", "]"}]}], ",", 
              RowBox[{"-", "rz"}]}], "}"}]}], ",", 
           RowBox[{"{", 
            RowBox[{"k", ",", "0", ",", 
             RowBox[{"n", "-", "1"}]}], "}"}]}], "]"}]}], "]"}], ",", 
       RowBox[{"mdlpolys", "[", 
        RowBox[{"\"\<tpzdh\>\"", ",", "n"}], "]"}]}], "]"}]}]}], 
   "\[IndentingNewLine]", "]"}]}]], "Input",
 CellLabel->
  "In[501]:=",ExpressionUUID->"bbae3fc8-2842-457f-be23-f31a9af34ace"],

Cell[BoxData[
 RowBox[{
  RowBox[{"model", "[", 
   RowBox[{"\"\<tpzdh skw\>\"", ",", "n_", ",", "r_", ",", "f_"}], "]"}], " ",
   ":=", " ", 
  RowBox[{"model", "[", 
   RowBox[{"\"\<tpzdh skw\>\"", ",", "n", ",", 
    RowBox[{"r", "*", 
     RowBox[{"Sqrt", "[", 
      RowBox[{"1", "-", 
       RowBox[{
        RowBox[{"(", 
         RowBox[{
          RowBox[{"Tan", "[", 
           RowBox[{
            RowBox[{"(", 
             RowBox[{"1", "+", "f"}], ")"}], 
            RowBox[{"Pi", "/", 
             RowBox[{"(", 
              RowBox[{"2", "n"}], ")"}]}]}], "]"}], "*", 
          RowBox[{"Tan", "[", 
           RowBox[{
            RowBox[{"(", 
             RowBox[{"1", "-", "f"}], ")"}], 
            RowBox[{"Pi", "/", 
             RowBox[{"(", 
              RowBox[{"2", "n"}], ")"}]}]}], "]"}]}], ")"}], "^", "2"}]}], 
      "]"}]}], ",", "r", ",", "f"}], "]"}]}]], "Input",
 CellLabel->
  "In[502]:=",ExpressionUUID->"9f6fd66b-8249-488e-9fb8-0cc4b94c2be5"],

Cell[BoxData[
 RowBox[{
  RowBox[{"model", "[", 
   RowBox[{"\"\<tpzdh\>\"", ",", "n_", ",", "r_", ",", "z_"}], "]"}], " ", ":=",
   " ", 
  RowBox[{"model", "[", 
   RowBox[{"\"\<tpzdh skw\>\"", ",", "n", ",", "r", ",", "z", ",", "0"}], 
   "]"}]}]], "Input",
 CellLabel->
  "In[503]:=",ExpressionUUID->"d7705b4d-138a-4e34-b5d5-88ffb31699aa"],

Cell[BoxData[
 RowBox[{
  RowBox[{"model", "[", 
   RowBox[{"\"\<tpzdh\>\"", ",", "n_", ",", "r_"}], "]"}], " ", ":=", " ", 
  RowBox[{"model", "[", 
   RowBox[{"\"\<tpzdh\>\"", ",", "n", ",", "r", ",", "r"}], "]"}]}]], "Input",\

 CellLabel->
  "In[504]:=",ExpressionUUID->"da989945-58cc-4c23-a414-0ff0538f89ae"]
}, Closed]],

Cell[CellGroupData[{

Cell["Prism", "Subsubsection",ExpressionUUID->"f8288bc0-a8e0-484a-8672-feabe8495fc5"],

Cell[BoxData[
 RowBox[{"(*", " ", 
  RowBox[{
   RowBox[{"Vertices", ":", " ", 
    RowBox[{"northern", " ", "belt"}]}], ",", " ", 
   RowBox[{"southern", " ", 
    RowBox[{"belt", ".", " ", 
     RowBox[{"Faces", ":", " ", 
      RowBox[{"north", " ", "cap"}]}]}]}], ",", " ", 
   RowBox[{"south", " ", "cap"}], ",", " ", 
   RowBox[{"equatorial", "."}]}], " ", "*)"}]], "Input",
 CellLabel->
  "In[505]:=",ExpressionUUID->"f4cae326-9379-4201-bf3b-838e03fdb384"],

Cell[BoxData[
 RowBox[{
  RowBox[{"mdlpolys", "[", 
   RowBox[{"\"\<prism\>\"", ",", "n_"}], "]"}], " ", ":=", " ", 
  RowBox[{"Module", "[", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{"k", ",", "kx", ",", "kn"}], "}"}], ",", 
    RowBox[{"Join", "[", 
     RowBox[{
      RowBox[{"{", 
       RowBox[{
        RowBox[{"Polygon", "[", 
         RowBox[{"Table", "[", 
          RowBox[{
           RowBox[{"1", "+", "k"}], ",", 
           RowBox[{"{", 
            RowBox[{"k", ",", "0", ",", 
             RowBox[{"n", "-", "1"}]}], "}"}]}], "]"}], "]"}], ",", 
        RowBox[{"Polygon", "[", 
         RowBox[{
          RowBox[{"kn", " ", "=", " ", 
           RowBox[{"Mod", "[", 
            RowBox[{
             RowBox[{"-", "k"}], ",", "n"}], "]"}]}], ";", " ", 
          RowBox[{"Table", "[", 
           RowBox[{
            RowBox[{"n", "+", "1", "+", "kn"}], ",", 
            RowBox[{"{", 
             RowBox[{"k", ",", "0", ",", 
              RowBox[{"n", "-", "1"}]}], "}"}]}], "]"}]}], "]"}]}], "}"}], 
      ",", 
      RowBox[{"Table", "[", 
       RowBox[{
        RowBox[{
         RowBox[{"kx", " ", "=", " ", 
          RowBox[{"Mod", "[", 
           RowBox[{
            RowBox[{"k", "+", "1"}], ",", "n"}], "]"}]}], ";", " ", 
         RowBox[{"Polygon", "[", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"1", "+", "k"}], ",", 
            RowBox[{"n", "+", "1", "+", "k"}], ",", 
            RowBox[{"n", "+", "1", "+", "kx"}], ",", 
            RowBox[{"1", "+", "kx"}]}], "}"}], "]"}]}], ",", 
        RowBox[{"{", 
         RowBox[{"k", ",", "0", ",", 
          RowBox[{"n", "-", "1"}]}], "}"}]}], "]"}]}], "]"}]}], 
   "\[IndentingNewLine]", "]"}]}]], "Input",
 CellLabel->
  "In[506]:=",ExpressionUUID->"c8fbc3c3-24f1-4bae-80c1-823c349d1b97"],

Cell[BoxData[
 RowBox[{
  RowBox[{"model", "[", 
   RowBox[{"\"\<prism\>\"", ",", "n_", ",", "r_", ",", "z_"}], "]"}], " ", ":=",
   " ", 
  RowBox[{"Module", "[", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{"k", ",", "a"}], "}"}], ",", 
    RowBox[{"GraphicsComplex", "[", 
     RowBox[{
      RowBox[{"Join", "[", 
       RowBox[{
        RowBox[{"Table", "[", 
         RowBox[{
          RowBox[{
           RowBox[{"a", " ", "=", " ", 
            RowBox[{"2", "Pi", "*", 
             RowBox[{"k", "/", "n"}]}]}], ";", " ", 
           RowBox[{"{", 
            RowBox[{
             RowBox[{"r", "*", 
              RowBox[{"Cos", "[", "a", "]"}]}], ",", 
             RowBox[{"r", "*", 
              RowBox[{"Sin", "[", "a", "]"}]}], ",", "z"}], "}"}]}], ",", 
          RowBox[{"{", 
           RowBox[{"k", ",", "0", ",", 
            RowBox[{"n", "-", "1"}]}], "}"}]}], "]"}], ",", 
        RowBox[{"Table", "[", 
         RowBox[{
          RowBox[{
           RowBox[{"a", " ", "=", " ", 
            RowBox[{"2", "Pi", "*", 
             RowBox[{"k", "/", "n"}]}]}], ";", " ", 
           RowBox[{"{", 
            RowBox[{
             RowBox[{"r", "*", 
              RowBox[{"Cos", "[", "a", "]"}]}], ",", 
             RowBox[{"r", "*", 
              RowBox[{"Sin", "[", "a", "]"}]}], ",", 
             RowBox[{"-", "z"}]}], "}"}]}], ",", 
          RowBox[{"{", 
           RowBox[{"k", ",", "0", ",", 
            RowBox[{"n", "-", "1"}]}], "}"}]}], "]"}]}], "]"}], ",", 
      RowBox[{"mdlpolys", "[", 
       RowBox[{"\"\<prism\>\"", ",", "n"}], "]"}]}], "]"}]}], 
   "\[IndentingNewLine]", "]"}]}]], "Input",
 CellLabel->
  "In[507]:=",ExpressionUUID->"f4e687c8-80eb-4d8f-aa18-3b045acf4c8c"],

Cell[BoxData[
 RowBox[{
  RowBox[{"model", "[", 
   RowBox[{"\"\<prism alt\>\"", ",", "n_", ",", "r_", ",", "z_", ",", "f_"}], 
   "]"}], " ", ":=", " ", 
  RowBox[{"Module", "[", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{"k", ",", "a"}], "}"}], ",", 
    RowBox[{"GraphicsComplex", "[", 
     RowBox[{
      RowBox[{"Join", "[", 
       RowBox[{
        RowBox[{"Table", "[", 
         RowBox[{
          RowBox[{
           RowBox[{"a", " ", "=", " ", 
            RowBox[{"Pi", "*", 
             RowBox[{
              RowBox[{"(", 
               RowBox[{"k", "+", 
                RowBox[{"f", "*", 
                 RowBox[{
                  RowBox[{"If", "[", 
                   RowBox[{
                    RowBox[{"EvenQ", "[", "k", "]"}], ",", "1", ",", 
                    RowBox[{"-", "1"}]}], "]"}], "/", "2"}]}]}], ")"}], "/", 
              "n"}]}]}], ";", " ", 
           RowBox[{"{", 
            RowBox[{
             RowBox[{"r", "*", 
              RowBox[{"Cos", "[", "a", "]"}]}], ",", 
             RowBox[{"r", "*", 
              RowBox[{"Sin", "[", "a", "]"}]}], ",", "z"}], "}"}]}], ",", 
          RowBox[{"{", 
           RowBox[{"k", ",", "0", ",", 
            RowBox[{
             RowBox[{"2", "n"}], "-", "1"}]}], "}"}]}], "]"}], ",", 
        RowBox[{"Table", "[", 
         RowBox[{
          RowBox[{
           RowBox[{"a", " ", "=", " ", 
            RowBox[{"Pi", "*", 
             RowBox[{
              RowBox[{"(", 
               RowBox[{"k", "+", 
                RowBox[{"f", "*", 
                 RowBox[{
                  RowBox[{"If", "[", 
                   RowBox[{
                    RowBox[{"EvenQ", "[", "k", "]"}], ",", "1", ",", 
                    RowBox[{"-", "1"}]}], "]"}], "/", "2"}]}]}], ")"}], "/", 
              "n"}]}]}], ";", " ", 
           RowBox[{"{", 
            RowBox[{
             RowBox[{"r", "*", 
              RowBox[{"Cos", "[", "a", "]"}]}], ",", 
             RowBox[{"r", "*", 
              RowBox[{"Sin", "[", "a", "]"}]}], ",", 
             RowBox[{"-", "z"}]}], "}"}]}], ",", 
          RowBox[{"{", 
           RowBox[{"k", ",", "0", ",", 
            RowBox[{
             RowBox[{"2", "n"}], "-", "1"}]}], "}"}]}], "]"}]}], "]"}], ",", 
      RowBox[{"mdlpolys", "[", 
       RowBox[{"\"\<prism\>\"", ",", 
        RowBox[{"2", "n"}]}], "]"}]}], "]"}]}], "\[IndentingNewLine]", 
   "]"}]}]], "Input",
 CellLabel->
  "In[508]:=",ExpressionUUID->"8f463335-882b-4b0c-89ed-798be711d1b2"],

Cell[BoxData[
 RowBox[{
  RowBox[{"model", "[", 
   RowBox[{"\"\<prism tpr\>\"", ",", "n_", ",", "r_", ",", "z_", ",", "f_"}], 
   "]"}], " ", ":=", " ", 
  RowBox[{"Module", "[", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{"k", ",", "a"}], "}"}], ",", 
    RowBox[{"GraphicsComplex", "[", 
     RowBox[{
      RowBox[{"Join", "[", 
       RowBox[{
        RowBox[{"Table", "[", 
         RowBox[{
          RowBox[{
           RowBox[{"a", " ", "=", " ", 
            RowBox[{"Pi", "*", 
             RowBox[{
              RowBox[{"(", 
               RowBox[{"k", "+", 
                RowBox[{"f", "*", 
                 RowBox[{
                  RowBox[{"If", "[", 
                   RowBox[{
                    RowBox[{"EvenQ", "[", "k", "]"}], ",", "1", ",", 
                    RowBox[{"-", "1"}]}], "]"}], "/", "2"}]}]}], ")"}], "/", 
              "n"}]}]}], ";", " ", 
           RowBox[{"{", 
            RowBox[{
             RowBox[{"r", "*", 
              RowBox[{"Cos", "[", "a", "]"}]}], ",", 
             RowBox[{"r", "*", 
              RowBox[{"Sin", "[", "a", "]"}]}], ",", "z"}], "}"}]}], ",", 
          RowBox[{"{", 
           RowBox[{"k", ",", "0", ",", 
            RowBox[{
             RowBox[{"2", "n"}], "-", "1"}]}], "}"}]}], "]"}], ",", 
        RowBox[{"Table", "[", 
         RowBox[{
          RowBox[{
           RowBox[{"a", " ", "=", " ", 
            RowBox[{"Pi", "*", 
             RowBox[{
              RowBox[{"(", 
               RowBox[{"k", "-", 
                RowBox[{"f", "*", 
                 RowBox[{
                  RowBox[{"If", "[", 
                   RowBox[{
                    RowBox[{"EvenQ", "[", "k", "]"}], ",", "1", ",", 
                    RowBox[{"-", "1"}]}], "]"}], "/", "2"}]}]}], ")"}], "/", 
              "n"}]}]}], ";", " ", 
           RowBox[{"{", 
            RowBox[{
             RowBox[{"r", "*", 
              RowBox[{"Cos", "[", "a", "]"}]}], ",", 
             RowBox[{"r", "*", 
              RowBox[{"Sin", "[", "a", "]"}]}], ",", 
             RowBox[{"-", "z"}]}], "}"}]}], ",", 
          RowBox[{"{", 
           RowBox[{"k", ",", "0", ",", 
            RowBox[{
             RowBox[{"2", "n"}], "-", "1"}]}], "}"}]}], "]"}]}], "]"}], ",", 
      RowBox[{"mdlpolys", "[", 
       RowBox[{"\"\<prism\>\"", ",", 
        RowBox[{"2", "n"}]}], "]"}]}], "]"}]}], "\[IndentingNewLine]", 
   "]"}]}]], "Input",
 CellLabel->
  "In[509]:=",ExpressionUUID->"4a2ef17e-6a4c-4f45-963e-850a9a359534"]
}, Closed]],

Cell[CellGroupData[{

Cell["Antiprism", "Subsubsection",ExpressionUUID->"0b0737f3-e63a-4b23-b7ed-670ac9d5cf67"],

Cell[BoxData[
 RowBox[{"(*", " ", 
  RowBox[{
   RowBox[{"Vertices", ":", " ", 
    RowBox[{"northern", " ", "belt"}]}], ",", " ", 
   RowBox[{"southern", " ", 
    RowBox[{"belt", ".", " ", 
     RowBox[{"Faces", ":", " ", 
      RowBox[{"north", " ", "cap"}]}]}]}], ",", " ", 
   RowBox[{"south", " ", "cap"}], ",", " ", 
   RowBox[{"northern", " ", "belt"}], ",", " ", 
   RowBox[{"southern", " ", 
    RowBox[{"belt", "."}]}]}], " ", "*)"}]], "Input",
 CellLabel->
  "In[510]:=",ExpressionUUID->"a850ba93-d68a-408c-93f5-24a8406282f9"],

Cell[BoxData[
 RowBox[{
  RowBox[{"mdlpolys", "[", 
   RowBox[{"\"\<apsm\>\"", ",", "n_"}], "]"}], " ", ":=", " ", 
  RowBox[{"Module", "[", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{"k", ",", "kx", ",", "kn"}], "}"}], ",", 
    RowBox[{"Join", "[", 
     RowBox[{
      RowBox[{"{", 
       RowBox[{
        RowBox[{"Polygon", "[", 
         RowBox[{"Table", "[", 
          RowBox[{
           RowBox[{"1", "+", "k"}], ",", 
           RowBox[{"{", 
            RowBox[{"k", ",", "0", ",", 
             RowBox[{"n", "-", "1"}]}], "}"}]}], "]"}], "]"}], ",", 
        RowBox[{"Polygon", "[", 
         RowBox[{
          RowBox[{"kn", " ", "=", " ", 
           RowBox[{"Mod", "[", 
            RowBox[{
             RowBox[{"-", "k"}], ",", "n"}], "]"}]}], ";", " ", 
          RowBox[{"Table", "[", 
           RowBox[{
            RowBox[{"n", "+", "1", "+", "kn"}], ",", 
            RowBox[{"{", 
             RowBox[{"k", ",", "0", ",", 
              RowBox[{"n", "-", "1"}]}], "}"}]}], "]"}]}], "]"}]}], "}"}], 
      ",", 
      RowBox[{"Table", "[", 
       RowBox[{
        RowBox[{
         RowBox[{"kx", " ", "=", " ", 
          RowBox[{"Mod", "[", 
           RowBox[{
            RowBox[{"k", "+", "1"}], ",", "n"}], "]"}]}], ";", " ", 
         RowBox[{"Polygon", "[", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"1", "+", "k"}], ",", 
            RowBox[{"n", "+", "1", "+", "k"}], ",", 
            RowBox[{"1", "+", "kx"}]}], "}"}], "]"}]}], ",", 
        RowBox[{"{", 
         RowBox[{"k", ",", "0", ",", 
          RowBox[{"n", "-", "1"}]}], "}"}]}], "]"}], ",", 
      RowBox[{"Table", "[", 
       RowBox[{
        RowBox[{
         RowBox[{"kx", " ", "=", " ", 
          RowBox[{"Mod", "[", 
           RowBox[{
            RowBox[{"k", "+", "1"}], ",", "n"}], "]"}]}], ";", " ", 
         RowBox[{"Polygon", "[", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"n", "+", "1", "+", "kx"}], ",", 
            RowBox[{"1", "+", "kx"}], ",", 
            RowBox[{"n", "+", "1", "+", "k"}]}], "}"}], "]"}]}], ",", 
        RowBox[{"{", 
         RowBox[{"k", ",", "0", ",", 
          RowBox[{"n", "-", "1"}]}], "}"}]}], "]"}]}], "]"}]}], 
   "\[IndentingNewLine]", "]"}]}]], "Input",
 CellLabel->
  "In[511]:=",ExpressionUUID->"75928021-f05a-480a-9b3c-efdbc13e64f3"],

Cell[BoxData[
 RowBox[{
  RowBox[{"model", "[", 
   RowBox[{"\"\<apsm skw\>\"", ",", "n_", ",", "r_", ",", "z_", ",", "f_"}], 
   "]"}], " ", ":=", " ", 
  RowBox[{"Module", "[", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{"k", ",", "a"}], "}"}], ",", 
    RowBox[{"GraphicsComplex", "[", 
     RowBox[{
      RowBox[{"Join", "[", 
       RowBox[{
        RowBox[{"Table", "[", 
         RowBox[{
          RowBox[{
           RowBox[{"a", " ", "=", " ", 
            RowBox[{"2", "Pi", "*", 
             RowBox[{"k", "/", "n"}]}]}], ";", " ", 
           RowBox[{"{", 
            RowBox[{
             RowBox[{"r", "*", 
              RowBox[{"Cos", "[", "a", "]"}]}], ",", 
             RowBox[{"r", "*", 
              RowBox[{"Sin", "[", "a", "]"}]}], ",", "z"}], "}"}]}], ",", 
          RowBox[{"{", 
           RowBox[{"k", ",", "0", ",", 
            RowBox[{"n", "-", "1"}]}], "}"}]}], "]"}], ",", 
        RowBox[{"Table", "[", 
         RowBox[{
          RowBox[{
           RowBox[{"a", " ", "=", " ", 
            RowBox[{"2", "Pi", "*", 
             RowBox[{
              RowBox[{"(", 
               RowBox[{"k", "+", 
                RowBox[{
                 RowBox[{"(", 
                  RowBox[{"1", "+", "f"}], ")"}], "/", "2"}]}], ")"}], "/", 
              "n"}]}]}], ";", " ", 
           RowBox[{"{", 
            RowBox[{
             RowBox[{"r", "*", 
              RowBox[{"Cos", "[", "a", "]"}]}], ",", 
             RowBox[{"r", "*", 
              RowBox[{"Sin", "[", "a", "]"}]}], ",", 
             RowBox[{"-", "z"}]}], "}"}]}], ",", 
          RowBox[{"{", 
           RowBox[{"k", ",", "0", ",", 
            RowBox[{"n", "-", "1"}]}], "}"}]}], "]"}]}], "]"}], ",", 
      RowBox[{"mdlpolys", "[", 
       RowBox[{"\"\<apsm\>\"", ",", "n"}], "]"}]}], "]"}]}], 
   "\[IndentingNewLine]", "]"}]}]], "Input",
 CellLabel->
  "In[512]:=",ExpressionUUID->"469f7560-1090-47b0-b1b9-9a03991231d1"],

Cell[BoxData[
 RowBox[{
  RowBox[{"model", "[", 
   RowBox[{"\"\<apsm\>\"", ",", "n_", ",", "r_", ",", "z_"}], "]"}], " ", ":=",
   " ", 
  RowBox[{"model", "[", 
   RowBox[{"\"\<apsm skw\>\"", ",", "n", ",", "r", ",", "z", ",", "0"}], 
   "]"}]}]], "Input",
 CellLabel->
  "In[513]:=",ExpressionUUID->"21d89791-5696-4243-b5b8-54ac7951e8b0"]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{

Cell["Quasi-Spherical", "Subsection",ExpressionUUID->"ab2cfebc-8327-45af-8877-f8f9a88eeeeb"],

Cell[CellGroupData[{

Cell["Regular-Solid Setup", "Subsubsection",ExpressionUUID->"5e91c0cc-5726-4cd6-9fea-74ed9360de51"],

Cell[BoxData[
 RowBox[{"(*", " ", 
  RowBox[{
   RowBox[{
    RowBox[{
     RowBox[{"Inspired", " ", "by", " ", "quasi"}], "-", 
     RowBox[{"spherical", " ", "quaternion", " ", 
      RowBox[{"groups", ".", "\[IndentingNewLine]", "\[IndentingNewLine]", 
       RowBox[{"What", "'"}]}], "s", " ", "what", " ", "for", " ", 
      "triangle"}], "-", 
     RowBox[{"facted", " ", "regular", " ", 
      RowBox[{"solids", ":", "\[IndentingNewLine]", "vt"}]}]}], " ", "=", " ",
     "vertex"}], ",", " ", 
   RowBox[{"ed", " ", "=", " ", "edge"}], ",", " ", 
   RowBox[{"fc", " ", "=", " ", 
    RowBox[{
    "face", "\[IndentingNewLine]", "All", " ", "of", " ", "them", " ", "are", 
     " ", "normalized", " ", "to", " ", "length", " ", "1"}]}]}], 
  "\[IndentingNewLine]", " ", "*)"}]], "Input",
 CellLabel->
  "In[514]:=",ExpressionUUID->"c6f9e590-1e32-4b45-9578-15a2d4507371"],

Cell[BoxData[
 RowBox[{"(*", " ", 
  RowBox[{
  "For", " ", "the", " ", "tetrahedron", " ", "and", " ", "the", " ", 
   RowBox[{"octahedron", " ", "/", " ", "cube"}]}], " ", "*)"}]], "Input",
 CellLabel->
  "In[515]:=",ExpressionUUID->"b6f9d69b-3c2d-439a-b7bd-daee5eb19320"],

Cell[BoxData[
 RowBox[{
  RowBox[{"rsst123", " ", "=", " ", 
   RowBox[{"Tuples", "[", 
    RowBox[{
     RowBox[{"Range", "[", 
      RowBox[{
       RowBox[{"-", "1"}], ",", "1"}], "]"}], ",", "3"}], "]"}]}], 
  ";"}]], "Input",
 CellLabel->
  "In[516]:=",ExpressionUUID->"0360dc62-2b86-4ded-b200-4f98d6fc8b49"],

Cell[BoxData[
 RowBox[{
  RowBox[{"rsst1", " ", "=", " ", 
   RowBox[{"Select", "[", 
    RowBox[{"rsst123", ",", 
     RowBox[{
      RowBox[{
       RowBox[{"Total", "[", 
        RowBox[{"Abs", "[", "#", "]"}], "]"}], "\[Equal]", "1"}], "&"}]}], 
    "]"}]}], ";"}]], "Input",
 CellLabel->
  "In[517]:=",ExpressionUUID->"8bc4efd8-d9d4-44b8-8304-1e0c97d53d8a"],

Cell[BoxData[
 RowBox[{
  RowBox[{"rsst2", " ", "=", " ", 
   RowBox[{"Select", "[", 
    RowBox[{"rsst123", ",", 
     RowBox[{
      RowBox[{
       RowBox[{"Total", "[", 
        RowBox[{"Abs", "[", "#", "]"}], "]"}], "\[Equal]", "2"}], "&"}]}], 
    "]"}]}], ";"}]], "Input",
 CellLabel->
  "In[518]:=",ExpressionUUID->"3735351b-d80a-461c-8227-48ad0710e9be"],

Cell[BoxData[
 RowBox[{
  RowBox[{"rsst3", " ", "=", " ", 
   RowBox[{"Select", "[", 
    RowBox[{"rsst123", ",", 
     RowBox[{
      RowBox[{
       RowBox[{"Total", "[", 
        RowBox[{"Abs", "[", "#", "]"}], "]"}], "\[Equal]", "3"}], "&"}]}], 
    "]"}]}], ";"}]], "Input",
 CellLabel->
  "In[519]:=",ExpressionUUID->"081e3055-56f3-4712-b91f-711f43a4a94c"],

Cell[BoxData[
 RowBox[{
  RowBox[{"rsst3p", " ", "=", " ", 
   RowBox[{"Select", "[", 
    RowBox[{"rsst3", ",", 
     RowBox[{
      RowBox[{
       RowBox[{"(", 
        RowBox[{"Times", " ", "@@", " ", "#"}], ")"}], " ", ">", " ", "0"}], 
      "&"}]}], "]"}]}], ";"}]], "Input",
 CellLabel->
  "In[520]:=",ExpressionUUID->"f93afacf-9701-4bcd-b5a9-875e868d5581"],

Cell[BoxData[
 RowBox[{
  RowBox[{"rsst3m", " ", "=", " ", 
   RowBox[{"Select", "[", 
    RowBox[{"rsst3", ",", 
     RowBox[{
      RowBox[{
       RowBox[{"(", 
        RowBox[{"Times", " ", "@@", " ", "#"}], ")"}], " ", "<", " ", "0"}], 
      "&"}]}], "]"}]}], ";"}]], "Input",
 CellLabel->
  "In[521]:=",ExpressionUUID->"55ec6bbb-8522-46b3-8032-7017a4105c49"],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{
    RowBox[{"regsld", "[", "3", "]"}], "[", "\"\<vt\>\"", "]"}], " ", "=", 
   " ", 
   RowBox[{"rsst3p", "/", 
    RowBox[{"Sqrt", "[", "3", "]"}]}]}], ";"}]], "Input",
 CellLabel->
  "In[522]:=",ExpressionUUID->"21da596c-a987-4363-8fdc-73e67084cfa7"],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{
    RowBox[{"regsld", "[", "3", "]"}], "[", "\"\<ed\>\"", "]"}], " ", "=", 
   " ", "rsst1"}], ";"}]], "Input",
 CellLabel->
  "In[523]:=",ExpressionUUID->"0258c629-e28a-422f-9d68-176f204c5724"],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{
    RowBox[{"regsld", "[", "3", "]"}], "[", "\"\<fc\>\"", "]"}], " ", "=", 
   " ", 
   RowBox[{"rsst3m", "/", 
    RowBox[{"Sqrt", "[", "3", "]"}]}]}], ";"}]], "Input",
 CellLabel->
  "In[524]:=",ExpressionUUID->"66c23abe-5fc4-44de-8d20-45bd4902b368"],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{
    RowBox[{"regsld", "[", "4", "]"}], "[", "\"\<vt\>\"", "]"}], " ", "=", 
   " ", "rsst1"}], ";"}]], "Input",
 CellLabel->
  "In[525]:=",ExpressionUUID->"939226ec-7517-4aa6-8240-8c6accdea30b"],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{
    RowBox[{"regsld", "[", "4", "]"}], "[", "\"\<ed\>\"", "]"}], " ", "=", 
   " ", 
   RowBox[{"rsst2", "/", 
    RowBox[{"Sqrt", "[", "2", "]"}]}]}], ";"}]], "Input",
 CellLabel->
  "In[526]:=",ExpressionUUID->"cec21b43-9702-4d04-8316-18ec31b74ed3"],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{
    RowBox[{"regsld", "[", "4", "]"}], "[", "\"\<fc\>\"", "]"}], " ", "=", 
   " ", 
   RowBox[{"rsst3", "/", 
    RowBox[{"Sqrt", "[", "3", "]"}]}]}], ";"}]], "Input",
 CellLabel->
  "In[527]:=",ExpressionUUID->"c8b65514-790e-4d72-acba-e802956bdb28"],

Cell[BoxData[
 RowBox[{"(*", " ", 
  RowBox[{"For", " ", "the", " ", 
   RowBox[{"icosahedron", " ", "/", " ", "dodecahedron"}]}], " ", 
  "*)"}]], "Input",
 CellLabel->
  "In[528]:=",ExpressionUUID->"97f29c25-34c7-43a9-9a52-e389ca83f792"],

Cell[BoxData[
 RowBox[{
  RowBox[{"icosaquatbase", " ", "=", " ", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"(", 
      RowBox[{
       RowBox[{"Sqrt", "[", "5", "]"}], "+", "1"}], ")"}], ",", "2", ",", 
     RowBox[{"(", 
      RowBox[{
       RowBox[{"Sqrt", "[", "5", "]"}], "-", "1"}], ")"}], ",", "0"}], 
    "}"}]}], ";"}]], "Input",
 CellLabel->
  "In[529]:=",ExpressionUUID->"fdb724cd-6a9a-4308-b52a-31dd539376a3"],

Cell[BoxData[
 RowBox[{
  RowBox[{"icosaqbsgns", " ", "=", " ", 
   RowBox[{
    RowBox[{
     RowBox[{
      RowBox[{"Append", "[", 
       RowBox[{"#", ",", "0"}], "]"}], "*", "icosaquatbase"}], "&"}], " ", "/@",
     " ", "rsst3"}]}], ";"}]], "Input",
 CellLabel->
  "In[530]:=",ExpressionUUID->"500d6e02-5681-4b6a-a348-ef75286bc778"],

Cell[BoxData[
 RowBox[{
  RowBox[{"evpm4", " ", "=", " ", 
   RowBox[{"Select", "[", 
    RowBox[{
     RowBox[{"Permutations", "[", 
      RowBox[{"Range", "[", "4", "]"}], "]"}], ",", 
     RowBox[{
      RowBox[{
       RowBox[{"Signature", "[", "#", "]"}], ">", "0"}], "&"}]}], "]"}]}], 
  ";"}]], "Input",
 CellLabel->
  "In[531]:=",ExpressionUUID->"a515aea1-e7ba-4d13-92fd-d987cb175f2d"],

Cell[BoxData[
 RowBox[{
  RowBox[{"icosaquat", " ", "=", " ", 
   RowBox[{
    RowBox[{
     RowBox[{
      RowBox[{"#", "[", 
       RowBox[{"[", "2", "]"}], "]"}], "[", 
      RowBox[{"[", 
       RowBox[{"#", "[", 
        RowBox[{"[", "1", "]"}], "]"}], "]"}], "]"}], "&"}], " ", "/@", " ", 
    RowBox[{"Tuples", "[", 
     RowBox[{"{", 
      RowBox[{"evpm4", ",", "icosaqbsgns"}], "}"}], "]"}]}]}], ";"}]], "Input",\

 CellLabel->
  "In[532]:=",ExpressionUUID->"c08c326f-4c03-4337-b096-7227bfdc31ca"],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{
    RowBox[{"regsld", "[", "5", "]"}], "[", "\"\<vt\>\"", "]"}], " ", "=", 
   RowBox[{
    RowBox[{"(", 
     RowBox[{"Rest", " ", "/@", " ", 
      RowBox[{"Select", "[", 
       RowBox[{"icosaquat", ",", 
        RowBox[{
         RowBox[{
          RowBox[{"First", "[", "#", "]"}], "\[Equal]", 
          RowBox[{"(", 
           RowBox[{
            RowBox[{"Sqrt", "[", "5", "]"}], "-", "1"}], ")"}]}], "&"}]}], 
       "]"}]}], ")"}], "/", 
    RowBox[{"Sqrt", "[", 
     RowBox[{"10", "+", 
      RowBox[{"2", 
       RowBox[{"Sqrt", "[", "5", "]"}]}]}], "]"}]}]}], ";"}]], "Input",
 CellLabel->
  "In[533]:=",ExpressionUUID->"6810484c-8ae5-4cbf-b6cd-8e6cff67bbe8"],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{
    RowBox[{"regsld", "[", "5", "]"}], "[", "\"\<ed\>\"", "]"}], " ", "=", 
   " ", 
   RowBox[{"Join", "[", 
    RowBox[{"rsst1", ",", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{"Rest", " ", "/@", " ", 
        RowBox[{"Select", "[", 
         RowBox[{"icosaquat", ",", 
          RowBox[{
           RowBox[{
            RowBox[{"First", "[", "#", "]"}], "\[Equal]", " ", "0"}], "&"}]}],
          "]"}]}], ")"}], "/", "4"}]}], "]"}]}], ";"}]], "Input",
 CellLabel->
  "In[534]:=",ExpressionUUID->"1fd2b621-54c2-437f-9469-c54d76b7295c"],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{
    RowBox[{"regsld", "[", "5", "]"}], "[", "\"\<fc\>\"", "]"}], " ", "=", 
   " ", 
   RowBox[{"Join", "[", 
    RowBox[{
     RowBox[{"rsst3", "/", 
      RowBox[{"Sqrt", "[", "3", "]"}]}], ",", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{"Rest", " ", "/@", " ", 
        RowBox[{"Select", "[", 
         RowBox[{"icosaquat", ",", 
          RowBox[{
           RowBox[{
            RowBox[{"First", "[", "#", "]"}], "\[Equal]", " ", "2"}], "&"}]}],
          "]"}]}], ")"}], "/", 
      RowBox[{"(", 
       RowBox[{"2", 
        RowBox[{"Sqrt", "[", "3", "]"}]}], ")"}]}]}], "]"}]}], ";"}]], "Input",\

 CellLabel->
  "In[535]:=",ExpressionUUID->"0884c15e-321a-47e0-a9c5-cc699eb06c74"],

Cell[BoxData[
 RowBox[{"(*", " ", 
  RowBox[{"Find", " ", "the", " ", "neighbor", " ", "lists"}], " ", 
  "*)"}]], "Input",
 CellLabel->
  "In[536]:=",ExpressionUUID->"6ea5cf51-ebc7-40cc-8406-f0c32652b3f6"],

Cell[BoxData[
 RowBox[{
  RowBox[{"VectorNgbrIndices", "[", 
   RowBox[{"vec_", ",", "vlst_"}], "]"}], " ", ":=", " ", 
  RowBox[{"Module", "[", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{
     "dps", ",", "dpsmax", ",", "dpsdiff", ",", "ngixs", ",", "oldnis", ",", 
      "newnis", ",", "vprev", ",", "nndp", ",", "nwix"}], "}"}], ",", 
    "\[IndentingNewLine]", 
    RowBox[{"(*", " ", 
     RowBox[{"Find", " ", "all", " ", "the", " ", "closest", " ", "vectors"}],
      " ", "*)"}], "\[IndentingNewLine]", 
    RowBox[{
     RowBox[{"dps", " ", "=", " ", 
      RowBox[{
       RowBox[{
        RowBox[{
         RowBox[{
          RowBox[{"(", 
           RowBox[{"vec", ".", "#"}], ")"}], "&"}], " ", "/@", " ", "vlst"}], 
        " ", "//", " ", "Expand"}], " ", "//", " ", "Factor"}]}], ";", 
     "\[IndentingNewLine]", 
     RowBox[{"dpsmax", " ", "=", " ", 
      RowBox[{"Max", "[", "dps", "]"}]}], ";", "\[IndentingNewLine]", 
     RowBox[{"dpsdiff", " ", "=", " ", 
      RowBox[{
       RowBox[{
        RowBox[{
         RowBox[{
          RowBox[{"(", 
           RowBox[{"dpsmax", " ", "-", " ", "#"}], ")"}], "&"}], " ", "/@", 
         " ", "dps"}], " ", "//", " ", "Expand"}], " ", "//", " ", 
       "Factor"}]}], ";", "\[IndentingNewLine]", 
     RowBox[{"ngixs", " ", "=", " ", 
      RowBox[{
       RowBox[{
        RowBox[{"#", "[", 
         RowBox[{"[", "1", "]"}], "]"}], "&"}], " ", "/@", " ", 
       RowBox[{"Select", "[", 
        RowBox[{
         RowBox[{"Transpose", "[", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"Range", "[", 
             RowBox[{"Length", "[", "dpsdiff", "]"}], "]"}], ",", "dpsdiff"}],
            "}"}], "]"}], ",", 
         RowBox[{
          RowBox[{
           RowBox[{"#", "[", 
            RowBox[{"[", "2", "]"}], "]"}], "\[Equal]", "0"}], "&"}]}], 
        "]"}]}]}], ";", "\[IndentingNewLine]", 
     RowBox[{"(*", " ", 
      RowBox[{
       RowBox[{"Sort", " ", "them", " ", "into", " ", 
        RowBox[{"(", "counter", ")"}], "clockwise", " ", "order"}], ",", " ", 
       
       RowBox[{"if", " ", "possible"}]}], " ", "*)"}], "\[IndentingNewLine]", 
     
     RowBox[{"ngixs", " ", "=", " ", 
      RowBox[{"Sort", "[", "ngixs", "]"}]}], ";", "\[IndentingNewLine]", 
     RowBox[{"If", "[", 
      RowBox[{
       RowBox[{
        RowBox[{"Length", "[", "ngixs", "]"}], " ", "<", " ", "3"}], ",", 
       RowBox[{"Return", "[", "ngixs", "]"}]}], "]"}], ";", 
     "\[IndentingNewLine]", 
     RowBox[{"oldnis", " ", "=", " ", 
      RowBox[{"Rest", "[", "ngixs", "]"}]}], ";", "\[IndentingNewLine]", 
     RowBox[{"newnis", " ", "=", " ", 
      RowBox[{"{", 
       RowBox[{"First", "[", "ngixs", "]"}], "}"}]}], ";", 
     "\[IndentingNewLine]", 
     RowBox[{"While", "[", 
      RowBox[{
       RowBox[{
        RowBox[{"Length", "[", "oldnis", "]"}], " ", ">", " ", "0"}], ",", 
       "\[IndentingNewLine]", 
       RowBox[{
        RowBox[{"vprev", " ", "=", " ", 
         RowBox[{"vlst", "[", 
          RowBox[{"[", 
           RowBox[{"Last", "[", "newnis", "]"}], "]"}], "]"}]}], ";", 
        "\[IndentingNewLine]", 
        RowBox[{"dps", " ", "=", " ", 
         RowBox[{
          RowBox[{
           RowBox[{
            RowBox[{
             RowBox[{"(", 
              RowBox[{"vprev", ".", "#"}], ")"}], "&"}], " ", "/@", " ", 
            RowBox[{"vlst", "[", 
             RowBox[{"[", "oldnis", "]"}], "]"}]}], " ", "//", " ", 
           "Expand"}], " ", "//", " ", "Factor"}]}], ";", 
        "\[IndentingNewLine]", 
        RowBox[{"nndp", " ", "=", " ", 
         RowBox[{"Transpose", "[", 
          RowBox[{"{", 
           RowBox[{"oldnis", ",", "dps"}], "}"}], "]"}]}], ";", 
        "\[IndentingNewLine]", 
        RowBox[{"nndp", " ", "=", " ", 
         RowBox[{"Select", "[", 
          RowBox[{"nndp", ",", 
           RowBox[{
            RowBox[{
             RowBox[{"Det", "[", 
              RowBox[{"{", 
               RowBox[{"vec", ",", "vprev", ",", 
                RowBox[{"vlst", "[", 
                 RowBox[{"[", 
                  RowBox[{"#", "[", 
                   RowBox[{"[", "1", "]"}], "]"}], "]"}], "]"}]}], "}"}], 
              "]"}], ">", "0"}], "&"}]}], "]"}]}], ";", "\[IndentingNewLine]", 
        RowBox[{"nndp", " ", "=", " ", 
         RowBox[{"SortBy", "[", 
          RowBox[{"nndp", ",", 
           RowBox[{
            RowBox[{"-", 
             RowBox[{"#", "[", 
              RowBox[{"[", "2", "]"}], "]"}]}], "&"}]}], "]"}]}], ";", 
        "\[IndentingNewLine]", 
        RowBox[{"nwix", " ", "=", " ", 
         RowBox[{"nndp", "[", 
          RowBox[{"[", 
           RowBox[{"1", ",", "1"}], "]"}], "]"}]}], ";", 
        "\[IndentingNewLine]", 
        RowBox[{"AppendTo", "[", 
         RowBox[{"newnis", ",", "nwix"}], "]"}], ";", "\[IndentingNewLine]", 
        RowBox[{"oldnis", " ", "=", " ", 
         RowBox[{"Complement", "[", 
          RowBox[{"oldnis", ",", 
           RowBox[{"{", "nwix", "}"}]}], "]"}]}], ";"}]}], 
      "\[IndentingNewLine]", "]"}], ";", "\[IndentingNewLine]", 
     RowBox[{"(*", " ", 
      RowBox[{"Kludge", " ", "for", " ", "pentagonal", " ", "faces"}], " ", 
      "*)"}], "\[IndentingNewLine]", 
     RowBox[{"If", "[", 
      RowBox[{
       RowBox[{
        RowBox[{"Length", "[", "newnis", "]"}], " ", "\[GreaterEqual]", " ", 
        "5"}], ",", 
       RowBox[{"newnis", "[", 
        RowBox[{"[", 
         RowBox[{"{", 
          RowBox[{"1", ",", "4", ",", "2", ",", "5", ",", "3"}], "}"}], "]"}],
         "]"}], ",", "newnis"}], "]"}]}]}], "\[IndentingNewLine]", 
   "]"}]}]], "Input",
 CellLabel->
  "In[537]:=",ExpressionUUID->"147c0c9d-bdd7-4c36-8a6f-e30f352a41a4"],

Cell[BoxData[
 RowBox[{
  RowBox[{"VecSetNgbrIndices", "[", 
   RowBox[{"vlst_", ",", "vlstx_"}], "]"}], " ", ":=", " ", 
  RowBox[{
   RowBox[{
    RowBox[{"VectorNgbrIndices", "[", 
     RowBox[{"#", ",", "vlstx"}], "]"}], "&"}], " ", "/@", " ", 
   "vlst"}]}]], "Input",
 CellLabel->
  "In[538]:=",ExpressionUUID->"77a9c045-0746-428a-b908-200dc6c1619a"],

Cell[BoxData[
 RowBox[{
  RowBox[{"RSVSNI", "[", "rs_", "]"}], " ", ":=", " ", 
  RowBox[{"Module", "[", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{"tps", ",", "tp1", ",", "tp2", ",", "k"}], "}"}], ",", 
    "\[IndentingNewLine]", 
    RowBox[{
     RowBox[{"tps", " ", "=", " ", 
      RowBox[{"{", 
       RowBox[{"\"\<vt\>\"", ",", "\"\<ed\>\"", ",", "\"\<fc\>\""}], "}"}]}], 
     ";", "\[IndentingNewLine]", 
     RowBox[{"Do", "[", 
      RowBox[{
       RowBox[{"If", "[", 
        RowBox[{
         RowBox[{"tp2", " ", "=!=", " ", "tp1"}], ",", 
         RowBox[{
          RowBox[{"rs", "[", 
           RowBox[{"tp1", ",", "tp2"}], "]"}], " ", "=", " ", 
          RowBox[{"VecSetNgbrIndices", "[", 
           RowBox[{
            RowBox[{"rs", "[", "tp1", "]"}], ",", 
            RowBox[{"rs", "[", "tp2", "]"}]}], "]"}]}]}], "]"}], ",", 
       RowBox[{"{", 
        RowBox[{"tp1", ",", "tps"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"tp2", ",", "tps"}], "}"}]}], "]"}], ";", 
     "\[IndentingNewLine]", 
     RowBox[{
      RowBox[{"rs", "[", 
       RowBox[{"\"\<ed\>\"", ",", "\"\<fc\>\""}], "]"}], " ", "=", " ", 
      RowBox[{"Table", "[", 
       RowBox[{
        RowBox[{"If", "[", 
         RowBox[{
          RowBox[{
           RowBox[{"Det", "[", 
            RowBox[{"{", 
             RowBox[{
              RowBox[{
               RowBox[{"rs", "[", "\"\<ed\>\"", "]"}], "[", 
               RowBox[{"[", "k", "]"}], "]"}], ",", 
              RowBox[{
               RowBox[{"rs", "[", "\"\<vt\>\"", "]"}], "[", 
               RowBox[{"[", 
                RowBox[{
                 RowBox[{"rs", "[", 
                  RowBox[{"\"\<ed\>\"", ",", "\"\<vt\>\""}], "]"}], "[", 
                 RowBox[{"[", 
                  RowBox[{"k", ",", "1"}], "]"}], "]"}], "]"}], "]"}], ",", 
              RowBox[{
               RowBox[{"rs", "[", "\"\<fc\>\"", "]"}], "[", 
               RowBox[{"[", 
                RowBox[{
                 RowBox[{"rs", "[", 
                  RowBox[{"\"\<ed\>\"", ",", "\"\<fc\>\""}], "]"}], "[", 
                 RowBox[{"[", 
                  RowBox[{"k", ",", "1"}], "]"}], "]"}], "]"}], "]"}]}], 
             "}"}], "]"}], " ", ">", " ", "0"}], ",", " ", 
          RowBox[{
           RowBox[{"rs", "[", 
            RowBox[{"\"\<ed\>\"", ",", "\"\<fc\>\""}], "]"}], "[", 
           RowBox[{"[", "k", "]"}], "]"}], ",", 
          RowBox[{"Reverse", "[", 
           RowBox[{
            RowBox[{"rs", "[", 
             RowBox[{"\"\<ed\>\"", ",", "\"\<fc\>\""}], "]"}], "[", 
            RowBox[{"[", "k", "]"}], "]"}], "]"}]}], "]"}], ",", 
        RowBox[{"{", 
         RowBox[{"k", ",", 
          RowBox[{"Length", "[", 
           RowBox[{"rs", "[", "\"\<ed\>\"", "]"}], "]"}]}], "}"}]}], 
       "]"}]}]}]}], "\[IndentingNewLine]", "]"}]}]], "Input",
 CellLabel->
  "In[539]:=",ExpressionUUID->"bce94e5c-53e4-4838-bae7-9c4d0ac88472"],

Cell[BoxData[
 RowBox[{
  RowBox[{"RSVSNIAll", "[", "]"}], " ", ":=", " ", 
  RowBox[{"Do", "[", 
   RowBox[{
    RowBox[{"RSVSNI", "[", 
     RowBox[{"regsld", "[", "k", "]"}], "]"}], ",", 
    RowBox[{"{", 
     RowBox[{"k", ",", "3", ",", "5"}], "}"}]}], "]"}]}]], "Input",
 CellLabel->
  "In[540]:=",ExpressionUUID->"2b668755-0c33-43a0-b6ed-8e1a811e9d87"],

Cell[BoxData[
 RowBox[{"RSVSNIAll", "[", "]"}]], "Input",
 CellLabel->
  "In[541]:=",ExpressionUUID->"7422f129-eed6-414f-8a32-90896942c799"],

Cell[BoxData[
 RowBox[{"(*", " ", "Verification", " ", "*)"}]], "Input",
 CellLabel->
  "In[542]:=",ExpressionUUID->"07f5ab55-b76e-490d-9dc3-6eb415152153"],

Cell[BoxData[
 RowBox[{
  RowBox[{"RegSldVerify", "[", "rs_", "]"}], " ", ":=", " ", 
  RowBox[{"Module", "[", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{
     "tp", ",", "pts", ",", "lenverf", ",", "tp1", ",", "tp2", ",", "cn1", 
      ",", "cn2", ",", "k", ",", "l", ",", "connverf"}], "}"}], ",", 
    "\[IndentingNewLine]", 
    RowBox[{
     RowBox[{"lenverf", " ", "=", " ", 
      RowBox[{"And", " ", "@@", " ", 
       RowBox[{"Flatten", "[", 
        RowBox[{"Table", "[", 
         RowBox[{
          RowBox[{
           RowBox[{"pts", " ", "=", " ", 
            RowBox[{"rs", "[", "tp", "]"}]}], ";", " ", 
           RowBox[{"And", " ", "@@", " ", 
            RowBox[{"(", 
             RowBox[{
              RowBox[{
               RowBox[{"(", 
                RowBox[{
                 RowBox[{"(", 
                  RowBox[{
                   RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{"#", ".", "#"}], ")"}], "-", "1"}], ")"}], " ", "//",
                     " ", "Expand"}], " ", "//", " ", "Factor"}], ")"}], " ", 
                 "\[Equal]", " ", "0"}], ")"}], "&"}], " ", "/@", " ", 
              "pts"}], ")"}]}]}], ",", 
          RowBox[{"{", 
           RowBox[{"tp", ",", 
            RowBox[{"{", 
             RowBox[{"\"\<vt\>\"", ",", "\"\<ed\>\"", ",", "\"\<fc\>\""}], 
             "}"}]}], "}"}]}], "]"}], "\[IndentingNewLine]", "]"}]}]}], ";", 
     "\[IndentingNewLine]", 
     RowBox[{"connverf", " ", "=", " ", 
      RowBox[{"And", " ", "@@", " ", 
       RowBox[{"Flatten", "[", 
        RowBox[{"Table", "[", "\[IndentingNewLine]", 
         RowBox[{
          RowBox[{"If", "[", 
           RowBox[{
            RowBox[{"tp1", "\[Equal]", "tp2"}], ",", 
            RowBox[{"{", 
             RowBox[{"{", "True", "}"}], "}"}], ",", 
            RowBox[{
             RowBox[{"cn1", "=", " ", 
              RowBox[{"rs", "[", 
               RowBox[{"tp1", ",", "tp2"}], "]"}]}], ";", " ", 
             RowBox[{"cn2", " ", "=", " ", 
              RowBox[{"rs", "[", 
               RowBox[{"tp2", ",", "tp1"}], "]"}]}], ";", 
             RowBox[{"Table", "[", 
              RowBox[{
               RowBox[{"MemberQ", "[", 
                RowBox[{
                 RowBox[{"cn2", "[", 
                  RowBox[{"[", 
                   RowBox[{"cn1", "[", 
                    RowBox[{"[", 
                    RowBox[{"k", ",", "l"}], "]"}], "]"}], "]"}], "]"}], ",", 
                 "k"}], "]"}], ",", 
               RowBox[{"{", 
                RowBox[{"k", ",", 
                 RowBox[{"Length", "[", "cn1", "]"}]}], "}"}], ",", 
               RowBox[{"{", 
                RowBox[{"l", ",", 
                 RowBox[{"Length", "[", 
                  RowBox[{"cn1", "[", 
                   RowBox[{"[", "k", "]"}], "]"}], "]"}]}], "}"}]}], 
              "]"}]}]}], "]"}], ",", "\[IndentingNewLine]", 
          RowBox[{"{", 
           RowBox[{"tp1", ",", 
            RowBox[{"{", 
             RowBox[{"\"\<vt\>\"", ",", "\"\<ed\>\"", ",", "\"\<fc\>\""}], 
             "}"}]}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{"tp2", ",", 
            RowBox[{"{", 
             RowBox[{"\"\<vt\>\"", ",", "\"\<ed\>\"", ",", "\"\<fc\>\""}], 
             "}"}]}], "}"}]}], "]"}], "]"}]}]}], ";", "\[IndentingNewLine]", 
     RowBox[{"{", 
      RowBox[{"lenverf", ",", "connverf"}], "}"}]}]}], "\[IndentingNewLine]", 
   "]"}]}]], "Input",
 CellLabel->
  "In[543]:=",ExpressionUUID->"ce408c5e-5b3c-458e-90db-1dc22d824f01"],

Cell[BoxData[
 RowBox[{
  RowBox[{"RegSldVerifyAll", "[", "]"}], " ", ":=", " ", 
  RowBox[{"Table", "[", 
   RowBox[{
    RowBox[{"RegSldVerify", "[", 
     RowBox[{"regsld", "[", "k", "]"}], "]"}], ",", 
    RowBox[{"{", 
     RowBox[{"k", ",", "3", ",", "5"}], "}"}]}], "]"}]}]], "Input",
 CellLabel->
  "In[544]:=",ExpressionUUID->"c38051c4-7066-4a61-81f3-c84e7d56425d"],

Cell[BoxData[
 RowBox[{"RegSldVerifyAll", "[", "]"}]], "Input",
 CellLabel->
  "In[545]:=",ExpressionUUID->"371f9b7a-f66c-4678-81d2-2ca734f36b33"],

Cell[BoxData[
 RowBox[{
  RowBox[{"Table", "[", 
   RowBox[{
    RowBox[{
     RowBox[{"rs", " ", "=", " ", 
      RowBox[{"regsld", "[", "k", "]"}]}], ";", 
     RowBox[{"show3d", "[", 
      RowBox[{"GraphicsComplex", "[", 
       RowBox[{
        RowBox[{"rs", "[", "\"\<ed\>\"", "]"}], ",", 
        RowBox[{"{", 
         RowBox[{
          RowBox[{"FaceForm", "[", 
           RowBox[{"Red", ",", "Blue"}], "]"}], ",", 
          RowBox[{"Polygon", "[", 
           RowBox[{"rs", "[", 
            RowBox[{"\"\<vt\>\"", ",", "\"\<ed\>\""}], "]"}], "]"}]}], 
         "}"}]}], "]"}], "]"}]}], ",", 
    RowBox[{"{", 
     RowBox[{"k", ",", "3", ",", "5"}], "}"}]}], "]"}], ";"}]], "Input",
 CellLabel->
  "In[546]:=",ExpressionUUID->"c9bd1305-79b9-4554-8ac0-5e47cfd0648e"],

Cell[BoxData[
 RowBox[{"(*", " ", 
  RowBox[{
   RowBox[{"Face", " ", 
    RowBox[{"Orientation", ":", " ", 
     RowBox[{"red", " ", "should", " ", "be", " ", "outward"}]}]}], ",", " ", 
   
   RowBox[{"blue", " ", "inward"}]}], " ", "*)"}]], "Input",
 CellLabel->
  "In[547]:=",ExpressionUUID->"0d1de2e3-e93f-4d90-bbff-84685226fc4b"],

Cell[BoxData[
 RowBox[{
  RowBox[{"OrientShowRegSld", "[", 
   RowBox[{"rs_", ",", "tp0_", ",", "tp1_"}], "]"}], " ", ":=", " ", 
  RowBox[{"show3d", "[", 
   RowBox[{"GraphicsComplex", "[", 
    RowBox[{
     RowBox[{"rs", "[", "tp1", "]"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"FaceForm", "[", 
        RowBox[{"Red", ",", "Blue"}], "]"}], ",", 
       RowBox[{"Polygon", "[", 
        RowBox[{"rs", "[", 
         RowBox[{"tp0", ",", "tp1"}], "]"}], "]"}]}], "}"}]}], "]"}], 
   "]"}]}]], "Input",
 CellLabel->
  "In[548]:=",ExpressionUUID->"e0c0e65b-0c08-46a6-a8db-22986e91d008"],

Cell[BoxData[
 RowBox[{
  RowBox[{"OrientShowEVF", "[", "rs_", "]"}], " ", ":=", " ", 
  RowBox[{"Module", "[", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{
     "pts", ",", "numeds", ",", "vtixs", ",", "fcixs", ",", "k", ",", "vts", 
      ",", "fcs", ",", "evfixs"}], "}"}], ",", "\[IndentingNewLine]", 
    RowBox[{
     RowBox[{"pts", " ", "=", " ", 
      RowBox[{"Join", "[", 
       RowBox[{
        RowBox[{"rs", "[", "\"\<ed\>\"", "]"}], ",", 
        RowBox[{"rs", "[", "\"\<vt\>\"", "]"}], ",", 
        RowBox[{"rs", "[", "\"\<fc\>\"", "]"}]}], "]"}]}], ";", 
     "\[IndentingNewLine]", 
     RowBox[{"numeds", " ", "=", " ", 
      RowBox[{"Length", "[", 
       RowBox[{"rs", "[", "\"\<ed\>\"", "]"}], "]"}]}], ";", 
     "\[IndentingNewLine]", 
     RowBox[{"vtixs", " ", "=", " ", 
      RowBox[{"numeds", " ", "+", " ", 
       RowBox[{"rs", "[", 
        RowBox[{"\"\<ed\>\"", ",", "\"\<vt\>\""}], "]"}]}]}], ";", 
     "\[IndentingNewLine]", 
     RowBox[{"fcixs", " ", "=", " ", 
      RowBox[{"numeds", " ", "+", " ", 
       RowBox[{"Length", "[", 
        RowBox[{"rs", "[", "\"\<vt\>\"", "]"}], "]"}], " ", "+", " ", 
       RowBox[{"rs", "[", 
        RowBox[{"\"\<ed\>\"", ",", "\"\<fc\>\""}], "]"}]}]}], ";", 
     "\[IndentingNewLine]", 
     RowBox[{"evfixs", " ", "=", " ", 
      RowBox[{"Table", "[", 
       RowBox[{
        RowBox[{
         RowBox[{"vts", " ", "=", " ", 
          RowBox[{"vtixs", "[", 
           RowBox[{"[", "k", "]"}], "]"}]}], ";", " ", 
         RowBox[{"fcs", " ", "=", " ", 
          RowBox[{"fcixs", "[", 
           RowBox[{"[", "k", "]"}], "]"}]}], ";", "\[IndentingNewLine]", 
         RowBox[{"{", 
          RowBox[{
           RowBox[{"{", 
            RowBox[{"k", ",", 
             RowBox[{"vts", "[", 
              RowBox[{"[", "1", "]"}], "]"}], ",", 
             RowBox[{"fcs", "[", 
              RowBox[{"[", "1", "]"}], "]"}]}], "}"}], ",", 
           RowBox[{"{", 
            RowBox[{"k", ",", 
             RowBox[{"fcs", "[", 
              RowBox[{"[", "1", "]"}], "]"}], ",", 
             RowBox[{"vts", "[", 
              RowBox[{"[", "2", "]"}], "]"}]}], "}"}], ",", 
           RowBox[{"{", 
            RowBox[{"k", ",", 
             RowBox[{"vts", "[", 
              RowBox[{"[", "2", "]"}], "]"}], ",", 
             RowBox[{"fcs", "[", 
              RowBox[{"[", "2", "]"}], "]"}]}], "}"}], ",", 
           RowBox[{"{", 
            RowBox[{"k", ",", 
             RowBox[{"fcs", "[", 
              RowBox[{"[", "2", "]"}], "]"}], ",", 
             RowBox[{"vts", "[", 
              RowBox[{"[", "1", "]"}], "]"}]}], "}"}]}], "}"}]}], ",", 
        RowBox[{"{", 
         RowBox[{"k", ",", "numeds"}], "}"}]}], "]"}]}], ";", 
     "\[IndentingNewLine]", 
     RowBox[{"show3d", "[", 
      RowBox[{"GraphicsComplex", "[", 
       RowBox[{"pts", ",", 
        RowBox[{"{", 
         RowBox[{
          RowBox[{"FaceForm", "[", 
           RowBox[{"Red", ",", "Blue"}], "]"}], ",", 
          RowBox[{"Polygon", "[", 
           RowBox[{"Flatten", "[", 
            RowBox[{"evfixs", ",", "1"}], "]"}], "]"}]}], "}"}]}], "]"}], 
      "]"}]}]}], "\[IndentingNewLine]", "]"}]}]], "Input",
 CellLabel->
  "In[549]:=",ExpressionUUID->"15c13b60-d651-41d5-b63d-13f6b07287c8"],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"OrientShowRegSldSet", "[", "rs_", "]"}], " ", ":=", " ", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{"OrientShowRegSld", "[", 
        RowBox[{"rs", ",", "\"\<vt\>\"", ",", "\"\<fc\>\""}], "]"}], ",", 
       RowBox[{"OrientShowRegSld", "[", 
        RowBox[{"rs", ",", "\"\<fc\>\"", ",", "\"\<vt\>\""}], "]"}]}], "}"}], 
     ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"OrientShowRegSld", "[", 
        RowBox[{"rs", ",", "\"\<vt\>\"", ",", "\"\<ed\>\""}], "]"}], ",", 
       RowBox[{"OrientShowRegSld", "[", 
        RowBox[{"rs", ",", "\"\<fc\>\"", ",", "\"\<ed\>\""}], "]"}]}], "}"}], 
     ",", 
     RowBox[{"{", 
      RowBox[{"OrientShowEVF", "[", "rs", "]"}], "}"}]}], "}"}]}], 
  ";"}]], "Input",
 CellLabel->
  "In[550]:=",ExpressionUUID->"3f62827a-06bf-4448-810f-5daf6e753278"],

Cell[BoxData[
 RowBox[{
  RowBox[{"OrientShowRegSldSetAll", "[", "]"}], " ", ":=", " ", 
  RowBox[{"Table", "[", 
   RowBox[{
    RowBox[{"OrientShowRegSldSet", "[", 
     RowBox[{"regsld", "[", "k", "]"}], "]"}], ",", 
    RowBox[{"{", 
     RowBox[{"k", ",", "3", ",", "5"}], "}"}]}], "]"}]}]], "Input",
 CellLabel->
  "In[551]:=",ExpressionUUID->"03f02fcb-fc56-4895-b035-f5ec089013aa"]
}, Closed]],

Cell[CellGroupData[{

Cell["Regular Solids", "Subsubsection",ExpressionUUID->"a7e245e9-96c9-42c8-b8e8-ef618db7dc86"],

Cell[BoxData[
 RowBox[{
  RowBox[{"model", "[", 
   RowBox[{"\"\<rs tri\>\"", ",", "n_", ",", "r_"}], "]"}], " ", ":=", " ", 
  RowBox[{"Module", "[", 
   RowBox[{
    RowBox[{"{", "rs", "}"}], ",", "\[IndentingNewLine]", 
    RowBox[{
     RowBox[{"rs", " ", "=", " ", 
      RowBox[{"regsld", "[", "n", "]"}]}], ";", "\[IndentingNewLine]", 
     RowBox[{"GraphicsComplex", "[", 
      RowBox[{
       RowBox[{"r", "*", 
        RowBox[{"rs", "[", "\"\<vt\>\"", "]"}]}], ",", 
       RowBox[{"Polygon", "[", 
        RowBox[{"rs", "[", 
         RowBox[{"\"\<fc\>\"", ",", "\"\<vt\>\""}], "]"}], "]"}]}], "]"}]}]}],
    "\[IndentingNewLine]", "]"}]}]], "Input",
 CellLabel->
  "In[552]:=",ExpressionUUID->"e03cadf8-26ab-4590-9f40-81467821d66c"],

Cell[BoxData[
 RowBox[{
  RowBox[{"model", "[", 
   RowBox[{"\"\<rs dual\>\"", ",", "n_", ",", "r_"}], "]"}], " ", ":=", " ", 
  RowBox[{"Module", "[", 
   RowBox[{
    RowBox[{"{", "rs", "}"}], ",", "\[IndentingNewLine]", 
    RowBox[{
     RowBox[{"rs", " ", "=", " ", 
      RowBox[{"regsld", "[", "n", "]"}]}], ";", "\[IndentingNewLine]", 
     RowBox[{"GraphicsComplex", "[", 
      RowBox[{
       RowBox[{"r", "*", 
        RowBox[{"rs", "[", "\"\<fc\>\"", "]"}]}], ",", 
       RowBox[{"Polygon", "[", 
        RowBox[{"rs", "[", 
         RowBox[{"\"\<vt\>\"", ",", "\"\<fc\>\""}], "]"}], "]"}]}], "]"}]}]}],
    "\[IndentingNewLine]", "]"}]}]], "Input",
 CellLabel->
  "In[553]:=",ExpressionUUID->"a0f8b9bc-d53b-4a2a-8222-04a0c9ad62e0"],

Cell[BoxData[
 RowBox[{"(*", " ", 
  RowBox[{"Triaxial", " ", "tetrahedron", " ", 
   RowBox[{"(", "disphenoid", ")"}]}], " ", "*)"}]], "Input",
 CellLabel->
  "In[554]:=",ExpressionUUID->"bd56d813-fec5-4ae3-9029-3dc2cae10121"],

Cell[BoxData[
 RowBox[{
  RowBox[{"model", "[", 
   RowBox[{"\"\<rs dsph\>\"", ",", "r1_", ",", "r2_", ",", "r3_"}], "]"}], 
  " ", ":=", " ", 
  RowBox[{"Module", "[", 
   RowBox[{
    RowBox[{"{", "rs", "}"}], ",", "\[IndentingNewLine]", 
    RowBox[{
     RowBox[{"rs", " ", "=", " ", 
      RowBox[{"regsld", "[", "3", "]"}]}], ";", "\[IndentingNewLine]", 
     RowBox[{"GraphicsComplex", "[", 
      RowBox[{
       RowBox[{
        RowBox[{
         RowBox[{
          RowBox[{"{", 
           RowBox[{"r1", ",", "r2", ",", "r3"}], "}"}], "*", "#"}], "&"}], 
        " ", "/@", " ", 
        RowBox[{"rs", "[", "\"\<vt\>\"", "]"}]}], ",", 
       RowBox[{"Polygon", "[", 
        RowBox[{"rs", "[", 
         RowBox[{"\"\<fc\>\"", ",", "\"\<vt\>\""}], "]"}], "]"}]}], "]"}]}]}],
    "\[IndentingNewLine]", "]"}]}]], "Input",
 CellLabel->
  "In[555]:=",ExpressionUUID->"fbb251fb-64c3-4506-b898-71b9022fe41c"],

Cell[BoxData[
 RowBox[{"(*", " ", 
  RowBox[{"Rectangular", " ", "cuboid"}], " ", "*)"}]], "Input",
 CellLabel->
  "In[556]:=",ExpressionUUID->"08c88a8f-da5b-4bc7-bd01-338c0503160a"],

Cell[BoxData[
 RowBox[{
  RowBox[{"model", "[", 
   RowBox[{"\"\<rs rect\>\"", ",", "r1_", ",", "r2_", ",", "r3_"}], "]"}], 
  " ", ":=", " ", 
  RowBox[{"Module", "[", 
   RowBox[{
    RowBox[{"{", "rs", "}"}], ",", "\[IndentingNewLine]", 
    RowBox[{
     RowBox[{"rs", " ", "=", " ", 
      RowBox[{"regsld", "[", "4", "]"}]}], ";", "\[IndentingNewLine]", 
     RowBox[{"GraphicsComplex", "[", 
      RowBox[{
       RowBox[{
        RowBox[{
         RowBox[{
          RowBox[{"{", 
           RowBox[{"r1", ",", "r2", ",", "r3"}], "}"}], "*", "#"}], "&"}], 
        " ", "/@", " ", 
        RowBox[{"rs", "[", "\"\<fc\>\"", "]"}]}], ",", "\[IndentingNewLine]", 
       
       RowBox[{"Polygon", "[", 
        RowBox[{"rs", "[", 
         RowBox[{"\"\<vt\>\"", ",", "\"\<fc\>\""}], "]"}], "]"}]}], "]"}]}]}],
    "\[IndentingNewLine]", "]"}]}]], "Input",
 CellLabel->
  "In[557]:=",ExpressionUUID->"a3e53d42-cb92-42be-a64c-3beb6b63b261"],

Cell[BoxData[
 RowBox[{"(*", " ", 
  RowBox[{
   RowBox[{"Irregular", " ", "isohedral", " ", "octahedra"}], " ", "-", " ", 
   RowBox[{"use", " ", "4"}], "-", "bipyramids"}], " ", "*)"}]], "Input",
 CellLabel->
  "In[558]:=",ExpressionUUID->"2ec2c2e7-8179-4094-9105-787386203a3b"],

Cell[BoxData[
 RowBox[{"(*", " ", 
  RowBox[{
   RowBox[{"Irregular", " ", "isohedral", " ", "cuboids"}], " ", "-", " ", 
   RowBox[{"use", " ", "3"}], "-", "trapezohedron"}], " ", "*)"}]], "Input",
 CellLabel->
  "In[559]:=",ExpressionUUID->"d3ea75e5-d47b-46d6-a1eb-62688f7e1209"]
}, Closed]],

Cell[CellGroupData[{

Cell["Pyramid Faces", "Subsubsection",ExpressionUUID->"94b52595-33a4-40f1-9cdf-e3433e7b0036"],

Cell[BoxData[
 RowBox[{
  RowBox[{"model", "[", 
   RowBox[{"\"\<rs pyr tri\>\"", ",", "n_", ",", "r1_", ",", "r2_"}], "]"}], 
  " ", ":=", " ", 
  RowBox[{"Module", "[", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{
     "rs", ",", "pts", ",", "ixs1", ",", "ixs2", ",", "k", ",", "ixs"}], 
     "}"}], ",", "\[IndentingNewLine]", 
    RowBox[{
     RowBox[{"rs", " ", "=", " ", 
      RowBox[{"regsld", "[", "n", "]"}]}], ";", "\[IndentingNewLine]", 
     RowBox[{"pts", " ", "=", " ", 
      RowBox[{"Join", "[", 
       RowBox[{
        RowBox[{"r1", "*", 
         RowBox[{"rs", "[", "\"\<vt\>\"", "]"}]}], ",", 
        RowBox[{"r2", "*", 
         RowBox[{"rs", "[", "\"\<fc\>\"", "]"}]}]}], "]"}]}], ";", 
     "\[IndentingNewLine]", 
     RowBox[{"ixs1", " ", "=", " ", 
      RowBox[{"rs", "[", 
       RowBox[{"\"\<ed\>\"", ",", "\"\<vt\>\""}], "]"}]}], ";", 
     "\[IndentingNewLine]", 
     RowBox[{"ixs2", " ", "=", " ", 
      RowBox[{
       RowBox[{"Length", "[", 
        RowBox[{"rs", "[", "\"\<vt\>\"", "]"}], "]"}], " ", "+", " ", 
       RowBox[{"rs", "[", 
        RowBox[{"\"\<ed\>\"", ",", "\"\<fc\>\""}], "]"}]}]}], ";", 
     "\[IndentingNewLine]", 
     RowBox[{"ixs", " ", "=", " ", 
      RowBox[{"Flatten", "[", 
       RowBox[{
        RowBox[{"Table", "[", 
         RowBox[{
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{
              RowBox[{"ixs1", "[", 
               RowBox[{"[", 
                RowBox[{"k", ",", "1"}], "]"}], "]"}], ",", 
              RowBox[{"ixs2", "[", 
               RowBox[{"[", 
                RowBox[{"k", ",", "1"}], "]"}], "]"}], ",", 
              RowBox[{"ixs1", "[", 
               RowBox[{"[", 
                RowBox[{"k", ",", "2"}], "]"}], "]"}]}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{
              RowBox[{"ixs1", "[", 
               RowBox[{"[", 
                RowBox[{"k", ",", "2"}], "]"}], "]"}], ",", 
              RowBox[{"ixs2", "[", 
               RowBox[{"[", 
                RowBox[{"k", ",", "2"}], "]"}], "]"}], ",", 
              RowBox[{"ixs1", "[", 
               RowBox[{"[", 
                RowBox[{"k", ",", "1"}], "]"}], "]"}]}], "}"}]}], "}"}], ",", 
          
          RowBox[{"{", 
           RowBox[{"k", ",", 
            RowBox[{"Length", "[", 
             RowBox[{"rs", "[", "\"\<ed\>\"", "]"}], "]"}]}], "}"}]}], "]"}], 
        ",", "1"}], "]"}]}], ";", "\[IndentingNewLine]", 
     RowBox[{"GraphicsComplex", "[", 
      RowBox[{"pts", ",", 
       RowBox[{"Polygon", "[", "ixs", "]"}]}], "]"}]}]}], 
   "\[IndentingNewLine]", "]"}]}]], "Input",
 CellLabel->
  "In[560]:=",ExpressionUUID->"d0fe8ca9-5403-4b4c-be8c-7b57e90cffcd"],

Cell[BoxData[
 RowBox[{
  RowBox[{"model", "[", 
   RowBox[{"\"\<rs pyr tri\>\"", ",", "n_", ",", "r_"}], "]"}], " ", ":=", 
  " ", 
  RowBox[{"model", "[", 
   RowBox[{"\"\<rs pyr tri\>\"", ",", "n", ",", "r", ",", "r"}], 
   "]"}]}]], "Input",
 CellLabel->
  "In[561]:=",ExpressionUUID->"8cd146e8-4ad3-4ac2-8a36-48a36a847f0c"],

Cell[BoxData[
 RowBox[{
  RowBox[{"model", "[", 
   RowBox[{"\"\<rs pyr dual\>\"", ",", "n_", ",", "r1_", ",", "r2_"}], "]"}], 
  " ", ":=", " ", 
  RowBox[{"Module", "[", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{
     "rs", ",", "pts", ",", "ixs1", ",", "ixs2", ",", "k", ",", "ixs"}], 
     "}"}], ",", "\[IndentingNewLine]", 
    RowBox[{
     RowBox[{"rs", " ", "=", " ", 
      RowBox[{"regsld", "[", "n", "]"}]}], ";", "\[IndentingNewLine]", 
     RowBox[{"pts", " ", "=", " ", 
      RowBox[{"Join", "[", 
       RowBox[{
        RowBox[{"r1", "*", 
         RowBox[{"rs", "[", "\"\<fc\>\"", "]"}]}], ",", 
        RowBox[{"r2", "*", 
         RowBox[{"rs", "[", "\"\<vt\>\"", "]"}]}]}], "]"}]}], ";", 
     "\[IndentingNewLine]", 
     RowBox[{"ixs1", " ", "=", " ", 
      RowBox[{"rs", "[", 
       RowBox[{"\"\<ed\>\"", ",", "\"\<fc\>\""}], "]"}]}], ";", 
     "\[IndentingNewLine]", 
     RowBox[{"ixs2", " ", "=", " ", 
      RowBox[{
       RowBox[{"Length", "[", 
        RowBox[{"rs", "[", "\"\<fc\>\"", "]"}], "]"}], " ", "+", " ", 
       RowBox[{"rs", "[", 
        RowBox[{"\"\<ed\>\"", ",", "\"\<vt\>\""}], "]"}]}]}], ";", 
     "\[IndentingNewLine]", 
     RowBox[{"ixs", " ", "=", " ", 
      RowBox[{"Flatten", "[", 
       RowBox[{
        RowBox[{"Table", "[", 
         RowBox[{
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{
              RowBox[{"ixs1", "[", 
               RowBox[{"[", 
                RowBox[{"k", ",", "1"}], "]"}], "]"}], ",", 
              RowBox[{"ixs1", "[", 
               RowBox[{"[", 
                RowBox[{"k", ",", "2"}], "]"}], "]"}], ",", 
              RowBox[{"ixs2", "[", 
               RowBox[{"[", 
                RowBox[{"k", ",", "1"}], "]"}], "]"}]}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{
              RowBox[{"ixs1", "[", 
               RowBox[{"[", 
                RowBox[{"k", ",", "2"}], "]"}], "]"}], ",", 
              RowBox[{"ixs1", "[", 
               RowBox[{"[", 
                RowBox[{"k", ",", "1"}], "]"}], "]"}], ",", 
              RowBox[{"ixs2", "[", 
               RowBox[{"[", 
                RowBox[{"k", ",", "2"}], "]"}], "]"}]}], "}"}]}], "}"}], ",", 
          
          RowBox[{"{", 
           RowBox[{"k", ",", 
            RowBox[{"Length", "[", 
             RowBox[{"rs", "[", "\"\<ed\>\"", "]"}], "]"}]}], "}"}]}], "]"}], 
        ",", "1"}], "]"}]}], ";", "\[IndentingNewLine]", 
     RowBox[{"GraphicsComplex", "[", 
      RowBox[{"pts", ",", 
       RowBox[{"Polygon", "[", "ixs", "]"}]}], "]"}]}]}], 
   "\[IndentingNewLine]", "]"}]}]], "Input",
 CellLabel->
  "In[562]:=",ExpressionUUID->"71a31246-06c5-469b-a430-55b0735b34f7"],

Cell[BoxData[
 RowBox[{
  RowBox[{"model", "[", 
   RowBox[{"\"\<rs pyr dual\>\"", ",", "n_", ",", "r_"}], "]"}], " ", ":=", 
  " ", 
  RowBox[{"model", "[", 
   RowBox[{"\"\<rs pyr dual\>\"", ",", "n", ",", "r", ",", "r"}], 
   "]"}]}]], "Input",
 CellLabel->
  "In[563]:=",ExpressionUUID->"06b23642-30fe-40c2-a4ca-da578c171117"],

Cell[BoxData[
 RowBox[{
  RowBox[{"model", "[", 
   RowBox[{
   "\"\<rs pyr both\>\"", ",", "n_", ",", "r1_", ",", "r2_", ",", "r3_"}], 
   "]"}], " ", ":=", " ", 
  RowBox[{"Module", "[", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{
     "rs", ",", "pts", ",", "ixs1", ",", "ixs2", ",", "ixs3", ",", "k", ",", 
      "ixs"}], "}"}], ",", "\[IndentingNewLine]", 
    RowBox[{
     RowBox[{"rs", " ", "=", " ", 
      RowBox[{"regsld", "[", "n", "]"}]}], ";", "\[IndentingNewLine]", 
     RowBox[{"pts", " ", "=", " ", 
      RowBox[{"Join", "[", 
       RowBox[{
        RowBox[{"r1", "*", 
         RowBox[{"rs", "[", "\"\<vt\>\"", "]"}]}], ",", 
        RowBox[{"r2", "*", 
         RowBox[{"rs", "[", "\"\<fc\>\"", "]"}]}], ",", 
        RowBox[{"r3", "*", 
         RowBox[{"rs", "[", "\"\<ed\>\"", "]"}]}]}], "]"}]}], ";", 
     "\[IndentingNewLine]", 
     RowBox[{"ixs1", " ", "=", " ", 
      RowBox[{"rs", "[", 
       RowBox[{"\"\<ed\>\"", ",", "\"\<vt\>\""}], "]"}]}], ";", 
     "\[IndentingNewLine]", 
     RowBox[{"ixs2", " ", "=", " ", 
      RowBox[{
       RowBox[{"Length", "[", 
        RowBox[{"rs", "[", "\"\<vt\>\"", "]"}], "]"}], " ", "+", " ", 
       RowBox[{"rs", "[", 
        RowBox[{"\"\<ed\>\"", ",", "\"\<fc\>\""}], "]"}]}]}], ";", 
     "\[IndentingNewLine]", 
     RowBox[{"ixs3", " ", "=", " ", 
      RowBox[{
       RowBox[{"(", 
        RowBox[{
         RowBox[{"Length", "[", 
          RowBox[{"rs", "[", "\"\<vt\>\"", "]"}], "]"}], " ", "+", 
         RowBox[{"Length", "[", 
          RowBox[{"rs", "[", "\"\<fc\>\"", "]"}], "]"}]}], ")"}], " ", "+", 
       " ", 
       RowBox[{"Range", "[", 
        RowBox[{"Length", "[", 
         RowBox[{"rs", "[", "\"\<ed\>\"", "]"}], "]"}], "]"}]}]}], ";", 
     "\[IndentingNewLine]", 
     RowBox[{"ixs", " ", "=", " ", 
      RowBox[{"Flatten", "[", 
       RowBox[{
        RowBox[{"Table", "[", 
         RowBox[{
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{
              RowBox[{"ixs1", "[", 
               RowBox[{"[", 
                RowBox[{"k", ",", "1"}], "]"}], "]"}], ",", 
              RowBox[{"ixs2", "[", 
               RowBox[{"[", 
                RowBox[{"k", ",", "1"}], "]"}], "]"}], ",", 
              RowBox[{"ixs3", "[", 
               RowBox[{"[", "k", "]"}], "]"}]}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{
              RowBox[{"ixs2", "[", 
               RowBox[{"[", 
                RowBox[{"k", ",", "1"}], "]"}], "]"}], ",", 
              RowBox[{"ixs1", "[", 
               RowBox[{"[", 
                RowBox[{"k", ",", "2"}], "]"}], "]"}], ",", 
              RowBox[{"ixs3", "[", 
               RowBox[{"[", "k", "]"}], "]"}]}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{
              RowBox[{"ixs1", "[", 
               RowBox[{"[", 
                RowBox[{"k", ",", "2"}], "]"}], "]"}], ",", 
              RowBox[{"ixs2", "[", 
               RowBox[{"[", 
                RowBox[{"k", ",", "2"}], "]"}], "]"}], ",", 
              RowBox[{"ixs3", "[", 
               RowBox[{"[", "k", "]"}], "]"}]}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{
              RowBox[{"ixs2", "[", 
               RowBox[{"[", 
                RowBox[{"k", ",", "2"}], "]"}], "]"}], ",", 
              RowBox[{"ixs1", "[", 
               RowBox[{"[", 
                RowBox[{"k", ",", "1"}], "]"}], "]"}], ",", 
              RowBox[{"ixs3", "[", 
               RowBox[{"[", "k", "]"}], "]"}]}], "}"}]}], "}"}], ",", 
          "\[IndentingNewLine]", 
          RowBox[{"{", 
           RowBox[{"k", ",", 
            RowBox[{"Length", "[", 
             RowBox[{"rs", "[", "\"\<ed\>\"", "]"}], "]"}]}], "}"}]}], "]"}], 
        ",", "1"}], "]"}]}], ";", "\[IndentingNewLine]", 
     RowBox[{"GraphicsComplex", "[", 
      RowBox[{"pts", ",", 
       RowBox[{"Polygon", "[", "ixs", "]"}]}], "]"}]}]}], 
   "\[IndentingNewLine]", "]"}]}]], "Input",
 CellLabel->
  "In[564]:=",ExpressionUUID->"5458d77c-9b64-443b-b1c3-ce5090245133"],

Cell[BoxData[
 RowBox[{
  RowBox[{"model", "[", 
   RowBox[{"\"\<rs pyr both\>\"", ",", "n_", ",", "r_"}], "]"}], " ", ":=", 
  " ", 
  RowBox[{"model", "[", 
   RowBox[{"\"\<rs pyr both\>\"", ",", "n", ",", "r", ",", "r", ",", "r"}], 
   "]"}]}]], "Input",
 CellLabel->
  "In[565]:=",ExpressionUUID->"c86af811-7107-46f2-91e0-38f444f06b9a"]
}, Closed]],

Cell[CellGroupData[{

Cell["Quad Faces", "Subsubsection",ExpressionUUID->"43826dcc-2681-4eee-bb33-a12a289de913"],

Cell[BoxData[
 RowBox[{
  RowBox[{"model", "[", 
   RowBox[{"\"\<rs rhomb\>\"", ",", "n_", ",", "r_"}], "]"}], " ", ":=", " ", 
  
  RowBox[{"Module", "[", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{
     "rs", ",", "c", ",", "r1", ",", "r2", ",", "pts", ",", "ixs1", ",", 
      "ixs2", ",", "k", ",", "ixs"}], "}"}], ",", "\[IndentingNewLine]", 
    RowBox[{
     RowBox[{"rs", " ", "=", " ", 
      RowBox[{"regsld", "[", "n", "]"}]}], ";", "\[IndentingNewLine]", 
     RowBox[{"c", " ", "=", " ", 
      RowBox[{"Cos", "[", 
       RowBox[{"2", 
        RowBox[{"Pi", "/", "n"}]}], "]"}]}], ";", "\[IndentingNewLine]", 
     RowBox[{"r1", " ", "=", " ", "r"}], ";", "\[IndentingNewLine]", 
     RowBox[{"r2", " ", "=", " ", 
      RowBox[{
       RowBox[{
        RowBox[{"(", 
         RowBox[{
          RowBox[{"Sqrt", "[", "3", "]"}], "/", "2"}], ")"}], "/", 
        RowBox[{"Sqrt", "[", 
         RowBox[{"1", "-", 
          RowBox[{"c", "^", "2"}]}], "]"}]}], "*", "r"}]}], ";", 
     "\[IndentingNewLine]", 
     RowBox[{"pts", " ", "=", " ", 
      RowBox[{"Join", "[", 
       RowBox[{
        RowBox[{"r1", "*", 
         RowBox[{"rs", "[", "\"\<vt\>\"", "]"}]}], ",", 
        RowBox[{"r2", "*", 
         RowBox[{"rs", "[", "\"\<fc\>\"", "]"}]}]}], "]"}]}], ";", 
     "\[IndentingNewLine]", 
     RowBox[{"ixs1", " ", "=", " ", 
      RowBox[{"rs", "[", 
       RowBox[{"\"\<ed\>\"", ",", "\"\<vt\>\""}], "]"}]}], ";", 
     "\[IndentingNewLine]", 
     RowBox[{"ixs2", " ", "=", " ", 
      RowBox[{
       RowBox[{"Length", "[", 
        RowBox[{"rs", "[", "\"\<vt\>\"", "]"}], "]"}], " ", "+", " ", 
       RowBox[{"rs", "[", 
        RowBox[{"\"\<ed\>\"", ",", "\"\<fc\>\""}], "]"}]}]}], ";", 
     "\[IndentingNewLine]", 
     RowBox[{"ixs", " ", "=", " ", 
      RowBox[{"Table", "[", 
       RowBox[{
        RowBox[{"{", 
         RowBox[{
          RowBox[{"ixs1", "[", 
           RowBox[{"[", 
            RowBox[{"k", ",", "1"}], "]"}], "]"}], ",", 
          RowBox[{"ixs2", "[", 
           RowBox[{"[", 
            RowBox[{"k", ",", "1"}], "]"}], "]"}], ",", 
          RowBox[{"ixs1", "[", 
           RowBox[{"[", 
            RowBox[{"k", ",", "2"}], "]"}], "]"}], ",", 
          RowBox[{"ixs2", "[", 
           RowBox[{"[", 
            RowBox[{"k", ",", "2"}], "]"}], "]"}]}], "}"}], ",", 
        RowBox[{"{", 
         RowBox[{"k", ",", 
          RowBox[{"Length", "[", 
           RowBox[{"rs", "[", "\"\<ed\>\"", "]"}], "]"}]}], "}"}]}], "]"}]}], 
     ";", "\[IndentingNewLine]", 
     RowBox[{"GraphicsComplex", "[", 
      RowBox[{"pts", ",", 
       RowBox[{"Polygon", "[", "ixs", "]"}]}], "]"}]}]}], 
   "\[IndentingNewLine]", "]"}]}]], "Input",
 CellLabel->
  "In[566]:=",ExpressionUUID->"2d3c8aa5-dcdd-478e-88f0-646e4a67dfba"],

Cell[BoxData[
 RowBox[{
  RowBox[{"model", "[", 
   RowBox[{"\"\<rs rhomb shft\>\"", ",", "r_", ",", "f_"}], "]"}], " ", ":=", 
  " ", 
  RowBox[{"Module", "[", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{
      RowBox[{"n", " ", "=", " ", "4"}], ",", "rs", ",", "c", ",", "r1", ",", 
      "r2", ",", "pts", ",", "ixs1", ",", "ixs2", ",", "k", ",", "ixs"}], 
     "}"}], ",", "\[IndentingNewLine]", 
    RowBox[{
     RowBox[{"rs", " ", "=", " ", 
      RowBox[{"regsld", "[", "n", "]"}]}], ";", "\[IndentingNewLine]", 
     RowBox[{"c", " ", "=", " ", 
      RowBox[{"Cos", "[", 
       RowBox[{"2", 
        RowBox[{"Pi", "/", "n"}]}], "]"}]}], ";", "\[IndentingNewLine]", 
     RowBox[{"r1", " ", "=", " ", "r"}], ";", "\[IndentingNewLine]", 
     RowBox[{"r2", " ", "=", " ", 
      RowBox[{
       RowBox[{
        RowBox[{"(", 
         RowBox[{
          RowBox[{"Sqrt", "[", "3", "]"}], "/", "2"}], ")"}], "/", 
        RowBox[{"Sqrt", "[", 
         RowBox[{"1", "-", 
          RowBox[{"c", "^", "2"}]}], "]"}]}], "*", "r"}]}], ";", 
     "\[IndentingNewLine]", 
     RowBox[{"pts", " ", "=", " ", 
      RowBox[{"Join", "[", 
       RowBox[{
        RowBox[{"r1", "*", 
         RowBox[{"rs", "[", "\"\<vt\>\"", "]"}]}], ",", 
        RowBox[{"r2", "*", 
         RowBox[{
          RowBox[{"rs", "[", "\"\<fc\>\"", "]"}], "/", 
          RowBox[{"(", 
           RowBox[{"1", "-", " ", 
            RowBox[{"f", "*", 
             RowBox[{"(", 
              RowBox[{
               RowBox[{
                RowBox[{"Sign", "[", 
                 RowBox[{"Times", " ", "@@", " ", "#"}], "]"}], "&"}], " ", "/@",
                " ", 
               RowBox[{"rs", "[", "\"\<fc\>\"", "]"}]}], ")"}]}]}], 
           ")"}]}]}]}], "]"}]}], ";", "\[IndentingNewLine]", 
     RowBox[{"ixs1", " ", "=", " ", 
      RowBox[{"rs", "[", 
       RowBox[{"\"\<ed\>\"", ",", "\"\<vt\>\""}], "]"}]}], ";", 
     "\[IndentingNewLine]", 
     RowBox[{"ixs2", " ", "=", " ", 
      RowBox[{
       RowBox[{"Length", "[", 
        RowBox[{"rs", "[", "\"\<vt\>\"", "]"}], "]"}], " ", "+", " ", 
       RowBox[{"rs", "[", 
        RowBox[{"\"\<ed\>\"", ",", "\"\<fc\>\""}], "]"}]}]}], ";", 
     "\[IndentingNewLine]", 
     RowBox[{"ixs", " ", "=", " ", 
      RowBox[{"Table", "[", 
       RowBox[{
        RowBox[{"{", 
         RowBox[{
          RowBox[{"ixs1", "[", 
           RowBox[{"[", 
            RowBox[{"k", ",", "1"}], "]"}], "]"}], ",", 
          RowBox[{"ixs2", "[", 
           RowBox[{"[", 
            RowBox[{"k", ",", "1"}], "]"}], "]"}], ",", 
          RowBox[{"ixs1", "[", 
           RowBox[{"[", 
            RowBox[{"k", ",", "2"}], "]"}], "]"}], ",", 
          RowBox[{"ixs2", "[", 
           RowBox[{"[", 
            RowBox[{"k", ",", "2"}], "]"}], "]"}]}], "}"}], ",", 
        RowBox[{"{", 
         RowBox[{"k", ",", 
          RowBox[{"Length", "[", 
           RowBox[{"rs", "[", "\"\<ed\>\"", "]"}], "]"}]}], "}"}]}], "]"}]}], 
     ";", "\[IndentingNewLine]", 
     RowBox[{"GraphicsComplex", "[", 
      RowBox[{"pts", ",", 
       RowBox[{"Polygon", "[", "ixs", "]"}]}], "]"}]}]}], 
   "\[IndentingNewLine]", "]"}]}]], "Input",
 CellLabel->
  "In[567]:=",ExpressionUUID->"6e4357d1-d2e3-4615-9523-052ecb97a994"],

Cell[BoxData[
 RowBox[{
  RowBox[{"kitepoints", "[", "rs_", "]"}], " ", ":=", " ", 
  RowBox[{"Module", "[", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{
     "ixsvf", ",", "ixs", ",", "ivt", ",", "ifc", ",", "ixsve", ",", "ixsfe", 
      ",", "ivteds", ",", "ifceds", ",", "eds", ",", "k", ",", "ei1", ",", 
      "ei2", ",", "ied1", ",", "ied2"}], "}"}], ",", "\[IndentingNewLine]", 
    RowBox[{
     RowBox[{"ixsvf", " ", "=", " ", 
      RowBox[{"rs", "[", 
       RowBox[{"\"\<vt\>\"", ",", "\"\<fc\>\""}], "]"}]}], ";", 
     "\[IndentingNewLine]", 
     RowBox[{"ixsve", " ", "=", " ", 
      RowBox[{"rs", "[", 
       RowBox[{"\"\<vt\>\"", ",", "\"\<ed\>\""}], "]"}]}], ";", 
     "\[IndentingNewLine]", 
     RowBox[{"ixsfe", " ", "=", " ", 
      RowBox[{"rs", "[", 
       RowBox[{"\"\<fc\>\"", ",", "\"\<ed\>\""}], "]"}]}], ";", 
     "\[IndentingNewLine]", 
     RowBox[{"ixs", " ", "=", " ", 
      RowBox[{"Flatten", "[", 
       RowBox[{
        RowBox[{"Table", "[", "\[IndentingNewLine]", 
         RowBox[{
          RowBox[{
           RowBox[{"ivteds", " ", "=", " ", 
            RowBox[{"ixsve", "[", 
             RowBox[{"[", "ivt", "]"}], "]"}]}], ";", "\[IndentingNewLine]", 
           RowBox[{"ifceds", " ", "=", " ", 
            RowBox[{"ixsfe", "[", 
             RowBox[{"[", "ifc", "]"}], "]"}]}], ";", "\[IndentingNewLine]", 
           RowBox[{"eds", " ", "=", " ", 
            RowBox[{"Intersection", "[", 
             RowBox[{"ivteds", ",", "ifceds"}], "]"}]}], ";", 
           "\[IndentingNewLine]", 
           RowBox[{"ei1", " ", "=", " ", "Null"}], ";", " ", 
           RowBox[{"ei2", " ", "=", " ", "Null"}], ";", "\[IndentingNewLine]", 
           RowBox[{"Do", "[", 
            RowBox[{
             RowBox[{
              RowBox[{"If", "[", 
               RowBox[{
                RowBox[{
                 RowBox[{"ivteds", "[", 
                  RowBox[{"[", "k", "]"}], "]"}], "\[Equal]", 
                 RowBox[{"eds", "[", 
                  RowBox[{"[", "1", "]"}], "]"}]}], ",", 
                RowBox[{"ei1", " ", "=", " ", "k"}]}], "]"}], ";", 
              "\[IndentingNewLine]", 
              RowBox[{"If", "[", 
               RowBox[{
                RowBox[{
                 RowBox[{"ivteds", "[", 
                  RowBox[{"[", "k", "]"}], "]"}], " ", "\[Equal]", " ", 
                 RowBox[{"eds", "[", 
                  RowBox[{"[", "2", "]"}], "]"}]}], ",", 
                RowBox[{"ei2", " ", "=", " ", "k"}]}], "]"}]}], ",", 
             "\[IndentingNewLine]", 
             RowBox[{"{", 
              RowBox[{"k", ",", 
               RowBox[{"Length", "[", "ivteds", "]"}]}], "}"}]}], "]"}], ";", 
           "\[IndentingNewLine]", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"ei1", ",", "ei2"}], "}"}], " ", "=", " ", 
            RowBox[{"Sort", "[", 
             RowBox[{"{", 
              RowBox[{"ei1", ",", "ei2"}], "}"}], "]"}]}], ";", 
           "\[IndentingNewLine]", 
           RowBox[{"If", "[", 
            RowBox[{
             RowBox[{
              RowBox[{"ei1", " ", "\[Equal]", " ", "1"}], " ", "&&", " ", 
              RowBox[{"ei2", " ", "\[Equal]", " ", 
               RowBox[{"Length", "[", "ivteds", "]"}]}]}], ",", 
             RowBox[{
              RowBox[{"{", 
               RowBox[{"ei1", ",", "ei2"}], "}"}], " ", "=", " ", 
              RowBox[{"{", 
               RowBox[{"ei2", ",", "ei1"}], "}"}]}], ",", 
             "\[IndentingNewLine]", 
             RowBox[{"If", "[", 
              RowBox[{
               RowBox[{"ei2", " ", "\[NotEqual]", " ", 
                RowBox[{"ei1", "+", "1"}]}], ",", 
               RowBox[{
                RowBox[{"{", 
                 RowBox[{"ei1", ",", "ei2"}], "}"}], " ", "=", " ", 
                RowBox[{"{", 
                 RowBox[{"Null", ",", "Null"}], "}"}]}]}], "]"}]}], 
            "\[IndentingNewLine]", "]"}], ";", "\[IndentingNewLine]", 
           RowBox[{"ied1", " ", "=", " ", 
            RowBox[{"ivteds", "[", 
             RowBox[{"[", "ei1", "]"}], "]"}]}], ";", " ", 
           RowBox[{"ied2", " ", "=", " ", 
            RowBox[{"ivteds", "[", 
             RowBox[{"[", "ei2", "]"}], "]"}]}], ";", "\[IndentingNewLine]", 
           RowBox[{"{", 
            RowBox[{"ivt", ",", "ifc", ",", 
             RowBox[{"{", 
              RowBox[{"ied1", ",", "ied2"}], "}"}]}], "}"}]}], ",", 
          "\[IndentingNewLine]", 
          RowBox[{"{", 
           RowBox[{"ivt", ",", 
            RowBox[{"Length", "[", 
             RowBox[{"rs", "[", "\"\<vt\>\"", "]"}], "]"}]}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{"ifc", ",", 
            RowBox[{"ixsvf", "[", 
             RowBox[{"[", "ivt", "]"}], "]"}]}], "}"}]}], "]"}], ",", "1"}], 
       "]"}]}]}]}], "\[IndentingNewLine]", "]"}]}]], "Input",
 CellLabel->
  "In[568]:=",ExpressionUUID->"cdc84a35-14fd-49c7-aa9b-53c0d2b743db"],

Cell[BoxData[
 RowBox[{
  RowBox[{"model", "[", 
   RowBox[{"\"\<rs kite\>\"", ",", "n_", ",", "r1_", ",", "r2_"}], "]"}], " ",
   ":=", " ", 
  RowBox[{"Module", "[", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{
     "rs", ",", "c", ",", "f", ",", "r2x", ",", "r3", ",", "pts", ",", "kps", 
      ",", "kp", ",", "kvt", ",", "kfc", ",", "keds", ",", "ixs"}], "}"}], 
    ",", "\[IndentingNewLine]", 
    RowBox[{
     RowBox[{"rs", " ", "=", " ", 
      RowBox[{"regsld", "[", "n", "]"}]}], ";", "\[IndentingNewLine]", 
     RowBox[{"c", " ", "=", " ", 
      RowBox[{"Cos", "[", 
       RowBox[{"2", 
        RowBox[{"Pi", "/", "n"}]}], "]"}]}], ";", "\[IndentingNewLine]", 
     RowBox[{"r2x", " ", "=", " ", 
      RowBox[{"r2", " ", "/", " ", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{"Sqrt", "[", "3", "]"}], "*", 
         RowBox[{
          RowBox[{"Sqrt", "[", 
           RowBox[{"1", "+", "c"}], "]"}], "/", 
          RowBox[{"Sqrt", "[", 
           RowBox[{"1", "-", "c"}], "]"}]}]}], ")"}]}]}], ";", 
     "\[IndentingNewLine]", 
     RowBox[{"r3", " ", "=", 
      RowBox[{
       RowBox[{"(", 
        RowBox[{"2", "*", 
         RowBox[{
          RowBox[{"Sqrt", "[", "2", "]"}], "/", 
          RowBox[{"Sqrt", "[", 
           RowBox[{"1", "-", "c"}], "]"}]}]}], ")"}], "*", 
       RowBox[{"(", 
        RowBox[{"r1", "*", 
         RowBox[{"r2x", "/", 
          RowBox[{"(", 
           RowBox[{"r1", "+", "r2x"}], ")"}]}]}], ")"}]}]}], ";", 
     "\[IndentingNewLine]", 
     RowBox[{"pts", " ", "=", " ", 
      RowBox[{"Join", "[", 
       RowBox[{
        RowBox[{"r1", "*", 
         RowBox[{"rs", "[", "\"\<vt\>\"", "]"}]}], ",", 
        RowBox[{"r2", "*", 
         RowBox[{"rs", "[", "\"\<fc\>\"", "]"}]}], ",", 
        RowBox[{"r3", "*", 
         RowBox[{"rs", "[", "\"\<ed\>\"", "]"}]}]}], "]"}]}], ";", 
     "\[IndentingNewLine]", 
     RowBox[{"kps", " ", "=", " ", 
      RowBox[{"kitepoints", "[", "rs", "]"}]}], ";", "\[IndentingNewLine]", 
     RowBox[{"ixs", " ", "=", " ", 
      RowBox[{"Table", "[", 
       RowBox[{
        RowBox[{
         RowBox[{"kvt", " ", "=", " ", 
          RowBox[{"kp", "[", 
           RowBox[{"[", "1", "]"}], "]"}]}], ";", "\[IndentingNewLine]", 
         RowBox[{"kfc", " ", "=", " ", 
          RowBox[{
           RowBox[{"Length", "[", 
            RowBox[{"rs", "[", "\"\<vt\>\"", "]"}], "]"}], " ", "+", " ", 
           RowBox[{"kp", "[", 
            RowBox[{"[", "2", "]"}], "]"}]}]}], ";", "\[IndentingNewLine]", 
         RowBox[{"keds", " ", "=", " ", 
          RowBox[{
           RowBox[{"Length", "[", 
            RowBox[{"rs", "[", "\"\<vt\>\"", "]"}], "]"}], " ", "+", " ", 
           RowBox[{"Length", "[", 
            RowBox[{"rs", "[", "\"\<fc\>\"", "]"}], "]"}], " ", "+", " ", 
           RowBox[{"kp", "[", 
            RowBox[{"[", "3", "]"}], "]"}]}]}], ";", "\[IndentingNewLine]", 
         RowBox[{"{", 
          RowBox[{"kvt", ",", 
           RowBox[{"keds", "[", 
            RowBox[{"[", "1", "]"}], "]"}], ",", "kfc", ",", 
           RowBox[{"keds", "[", 
            RowBox[{"[", "2", "]"}], "]"}]}], "}"}]}], ",", 
        "\[IndentingNewLine]", 
        RowBox[{"{", 
         RowBox[{"kp", ",", "kps"}], "}"}]}], "]"}]}], ";", 
     "\[IndentingNewLine]", 
     RowBox[{"GraphicsComplex", "[", 
      RowBox[{"pts", ",", 
       RowBox[{"Polygon", "[", "ixs", "]"}]}], "]"}]}]}], 
   "\[IndentingNewLine]", "]"}]}]], "Input",
 CellLabel->
  "In[569]:=",ExpressionUUID->"2f65df4f-22e8-4ca6-bdfa-920060f75350"],

Cell[BoxData[
 RowBox[{
  RowBox[{"model", "[", 
   RowBox[{"\"\<rs kite\>\"", ",", "n_", ",", "r_"}], "]"}], " ", ":=", " ", 
  RowBox[{"model", "[", 
   RowBox[{"\"\<rs kite\>\"", ",", "n", ",", "r", ",", "r"}], 
   "]"}]}]], "Input",
 CellLabel->
  "In[570]:=",ExpressionUUID->"52e758ac-179b-4502-959a-33fc4b0092cd"],

Cell[BoxData[
 RowBox[{
  RowBox[{"model", "[", 
   RowBox[{"\"\<rs kite shft\>\"", ",", "r1_", ",", "r2_", ",", "f_"}], "]"}],
   " ", ":=", " ", "\[IndentingNewLine]", 
  RowBox[{"Module", "[", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{
      RowBox[{"n", " ", "=", " ", "4"}], ",", "rs", ",", "c", ",", "r2x", ",",
       "r3", ",", "r31", ",", "r32", ",", "edfcs", ",", "edvts", ",", "fcpts",
       ",", "vtpts", ",", "k", ",", "fcpi", ",", "vtpi", ",", "edx", ",", 
      "pts", ",", "kps", ",", "kp", ",", "kvt", ",", "kfc", ",", "keds", ",", 
      "ixs"}], "}"}], ",", "\[IndentingNewLine]", 
    RowBox[{
     RowBox[{"rs", " ", "=", " ", 
      RowBox[{"regsld", "[", "n", "]"}]}], ";", "\[IndentingNewLine]", 
     RowBox[{"c", " ", "=", " ", 
      RowBox[{"Cos", "[", 
       RowBox[{"2", 
        RowBox[{"Pi", "/", "n"}]}], "]"}]}], ";", "\[IndentingNewLine]", 
     RowBox[{"r2x", " ", "=", " ", 
      RowBox[{"r2", " ", "/", " ", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{"Sqrt", "[", "3", "]"}], "*", 
         RowBox[{
          RowBox[{"Sqrt", "[", 
           RowBox[{"1", "+", "c"}], "]"}], "/", 
          RowBox[{"Sqrt", "[", 
           RowBox[{"1", "-", "c"}], "]"}]}]}], ")"}]}]}], ";", 
     "\[IndentingNewLine]", 
     RowBox[{"r3", " ", "=", 
      RowBox[{"2", "*", 
       RowBox[{"(", 
        RowBox[{"r1", "*", 
         RowBox[{"r2x", "/", 
          RowBox[{"(", 
           RowBox[{
            RowBox[{"r1", "*", 
             RowBox[{"(", 
              RowBox[{"1", "-", 
               RowBox[{"f", "^", "2"}]}], ")"}]}], "+", 
            RowBox[{"r2x", "*", 
             RowBox[{"(", 
              RowBox[{"1", "+", 
               RowBox[{"3", 
                RowBox[{"f", "^", "2"}]}]}], ")"}]}]}], ")"}]}]}], ")"}]}]}], 
     ";", "\[IndentingNewLine]", 
     RowBox[{"r31", " ", "=", " ", 
      RowBox[{"r3", "*", 
       RowBox[{"(", 
        RowBox[{"1", "+", "f"}], ")"}]}]}], ";", "\[IndentingNewLine]", 
     RowBox[{"r32", " ", "=", " ", 
      RowBox[{"r3", "*", 
       RowBox[{"(", 
        RowBox[{"1", "-", "f"}], ")"}]}]}], ";", "\[IndentingNewLine]", 
     RowBox[{"edfcs", " ", "=", " ", 
      RowBox[{"rs", "[", 
       RowBox[{"\"\<ed\>\"", ",", "\"\<fc\>\""}], "]"}]}], ";", 
     "\[IndentingNewLine]", 
     RowBox[{"edvts", " ", "=", " ", 
      RowBox[{"rs", "[", 
       RowBox[{"\"\<ed\>\"", ",", "\"\<vt\>\""}], "]"}]}], ";", 
     "\[IndentingNewLine]", 
     RowBox[{"fcpts", " ", "=", " ", 
      RowBox[{"rs", "[", "\"\<fc\>\"", "]"}]}], ";", "\[IndentingNewLine]", 
     RowBox[{"vtpts", " ", "=", " ", 
      RowBox[{"rs", "[", "\"\<vt\>\"", "]"}]}], ";", "\[IndentingNewLine]", 
     RowBox[{"edx", " ", "=", " ", 
      RowBox[{"Table", "[", "\[IndentingNewLine]", 
       RowBox[{
        RowBox[{
         RowBox[{"fcpi", " ", "=", " ", 
          RowBox[{"edfcs", "[", 
           RowBox[{"[", "k", "]"}], "]"}]}], ";", " ", 
         RowBox[{"vtpi", " ", "=", " ", 
          RowBox[{"edvts", "[", 
           RowBox[{"[", "k", "]"}], "]"}]}], ";", "\[IndentingNewLine]", 
         RowBox[{"If", "[", 
          RowBox[{
           RowBox[{
            RowBox[{"(", 
             RowBox[{
              RowBox[{
               RowBox[{"(", 
                RowBox[{
                 RowBox[{"#", "[", 
                  RowBox[{"[", "1", "]"}], "]"}], "-", 
                 RowBox[{"#", "[", 
                  RowBox[{"[", "2", "]"}], "]"}]}], ")"}], "&"}], " ", "@", 
              " ", 
              RowBox[{"(", 
               RowBox[{
                RowBox[{
                 RowBox[{"(", 
                  RowBox[{"Times", " ", "@@", " ", "#"}], ")"}], "&"}], " ", "/@",
                 " ", 
                RowBox[{"fcpts", "[", 
                 RowBox[{"[", "fcpi", "]"}], "]"}]}], ")"}]}], ")"}], " ", 
            "<", " ", "0"}], ",", 
           RowBox[{"vtpi", " ", "=", " ", 
            RowBox[{"Reverse", "[", "vtpi", "]"}]}]}], "]"}], ";", 
         "\[IndentingNewLine]", 
         RowBox[{
          RowBox[{"r31", "*", 
           RowBox[{"vtpts", "[", 
            RowBox[{"[", 
             RowBox[{"vtpi", "[", 
              RowBox[{"[", "1", "]"}], "]"}], "]"}], "]"}]}], " ", "+", " ", 
          RowBox[{"r32", "*", 
           RowBox[{"vtpts", "[", 
            RowBox[{"[", 
             RowBox[{"vtpi", "[", 
              RowBox[{"[", "2", "]"}], "]"}], "]"}], "]"}]}]}]}], ",", 
        "\[IndentingNewLine]", 
        RowBox[{"{", 
         RowBox[{"k", ",", 
          RowBox[{"Length", "[", 
           RowBox[{"rs", "[", "\"\<ed\>\"", "]"}], "]"}]}], "}"}]}], "]"}]}], 
     ";", "\[IndentingNewLine]", 
     RowBox[{"pts", " ", "=", " ", 
      RowBox[{"Join", "[", 
       RowBox[{
        RowBox[{"r1", "*", 
         RowBox[{"rs", "[", "\"\<vt\>\"", "]"}]}], ",", 
        RowBox[{"r2", "*", 
         RowBox[{"rs", "[", "\"\<fc\>\"", "]"}]}], ",", "edx"}], "]"}]}], ";",
      "\[IndentingNewLine]", 
     RowBox[{"kps", " ", "=", " ", 
      RowBox[{"kitepoints", "[", "rs", "]"}]}], ";", "\[IndentingNewLine]", 
     RowBox[{"ixs", " ", "=", " ", 
      RowBox[{"Table", "[", 
       RowBox[{
        RowBox[{
         RowBox[{"kvt", " ", "=", " ", 
          RowBox[{"kp", "[", 
           RowBox[{"[", "1", "]"}], "]"}]}], ";", "\[IndentingNewLine]", 
         RowBox[{"kfc", " ", "=", " ", 
          RowBox[{
           RowBox[{"Length", "[", 
            RowBox[{"rs", "[", "\"\<vt\>\"", "]"}], "]"}], " ", "+", " ", 
           RowBox[{"kp", "[", 
            RowBox[{"[", "2", "]"}], "]"}]}]}], ";", "\[IndentingNewLine]", 
         RowBox[{"keds", " ", "=", " ", 
          RowBox[{
           RowBox[{"Length", "[", 
            RowBox[{"rs", "[", "\"\<vt\>\"", "]"}], "]"}], " ", "+", " ", 
           RowBox[{"Length", "[", 
            RowBox[{"rs", "[", "\"\<fc\>\"", "]"}], "]"}], " ", "+", " ", 
           RowBox[{"kp", "[", 
            RowBox[{"[", "3", "]"}], "]"}]}]}], ";", "\[IndentingNewLine]", 
         RowBox[{"{", 
          RowBox[{"kvt", ",", 
           RowBox[{"keds", "[", 
            RowBox[{"[", "1", "]"}], "]"}], ",", "kfc", ",", 
           RowBox[{"keds", "[", 
            RowBox[{"[", "2", "]"}], "]"}]}], "}"}]}], ",", 
        "\[IndentingNewLine]", 
        RowBox[{"{", 
         RowBox[{"kp", ",", "kps"}], "}"}]}], "]"}]}], ";", 
     "\[IndentingNewLine]", 
     RowBox[{"GraphicsComplex", "[", 
      RowBox[{"pts", ",", 
       RowBox[{"Polygon", "[", "ixs", "]"}]}], "]"}]}]}], 
   "\[IndentingNewLine]", "]"}]}]], "Input",
 CellLabel->
  "In[571]:=",ExpressionUUID->"cd30f3bd-48c5-4b94-8c3e-086421773609"],

Cell[BoxData[
 RowBox[{
  RowBox[{"model", "[", 
   RowBox[{"\"\<rs kite shft\>\"", ",", "r_", ",", "f_"}], "]"}], " ", ":=", 
  " ", 
  RowBox[{"model", "[", 
   RowBox[{"\"\<rs kite shft\>\"", ",", "r", ",", "r", ",", "f"}], 
   "]"}]}]], "Input",
 CellLabel->
  "In[572]:=",ExpressionUUID->"e87cf65c-8a41-4fe3-a402-82929815dfdd"],

Cell[BoxData[
 RowBox[{"(*", " ", 
  RowBox[{
   RowBox[{"Deformed", " ", "pentagons", " ", "if", " ", "f"}], " ", 
   "\[Rule]", " ", 
   RowBox[{
    RowBox[{"(", 
     RowBox[{"1", "/", 
      RowBox[{"Sqrt", "[", "3", "]"}]}], ")"}], "*", 
    RowBox[{
     RowBox[{"(", 
      RowBox[{
       RowBox[{"r1", "*", 
        RowBox[{"Sqrt", "[", "3", "]"}]}], "-", "r2"}], ")"}], "/", 
     RowBox[{"(", 
      RowBox[{
       RowBox[{"r2", "*", 
        RowBox[{"Sqrt", "[", "3", "]"}]}], "-", "r1"}], ")"}]}]}]}], " ", 
  "*)"}]], "Input",
 CellLabel->
  "In[573]:=",ExpressionUUID->"957edeef-ad6d-4058-8b6d-14962ce9bbe9"]
}, Closed]],

Cell[CellGroupData[{

Cell["Pentagonal Faces", "Subsubsection",ExpressionUUID->"e9c16a55-3347-4251-99e3-fa3cbc231c17"],

Cell[BoxData[
 RowBox[{
  RowBox[{"kttripoints", "[", "rs_", "]"}], " ", ":=", " ", 
  RowBox[{"Module", "[", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{
     "kps", ",", "i", ",", "evts", ",", "ptixs", ",", "kp", ",", "kpv1", ",", 
      "kpv2", ",", "kpv3", ",", "kpf", ",", "kpe"}], "}"}], ",", 
    "\[IndentingNewLine]", 
    RowBox[{
     RowBox[{"kps", " ", "=", " ", 
      RowBox[{"kitepoints", "[", "rs", "]"}]}], ";", "\[IndentingNewLine]", 
     RowBox[{"Do", "[", 
      RowBox[{
       RowBox[{
        RowBox[{"evts", " ", "=", " ", 
         RowBox[{
          RowBox[{"rs", "[", 
           RowBox[{"\"\<ed\>\"", ",", "\"\<vt\>\""}], "]"}], "[", 
          RowBox[{"[", "i", "]"}], "]"}]}], ";", "\[IndentingNewLine]", 
        RowBox[{
         RowBox[{"ptixs", "[", "evts", "]"}], " ", "=", " ", 
         RowBox[{
          RowBox[{"ptixs", "[", 
           RowBox[{"Reverse", "[", "evts", "]"}], "]"}], " ", "=", " ", 
          "i"}]}]}], ",", "\[IndentingNewLine]", 
       RowBox[{"{", 
        RowBox[{"i", ",", 
         RowBox[{"Length", "[", 
          RowBox[{"rs", "[", "\"\<ed\>\"", "]"}], "]"}]}], "}"}]}], "]"}], 
     ";", "\[IndentingNewLine]", 
     RowBox[{"Table", "[", "\[IndentingNewLine]", 
      RowBox[{
       RowBox[{
        RowBox[{"kpv1", " ", "=", " ", 
         RowBox[{"kp", "[", 
          RowBox[{"[", "1", "]"}], "]"}]}], ";", " ", 
        RowBox[{"kpf", " ", "=", " ", 
         RowBox[{"kp", "[", 
          RowBox[{"[", "2", "]"}], "]"}]}], ";", " ", 
        RowBox[{"kpe", " ", "=", " ", 
         RowBox[{"kp", "[", 
          RowBox[{"[", 
           RowBox[{"3", ",", "1"}], "]"}], "]"}]}], ";", 
        "\[IndentingNewLine]", 
        RowBox[{"kpv2", " ", "=", " ", 
         RowBox[{"First", "[", 
          RowBox[{"Complement", "[", 
           RowBox[{
            RowBox[{
             RowBox[{"rs", "[", 
              RowBox[{"\"\<ed\>\"", ",", "\"\<vt\>\""}], "]"}], "[", 
             RowBox[{"[", "kpe", "]"}], "]"}], ",", 
            RowBox[{"{", "kpv1", "}"}]}], "]"}], "]"}]}], ";", 
        "\[IndentingNewLine]", 
        RowBox[{"kpv3", " ", "=", " ", 
         RowBox[{"First", "[", 
          RowBox[{"Complement", "[", 
           RowBox[{
            RowBox[{
             RowBox[{"rs", "[", 
              RowBox[{"\"\<fc\>\"", ",", "\"\<vt\>\""}], "]"}], "[", 
             RowBox[{"[", "kpf", "]"}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"kpv1", ",", "kpv2"}], "}"}]}], "]"}], "]"}]}], ";", 
        "\[IndentingNewLine]", 
        RowBox[{"{", 
         RowBox[{
          RowBox[{"{", 
           RowBox[{"kpv1", ",", "kpv2", ",", "kpv3"}], "}"}], ",", "kpf", ",", 
          RowBox[{"{", 
           RowBox[{"kpe", ",", 
            RowBox[{"ptixs", "[", 
             RowBox[{"{", 
              RowBox[{"kpv2", ",", "kpv3"}], "}"}], "]"}], ",", 
            RowBox[{"ptixs", "[", 
             RowBox[{"{", 
              RowBox[{"kpv3", ",", "kpv1"}], "}"}], "]"}]}], "}"}]}], "}"}]}],
        ",", "\[IndentingNewLine]", 
       RowBox[{"{", 
        RowBox[{"kp", ",", "kps"}], "}"}]}], "]"}]}]}], "\[IndentingNewLine]",
    "]"}]}]], "Input",
 CellLabel->
  "In[574]:=",ExpressionUUID->"fdb4e6b4-2fd4-4f88-8d3b-0f50f1623376"],

Cell[BoxData[
 RowBox[{
  RowBox[{"model", "[", 
   RowBox[{"\"\<rs pntg\>\"", ",", "n_", ",", "r_", ",", "f_", ",", "fx_"}], 
   "]"}], " ", ":=", " ", 
  RowBox[{"Module", "[", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{
     "rs", ",", "c", ",", "r1", ",", "r2", ",", "r31", ",", "r32", ",", "r33",
       ",", "kps", ",", "kp", ",", "vts", ",", "ptpx", ",", "pts", ",", "i", 
      ",", "kpixs", ",", "ixs"}], "}"}], ",", "\[IndentingNewLine]", 
    RowBox[{
     RowBox[{"rs", " ", "=", " ", 
      RowBox[{"regsld", "[", "n", "]"}]}], ";", "\[IndentingNewLine]", 
     RowBox[{"c", " ", "=", " ", 
      RowBox[{"Cos", "[", 
       RowBox[{"2", 
        RowBox[{"Pi", "/", "n"}]}], "]"}]}], ";", "\[IndentingNewLine]", 
     RowBox[{"r1", " ", "=", " ", "r"}], ";", "\[IndentingNewLine]", 
     RowBox[{"r2", " ", "=", " ", 
      RowBox[{
       RowBox[{"r", "/", 
        RowBox[{"Sqrt", "[", "3", "]"}]}], "*", "f", "*", 
       RowBox[{
        RowBox[{"Sqrt", "[", 
         RowBox[{"1", "+", "c"}], "]"}], "/", 
        RowBox[{"Sqrt", "[", 
         RowBox[{"1", "-", "c"}], "]"}]}]}]}], ";", "\[IndentingNewLine]", 
     RowBox[{"r31", " ", "=", " ", 
      RowBox[{"r", "*", 
       RowBox[{
        RowBox[{"(", 
         RowBox[{"fx", "*", 
          RowBox[{"(", 
           RowBox[{
            RowBox[{"4", 
             RowBox[{"(", 
              RowBox[{"2", "+", "c"}], ")"}], 
             RowBox[{"f", "^", "2"}]}], "-", 
            RowBox[{"3", 
             RowBox[{"(", 
              RowBox[{"5", "+", 
               RowBox[{"2", "c"}]}], ")"}], "*", "f", "*", "fx"}], "+", 
            RowBox[{"9", 
             RowBox[{"fx", "^", "2"}]}], "-", 
            RowBox[{
             RowBox[{"(", 
              RowBox[{"3", "-", 
               RowBox[{"2", "c"}]}], ")"}], 
             RowBox[{"f", "^", "2"}], "*", "fx"}], "+", 
            RowBox[{
             RowBox[{"f", "^", "2"}], "*", 
             RowBox[{"fx", "^", "2"}]}]}], ")"}]}], ")"}], "/", 
        RowBox[{"(", 
         RowBox[{
          RowBox[{"8", 
           RowBox[{"(", 
            RowBox[{"1", "+", "c"}], ")"}], 
           RowBox[{"f", "^", "2"}]}], "-", 
          RowBox[{"12", 
           RowBox[{"(", 
            RowBox[{"1", "+", "c"}], ")"}], "f", "*", "fx"}], "+", 
          RowBox[{"9", 
           RowBox[{"fx", "^", "2"}]}], "-", 
          RowBox[{"4", 
           RowBox[{"(", 
            RowBox[{"1", "+", "c"}], ")"}], 
           RowBox[{"f", "^", "2"}], "*", "fx"}], "-", 
          RowBox[{"3", 
           RowBox[{"(", 
            RowBox[{"1", "-", 
             RowBox[{"2", "c"}]}], ")"}], "f", "*", 
           RowBox[{"fx", "^", "2"}]}], "+", 
          RowBox[{"2", 
           RowBox[{"(", 
            RowBox[{"1", "+", "c"}], ")"}], 
           RowBox[{"f", "^", "2"}], "*", 
           RowBox[{"fx", "^", "2"}]}]}], ")"}]}]}]}], ";", 
     "\[IndentingNewLine]", 
     RowBox[{"r32", " ", "=", " ", 
      RowBox[{"r", "*", 
       RowBox[{
        RowBox[{"(", 
         RowBox[{"f", "*", 
          RowBox[{"(", 
           RowBox[{
            RowBox[{"-", "1"}], "+", "fx"}], ")"}], "*", "fx", "*", 
          RowBox[{"(", 
           RowBox[{
            RowBox[{"4", "c", "*", "f"}], "-", 
            RowBox[{"3", "fx"}], "+", 
            RowBox[{"f", "*", "fx"}]}], ")"}]}], ")"}], "/", 
        RowBox[{"(", 
         RowBox[{
          RowBox[{"8", 
           RowBox[{"(", 
            RowBox[{"1", "+", "c"}], ")"}], 
           RowBox[{"f", "^", "2"}]}], "-", 
          RowBox[{"12", 
           RowBox[{"(", 
            RowBox[{"1", "+", "c"}], ")"}], "f", "*", "fx"}], "+", 
          RowBox[{"9", 
           RowBox[{"fx", "^", "2"}]}], "-", 
          RowBox[{"4", 
           RowBox[{"(", 
            RowBox[{"1", "+", "c"}], ")"}], 
           RowBox[{"f", "^", "2"}], "*", "fx"}], "-", 
          RowBox[{"3", 
           RowBox[{"(", 
            RowBox[{"1", "-", 
             RowBox[{"2", "c"}]}], ")"}], "f", "*", 
           RowBox[{"fx", "^", "2"}]}], "+", 
          RowBox[{"2", 
           RowBox[{"(", 
            RowBox[{"1", "+", "c"}], ")"}], 
           RowBox[{"f", "^", "2"}], "*", 
           RowBox[{"fx", "^", "2"}]}]}], ")"}]}]}]}], ";", 
     "\[IndentingNewLine]", 
     RowBox[{"r33", " ", "=", 
      RowBox[{"r", "*", 
       RowBox[{
        RowBox[{"(", 
         RowBox[{"f", "*", 
          RowBox[{"(", 
           RowBox[{
            RowBox[{"-", "1"}], "+", "fx"}], ")"}], "*", "fx", "*", 
          RowBox[{"(", 
           RowBox[{
            RowBox[{
             RowBox[{"-", "4"}], "f"}], "+", 
            RowBox[{"3", "fx"}], "+", 
            RowBox[{"f", "*", "fx"}]}], ")"}]}], ")"}], "/", 
        RowBox[{"(", 
         RowBox[{
          RowBox[{"8", 
           RowBox[{"(", 
            RowBox[{"1", "+", "c"}], ")"}], 
           RowBox[{"f", "^", "2"}]}], "-", 
          RowBox[{"12", 
           RowBox[{"(", 
            RowBox[{"1", "+", "c"}], ")"}], "f", "*", "fx"}], "+", 
          RowBox[{"9", 
           RowBox[{"fx", "^", "2"}]}], "-", 
          RowBox[{"4", 
           RowBox[{"(", 
            RowBox[{"1", "+", "c"}], ")"}], 
           RowBox[{"f", "^", "2"}], "*", "fx"}], "-", 
          RowBox[{"3", 
           RowBox[{"(", 
            RowBox[{"1", "-", 
             RowBox[{"2", "c"}]}], ")"}], "f", "*", 
           RowBox[{"fx", "^", "2"}]}], "+", 
          RowBox[{"2", 
           RowBox[{"(", 
            RowBox[{"1", "+", "c"}], ")"}], 
           RowBox[{"f", "^", "2"}], "*", 
           RowBox[{"fx", "^", "2"}]}]}], ")"}]}]}]}], ";", 
     "\[IndentingNewLine]", 
     RowBox[{"kps", " ", "=", 
      RowBox[{"kttripoints", "[", "rs", "]"}]}], ";", "\[IndentingNewLine]", 
     RowBox[{"vts", " ", "=", " ", 
      RowBox[{"rs", "[", "\"\<vt\>\"", "]"}]}], ";", "\[IndentingNewLine]", 
     RowBox[{"ptpx", " ", "=", " ", 
      RowBox[{"Table", "[", 
       RowBox[{
        RowBox[{
         RowBox[{"r31", "*", 
          RowBox[{"vts", "[", 
           RowBox[{"[", 
            RowBox[{"kp", "[", 
             RowBox[{"[", 
              RowBox[{"1", ",", "1"}], "]"}], "]"}], "]"}], "]"}]}], " ", "+",
          " ", 
         RowBox[{"r32", "*", 
          RowBox[{"vts", "[", 
           RowBox[{"[", 
            RowBox[{"kp", "[", 
             RowBox[{"[", 
              RowBox[{"1", ",", "2"}], "]"}], "]"}], "]"}], "]"}]}], " ", "+",
          " ", 
         RowBox[{"r33", "*", 
          RowBox[{"vts", "[", 
           RowBox[{"[", 
            RowBox[{"kp", "[", 
             RowBox[{"[", 
              RowBox[{"1", ",", "3"}], "]"}], "]"}], "]"}], "]"}]}]}], ",", 
        " ", "\[IndentingNewLine]", 
        RowBox[{"{", 
         RowBox[{"kp", ",", "kps"}], "}"}]}], "]"}]}], ";", 
     "\[IndentingNewLine]", 
     RowBox[{"pts", " ", "=", " ", 
      RowBox[{"Join", "[", 
       RowBox[{
        RowBox[{"r1", "*", 
         RowBox[{"rs", "[", "\"\<vt\>\"", "]"}]}], ",", 
        RowBox[{"r2", "*", 
         RowBox[{"rs", "[", "\"\<fc\>\"", "]"}]}], ",", "ptpx"}], "]"}]}], 
     ";", "\[IndentingNewLine]", 
     RowBox[{"Do", "[", 
      RowBox[{
       RowBox[{
        RowBox[{"kp", " ", "=", " ", 
         RowBox[{"kps", "[", 
          RowBox[{"[", "i", "]"}], "]"}]}], ";", 
        RowBox[{
         RowBox[{"kpixs", "[", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"kp", "[", 
             RowBox[{"[", 
              RowBox[{"1", ",", "1"}], "]"}], "]"}], ",", 
            RowBox[{"kp", "[", 
             RowBox[{"[", "2", "]"}], "]"}]}], "}"}], "]"}], " ", "=", " ", 
         RowBox[{
          RowBox[{"Length", "[", 
           RowBox[{"rs", "[", "\"\<vt\>\"", "]"}], "]"}], "+", 
          RowBox[{"Length", "[", 
           RowBox[{"rs", "[", "\"\<fc\>\"", "]"}], "]"}], "+", "i"}]}]}], ",", 
       RowBox[{"{", 
        RowBox[{"i", ",", 
         RowBox[{"Length", "[", "kps", "]"}]}], "}"}]}], "]"}], ";", 
     "\[IndentingNewLine]", 
     RowBox[{"ixs", " ", "=", " ", 
      RowBox[{"Table", "[", 
       RowBox[{
        RowBox[{"{", 
         RowBox[{
          RowBox[{"kp", "[", 
           RowBox[{"[", 
            RowBox[{"1", ",", "1"}], "]"}], "]"}], ",", 
          RowBox[{"kpixs", "[", 
           RowBox[{"{", 
            RowBox[{
             RowBox[{"kp", "[", 
              RowBox[{"[", 
               RowBox[{"1", ",", "1"}], "]"}], "]"}], ",", 
             RowBox[{"kp", "[", 
              RowBox[{"[", "2", "]"}], "]"}]}], "}"}], "]"}], ",", 
          RowBox[{
           RowBox[{"Length", "[", 
            RowBox[{"rs", "[", "\"\<vt\>\"", "]"}], "]"}], "+", 
           RowBox[{"kp", "[", 
            RowBox[{"[", "2", "]"}], "]"}]}], ",", 
          RowBox[{"kpixs", "[", 
           RowBox[{"{", 
            RowBox[{
             RowBox[{"kp", "[", 
              RowBox[{"[", 
               RowBox[{"1", ",", "3"}], "]"}], "]"}], ",", 
             RowBox[{"kp", "[", 
              RowBox[{"[", "2", "]"}], "]"}]}], "}"}], "]"}], ",", 
          RowBox[{"kpixs", "[", 
           RowBox[{"{", 
            RowBox[{
             RowBox[{"kp", "[", 
              RowBox[{"[", 
               RowBox[{"1", ",", "1"}], "]"}], "]"}], ",", 
             RowBox[{"First", "[", 
              RowBox[{"Complement", "[", 
               RowBox[{
                RowBox[{
                 RowBox[{"rs", "[", 
                  RowBox[{"\"\<ed\>\"", ",", "\"\<fc\>\""}], "]"}], "[", 
                 RowBox[{"[", 
                  RowBox[{"kp", "[", 
                   RowBox[{"[", 
                    RowBox[{"3", ",", "3"}], "]"}], "]"}], "]"}], "]"}], ",", 
                
                RowBox[{"{", 
                 RowBox[{"kp", "[", 
                  RowBox[{"[", "2", "]"}], "]"}], "}"}]}], "]"}], "]"}]}], 
            "}"}], "]"}]}], "}"}], ",", "\[IndentingNewLine]", 
        RowBox[{"{", 
         RowBox[{"kp", ",", "kps"}], "}"}]}], "]"}]}], ";", 
     "\[IndentingNewLine]", 
     RowBox[{"GraphicsComplex", "[", 
      RowBox[{"pts", ",", 
       RowBox[{"Polygon", "[", "ixs", "]"}]}], "]"}]}]}], 
   "\[IndentingNewLine]", "]"}]}]], "Input",
 CellLabel->
  "In[575]:=",ExpressionUUID->"5ffbef42-18c0-4eb9-b417-cecc7c238f96"],

Cell[BoxData[
 RowBox[{
  RowBox[{"model", "[", 
   RowBox[{"\"\<rs pntg\>\"", ",", "n_", ",", "r_", ",", "fx_"}], "]"}], " ", 
  ":=", " ", 
  RowBox[{"model", "[", 
   RowBox[{"\"\<rs pntg\>\"", ",", "n", ",", "r", ",", 
    RowBox[{
     RowBox[{"Sqrt", "[", "3", "]"}], "*", 
     RowBox[{"Tan", "[", 
      RowBox[{"Pi", "/", "n"}], "]"}]}], ",", "fx"}], "]"}]}]], "Input",
 CellLabel->
  "In[576]:=",ExpressionUUID->"503a722b-c56a-4604-a540-fa69c250f2ec"]
}, Closed]],

Cell[CellGroupData[{

Cell["Truncated", "Subsubsection",ExpressionUUID->"a201553b-2d37-4e46-bca1-a4a8e1119b57"],

Cell[BoxData[
 RowBox[{
  RowBox[{"model", "[", 
   RowBox[{"\"\<rs both trunc\>\"", ",", "n_", ",", "r_"}], "]"}], " ", ":=", 
  " ", 
  RowBox[{"Module", "[", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{"rs", ",", "pts", ",", "ixs1", ",", "ixs2"}], "}"}], ",", 
    "\[IndentingNewLine]", 
    RowBox[{
     RowBox[{"rs", " ", "=", " ", 
      RowBox[{"regsld", "[", "n", "]"}]}], ";", "\[IndentingNewLine]", 
     RowBox[{"pts", " ", "=", " ", 
      RowBox[{"r", "*", 
       RowBox[{"rs", "[", "\"\<ed\>\"", "]"}]}]}], ";", "\[IndentingNewLine]", 
     RowBox[{"ixs1", " ", "=", " ", 
      RowBox[{"rs", "[", 
       RowBox[{"\"\<vt\>\"", ",", "\"\<ed\>\""}], "]"}]}], ";", 
     "\[IndentingNewLine]", 
     RowBox[{"ixs2", " ", "=", " ", 
      RowBox[{"rs", "[", 
       RowBox[{"\"\<fc\>\"", ",", "\"\<ed\>\""}], "]"}]}], ";", 
     "\[IndentingNewLine]", 
     RowBox[{"GraphicsComplex", "[", 
      RowBox[{"pts", ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"Polygon", "[", "ixs1", "]"}], ",", 
         RowBox[{"Polygon", "[", "ixs2", "]"}]}], "}"}]}], "]"}]}]}], 
   "\[IndentingNewLine]", "]"}]}]], "Input",
 CellLabel->
  "In[577]:=",ExpressionUUID->"0747b300-f25b-4606-aa84-39194a44e0e9"],

Cell[BoxData[
 RowBox[{
  RowBox[{"fillfc", "[", "rs_", "]"}], " ", ":=", " ", 
  RowBox[{"Module", "[", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{
     "fcvts", ",", "edvts", ",", "evixs", ",", "i", ",", "vts", ",", "vtsx", 
      ",", "j"}], "}"}], ",", "\[IndentingNewLine]", 
    RowBox[{
     RowBox[{"fcvts", " ", "=", " ", 
      RowBox[{"rs", "[", 
       RowBox[{"\"\<fc\>\"", ",", "\"\<vt\>\""}], "]"}]}], ";", 
     "\[IndentingNewLine]", 
     RowBox[{"edvts", " ", "=", " ", 
      RowBox[{"rs", "[", 
       RowBox[{"\"\<ed\>\"", ",", "\"\<vt\>\""}], "]"}]}], ";", 
     "\[IndentingNewLine]", 
     RowBox[{"Do", "[", 
      RowBox[{
       RowBox[{
        RowBox[{"vts", " ", "=", " ", 
         RowBox[{"edvts", "[", 
          RowBox[{"[", "i", "]"}], "]"}]}], ";", "\[IndentingNewLine]", 
        RowBox[{
         RowBox[{"evixs", "[", "vts", "]"}], " ", "=", " ", 
         RowBox[{
          RowBox[{"evixs", "[", 
           RowBox[{"Reverse", "[", "vts", "]"}], "]"}], " ", "=", " ", 
          "i"}]}]}], ",", 
       RowBox[{"{", 
        RowBox[{"i", ",", 
         RowBox[{"Length", "[", 
          RowBox[{"rs", "[", "\"\<ed\>\"", "]"}], "]"}]}], "}"}]}], "]"}], 
     ";", "\[IndentingNewLine]", 
     RowBox[{"Table", "[", 
      RowBox[{
       RowBox[{
        RowBox[{"vts", " ", "=", " ", 
         RowBox[{"fcvts", "[", 
          RowBox[{"[", "i", "]"}], "]"}]}], ";", "\[IndentingNewLine]", 
        RowBox[{"vtsx", " ", "=", " ", 
         RowBox[{"Append", "[", 
          RowBox[{"vts", ",", 
           RowBox[{"First", "[", "vts", "]"}]}], "]"}]}], ";", 
        "\[IndentingNewLine]", 
        RowBox[{"Flatten", "[", 
         RowBox[{
          RowBox[{"Table", "[", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{
              RowBox[{"vts", "[", 
               RowBox[{"[", "j", "]"}], "]"}], ",", 
              RowBox[{"evixs", "[", 
               RowBox[{"{", 
                RowBox[{
                 RowBox[{"vtsx", "[", 
                  RowBox[{"[", "j", "]"}], "]"}], ",", 
                 RowBox[{"vtsx", "[", 
                  RowBox[{"[", 
                   RowBox[{"j", "+", "1"}], "]"}], "]"}]}], "}"}], "]"}]}], 
             "}"}], ",", 
            RowBox[{"{", 
             RowBox[{"j", ",", 
              RowBox[{"Length", "[", "vts", "]"}]}], "}"}]}], "]"}], ",", 
          "1"}], "]"}]}], ",", "\[IndentingNewLine]", 
       RowBox[{"{", 
        RowBox[{"i", ",", 
         RowBox[{"Length", "[", 
          RowBox[{"rs", "[", "\"\<fc\>\"", "]"}], "]"}]}], "}"}]}], "]"}]}]}],
    "\[IndentingNewLine]", "]"}]}]], "Input",
 CellLabel->
  "In[578]:=",ExpressionUUID->"22ba124d-2224-4e80-a525-27a198f82173"],

Cell[BoxData[
 RowBox[{
  RowBox[{"model", "[", 
   RowBox[{"\"\<rs tri trunc\>\"", ",", "n_", ",", "r1_", ",", "r2_"}], "]"}],
   " ", ":=", " ", 
  RowBox[{"Module", "[", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{
     "rs", ",", "pts", ",", "ix", ",", "vteds", ",", "ptixs", ",", "i", ",", 
      "eds", ",", "j", ",", "ixs1", ",", "fcves", ",", "ves", ",", "vesx", 
      ",", "ixs2"}], "}"}], ",", "\[IndentingNewLine]", 
    RowBox[{
     RowBox[{"rs", " ", "=", " ", 
      RowBox[{"regsld", "[", "n", "]"}]}], ";", "\[IndentingNewLine]", 
     RowBox[{"ix", " ", "=", " ", "1"}], ";", "\[IndentingNewLine]", 
     RowBox[{"vteds", " ", "=", " ", 
      RowBox[{"rs", "[", 
       RowBox[{"\"\<vt\>\"", ",", "\"\<ed\>\""}], "]"}]}], ";", 
     "\[IndentingNewLine]", 
     RowBox[{"pts", " ", "=", " ", 
      RowBox[{"Flatten", "[", 
       RowBox[{
        RowBox[{"Table", "[", "\[IndentingNewLine]", 
         RowBox[{
          RowBox[{
           RowBox[{"eds", " ", "=", " ", 
            RowBox[{"vteds", "[", 
             RowBox[{"[", "i", "]"}], "]"}]}], ";", "\[IndentingNewLine]", 
           RowBox[{"Table", "[", "\[IndentingNewLine]", 
            RowBox[{
             RowBox[{
              RowBox[{
               RowBox[{"ptixs", "[", 
                RowBox[{"{", 
                 RowBox[{"i", ",", "j"}], "}"}], "]"}], " ", "=", " ", 
               RowBox[{"ix", "++"}]}], ";", "\[IndentingNewLine]", 
              RowBox[{
               RowBox[{"r1", "*", 
                RowBox[{
                 RowBox[{"rs", "[", "\"\<vt\>\"", "]"}], "[", 
                 RowBox[{"[", "i", "]"}], "]"}]}], " ", "+", " ", 
               RowBox[{"r2", "*", 
                RowBox[{
                 RowBox[{"rs", "[", "\"\<ed\>\"", "]"}], "[", 
                 RowBox[{"[", "j", "]"}], "]"}]}]}]}], ",", 
             "\[IndentingNewLine]", 
             RowBox[{"{", 
              RowBox[{"j", ",", "eds"}], "}"}]}], "]"}]}], ",", 
          "\[IndentingNewLine]", 
          RowBox[{"{", 
           RowBox[{"i", ",", 
            RowBox[{"Length", "[", 
             RowBox[{"rs", "[", "\"\<vt\>\"", "]"}], "]"}]}], "}"}]}], "]"}], 
        ",", "1"}], "]"}]}], ";", "\[IndentingNewLine]", 
     RowBox[{"ixs1", " ", "=", " ", 
      RowBox[{"Table", "[", 
       RowBox[{
        RowBox[{
         RowBox[{"eds", " ", "=", " ", 
          RowBox[{"vteds", "[", 
           RowBox[{"[", "i", "]"}], "]"}]}], ";", "\[IndentingNewLine]", 
         RowBox[{"Table", "[", 
          RowBox[{
           RowBox[{"ptixs", "[", 
            RowBox[{"{", 
             RowBox[{"i", ",", "j"}], "}"}], "]"}], ",", 
           RowBox[{"{", 
            RowBox[{"j", ",", "eds"}], "}"}]}], "]"}]}], ",", 
        "\[IndentingNewLine]", " ", 
        RowBox[{"{", 
         RowBox[{"i", ",", 
          RowBox[{"Length", "[", 
           RowBox[{"rs", "[", "\"\<vt\>\"", "]"}], "]"}]}], "}"}]}], "]"}]}], 
     ";", "\[IndentingNewLine]", 
     RowBox[{"fcves", " ", "=", " ", 
      RowBox[{"fillfc", "[", "rs", "]"}]}], ";", "\[IndentingNewLine]", 
     RowBox[{"ixs2", " ", "=", " ", 
      RowBox[{"Table", "[", 
       RowBox[{
        RowBox[{
         RowBox[{"vesx", " ", "=", " ", 
          RowBox[{"Append", "[", 
           RowBox[{"ves", ",", 
            RowBox[{"First", "[", "ves", "]"}]}], "]"}]}], ";", 
         "\[IndentingNewLine]", 
         RowBox[{"Flatten", "[", 
          RowBox[{
           RowBox[{"Table", "[", 
            RowBox[{
             RowBox[{"{", 
              RowBox[{
               RowBox[{"ptixs", "[", 
                RowBox[{"{", 
                 RowBox[{
                  RowBox[{"vesx", "[", 
                   RowBox[{"[", 
                    RowBox[{
                    RowBox[{"2", "i"}], "-", "1"}], "]"}], "]"}], ",", 
                  RowBox[{"vesx", "[", 
                   RowBox[{"[", 
                    RowBox[{"2", "i"}], "]"}], "]"}]}], "}"}], "]"}], ",", 
               RowBox[{"ptixs", "[", 
                RowBox[{"{", 
                 RowBox[{
                  RowBox[{"vesx", "[", 
                   RowBox[{"[", 
                    RowBox[{
                    RowBox[{"2", "i"}], "+", "1"}], "]"}], "]"}], ",", 
                  RowBox[{"vesx", "[", 
                   RowBox[{"[", 
                    RowBox[{"2", "i"}], "]"}], "]"}]}], "}"}], "]"}]}], "}"}],
              ",", "\[IndentingNewLine]", 
             RowBox[{"{", 
              RowBox[{"i", ",", 
               RowBox[{
                RowBox[{"Length", "[", "ves", "]"}], "/", "2"}]}], "}"}]}], 
            "]"}], ",", "1"}], "]"}]}], ",", "\[IndentingNewLine]", 
        RowBox[{"{", 
         RowBox[{"ves", ",", "fcves"}], "}"}]}], "]"}]}], ";", 
     "\[IndentingNewLine]", 
     RowBox[{"GraphicsComplex", "[", 
      RowBox[{"pts", ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"Polygon", "[", "ixs1", "]"}], ",", 
         RowBox[{"Polygon", "[", "ixs2", "]"}]}], "}"}]}], "]"}]}]}], 
   "\[IndentingNewLine]", "]"}]}]], "Input",
 CellLabel->
  "In[579]:=",ExpressionUUID->"e37755ee-8872-49bf-b45b-403dae2022ad"],

Cell[BoxData[
 RowBox[{
  RowBox[{"fillvt", "[", "rs_", "]"}], " ", ":=", " ", 
  RowBox[{"Module", "[", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{
     "vtfcs", ",", "edfcs", ",", "efixs", ",", "i", ",", "fcs", ",", "fcsx", 
      ",", "j"}], "}"}], ",", "\[IndentingNewLine]", 
    RowBox[{
     RowBox[{"vtfcs", " ", "=", " ", 
      RowBox[{"rs", "[", 
       RowBox[{"\"\<vt\>\"", ",", "\"\<fc\>\""}], "]"}]}], ";", 
     "\[IndentingNewLine]", 
     RowBox[{"edfcs", " ", "=", " ", 
      RowBox[{"rs", "[", 
       RowBox[{"\"\<ed\>\"", ",", "\"\<fc\>\""}], "]"}]}], ";", 
     "\[IndentingNewLine]", 
     RowBox[{"Do", "[", 
      RowBox[{
       RowBox[{
        RowBox[{"fcs", " ", "=", " ", 
         RowBox[{"edfcs", "[", 
          RowBox[{"[", "i", "]"}], "]"}]}], ";", "\[IndentingNewLine]", 
        RowBox[{
         RowBox[{"efixs", "[", "fcs", "]"}], " ", "=", " ", 
         RowBox[{
          RowBox[{"efixs", "[", 
           RowBox[{"Reverse", "[", "fcs", "]"}], "]"}], " ", "=", " ", 
          "i"}]}]}], ",", 
       RowBox[{"{", 
        RowBox[{"i", ",", 
         RowBox[{"Length", "[", 
          RowBox[{"rs", "[", "\"\<ed\>\"", "]"}], "]"}]}], "}"}]}], "]"}], 
     ";", "\[IndentingNewLine]", 
     RowBox[{"Table", "[", 
      RowBox[{
       RowBox[{
        RowBox[{"fcs", " ", "=", " ", 
         RowBox[{"vtfcs", "[", 
          RowBox[{"[", "i", "]"}], "]"}]}], ";", "\[IndentingNewLine]", 
        RowBox[{"fcsx", " ", "=", " ", 
         RowBox[{"Append", "[", 
          RowBox[{"fcs", ",", 
           RowBox[{"First", "[", "fcs", "]"}]}], "]"}]}], ";", 
        "\[IndentingNewLine]", 
        RowBox[{"Flatten", "[", 
         RowBox[{
          RowBox[{"Table", "[", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{
              RowBox[{"fcs", "[", 
               RowBox[{"[", "j", "]"}], "]"}], ",", 
              RowBox[{"efixs", "[", 
               RowBox[{"{", 
                RowBox[{
                 RowBox[{"fcsx", "[", 
                  RowBox[{"[", "j", "]"}], "]"}], ",", 
                 RowBox[{"fcsx", "[", 
                  RowBox[{"[", 
                   RowBox[{"j", "+", "1"}], "]"}], "]"}]}], "}"}], "]"}]}], 
             "}"}], ",", 
            RowBox[{"{", 
             RowBox[{"j", ",", 
              RowBox[{"Length", "[", "fcs", "]"}]}], "}"}]}], "]"}], ",", 
          "1"}], "]"}]}], "\[IndentingNewLine]", ",", "\[IndentingNewLine]", 
       RowBox[{"{", 
        RowBox[{"i", ",", 
         RowBox[{"Length", "[", 
          RowBox[{"rs", "[", "\"\<vt\>\"", "]"}], "]"}]}], "}"}]}], "]"}]}]}],
    "\[IndentingNewLine]", "]"}]}]], "Input",
 CellLabel->
  "In[580]:=",ExpressionUUID->"daf48ceb-fdce-48c7-8b8c-6b88d43139ee"],

Cell[BoxData[
 RowBox[{
  RowBox[{"model", "[", 
   RowBox[{"\"\<rs dual trunc\>\"", ",", "n_", ",", "r1_", ",", "r2_"}], 
   "]"}], " ", ":=", " ", 
  RowBox[{"Module", "[", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{
     "rs", ",", "pts", ",", "ix", ",", "fceds", ",", "ptixs", ",", "i", ",", 
      "eds", ",", "j", ",", "ixs1", ",", "vtfes", ",", "fes", ",", "fesx", 
      ",", "ixs2"}], "}"}], ",", "\[IndentingNewLine]", 
    RowBox[{
     RowBox[{"rs", " ", "=", " ", 
      RowBox[{"regsld", "[", "n", "]"}]}], ";", "\[IndentingNewLine]", 
     RowBox[{"ix", " ", "=", " ", "1"}], ";", "\[IndentingNewLine]", 
     RowBox[{"fceds", " ", "=", " ", 
      RowBox[{"rs", "[", 
       RowBox[{"\"\<fc\>\"", ",", "\"\<ed\>\""}], "]"}]}], ";", 
     "\[IndentingNewLine]", 
     RowBox[{"pts", " ", "=", " ", 
      RowBox[{"Flatten", "[", 
       RowBox[{
        RowBox[{"Table", "[", "\[IndentingNewLine]", 
         RowBox[{
          RowBox[{
           RowBox[{"eds", " ", "=", " ", 
            RowBox[{"fceds", "[", 
             RowBox[{"[", "i", "]"}], "]"}]}], ";", "\[IndentingNewLine]", 
           RowBox[{"Table", "[", "\[IndentingNewLine]", 
            RowBox[{
             RowBox[{
              RowBox[{
               RowBox[{"ptixs", "[", 
                RowBox[{"{", 
                 RowBox[{"i", ",", "j"}], "}"}], "]"}], " ", "=", " ", 
               RowBox[{"ix", "++"}]}], ";", "\[IndentingNewLine]", 
              RowBox[{
               RowBox[{"r1", "*", 
                RowBox[{
                 RowBox[{"rs", "[", "\"\<fc\>\"", "]"}], "[", 
                 RowBox[{"[", "i", "]"}], "]"}]}], " ", "+", " ", 
               RowBox[{"r2", "*", 
                RowBox[{
                 RowBox[{"rs", "[", "\"\<ed\>\"", "]"}], "[", 
                 RowBox[{"[", "j", "]"}], "]"}]}]}]}], ",", 
             "\[IndentingNewLine]", 
             RowBox[{"{", 
              RowBox[{"j", ",", "eds"}], "}"}]}], "]"}]}], ",", 
          "\[IndentingNewLine]", 
          RowBox[{"{", 
           RowBox[{"i", ",", 
            RowBox[{"Length", "[", 
             RowBox[{"rs", "[", "\"\<fc\>\"", "]"}], "]"}]}], "}"}]}], "]"}], 
        ",", "1"}], "]"}]}], ";", "\[IndentingNewLine]", 
     RowBox[{"ixs1", " ", "=", " ", 
      RowBox[{"Table", "[", 
       RowBox[{
        RowBox[{
         RowBox[{"eds", " ", "=", " ", 
          RowBox[{"fceds", "[", 
           RowBox[{"[", "i", "]"}], "]"}]}], ";", "\[IndentingNewLine]", 
         RowBox[{"Table", "[", 
          RowBox[{
           RowBox[{"ptixs", "[", 
            RowBox[{"{", 
             RowBox[{"i", ",", "j"}], "}"}], "]"}], ",", 
           RowBox[{"{", 
            RowBox[{"j", ",", "eds"}], "}"}]}], "]"}]}], ",", 
        "\[IndentingNewLine]", " ", 
        RowBox[{"{", 
         RowBox[{"i", ",", 
          RowBox[{"Length", "[", 
           RowBox[{"rs", "[", "\"\<fc\>\"", "]"}], "]"}]}], "}"}]}], "]"}]}], 
     ";", "\[IndentingNewLine]", 
     RowBox[{"vtfes", " ", "=", " ", 
      RowBox[{"fillvt", "[", "rs", "]"}]}], ";", "\[IndentingNewLine]", 
     RowBox[{"ixs2", " ", "=", " ", 
      RowBox[{"Table", "[", 
       RowBox[{
        RowBox[{
         RowBox[{"fesx", " ", "=", " ", 
          RowBox[{"Append", "[", 
           RowBox[{"fes", ",", 
            RowBox[{"First", "[", "fes", "]"}]}], "]"}]}], ";", 
         "\[IndentingNewLine]", 
         RowBox[{"Flatten", "[", 
          RowBox[{
           RowBox[{"Table", "[", 
            RowBox[{
             RowBox[{"{", 
              RowBox[{
               RowBox[{"ptixs", "[", 
                RowBox[{"{", 
                 RowBox[{
                  RowBox[{"fesx", "[", 
                   RowBox[{"[", 
                    RowBox[{
                    RowBox[{"2", "i"}], "-", "1"}], "]"}], "]"}], ",", 
                  RowBox[{"fesx", "[", 
                   RowBox[{"[", 
                    RowBox[{"2", "i"}], "]"}], "]"}]}], "}"}], "]"}], ",", 
               RowBox[{"ptixs", "[", 
                RowBox[{"{", 
                 RowBox[{
                  RowBox[{"fesx", "[", 
                   RowBox[{"[", 
                    RowBox[{
                    RowBox[{"2", "i"}], "+", "1"}], "]"}], "]"}], ",", 
                  RowBox[{"fesx", "[", 
                   RowBox[{"[", 
                    RowBox[{"2", "i"}], "]"}], "]"}]}], "}"}], "]"}]}], "}"}],
              ",", "\[IndentingNewLine]", 
             RowBox[{"{", 
              RowBox[{"i", ",", 
               RowBox[{
                RowBox[{"Length", "[", "fes", "]"}], "/", "2"}]}], "}"}]}], 
            "]"}], ",", "1"}], "]"}]}], ",", "\[IndentingNewLine]", 
        RowBox[{"{", 
         RowBox[{"fes", ",", "vtfes"}], "}"}]}], "]"}]}], ";", 
     "\[IndentingNewLine]", 
     RowBox[{"GraphicsComplex", "[", 
      RowBox[{"pts", ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"Polygon", "[", "ixs1", "]"}], ",", 
         RowBox[{"Polygon", "[", "ixs2", "]"}]}], "}"}]}], "]"}]}]}], 
   "\[IndentingNewLine]", "]"}]}]], "Input",
 CellLabel->
  "In[581]:=",ExpressionUUID->"95eb6d9a-f35c-48e3-b3d0-35ddb0b4364c"],

Cell[BoxData[
 RowBox[{
  RowBox[{"model", "[", 
   RowBox[{"\"\<rs edge trunc\>\"", ",", "n_", ",", "r1_", ",", "r2_"}], 
   "]"}], " ", ":=", " ", 
  RowBox[{"Module", "[", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{
     "rs", ",", "vtfcs", ",", "fcvts", ",", "pts", ",", "ix", ",", "i", ",", 
      "vfs", ",", "fvs", ",", "j", ",", "ptixs", ",", "edvts", ",", "edfcs", 
      ",", "ev", ",", "ef", ",", "ixs1", ",", "ixs2", ",", "ixs3"}], "}"}], 
    ",", "\[IndentingNewLine]", 
    RowBox[{
     RowBox[{"rs", " ", "=", " ", 
      RowBox[{"regsld", "[", "n", "]"}]}], ";", "\[IndentingNewLine]", 
     RowBox[{"vtfcs", " ", "=", " ", 
      RowBox[{"rs", "[", 
       RowBox[{"\"\<vt\>\"", ",", "\"\<fc\>\""}], "]"}]}], ";", 
     "\[IndentingNewLine]", 
     RowBox[{"fcvts", " ", "=", " ", 
      RowBox[{"rs", "[", 
       RowBox[{"\"\<fc\>\"", ",", "\"\<vt\>\""}], "]"}]}], ";", 
     "\[IndentingNewLine]", 
     RowBox[{"ix", " ", "=", " ", "1"}], ";", "\[IndentingNewLine]", 
     RowBox[{"pts", " ", "=", " ", 
      RowBox[{"Flatten", "[", 
       RowBox[{
        RowBox[{"Table", "[", "\[IndentingNewLine]", 
         RowBox[{
          RowBox[{
           RowBox[{"vfs", " ", "=", " ", 
            RowBox[{"vtfcs", "[", 
             RowBox[{"[", "i", "]"}], "]"}]}], ";", "\[IndentingNewLine]", 
           RowBox[{"Table", "[", "\[IndentingNewLine]", 
            RowBox[{
             RowBox[{
              RowBox[{
               RowBox[{"ptixs", "[", 
                RowBox[{"{", 
                 RowBox[{"i", ",", "j"}], "}"}], "]"}], " ", "=", " ", 
               RowBox[{"ix", "++"}]}], ";", "\[IndentingNewLine]", 
              RowBox[{
               RowBox[{"r1", "*", 
                RowBox[{
                 RowBox[{"rs", "[", "\"\<vt\>\"", "]"}], "[", 
                 RowBox[{"[", "i", "]"}], "]"}]}], " ", "+", " ", 
               RowBox[{"r2", "*", 
                RowBox[{
                 RowBox[{"rs", "[", "\"\<fc\>\"", "]"}], "[", 
                 RowBox[{"[", "j", "]"}], "]"}]}]}]}], ",", 
             "\[IndentingNewLine]", 
             RowBox[{"{", 
              RowBox[{"j", ",", "vfs"}], "}"}]}], "]"}]}], ",", 
          "\[IndentingNewLine]", 
          RowBox[{"{", 
           RowBox[{"i", ",", 
            RowBox[{"Length", "[", 
             RowBox[{"rs", "[", "\"\<vt\>\"", "]"}], "]"}]}], "}"}]}], "]"}], 
        ",", "1"}], "]"}]}], ";", "\[IndentingNewLine]", 
     RowBox[{"ixs1", " ", "=", " ", 
      RowBox[{"Table", "[", 
       RowBox[{
        RowBox[{
         RowBox[{"vfs", " ", "=", " ", 
          RowBox[{"vtfcs", "[", 
           RowBox[{"[", "i", "]"}], "]"}]}], ";", "\[IndentingNewLine]", 
         RowBox[{"Table", "[", 
          RowBox[{
           RowBox[{"ptixs", "[", 
            RowBox[{"{", 
             RowBox[{"i", ",", "j"}], "}"}], "]"}], ",", 
           RowBox[{"{", 
            RowBox[{"j", ",", "vfs"}], "}"}]}], "]"}]}], ",", 
        "\[IndentingNewLine]", 
        RowBox[{"{", 
         RowBox[{"i", ",", 
          RowBox[{"Length", "[", 
           RowBox[{"rs", "[", "\"\<vt\>\"", "]"}], "]"}]}], "}"}]}], "]"}]}], 
     ";", "\[IndentingNewLine]", 
     RowBox[{"ixs2", " ", "=", " ", 
      RowBox[{"Table", "[", 
       RowBox[{
        RowBox[{
         RowBox[{"fvs", " ", "=", " ", 
          RowBox[{"fcvts", "[", 
           RowBox[{"[", "i", "]"}], "]"}]}], ";", "\[IndentingNewLine]", 
         RowBox[{"Table", "[", 
          RowBox[{
           RowBox[{"ptixs", "[", 
            RowBox[{"{", 
             RowBox[{"j", ",", "i"}], "}"}], "]"}], ",", 
           RowBox[{"{", 
            RowBox[{"j", ",", "fvs"}], "}"}]}], "]"}]}], ",", 
        "\[IndentingNewLine]", 
        RowBox[{"{", 
         RowBox[{"i", ",", 
          RowBox[{"Length", "[", 
           RowBox[{"rs", "[", "\"\<fc\>\"", "]"}], "]"}]}], "}"}]}], "]"}]}], 
     ";", "\[IndentingNewLine]", 
     RowBox[{"edvts", " ", "=", " ", 
      RowBox[{"rs", "[", 
       RowBox[{"\"\<ed\>\"", ",", "\"\<vt\>\""}], "]"}]}], ";", 
     "\[IndentingNewLine]", 
     RowBox[{"edfcs", " ", "=", " ", 
      RowBox[{"rs", "[", 
       RowBox[{"\"\<ed\>\"", ",", "\"\<fc\>\""}], "]"}]}], ";", 
     "\[IndentingNewLine]", 
     RowBox[{"ixs3", " ", "=", " ", 
      RowBox[{"Table", "[", 
       RowBox[{
        RowBox[{
         RowBox[{"ev", " ", "=", " ", 
          RowBox[{"edvts", "[", 
           RowBox[{"[", "i", "]"}], "]"}]}], ";", 
         RowBox[{"ef", " ", "=", " ", 
          RowBox[{"edfcs", "[", 
           RowBox[{"[", "i", "]"}], "]"}]}], ";", "\[IndentingNewLine]", 
         RowBox[{"{", 
          RowBox[{
           RowBox[{"ptixs", "[", 
            RowBox[{"{", 
             RowBox[{
              RowBox[{"ev", "[", 
               RowBox[{"[", "1", "]"}], "]"}], ",", 
              RowBox[{"ef", "[", 
               RowBox[{"[", "1", "]"}], "]"}]}], "}"}], "]"}], ",", 
           RowBox[{"ptixs", "[", 
            RowBox[{"{", 
             RowBox[{
              RowBox[{"ev", "[", 
               RowBox[{"[", "2", "]"}], "]"}], ",", 
              RowBox[{"ef", "[", 
               RowBox[{"[", "1", "]"}], "]"}]}], "}"}], "]"}], ",", 
           RowBox[{"ptixs", "[", 
            RowBox[{"{", 
             RowBox[{
              RowBox[{"ev", "[", 
               RowBox[{"[", "2", "]"}], "]"}], ",", 
              RowBox[{"ef", "[", 
               RowBox[{"[", "2", "]"}], "]"}]}], "}"}], "]"}], ",", 
           RowBox[{"ptixs", "[", 
            RowBox[{"{", 
             RowBox[{
              RowBox[{"ev", "[", 
               RowBox[{"[", "1", "]"}], "]"}], ",", 
              RowBox[{"ef", "[", 
               RowBox[{"[", "2", "]"}], "]"}]}], "}"}], "]"}]}], "}"}]}], ",",
         "\[IndentingNewLine]", 
        RowBox[{"{", 
         RowBox[{"i", ",", 
          RowBox[{"Length", "[", 
           RowBox[{"rs", "[", "\"\<ed\>\"", "]"}], "]"}]}], "}"}]}], "]"}]}], 
     ";", "\[IndentingNewLine]", 
     RowBox[{"GraphicsComplex", "[", 
      RowBox[{"pts", ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"Polygon", "[", "ixs1", "]"}], ",", 
         RowBox[{"Polygon", "[", "ixs2", "]"}], ",", 
         RowBox[{"Polygon", "[", "ixs3", "]"}]}], "}"}]}], "]"}]}]}], 
   "\[IndentingNewLine]", "]"}]}]], "Input",
 CellLabel->
  "In[582]:=",ExpressionUUID->"2ede95c5-9fea-48d8-b31d-7f2197ffd1c2"],

Cell[BoxData[
 RowBox[{
  RowBox[{"model", "[", 
   RowBox[{
   "\"\<rs max trunc\>\"", ",", "n_", ",", "r1_", ",", "r2_", ",", "r3_"}], 
   "]"}], " ", ":=", " ", 
  RowBox[{"Module", "[", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{
     "rs", ",", "kps", ",", "ix", ",", "kp", ",", "kpv", ",", "kpf", ",", 
      "kpe", ",", "pt1", ",", "pt2", ",", "pts", ",", "ptixs", ",", "vtfes", 
      ",", "fcves", ",", "vfe", ",", "vfex", ",", "fve", ",", "fvex", ",", 
      "i", ",", "j", ",", "edvts", ",", "edfcs", ",", "ev", ",", "ef", ",", 
      "ixs1", ",", "ixs2", ",", "ixs3"}], "}"}], ",", "\[IndentingNewLine]", 
    RowBox[{
     RowBox[{"rs", " ", "=", " ", 
      RowBox[{"regsld", "[", "n", "]"}]}], ";", "\[IndentingNewLine]", 
     RowBox[{"kps", " ", "=", " ", 
      RowBox[{"kitepoints", "[", "rs", "]"}]}], ";", "\[IndentingNewLine]", 
     RowBox[{"ix", " ", "=", " ", "1"}], ";", "\[IndentingNewLine]", 
     RowBox[{"pts", " ", "=", " ", 
      RowBox[{"Flatten", "[", 
       RowBox[{
        RowBox[{"Table", "[", 
         RowBox[{
          RowBox[{
           RowBox[{"kpv", " ", "=", " ", 
            RowBox[{"kp", "[", 
             RowBox[{"[", "1", "]"}], "]"}]}], ";", " ", 
           RowBox[{"kpf", " ", "=", " ", 
            RowBox[{"kp", "[", 
             RowBox[{"[", "2", "]"}], "]"}]}], ";", " ", 
           RowBox[{"kpe", " ", "=", " ", 
            RowBox[{"kp", "[", 
             RowBox[{"[", 
              RowBox[{"3", ",", "1"}], "]"}], "]"}]}], ";", 
           "\[IndentingNewLine]", 
           RowBox[{
            RowBox[{"ptixs", "[", 
             RowBox[{"{", 
              RowBox[{"kpv", ",", "kpf", ",", "kpe"}], "}"}], "]"}], " ", "=",
             " ", 
            RowBox[{"ix", "++"}]}], ";", "\[IndentingNewLine]", 
           RowBox[{"pt1", " ", "=", " ", 
            RowBox[{
             RowBox[{"r1", "*", 
              RowBox[{
               RowBox[{"rs", "[", "\"\<vt\>\"", "]"}], "[", 
               RowBox[{"[", "kpv", "]"}], "]"}]}], " ", "+", " ", 
             RowBox[{"r2", "*", 
              RowBox[{
               RowBox[{"rs", "[", "\"\<fc\>\"", "]"}], "[", 
               RowBox[{"[", "kpf", "]"}], "]"}]}], " ", "+", " ", 
             RowBox[{"r3", "*", 
              RowBox[{
               RowBox[{"rs", "[", "\"\<ed\>\"", "]"}], "[", 
               RowBox[{"[", "kpe", "]"}], "]"}]}]}]}], ";", 
           "\[IndentingNewLine]", 
           RowBox[{"kpe", " ", "=", " ", 
            RowBox[{"kp", "[", 
             RowBox[{"[", 
              RowBox[{"3", ",", "2"}], "]"}], "]"}]}], ";", 
           "\[IndentingNewLine]", 
           RowBox[{
            RowBox[{"ptixs", "[", 
             RowBox[{"{", 
              RowBox[{"kpv", ",", "kpf", ",", "kpe"}], "}"}], "]"}], " ", "=",
             " ", 
            RowBox[{"ix", "++"}]}], ";", "\[IndentingNewLine]", 
           RowBox[{"pt2", " ", "=", " ", 
            RowBox[{
             RowBox[{"r1", "*", 
              RowBox[{
               RowBox[{"rs", "[", "\"\<vt\>\"", "]"}], "[", 
               RowBox[{"[", "kpv", "]"}], "]"}]}], " ", "+", " ", 
             RowBox[{"r2", "*", 
              RowBox[{
               RowBox[{"rs", "[", "\"\<fc\>\"", "]"}], "[", 
               RowBox[{"[", "kpf", "]"}], "]"}]}], " ", "+", " ", 
             RowBox[{"r3", "*", 
              RowBox[{
               RowBox[{"rs", "[", "\"\<ed\>\"", "]"}], "[", 
               RowBox[{"[", "kpe", "]"}], "]"}]}]}]}], ";", 
           "\[IndentingNewLine]", 
           RowBox[{"{", 
            RowBox[{"pt1", ",", "pt2"}], "}"}]}], ",", "\[IndentingNewLine]", 
          
          RowBox[{"{", 
           RowBox[{"kp", ",", "kps"}], "}"}]}], "]"}], ",", "1"}], "]"}]}], 
     ";", "\[IndentingNewLine]", 
     RowBox[{"vtfes", " ", "=", " ", 
      RowBox[{"fillvt", "[", "rs", "]"}]}], ";", "\[IndentingNewLine]", 
     RowBox[{"fcves", " ", "=", " ", 
      RowBox[{"fillfc", "[", "rs", "]"}]}], ";", "\[IndentingNewLine]", 
     RowBox[{"ixs1", " ", "=", " ", 
      RowBox[{"Table", "[", "\[IndentingNewLine]", 
       RowBox[{
        RowBox[{
         RowBox[{"vfe", " ", "=", " ", 
          RowBox[{"vtfes", "[", 
           RowBox[{"[", "i", "]"}], "]"}]}], ";", "\[IndentingNewLine]", 
         RowBox[{"vfex", " ", "=", " ", 
          RowBox[{"Append", "[", 
           RowBox[{"vfe", ",", 
            RowBox[{"First", "[", "vfe", "]"}]}], "]"}]}], ";", 
         "\[IndentingNewLine]", 
         RowBox[{"Flatten", "[", 
          RowBox[{
           RowBox[{"Table", "[", "\[IndentingNewLine]", 
            RowBox[{
             RowBox[{"{", 
              RowBox[{
               RowBox[{"ptixs", "[", 
                RowBox[{"{", 
                 RowBox[{"i", ",", 
                  RowBox[{"vfex", "[", 
                   RowBox[{"[", 
                    RowBox[{
                    RowBox[{"2", "j"}], "-", "1"}], "]"}], "]"}], ",", 
                  RowBox[{"vfex", "[", 
                   RowBox[{"[", 
                    RowBox[{"2", "j"}], "]"}], "]"}]}], "}"}], "]"}], ",", 
               RowBox[{"ptixs", "[", 
                RowBox[{"{", 
                 RowBox[{"i", ",", 
                  RowBox[{"vfex", "[", 
                   RowBox[{"[", 
                    RowBox[{
                    RowBox[{"2", "j"}], "+", "1"}], "]"}], "]"}], ",", 
                  RowBox[{"vfex", "[", 
                   RowBox[{"[", 
                    RowBox[{"2", "j"}], "]"}], "]"}]}], "}"}], "]"}]}], "}"}],
              ",", "\[IndentingNewLine]", 
             RowBox[{"{", 
              RowBox[{"j", ",", 
               RowBox[{
                RowBox[{"Length", "[", "vfe", "]"}], "/", "2"}]}], "}"}]}], 
            "]"}], ",", "1"}], "]"}]}], ",", "\[IndentingNewLine]", 
        RowBox[{"{", 
         RowBox[{"i", ",", 
          RowBox[{"Length", "[", 
           RowBox[{"rs", "[", "\"\<vt\>\"", "]"}], "]"}]}], "}"}]}], "]"}]}], 
     ";", "\[IndentingNewLine]", 
     RowBox[{"ixs2", " ", "=", " ", 
      RowBox[{"Table", "[", "\[IndentingNewLine]", 
       RowBox[{
        RowBox[{
         RowBox[{"fve", " ", "=", " ", 
          RowBox[{"fcves", "[", 
           RowBox[{"[", "i", "]"}], "]"}]}], ";", "\[IndentingNewLine]", 
         RowBox[{"fvex", " ", "=", " ", 
          RowBox[{"Append", "[", 
           RowBox[{"fve", ",", 
            RowBox[{"First", "[", "fve", "]"}]}], "]"}]}], ";", 
         "\[IndentingNewLine]", 
         RowBox[{"Flatten", "[", 
          RowBox[{
           RowBox[{"Table", "[", "\[IndentingNewLine]", 
            RowBox[{
             RowBox[{"{", 
              RowBox[{
               RowBox[{"ptixs", "[", 
                RowBox[{"{", 
                 RowBox[{
                  RowBox[{"fvex", "[", 
                   RowBox[{"[", 
                    RowBox[{
                    RowBox[{"2", "j"}], "-", "1"}], "]"}], "]"}], ",", "i", 
                  ",", 
                  RowBox[{"fvex", "[", 
                   RowBox[{"[", 
                    RowBox[{"2", "j"}], "]"}], "]"}]}], "}"}], "]"}], ",", 
               RowBox[{"ptixs", "[", 
                RowBox[{"{", 
                 RowBox[{
                  RowBox[{"fvex", "[", 
                   RowBox[{"[", 
                    RowBox[{
                    RowBox[{"2", "j"}], "+", "1"}], "]"}], "]"}], ",", "i", 
                  ",", 
                  RowBox[{"fvex", "[", 
                   RowBox[{"[", 
                    RowBox[{"2", "j"}], "]"}], "]"}]}], "}"}], "]"}]}], "}"}],
              ",", "\[IndentingNewLine]", 
             RowBox[{"{", 
              RowBox[{"j", ",", 
               RowBox[{
                RowBox[{"Length", "[", "fve", "]"}], "/", "2"}]}], "}"}]}], 
            "]"}], ",", "1"}], "]"}]}], ",", "\[IndentingNewLine]", 
        RowBox[{"{", 
         RowBox[{"i", ",", 
          RowBox[{"Length", "[", 
           RowBox[{"rs", "[", "\"\<fc\>\"", "]"}], "]"}]}], "}"}]}], "]"}]}], 
     ";", "\[IndentingNewLine]", 
     RowBox[{"edvts", " ", "=", " ", 
      RowBox[{"rs", "[", 
       RowBox[{"\"\<ed\>\"", ",", "\"\<vt\>\""}], "]"}]}], ";", 
     "\[IndentingNewLine]", 
     RowBox[{"edfcs", " ", "=", " ", 
      RowBox[{"rs", "[", 
       RowBox[{"\"\<ed\>\"", ",", "\"\<fc\>\""}], "]"}]}], ";", 
     "\[IndentingNewLine]", 
     RowBox[{"ixs3", " ", "=", " ", 
      RowBox[{"Table", "[", 
       RowBox[{
        RowBox[{
         RowBox[{"ev", " ", "=", " ", 
          RowBox[{"edvts", "[", 
           RowBox[{"[", "i", "]"}], "]"}]}], ";", 
         RowBox[{"ef", " ", "=", " ", 
          RowBox[{"edfcs", "[", 
           RowBox[{"[", "i", "]"}], "]"}]}], ";", "\[IndentingNewLine]", 
         RowBox[{"{", 
          RowBox[{
           RowBox[{"ptixs", "[", 
            RowBox[{"{", 
             RowBox[{
              RowBox[{"ev", "[", 
               RowBox[{"[", "1", "]"}], "]"}], ",", 
              RowBox[{"ef", "[", 
               RowBox[{"[", "1", "]"}], "]"}], ",", "i"}], "}"}], "]"}], ",", 
           
           RowBox[{"ptixs", "[", 
            RowBox[{"{", 
             RowBox[{
              RowBox[{"ev", "[", 
               RowBox[{"[", "2", "]"}], "]"}], ",", 
              RowBox[{"ef", "[", 
               RowBox[{"[", "1", "]"}], "]"}], ",", "i"}], "}"}], "]"}], ",", 
           
           RowBox[{"ptixs", "[", 
            RowBox[{"{", 
             RowBox[{
              RowBox[{"ev", "[", 
               RowBox[{"[", "2", "]"}], "]"}], ",", 
              RowBox[{"ef", "[", 
               RowBox[{"[", "2", "]"}], "]"}], ",", "i"}], "}"}], "]"}], ",", 
           
           RowBox[{"ptixs", "[", 
            RowBox[{"{", 
             RowBox[{
              RowBox[{"ev", "[", 
               RowBox[{"[", "1", "]"}], "]"}], ",", 
              RowBox[{"ef", "[", 
               RowBox[{"[", "2", "]"}], "]"}], ",", "i"}], "}"}], "]"}]}], 
          "}"}]}], ",", "\[IndentingNewLine]", 
        RowBox[{"{", 
         RowBox[{"i", ",", 
          RowBox[{"Length", "[", 
           RowBox[{"rs", "[", "\"\<ed\>\"", "]"}], "]"}]}], "}"}]}], "]"}]}], 
     ";", "\[IndentingNewLine]", 
     RowBox[{"GraphicsComplex", "[", 
      RowBox[{"pts", ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"Polygon", "[", "ixs1", "]"}], ",", 
         RowBox[{"Polygon", "[", "ixs2", "]"}], ",", 
         RowBox[{"Polygon", "[", "ixs3", "]"}]}], "}"}]}], "]"}]}]}], 
   "\[IndentingNewLine]", "]"}]}]], "Input",
 CellLabel->
  "In[583]:=",ExpressionUUID->"a5597e2a-9685-47c5-9b2f-ee0d79dbea6f"]
}, Closed]],

Cell[CellGroupData[{

Cell["Snub", "Subsubsection",ExpressionUUID->"dd227e10-a214-4c22-8ec7-0001842e60b8"],

Cell[BoxData[
 RowBox[{
  RowBox[{"model", "[", 
   RowBox[{"\"\<rs snub\>\"", ",", "n_", ",", "r1_", ",", "r2_", ",", "r3_"}],
    "]"}], " ", ":=", " ", 
  RowBox[{"Module", "[", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{
     "rs", ",", "kps", ",", "kp", ",", "kpv", ",", "kpf", ",", "kpe", ",", 
      "pts", ",", "ix", ",", "ptixs", ",", "vtfcs", ",", "fcvts", ",", "i", 
      ",", "j", ",", "vf", ",", "fv", ",", "kpixs", ",", "kpx", ",", "ixs1", 
      ",", "ixs2", ",", "ixs3"}], "}"}], ",", "\[IndentingNewLine]", 
    RowBox[{
     RowBox[{"rs", " ", "=", " ", 
      RowBox[{"regsld", "[", "n", "]"}]}], ";", "\[IndentingNewLine]", 
     RowBox[{"kps", " ", "=", 
      RowBox[{"kttripoints", "[", "rs", "]"}]}], ";", "\[IndentingNewLine]", 
     RowBox[{"ix", " ", "=", " ", "1"}], ";", "\[IndentingNewLine]", 
     RowBox[{"pts", " ", "=", " ", 
      RowBox[{"Table", "[", 
       RowBox[{
        RowBox[{
         RowBox[{"kpv", " ", "=", " ", 
          RowBox[{"kp", "[", 
           RowBox[{"[", 
            RowBox[{"1", ",", "1"}], "]"}], "]"}]}], ";", " ", 
         RowBox[{"kpf", " ", "=", " ", 
          RowBox[{"kp", "[", 
           RowBox[{"[", "2", "]"}], "]"}]}], ";", " ", 
         RowBox[{"kpe", " ", "=", " ", 
          RowBox[{"kp", "[", 
           RowBox[{"[", 
            RowBox[{"3", ",", "1"}], "]"}], "]"}]}], ";", 
         "\[IndentingNewLine]", 
         RowBox[{
          RowBox[{"ptixs", "[", 
           RowBox[{"{", 
            RowBox[{"kpv", ",", "kpf"}], "}"}], "]"}], " ", "=", " ", 
          RowBox[{"ix", "++"}]}], ";", "\[IndentingNewLine]", 
         RowBox[{
          RowBox[{"r1", "*", 
           RowBox[{
            RowBox[{"rs", "[", "\"\<vt\>\"", "]"}], "[", 
            RowBox[{"[", "kpv", "]"}], "]"}]}], "+", 
          RowBox[{"r2", "*", 
           RowBox[{
            RowBox[{"rs", "[", "\"\<fc\>\"", "]"}], "[", 
            RowBox[{"[", "kpf", "]"}], "]"}]}], "+", 
          RowBox[{"r3", "*", 
           RowBox[{
            RowBox[{"rs", "[", "\"\<ed\>\"", "]"}], "[", 
            RowBox[{"[", "kpe", "]"}], "]"}]}]}]}], ",", 
        "\[IndentingNewLine]", 
        RowBox[{"{", 
         RowBox[{"kp", ",", "kps"}], "}"}]}], "]"}]}], ";", 
     "\[IndentingNewLine]", 
     RowBox[{"vtfcs", " ", "=", " ", 
      RowBox[{"rs", "[", 
       RowBox[{"\"\<vt\>\"", ",", "\"\<fc\>\""}], "]"}]}], ";", 
     "\[IndentingNewLine]", 
     RowBox[{"fcvts", " ", "=", " ", 
      RowBox[{"rs", "[", 
       RowBox[{"\"\<fc\>\"", ",", "\"\<vt\>\""}], "]"}]}], ";", 
     "\[IndentingNewLine]", 
     RowBox[{"ixs1", " ", "=", " ", 
      RowBox[{"Table", "[", 
       RowBox[{
        RowBox[{
         RowBox[{"vf", " ", "=", " ", 
          RowBox[{"vtfcs", "[", 
           RowBox[{"[", "i", "]"}], "]"}]}], ";", "\[IndentingNewLine]", 
         RowBox[{"Table", "[", 
          RowBox[{
           RowBox[{"ptixs", "[", 
            RowBox[{"{", 
             RowBox[{"i", ",", "j"}], "}"}], "]"}], ",", 
           "\[IndentingNewLine]", 
           RowBox[{"{", 
            RowBox[{"j", ",", "vf"}], "}"}]}], "]"}]}], ",", 
        "\[IndentingNewLine]", 
        RowBox[{"{", 
         RowBox[{"i", ",", 
          RowBox[{"Length", "[", 
           RowBox[{"rs", "[", "\"\<vt\>\"", "]"}], "]"}]}], "}"}]}], "]"}]}], 
     ";", "\[IndentingNewLine]", 
     RowBox[{"ixs2", " ", "=", " ", 
      RowBox[{"Table", "[", 
       RowBox[{
        RowBox[{
         RowBox[{"fv", " ", "=", " ", 
          RowBox[{"fcvts", "[", 
           RowBox[{"[", "i", "]"}], "]"}]}], ";", "\[IndentingNewLine]", 
         RowBox[{"Table", "[", 
          RowBox[{
           RowBox[{"ptixs", "[", 
            RowBox[{"{", 
             RowBox[{"j", ",", "i"}], "}"}], "]"}], ",", 
           "\[IndentingNewLine]", 
           RowBox[{"{", 
            RowBox[{"j", ",", "fv"}], "}"}]}], "]"}]}], ",", 
        "\[IndentingNewLine]", 
        RowBox[{"{", 
         RowBox[{"i", ",", 
          RowBox[{"Length", "[", 
           RowBox[{"rs", "[", "\"\<fc\>\"", "]"}], "]"}]}], "}"}]}], "]"}]}], 
     ";", "\[IndentingNewLine]", 
     RowBox[{"Do", "[", 
      RowBox[{
       RowBox[{
        RowBox[{"kp", " ", "=", " ", 
         RowBox[{"kps", "[", 
          RowBox[{"[", "i", "]"}], "]"}]}], ";", "\[IndentingNewLine]", 
        RowBox[{
         RowBox[{"kpixs", "[", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"kp", "[", 
             RowBox[{"[", 
              RowBox[{"1", ",", "1"}], "]"}], "]"}], ",", 
            RowBox[{"kp", "[", 
             RowBox[{"[", "2", "]"}], "]"}]}], "}"}], "]"}], " ", "=", " ", 
         "i"}]}], ",", "\[IndentingNewLine]", 
       RowBox[{"{", 
        RowBox[{"i", ",", 
         RowBox[{"Length", "[", "kps", "]"}]}], "}"}]}], "]"}], ";", 
     "\[IndentingNewLine]", 
     RowBox[{"ixs3", " ", "=", " ", 
      RowBox[{"Table", "[", 
       RowBox[{
        RowBox[{
         RowBox[{"kpx", " ", "=", " ", 
          RowBox[{"kps", "[", 
           RowBox[{"[", 
            RowBox[{"kpixs", "[", 
             RowBox[{"{", 
              RowBox[{
               RowBox[{"kp", "[", 
                RowBox[{"[", 
                 RowBox[{"1", ",", "1"}], "]"}], "]"}], ",", 
               RowBox[{"First", "[", 
                RowBox[{"Complement", "[", 
                 RowBox[{
                  RowBox[{
                   RowBox[{"rs", "[", 
                    RowBox[{"\"\<ed\>\"", ",", "\"\<fc\>\""}], "]"}], "[", 
                   RowBox[{"[", 
                    RowBox[{"kp", "[", 
                    RowBox[{"[", 
                    RowBox[{"3", ",", "1"}], "]"}], "]"}], "]"}], "]"}], ",", 
                  
                  RowBox[{"{", 
                   RowBox[{"kp", "[", 
                    RowBox[{"[", "2", "]"}], "]"}], "}"}]}], "]"}], "]"}]}], 
              "}"}], "]"}], "]"}], "]"}]}], ";", "\[IndentingNewLine]", 
         RowBox[{"{", 
          RowBox[{
           RowBox[{"ptixs", "[", 
            RowBox[{"{", 
             RowBox[{
              RowBox[{"kp", "[", 
               RowBox[{"[", 
                RowBox[{"1", ",", "1"}], "]"}], "]"}], ",", 
              RowBox[{"kp", "[", 
               RowBox[{"[", "2", "]"}], "]"}]}], "}"}], "]"}], ",", 
           RowBox[{"ptixs", "[", 
            RowBox[{"{", 
             RowBox[{
              RowBox[{"kpx", "[", 
               RowBox[{"[", 
                RowBox[{"1", ",", "3"}], "]"}], "]"}], ",", 
              RowBox[{"kpx", "[", 
               RowBox[{"[", "2", "]"}], "]"}]}], "}"}], "]"}], ",", 
           RowBox[{"ptixs", "[", 
            RowBox[{"{", 
             RowBox[{
              RowBox[{"kp", "[", 
               RowBox[{"[", 
                RowBox[{"1", ",", "2"}], "]"}], "]"}], ",", 
              RowBox[{"kp", "[", 
               RowBox[{"[", "2", "]"}], "]"}]}], "}"}], "]"}]}], "}"}]}], ",",
         "\[IndentingNewLine]", 
        RowBox[{"{", 
         RowBox[{"kp", ",", "kps"}], "}"}]}], "]"}]}], ";", 
     "\[IndentingNewLine]", 
     RowBox[{"GraphicsComplex", "[", 
      RowBox[{"pts", ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"Polygon", "[", "ixs1", "]"}], ",", 
         RowBox[{"Polygon", "[", "ixs2", "]"}], ",", 
         RowBox[{"Polygon", "[", "ixs3", "]"}]}], "}"}]}], "]"}]}]}], 
   "\[IndentingNewLine]", "]"}]}]], "Input",
 CellLabel->
  "In[584]:=",ExpressionUUID->"d1d27070-0f7d-46ad-a09f-8bdbfba4b3dc"]
}, Closed]]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{

Cell["Displays", "Section",ExpressionUUID->"9f39b2f3-6503-49ad-afc3-7460fa5aaca7"],

Cell[CellGroupData[{

Cell["Axial", "Subsection",ExpressionUUID->"a4fe0d83-6196-4604-bb54-290a711062ad"],

Cell[CellGroupData[{

Cell["Gallery", "Subsubsection",ExpressionUUID->"24f1925a-801d-4d2d-96ef-cac6c5016211"],

Cell[BoxData[
 RowBox[{
  RowBox[{"axnum", " ", "=", " ", "5"}], ";"}]], "Input",
 CellLabel->
  "In[585]:=",ExpressionUUID->"49ac9349-e8d9-4d43-b313-c2761f6c4b4f"],

Cell[BoxData[
 RowBox[{
  RowBox[{"axldsp", " ", "=", " ", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"\"\<bipyr\>\"", ",", 
       RowBox[{"show3dfront", "[", 
        RowBox[{"model", "[", 
         RowBox[{"\"\<bipyr\>\"", ",", "axnum", ",", "1"}], "]"}], "]"}]}], 
      "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"\"\<bipyr rad\>\"", ",", 
       RowBox[{"show3dfront", "[", 
        RowBox[{"model", "[", 
         RowBox[{"\"\<bipyr rad\>\"", ",", "axnum", ",", 
          RowBox[{"5", "/", "4"}], ",", 
          RowBox[{"3", "/", "4"}], ",", "1"}], "]"}], "]"}], ",", 
       "\"\<bipyr axl\>\"", ",", 
       RowBox[{"show3dfront", "[", 
        RowBox[{"model", "[", 
         RowBox[{"\"\<bipyr axl\>\"", ",", "axnum", ",", "1", ",", 
          RowBox[{"1", "/", "4"}]}], "]"}], "]"}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"\"\<tpzdh\>\"", ",", 
       RowBox[{"show3dfront", "[", 
        RowBox[{"model", "[", 
         RowBox[{"\"\<tpzdh\>\"", ",", "axnum", ",", "1"}], "]"}], "]"}], 
       ",", "\"\<tpzdh skw\>\"", ",", 
       RowBox[{"show3dfront", "[", 
        RowBox[{"model", "[", 
         RowBox[{"\"\<tpzdh skw\>\"", ",", "axnum", ",", "1", ",", 
          RowBox[{"1", "/", "2"}]}], "]"}], "]"}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"\"\<prism\>\"", ",", 
       RowBox[{"show3dfront", "[", 
        RowBox[{"model", "[", 
         RowBox[{"\"\<prism\>\"", ",", "axnum", ",", "1", ",", "1"}], "]"}], 
        "]"}], ",", "\"\<prism tpr\>\"", ",", 
       RowBox[{"show3dfront", "[", 
        RowBox[{"model", "[", 
         RowBox[{"\"\<prism tpr\>\"", ",", "axnum", ",", "1", ",", "1", ",", 
          RowBox[{"1", "/", "2"}]}], "]"}], "]"}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"\"\<apsm\>\"", ",", 
       RowBox[{"show3dfront", "[", 
        RowBox[{"model", "[", 
         RowBox[{"\"\<apsm\>\"", ",", "axnum", ",", "1", ",", "1"}], "]"}], 
        "]"}], ",", "\"\<apsm skw\>\"", ",", 
       RowBox[{"show3dfront", "[", 
        RowBox[{"model", "[", 
         RowBox[{"\"\<apsm skw\>\"", ",", "axnum", ",", "1", ",", "1", ",", 
          RowBox[{"1", "/", "2"}]}], "]"}], "]"}]}], "}"}]}], "}"}]}], 
  ";"}]], "Input",
 CellLabel->
  "In[586]:=",ExpressionUUID->"c70afba9-40b0-4196-87d7-f530d51d51a4"],

Cell[BoxData[
 RowBox[{"Grid", "[", "axldsp", "]"}]], "Input",
 CellLabel->
  "In[587]:=",ExpressionUUID->"5b76ff9b-6301-4abe-a26e-87f9376bafb4"]
}, Closed]],

Cell[CellGroupData[{

Cell["Interactive", "Subsubsection",ExpressionUUID->"c4cccb37-53cc-489b-847d-fc0dc218d517"],

Cell[BoxData[
 RowBox[{"Manipulate", "[", 
  RowBox[{
   RowBox[{"show3dfront", "[", 
    RowBox[{"model", "[", 
     RowBox[{"type", ",", "n", ",", "r", ",", 
      RowBox[{"1", "-", "r"}]}], "]"}], "]"}], ",", 
   RowBox[{"{", 
    RowBox[{"type", ",", " ", 
     RowBox[{"{", 
      RowBox[{
      "\"\<bipyr\>\"", ",", "\"\<tpzdh\>\"", ",", "\"\<prism\>\"", ",", 
       "\"\<apsm\>\""}], "}"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"n", ",", "5"}], "}"}], ",", 
     RowBox[{"Range", "[", 
      RowBox[{"3", ",", "12"}], "]"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"r", ",", "0.5"}], "}"}], ",", "0", ",", "1"}], "}"}]}], 
  "]"}]], "Input",
 CellLabel->
  "In[588]:=",ExpressionUUID->"ca396b18-267d-4028-be61-f33218446436"],

Cell[BoxData[
 RowBox[{"Manipulate", "[", 
  RowBox[{
   RowBox[{"show3dfront", "[", 
    RowBox[{"Which", "[", 
     RowBox[{
      RowBox[{"type", "\[Equal]", "\"\<bipyr rad\>\""}], ",", 
      RowBox[{"model", "[", 
       RowBox[{"type", ",", "n", ",", 
        RowBox[{"r", 
         RowBox[{"(", 
          RowBox[{"1", "+", "f"}], ")"}]}], ",", 
        RowBox[{"r", 
         RowBox[{"(", 
          RowBox[{"1", "-", "f"}], ")"}]}], ",", 
        RowBox[{"1", "-", "r"}]}], "]"}], ",", 
      RowBox[{"type", "\[Equal]", "\"\<bipyr axl\>\""}], ",", 
      RowBox[{"model", "[", 
       RowBox[{"type", ",", "n", ",", "r", ",", 
        RowBox[{
         RowBox[{"(", 
          RowBox[{"1", "-", "r"}], ")"}], "*", "f"}], ",", 
        RowBox[{"1", "-", "r"}]}], "]"}], ",", "True", ",", 
      RowBox[{"model", "[", 
       RowBox[{"type", ",", "n", ",", "r", ",", 
        RowBox[{"1", "-", "r"}], ",", "f"}], "]"}]}], "]"}], "]"}], ",", 
   RowBox[{"{", 
    RowBox[{"type", ",", " ", 
     RowBox[{"{", 
      RowBox[{
      "\"\<bipyr rad\>\"", ",", "\"\<bipyr axl\>\"", ",", "\"\<tpzdh skw\>\"",
        ",", "\"\<prism alt\>\"", ",", "\"\<prism tpr\>\"", ",", 
       "\"\<apsm skw\>\""}], "}"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"n", ",", "5"}], "}"}], ",", 
     RowBox[{"Range", "[", 
      RowBox[{"3", ",", "12"}], "]"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"r", ",", "0.5"}], "}"}], ",", "0", ",", "1"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"f", ",", "0"}], "}"}], ",", 
     RowBox[{"-", "1"}], ",", "1"}], "}"}]}], "]"}]], "Input",
 CellLabel->
  "In[589]:=",ExpressionUUID->"435a33e1-11af-4e98-9d58-65aa16ed1aea"]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{

Cell["Quasi-Spherical", "Subsection",ExpressionUUID->"5e924064-95c6-4fd3-a290-3541e4e369d7"],

Cell[CellGroupData[{

Cell["Gallery", "Subsubsection",ExpressionUUID->"8f6b49ce-3b3b-4f77-9059-0e48096deafe"],

Cell[BoxData[
 RowBox[{
  RowBox[{"rsdsp", " ", "=", " ", 
   RowBox[{"Table", "[", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"n", ",", "\"\<rs tri\>\"", ",", 
       RowBox[{"show3dfront", "[", 
        RowBox[{"model", "[", 
         RowBox[{"\"\<rs tri\>\"", ",", "n", ",", "1"}], "]"}], "]"}], ",", 
       "\"\<rs dual\>\"", ",", 
       RowBox[{"show3dfront", "[", 
        RowBox[{"model", "[", 
         RowBox[{"\"\<rs dual\>\"", ",", "n", ",", "1"}], "]"}], "]"}]}], 
      "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"n", ",", "3", ",", "5"}], "}"}]}], "]"}]}], ";"}]], "Input",
 CellLabel->
  "In[590]:=",ExpressionUUID->"095370fa-f85e-4864-9505-3a510da0e1c5"],

Cell[BoxData[
 RowBox[{
  RowBox[{"rsdspt", " ", "=", " ", 
   RowBox[{"Table", "[", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"n", ",", "\"\<rs pyr tri\>\"", ",", 
       RowBox[{"show3dfront", "[", 
        RowBox[{"model", "[", 
         RowBox[{"\"\<rs pyr tri\>\"", ",", "n", ",", "1", ",", 
          RowBox[{"dctripyrht", "[", 
           RowBox[{"cval", "[", "n", "]"}], "]"}]}], "]"}], "]"}], ",", 
       "\"\<rs pyr dual\>\"", ",", 
       RowBox[{"show3dfront", "[", 
        RowBox[{"model", "[", 
         RowBox[{"\"\<rs pyr dual\>\"", ",", "n", ",", "1", ",", 
          RowBox[{"dcdualpyrht", "[", 
           RowBox[{"cval", "[", "n", "]"}], "]"}]}], "]"}], "]"}]}], "}"}], 
     ",", 
     RowBox[{"{", 
      RowBox[{"n", ",", "3", ",", "5"}], "}"}]}], "]"}]}], ";"}]], "Input",
 CellLabel->
  "In[591]:=",ExpressionUUID->"641334e3-b529-48eb-ae6e-1fecce642e96"],

Cell[BoxData[
 RowBox[{
  RowBox[{"rsdsptb", " ", "=", " ", 
   RowBox[{"Table", "[", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"n", ",", "\"\<rs pyr both\>\"", ",", 
       RowBox[{"show3dfront", "[", 
        RowBox[{"model", "[", 
         RowBox[{"\"\<rs pyr both\>\"", ",", "n", ",", "1"}], "]"}], "]"}]}], 
      "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"n", ",", "3", ",", "5"}], "}"}]}], "]"}]}], ";"}]], "Input",
 CellLabel->
  "In[592]:=",ExpressionUUID->"10324467-83ff-4a7a-af73-f789f985ae87"],

Cell[BoxData[
 RowBox[{
  RowBox[{"rsdspq", " ", "=", " ", 
   RowBox[{"Table", "[", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"n", ",", "\"\<rs rhomb\>\"", ",", 
       RowBox[{"show3dfront", "[", 
        RowBox[{"model", "[", 
         RowBox[{"\"\<rs rhomb\>\"", ",", "n", ",", "1"}], "]"}], "]"}], ",", 
       "\"\<rs kite\>\"", ",", 
       RowBox[{"show3dfront", "[", 
        RowBox[{"model", "[", 
         RowBox[{"\"\<rs kite\>\"", ",", "n", ",", "1"}], "]"}], "]"}]}], 
      "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"n", ",", "3", ",", "5"}], "}"}]}], "]"}]}], ";"}]], "Input",
 CellLabel->
  "In[593]:=",ExpressionUUID->"221d87a2-cfa1-42eb-9978-a955196eb2b1"],

Cell[BoxData[
 RowBox[{
  RowBox[{"rsdspk", " ", "=", " ", 
   RowBox[{"Table", "[", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"n", ",", "\"\<rs tri trunc\>\"", ",", 
       RowBox[{"show3dfront", "[", 
        RowBox[{"model", "[", 
         RowBox[{"\"\<rs tri trunc\>\"", ",", "n", ",", "1", ",", "1"}], 
         "]"}], "]"}], ",", "\"\<rs dual trunc\>\"", ",", 
       RowBox[{"show3dfront", "[", 
        RowBox[{"model", "[", 
         RowBox[{"\"\<rs dual trunc\>\"", ",", "n", ",", "1", ",", "1"}], 
         "]"}], "]"}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"n", ",", "3", ",", "5"}], "}"}]}], "]"}]}], ";"}]], "Input",
 CellLabel->
  "In[594]:=",ExpressionUUID->"4f0befa0-4d27-437f-b014-7b9f472b6059"],

Cell[BoxData[
 RowBox[{
  RowBox[{"rsdspkb", " ", "=", " ", 
   RowBox[{"Table", "[", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"n", ",", "\"\<rs both trunc\>\"", ",", 
       RowBox[{"show3dfront", "[", 
        RowBox[{"model", "[", 
         RowBox[{"\"\<rs both trunc\>\"", ",", "n", ",", "1"}], "]"}], 
        "]"}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"n", ",", "3", ",", "5"}], "}"}]}], "]"}]}], ";"}]], "Input",
 CellLabel->
  "In[595]:=",ExpressionUUID->"ec7854e0-1e35-41c0-b9df-5b1d7cb24fb7"],

Cell[BoxData[
 RowBox[{
  RowBox[{"rsdspke", " ", "=", " ", 
   RowBox[{"Table", "[", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"n", ",", "\"\<rs edge trunc\>\"", ",", 
       RowBox[{"show3dfront", "[", 
        RowBox[{"model", "[", 
         RowBox[{"\"\<rs edge trunc\>\"", ",", "n", ",", "1", ",", "1"}], 
         "]"}], "]"}], ",", "\"\<rs max trunc\>\"", ",", 
       RowBox[{"show3dfront", "[", 
        RowBox[{"model", "[", 
         RowBox[{
         "\"\<rs max trunc\>\"", ",", "n", ",", "1", ",", "1", ",", "1"}], 
         "]"}], "]"}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"n", ",", "3", ",", "5"}], "}"}]}], "]"}]}], ";"}]], "Input",
 CellLabel->
  "In[596]:=",ExpressionUUID->"dd061aa4-265e-4180-aea1-d731166f68c6"],

Cell[BoxData[
 RowBox[{
  RowBox[{"rsdspx", " ", "=", " ", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"3", ",", "\"\<rs pntg\>\"", ",", 
       RowBox[{"show3dfront", "[", 
        RowBox[{"model", "[", 
         RowBox[{"\"\<rs pntg\>\"", ",", "3", ",", "1", ",", "1.5"}], "]"}], 
        "]"}], ",", "\"\<rs snub\>\"", ",", 
       RowBox[{"show3dfront", "[", 
        RowBox[{"model", "[", 
         RowBox[{"\"\<rs snub\>\"", ",", "3", ",", "1", ",", "1", ",", "1"}], 
         "]"}], "]"}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"4", ",", "\"\<rs pntg\>\"", ",", 
       RowBox[{"show3dfront", "[", 
        RowBox[{"model", "[", 
         RowBox[{"\"\<rs pntg\>\"", ",", "4", ",", "1", ",", "1.3"}], "]"}], 
        "]"}], ",", "\"\<rs snub\>\"", ",", 
       RowBox[{"show3dfront", "[", 
        RowBox[{"model", "[", 
         RowBox[{"\"\<rs snub\>\"", ",", "4", ",", "1", ",", "1", ",", "1"}], 
         "]"}], "]"}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"5", ",", "\"\<rs pntg\>\"", ",", 
       RowBox[{"show3dfront", "[", 
        RowBox[{"model", "[", 
         RowBox[{"\"\<rs pntg\>\"", ",", "5", ",", "1", ",", "1.15"}], "]"}], 
        "]"}], ",", "\"\<rs snub\>\"", ",", 
       RowBox[{"show3dfront", "[", 
        RowBox[{"model", "[", 
         RowBox[{"\"\<rs snub\>\"", ",", "5", ",", "1", ",", "1", ",", "1"}], 
         "]"}], "]"}]}], "}"}]}], "}"}]}], ";"}]], "Input",
 CellLabel->
  "In[597]:=",ExpressionUUID->"3d77d784-dca6-40f2-aa6d-f0c22231d18b"],

Cell[BoxData[
 RowBox[{
  RowBox[{"rsdspi", " ", "=", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"\"\<rs dsph\>\"", ",", 
       RowBox[{"show3dfront", "[", 
        RowBox[{"model", "[", 
         RowBox[{"\"\<rs dsph\>\"", ",", "1", ",", 
          RowBox[{"3", "/", "2"}], ",", "2"}], "]"}], "]"}], ",", 
       "\"\<rs rect\>\"", ",", 
       RowBox[{"show3dfront", "[", 
        RowBox[{"model", "[", 
         RowBox[{"\"\<rs rect\>\"", ",", "1", ",", 
          RowBox[{"3", "/", "2"}], ",", "2"}], "]"}], "]"}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"\"\<rs tpzdh\>\"", ",", 
       RowBox[{"show3dfront", "[", 
        RowBox[{"model", "[", 
         RowBox[{"\"\<tpzdh\>\"", ",", "3", ",", 
          RowBox[{"1", "/", "2"}], ",", "1"}], "]"}], "]"}], ",", 
       "\"\<rs tpzdh skw\>\"", ",", 
       RowBox[{"show3dfront", "[", 
        RowBox[{"model", "[", 
         RowBox[{"\"\<tpzdh skw\>\"", ",", "3", ",", 
          RowBox[{"1", "/", "2"}], ",", "1", ",", 
          RowBox[{"1", "/", "2"}]}], "]"}], "]"}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"\"\<rs bipyr\>\"", ",", 
       RowBox[{"show3dfront", "[", 
        RowBox[{"model", "[", 
         RowBox[{"\"\<bipyr\>\"", ",", "4", ",", "1", ",", 
          RowBox[{"3", "/", "2"}]}], "]"}], "]"}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"\"\<rs bipyr rad\>\"", ",", 
       RowBox[{"show3dfront", "[", 
        RowBox[{"model", "[", 
         RowBox[{"\"\<bipyr rad\>\"", ",", "2", ",", 
          RowBox[{"5", "/", "4"}], ",", 
          RowBox[{"3", "/", "4"}], ",", 
          RowBox[{"3", "/", "2"}]}], "]"}], "]"}], ",", 
       "\"\<rs bipyr axl\>\"", ",", 
       RowBox[{"show3dfront", "[", 
        RowBox[{"model", "[", 
         RowBox[{"\"\<bipyr axl\>\"", ",", "2", ",", "1", ",", 
          RowBox[{"1", "/", "4"}], ",", 
          RowBox[{"3", "/", "2"}]}], "]"}], "]"}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"\"\<rs pntg\>\"", ",", 
       RowBox[{"show3dfront", "[", 
        RowBox[{"model", "[", 
         RowBox[{"\"\<rs pntg\>\"", ",", "3", ",", "1", ",", "1.5"}], "]"}], 
        "]"}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"\"\<rs rhomb shft\>\"", ",", 
       RowBox[{"show3dfront", "[", 
        RowBox[{"model", "[", 
         RowBox[{"\"\<rs rhomb shft\>\"", ",", "1", ",", 
          RowBox[{"1", "/", "4"}]}], "]"}], "]"}], ",", 
       "\"\<rs kite shft\>\"", ",", 
       RowBox[{"show3dfront", "[", 
        RowBox[{"model", "[", 
         RowBox[{"\"\<rs kite shft\>\"", ",", "1", ",", 
          RowBox[{"1", "/", "4"}]}], "]"}], "]"}]}], "}"}]}], "}"}]}], 
  ";"}]], "Input",
 CellLabel->
  "In[598]:=",ExpressionUUID->"482c5223-e46d-443e-aa80-4f086c2084a7"],

Cell[BoxData[
 RowBox[{"(*", " ", 
  RowBox[{
   RowBox[{"Great", " ", "dodecahedron"}], ",", " ", 
   RowBox[{"small", " ", "stellated", " ", "dodecahedron"}], ",", " ", 
   RowBox[{"great", " ", "stellated", " ", 
    RowBox[{"dodecahedron", " ", "--"}], " ", "could", " ", "not", " ", "do", 
    " ", "the", " ", "great", " ", "icosahedron"}]}], " ", "*)"}]], "Input",
 CellLabel->
  "In[599]:=",ExpressionUUID->"16031b53-849c-4778-8d65-400a83c65325"],

Cell[BoxData[
 RowBox[{
  RowBox[{"stelht", "[", "\"\<grt ddc\>\"", "]"}], " ", ":=", " ", 
  RowBox[{"Module", "[", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{"stelsrc", ",", "xfc", ",", "fcvts", ",", "xvt0", ",", "xvt1"}], 
     "}"}], ",", "\[IndentingNewLine]", 
    RowBox[{
     RowBox[{"stelsrc", " ", "=", " ", 
      RowBox[{"regsld", "[", "5", "]"}]}], ";", "\[IndentingNewLine]", 
     RowBox[{"xfc", " ", "=", " ", 
      RowBox[{
       RowBox[{"stelsrc", "[", "\"\<fc\>\"", "]"}], "[", 
       RowBox[{"[", "1", "]"}], "]"}]}], ";", "\[IndentingNewLine]", 
     RowBox[{"fcvts", " ", "=", " ", 
      RowBox[{
       RowBox[{"stelsrc", "[", 
        RowBox[{"\"\<fc\>\"", ",", "\"\<vt\>\""}], "]"}], "[", 
       RowBox[{"[", "1", "]"}], "]"}]}], ";", "\[IndentingNewLine]", 
     RowBox[{"xvt0", " ", "=", " ", 
      RowBox[{
       RowBox[{"stelsrc", "[", "\"\<vt\>\"", "]"}], "[", 
       RowBox[{"[", 
        RowBox[{"fcvts", "[", 
         RowBox[{"[", "1", "]"}], "]"}], "]"}], "]"}]}], ";", 
     "\[IndentingNewLine]", 
     RowBox[{"xvt1", " ", "=", " ", 
      RowBox[{
       RowBox[{"stelsrc", "[", "\"\<vt\>\"", "]"}], "[", 
       RowBox[{"[", 
        RowBox[{"fcvts", "[", 
         RowBox[{"[", "2", "]"}], "]"}], "]"}], "]"}]}], ";", 
     "\[IndentingNewLine]", 
     RowBox[{
      RowBox[{
       RowBox[{
        RowBox[{"(", 
         RowBox[{"xvt1", ".", "xvt0"}], ")"}], "/", 
        RowBox[{"(", 
         RowBox[{"xfc", ".", "xvt0"}], ")"}]}], " ", "//", " ", "Expand"}], 
      " ", "//", " ", "Factor"}]}]}], "\[IndentingNewLine]", "]"}]}]], "Input",\

 CellLabel->
  "In[600]:=",ExpressionUUID->"323e4ead-f3ac-4119-ac76-ee7a2e1290b4"],

Cell[BoxData[
 RowBox[{
  RowBox[{"stelht", "[", "\"\<sml stl ddc\>\"", "]"}], " ", ":=", " ", 
  RowBox[{"Module", "[", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{
     "stelsrc", ",", "xvts", ",", "xfcs", ",", "vtfcs", ",", "fcvts", ",", 
      "frstvt", ",", "fclst", ",", "fcvtlst", ",", "nxtvts", ",", "xvt0", ",",
       "xfc", ",", "xvt1"}], "}"}], ",", "\[IndentingNewLine]", 
    RowBox[{
     RowBox[{"stelsrc", " ", "=", " ", 
      RowBox[{"regsld", "[", "5", "]"}]}], ";", "\[IndentingNewLine]", 
     RowBox[{"xvts", " ", "=", " ", 
      RowBox[{"stelsrc", "[", "\"\<vt\>\"", "]"}]}], ";", 
     "\[IndentingNewLine]", 
     RowBox[{"xfcs", " ", "=", " ", 
      RowBox[{"stelsrc", "[", "\"\<fc\>\"", "]"}]}], ";", 
     "\[IndentingNewLine]", 
     RowBox[{"vtfcs", " ", "=", " ", 
      RowBox[{"stelsrc", "[", 
       RowBox[{"\"\<vt\>\"", ",", "\"\<fc\>\""}], "]"}]}], ";", 
     "\[IndentingNewLine]", 
     RowBox[{"fcvts", " ", "=", " ", 
      RowBox[{"stelsrc", "[", 
       RowBox[{"\"\<fc\>\"", ",", "\"\<vt\>\""}], "]"}]}], ";", 
     "\[IndentingNewLine]", 
     RowBox[{"frstvt", " ", "=", " ", "1"}], ";", "\[IndentingNewLine]", 
     RowBox[{"fclst", " ", "=", " ", 
      RowBox[{"vtfcs", "[", 
       RowBox[{"[", "frstvt", "]"}], "]"}]}], ";", "\[IndentingNewLine]", 
     RowBox[{"fcvtlst", " ", "=", " ", 
      RowBox[{
       RowBox[{
        RowBox[{"Complement", "[", 
         RowBox[{"#", ",", 
          RowBox[{"{", "frstvt", "}"}]}], "]"}], "&"}], " ", "/@", " ", 
       RowBox[{"fcvts", "[", 
        RowBox[{"[", "fclst", "]"}], "]"}]}]}], ";", "\[IndentingNewLine]", 
     RowBox[{"nxtvts", " ", "=", " ", 
      RowBox[{
       RowBox[{
        RowBox[{"Select", "[", 
         RowBox[{
          RowBox[{"Flatten", "[", 
           RowBox[{
            RowBox[{"Outer", "[", 
             RowBox[{
             "Intersection", ",", "fcvtlst", ",", "fcvtlst", ",", "1"}], 
             "]"}], ",", "1"}], "]"}], ",", 
          RowBox[{
           RowBox[{
            RowBox[{"Length", "[", "#", "]"}], "\[Equal]", "1"}], "&"}]}], 
         "]"}], " ", "//", " ", "Flatten"}], " ", "//", " ", "Union"}]}], ";",
      "\[IndentingNewLine]", 
     RowBox[{"xvt0", " ", "=", " ", 
      RowBox[{"xvts", "[", 
       RowBox[{"[", "frstvt", "]"}], "]"}]}], ";", "\[IndentingNewLine]", 
     RowBox[{"xfc", " ", "=", " ", 
      RowBox[{"xfcs", "[", 
       RowBox[{"[", 
        RowBox[{"First", "[", "fclst", "]"}], "]"}], "]"}]}], ";", 
     "\[IndentingNewLine]", 
     RowBox[{"xvt1", " ", "=", " ", 
      RowBox[{"xvts", "[", 
       RowBox[{"[", 
        RowBox[{"First", "[", "nxtvts", "]"}], "]"}], "]"}]}], ";", 
     "\[IndentingNewLine]", 
     RowBox[{
      RowBox[{
       RowBox[{
        RowBox[{"(", 
         RowBox[{"xfc", ".", "xvt0"}], ")"}], "/", 
        RowBox[{"(", 
         RowBox[{"xvt1", ".", "xvt0"}], ")"}]}], " ", "//", " ", "Expand"}], 
      " ", "//", " ", "Factor"}]}]}], "\[IndentingNewLine]", "]"}]}]], "Input",\

 CellLabel->
  "In[601]:=",ExpressionUUID->"374383ed-fdf7-4446-85ef-971be9d4e399"],

Cell[BoxData[
 RowBox[{
  RowBox[{"stelht", "[", "\"\<grt stl ddc\>\"", "]"}], " ", ":=", " ", 
  RowBox[{"Module", "[", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{
     "stelsrc", ",", "xvts", ",", "xfcs", ",", "vtfcs", ",", "fcvts", ",", 
      "frstvt", ",", "frstfcs", ",", "fcvtlst", ",", "nxtvts", ",", "vtfclst",
       ",", "nxtfcs", ",", "xvt0", ",", "xfc", ",", "xvt1"}], "}"}], ",", 
    "\[IndentingNewLine]", 
    RowBox[{
     RowBox[{"stelsrc", " ", "=", " ", 
      RowBox[{"regsld", "[", "5", "]"}]}], ";", "\[IndentingNewLine]", 
     RowBox[{"xvts", " ", "=", " ", 
      RowBox[{"stelsrc", "[", "\"\<vt\>\"", "]"}]}], ";", 
     "\[IndentingNewLine]", 
     RowBox[{"xfcs", " ", "=", " ", 
      RowBox[{"stelsrc", "[", "\"\<fc\>\"", "]"}]}], ";", 
     "\[IndentingNewLine]", 
     RowBox[{"vtfcs", " ", "=", " ", 
      RowBox[{"stelsrc", "[", 
       RowBox[{"\"\<vt\>\"", ",", "\"\<fc\>\""}], "]"}]}], ";", 
     "\[IndentingNewLine]", 
     RowBox[{"fcvts", " ", "=", " ", 
      RowBox[{"stelsrc", "[", 
       RowBox[{"\"\<fc\>\"", ",", "\"\<vt\>\""}], "]"}]}], ";", 
     "\[IndentingNewLine]", 
     RowBox[{"frstvt", " ", "=", " ", "1"}], ";", "\[IndentingNewLine]", 
     RowBox[{"frstfcs", " ", "=", " ", 
      RowBox[{"vtfcs", "[", 
       RowBox[{"[", "frstvt", "]"}], "]"}]}], ";", "\[IndentingNewLine]", 
     RowBox[{"fcvtlst", " ", "=", " ", 
      RowBox[{
       RowBox[{
        RowBox[{"Complement", "[", 
         RowBox[{"#", ",", 
          RowBox[{"{", "frstvt", "}"}]}], "]"}], "&"}], " ", "/@", " ", 
       RowBox[{"fcvts", "[", 
        RowBox[{"[", "frstfcs", "]"}], "]"}]}]}], ";", "\[IndentingNewLine]", 
     
     RowBox[{"nxtvts", " ", "=", " ", 
      RowBox[{
       RowBox[{
        RowBox[{"Select", "[", 
         RowBox[{
          RowBox[{"Flatten", "[", 
           RowBox[{
            RowBox[{"Outer", "[", 
             RowBox[{
             "Intersection", ",", "fcvtlst", ",", "fcvtlst", ",", "1"}], 
             "]"}], ",", "1"}], "]"}], ",", 
          RowBox[{
           RowBox[{
            RowBox[{"Length", "[", "#", "]"}], "\[Equal]", "1"}], "&"}]}], 
         "]"}], " ", "//", " ", "Flatten"}], " ", "//", " ", "Union"}]}], ";",
      "\[IndentingNewLine]", 
     RowBox[{"vtfclst", " ", "=", " ", 
      RowBox[{
       RowBox[{
        RowBox[{"Complement", "[", 
         RowBox[{"#", ",", "frstfcs"}], "]"}], "&"}], " ", "/@", " ", 
       RowBox[{"vtfcs", "[", 
        RowBox[{"[", "nxtvts", "]"}], "]"}]}]}], ";", "\[IndentingNewLine]", 
     RowBox[{"nxtfcs", " ", "=", " ", 
      RowBox[{
       RowBox[{
        RowBox[{"Select", "[", 
         RowBox[{
          RowBox[{"Flatten", "[", 
           RowBox[{
            RowBox[{"Outer", "[", 
             RowBox[{
             "Intersection", ",", "vtfclst", ",", "vtfclst", ",", "1"}], 
             "]"}], ",", "1"}], "]"}], ",", 
          RowBox[{
           RowBox[{
            RowBox[{"Length", "[", "#", "]"}], "\[Equal]", "1"}], "&"}]}], 
         "]"}], " ", "//", " ", "Flatten"}], " ", "//", " ", "Union"}]}], ";",
      "\[IndentingNewLine]", 
     RowBox[{"xvt0", " ", "=", " ", 
      RowBox[{"xvts", "[", 
       RowBox[{"[", "frstvt", "]"}], "]"}]}], ";", "\[IndentingNewLine]", 
     RowBox[{"xvt1", "=", " ", 
      RowBox[{"xvts", "[", 
       RowBox[{"[", 
        RowBox[{"First", "[", "nxtvts", "]"}], "]"}], "]"}]}], ";", 
     "\[IndentingNewLine]", 
     RowBox[{"xfc", " ", "=", " ", 
      RowBox[{"xfcs", "[", 
       RowBox[{"[", 
        RowBox[{"First", "[", "nxtfcs", "]"}], "]"}], "]"}]}], ";", 
     "\[IndentingNewLine]", 
     RowBox[{
      RowBox[{
       RowBox[{
        RowBox[{"(", 
         RowBox[{"xvt1", ".", "xvt0"}], ")"}], "/", 
        RowBox[{"(", 
         RowBox[{"xfc", ".", "xvt0"}], ")"}]}], " ", "//", " ", "Expand"}], 
      " ", "//", " ", "Factor"}]}]}], "\[IndentingNewLine]", "]"}]}]], "Input",\

 CellLabel->
  "In[602]:=",ExpressionUUID->"8698f7f9-0c1e-406a-8a87-46eb125b93e0"],

Cell[BoxData[
 RowBox[{
  RowBox[{"rsdspstel", " ", "=", " ", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"\"\<grt ddc\>\"", ",", 
       RowBox[{"show3dfront", "[", 
        RowBox[{"model", "[", 
         RowBox[{"\"\<rs pyr tri\>\"", ",", "5", ",", "1", ",", 
          RowBox[{"stelht", "[", "\"\<grt ddc\>\"", "]"}]}], "]"}], "]"}]}], 
      "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"\"\<sml stl ddc\>\"", ",", 
       RowBox[{"show3dfront", "[", 
        RowBox[{"model", "[", 
         RowBox[{"\"\<rs pyr dual\>\"", ",", "5", ",", "1", ",", 
          RowBox[{"stelht", "[", "\"\<sml stl ddc\>\"", "]"}]}], "]"}], 
        "]"}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"\"\<grt stl ddc\>\"", ",", 
       RowBox[{"show3dfront", "[", 
        RowBox[{"model", "[", 
         RowBox[{"\"\<rs pyr tri\>\"", ",", "5", ",", "1", ",", 
          RowBox[{"stelht", "[", "\"\<grt stl ddc\>\"", "]"}]}], "]"}], 
        "]"}]}], "}"}]}], "}"}]}], ";"}]], "Input",
 CellLabel->
  "In[603]:=",ExpressionUUID->"f22cd3ed-cd2c-4d1c-a4b6-51207b53e90e"],

Cell[BoxData[
 RowBox[{"Grid", "[", "rsdsp", "]"}]], "Input",
 CellLabel->
  "In[604]:=",ExpressionUUID->"88370af9-8293-46c7-9a4e-cdac3cebfd61"],

Cell[BoxData[
 RowBox[{"Grid", "[", "rsdspt", "]"}]], "Input",
 CellLabel->
  "In[605]:=",ExpressionUUID->"a07ee79f-2627-4948-972d-739afc488738"],

Cell[BoxData[
 RowBox[{"Grid", "[", "rsdsptb", "]"}]], "Input",
 CellLabel->
  "In[606]:=",ExpressionUUID->"f1c77784-6add-4305-981d-e5c324b77cb5"],

Cell[BoxData[
 RowBox[{"Grid", "[", "rsdspq", "]"}]], "Input",
 CellLabel->
  "In[607]:=",ExpressionUUID->"974b5e50-5d9f-4042-a26b-b37598143b24"],

Cell[BoxData[
 RowBox[{"Grid", "[", "rsdspk", "]"}]], "Input",
 CellLabel->
  "In[608]:=",ExpressionUUID->"ce68db5c-339f-4989-94a3-fdb0ced88cb4"],

Cell[BoxData[
 RowBox[{"Grid", "[", "rsdspkb", "]"}]], "Input",
 CellLabel->
  "In[609]:=",ExpressionUUID->"080bec97-32f8-4115-85ec-232e81c30884"],

Cell[BoxData[
 RowBox[{"Grid", "[", "rsdspke", "]"}]], "Input",
 CellLabel->
  "In[610]:=",ExpressionUUID->"ab70f81d-9db7-44f3-bcf0-bb64eaed3c1e"],

Cell[BoxData[
 RowBox[{"Grid", "[", "rsdspx", "]"}]], "Input",
 CellLabel->
  "In[611]:=",ExpressionUUID->"6ba48970-fa53-45df-9efe-ed1d863f0052"],

Cell[BoxData[
 RowBox[{"Grid", "[", "rsdspi", "]"}]], "Input",
 CellLabel->
  "In[612]:=",ExpressionUUID->"f1e9e0a6-3cab-4b59-b928-0ab55276e09c"],

Cell[BoxData[
 RowBox[{"Grid", "[", "rsdspstel", "]"}]], "Input",
 CellLabel->
  "In[613]:=",ExpressionUUID->"e9c97910-c1f5-4422-8c00-faa751d7387b"]
}, Closed]],

Cell[CellGroupData[{

Cell["Interactive", "Subsubsection",ExpressionUUID->"319e95d1-dfb4-432d-b621-484921742311"],

Cell[BoxData[
 RowBox[{"Manipulate", "[", 
  RowBox[{
   RowBox[{"show3dfront", "[", 
    RowBox[{"model", "[", 
     RowBox[{"type", ",", "n", ",", "1"}], "]"}], "]"}], ",", 
   RowBox[{"{", 
    RowBox[{"type", ",", " ", 
     RowBox[{"{", 
      RowBox[{
      "\"\<rs tri\>\"", ",", "\"\<rs dual\>\"", ",", "\"\<rs pyr tri\>\"", 
       ",", "\"\<rs pyr dual\>\"", ",", "\"\<rs pyr both\>\"", ",", 
       "\"\<rs rhomb\>\"", ",", "\"\<rs kite\>\"", ",", 
       "\"\<rs both trunc\>\""}], "}"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"n", ",", "3"}], "}"}], ",", 
     RowBox[{"Range", "[", 
      RowBox[{"3", ",", "5"}], "]"}]}], "}"}]}], "]"}]], "Input",
 CellLabel->
  "In[614]:=",ExpressionUUID->"9a910a9e-37e8-4540-83b7-67f07fd3928f"],

Cell[BoxData[
 RowBox[{"(*", " ", 
  RowBox[{
   RowBox[{"For", " ", "other", " ", "semiregular", " ", "cuboids"}], ",", 
   " ", 
   RowBox[{
    RowBox[{"see", " ", "3"}], "-", 
    RowBox[{
     RowBox[{"trapezohedron", ".", " ", "For"}], " ", "semiregular", " ", 
     "octahedra"}]}], ",", " ", 
   RowBox[{
    RowBox[{"see", " ", "4"}], "-", 
    RowBox[{"bipyramids", "."}]}]}], " ", "*)"}]], "Input",
 CellLabel->
  "In[615]:=",ExpressionUUID->"3f4e0cbb-c847-4a03-bc49-977b75192fc5"],

Cell[BoxData[
 RowBox[{"Manipulate", "[", 
  RowBox[{
   RowBox[{"show3dfront", "[", 
    RowBox[{"model", "[", 
     RowBox[{"type", ",", "n", ",", 
      RowBox[{"1", "-", "f"}], ",", "f"}], "]"}], "]"}], ",", 
   RowBox[{"{", 
    RowBox[{"type", ",", " ", 
     RowBox[{"{", 
      RowBox[{
      "\"\<rs pyr tri\>\"", ",", "\"\<rs pyr dual\>\"", ",", 
       "\"\<rs kite\>\"", ",", "\"\<rs tri trunc\>\"", ",", 
       "\"\<rs dual trunc\>\"", ",", "\"\<rs edge trunc\>\""}], "}"}]}], 
    "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"n", ",", "3"}], "}"}], ",", 
     RowBox[{"Range", "[", 
      RowBox[{"3", ",", "5"}], "]"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"f", ",", "0.5"}], "}"}], ",", "0", ",", "1"}], "}"}]}], 
  "]"}]], "Input",
 CellLabel->
  "In[616]:=",ExpressionUUID->"b5b6585b-6bf7-45a8-8fd4-b5b7569d5f94"],

Cell[BoxData[
 RowBox[{"Manipulate", "[", 
  RowBox[{
   RowBox[{"show3dfront", "[", 
    RowBox[{"model", "[", 
     RowBox[{"type", ",", "1", ",", 
      RowBox[{"Min", "[", 
       RowBox[{"f", ",", "0.9999"}], "]"}]}], "]"}], "]"}], ",", 
   RowBox[{"{", 
    RowBox[{"type", ",", " ", 
     RowBox[{"{", "\"\<rs rhomb shft\>\"", "}"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"f", ",", 
       RowBox[{"1", "/", "3"}]}], "}"}], ",", "0", ",", "1"}], "}"}]}], 
  "]"}]], "Input",
 CellLabel->
  "In[632]:=",ExpressionUUID->"7ce956c3-46fc-4224-95a8-ccd3d7eebcb7"],

Cell[BoxData[
 RowBox[{"Manipulate", "[", 
  RowBox[{
   RowBox[{"show3dfront", "[", 
    RowBox[{"model", "[", 
     RowBox[{"type", ",", 
      RowBox[{"1", "-", "f"}], ",", "f", ",", 
      RowBox[{
       RowBox[{"(", 
        RowBox[{"1", "/", "1"}], ")"}], "fx"}]}], "]"}], "]"}], ",", 
   RowBox[{"{", 
    RowBox[{"type", ",", " ", 
     RowBox[{"{", "\"\<rs kite shft\>\"", "}"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"f", ",", 
       RowBox[{"1", "/", "2"}]}], "}"}], ",", "0", ",", "1"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"fx", ",", 
       RowBox[{"1", "/", "3"}]}], "}"}], ",", "0", ",", "1"}], "}"}]}], 
  "]"}]], "Input",
 CellLabel->
  "In[636]:=",ExpressionUUID->"28f19646-1cc9-4462-9b7e-c52fbefbe264"],

Cell[BoxData[
 RowBox[{"Manipulate", "[", 
  RowBox[{
   RowBox[{"show3dfront", "[", 
    RowBox[{"model", "[", 
     RowBox[{"type", ",", "n", ",", 
      RowBox[{
       RowBox[{"(", 
        RowBox[{"1", "-", "g"}], ")"}], 
       RowBox[{"(", 
        RowBox[{"1", "-", "f"}], ")"}]}], ",", 
      RowBox[{
       RowBox[{"(", 
        RowBox[{"1", "-", "g"}], ")"}], "f"}], ",", "g"}], "]"}], "]"}], ",", 
   
   RowBox[{"{", 
    RowBox[{"type", ",", " ", 
     RowBox[{"{", 
      RowBox[{"\"\<rs max trunc\>\"", ",", "\"\<rs snub\>\""}], "}"}]}], 
    "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"n", ",", "3"}], "}"}], ",", 
     RowBox[{"Range", "[", 
      RowBox[{"3", ",", "5"}], "]"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"f", ",", "0.5"}], "}"}], ",", "0", ",", "1"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"g", ",", "0.5"}], "}"}], ",", "0", ",", "1"}], "}"}]}], 
  "]"}]], "Input",
 CellLabel->
  "In[618]:=",ExpressionUUID->"f00987e2-c331-41a6-bf47-3f9eebaa9ea1"],

Cell[BoxData[
 RowBox[{"Manipulate", "[", 
  RowBox[{
   RowBox[{"show3dfront", "[", 
    RowBox[{"model", "[", 
     RowBox[{"type", ",", 
      RowBox[{
       RowBox[{"(", 
        RowBox[{"1", "-", "g"}], ")"}], 
       RowBox[{"(", 
        RowBox[{"1", "-", "f"}], ")"}]}], ",", 
      RowBox[{
       RowBox[{"(", 
        RowBox[{"1", "-", "g"}], ")"}], "f"}], ",", "g"}], "]"}], "]"}], ",", 
   
   RowBox[{"{", 
    RowBox[{"type", ",", " ", 
     RowBox[{"{", "\"\<rs rect\>\"", "}"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"f", ",", "0.5"}], "}"}], ",", "0", ",", "1"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"g", ",", "0.5"}], "}"}], ",", "0", ",", "1"}], "}"}]}], 
  "]"}]], "Input",
 CellLabel->
  "In[619]:=",ExpressionUUID->"d4c051e3-3d11-454a-ac10-a83d0256c5eb"],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{
    RowBox[{"rsptf0", "[", "3", "]"}], " ", "=", " ", "1.001"}], ";", " ", 
   RowBox[{
    RowBox[{"rsptf0", "[", "4", "]"}], " ", "=", " ", "1.155"}], ";", " ", 
   RowBox[{
    RowBox[{"rsptf0", "[", "5", "]"}], " ", "=", " ", "1.098"}], ";"}], 
  " "}]], "Input",
 CellLabel->
  "In[620]:=",ExpressionUUID->"2151431a-7d1c-4331-871e-028b19b33079"],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"rsptf1", "[", "3", "]"}], " ", "=", " ", "0.999"}], ";", " ", 
  RowBox[{
   RowBox[{"rsptf1", "[", "4", "]"}], " ", "=", " ", "0.309"}], ";", " ", 
  RowBox[{
   RowBox[{"rsptf1", "[", "5", "]"}], " ", "=", " ", "0.083"}], 
  ";"}]], "Input",
 CellLabel->
  "In[621]:=",ExpressionUUID->"617f815f-9e67-4b36-81ad-3d4a562ef8b2"],

Cell[BoxData[
 RowBox[{"Manipulate", "[", 
  RowBox[{
   RowBox[{"show3dfront", "[", 
    RowBox[{"model", "[", 
     RowBox[{"type", ",", "n", ",", "1", ",", 
      RowBox[{
       RowBox[{"rsptf0", "[", "n", "]"}], "+", 
       RowBox[{
        RowBox[{"rsptf1", "[", "n", "]"}], "*", "f"}]}]}], "]"}], "]"}], ",", 
   
   RowBox[{"{", 
    RowBox[{"type", ",", " ", 
     RowBox[{"{", "\"\<rs pntg\>\"", "}"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"n", ",", "3"}], "}"}], ",", 
     RowBox[{"Range", "[", 
      RowBox[{"3", ",", "5"}], "]"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"f", ",", "0", ",", "1"}], "}"}]}], "]"}]], "Input",
 CellLabel->
  "In[622]:=",ExpressionUUID->"b285c346-13e8-480c-b817-f8a60fcddf04"]
}, Closed]]
}, Closed]]
}, Closed]]
},
WindowSize->{646, 761},
WindowMargins->{{Automatic, 164}, {Automatic, 0}},
ShowSelection->True,
FrontEndVersion->"11.3 for Mac OS X x86 (32-bit, 64-bit Kernel) (March 5, \
2018)",
StyleDefinitions->"Default.nb"
]
(* End of Notebook Content *)

(* Internal cache information *)
(*CellTagsOutline
CellTagsIndex->{}
*)
(*CellTagsIndex
CellTagsIndex->{}
*)
(*NotebookFileOutline
Notebook[{
Cell[CellGroupData[{
Cell[567, 22, 86, 0, 67, "Section",ExpressionUUID->"00e7d1ff-3c24-45c5-8056-6d9002a478f2"],
Cell[656, 24, 1969, 60, 1346, "Text",ExpressionUUID->"92838113-268b-4ab7-ab49-5547153c9fcd"]
}, Open  ]],
Cell[CellGroupData[{
Cell[2662, 89, 82, 0, 67, "Section",ExpressionUUID->"7547bb61-bce4-46d9-9087-4f11a780bee6"],
Cell[CellGroupData[{
Cell[2769, 93, 83, 0, 54, "Subsection",ExpressionUUID->"7555a5d6-6128-4aee-961c-b0eee04b2666"],
Cell[2855, 95, 489, 12, 54, "Input",ExpressionUUID->"7f9fe089-54a9-46df-8fcc-331ba0fe4773"],
Cell[3347, 109, 286, 7, 32, "Input",ExpressionUUID->"4de6522c-5cd0-482e-9c79-440a76759eb5"],
Cell[3636, 118, 359, 11, 32, "Input",ExpressionUUID->"f036ede8-d8a8-4bd3-bb69-6216146e2aad"],
Cell[3998, 131, 266, 6, 32, "Input",ExpressionUUID->"e7771895-f02f-49fc-a50a-ce42be2fe959"],
Cell[4267, 139, 571, 18, 32, "Input",ExpressionUUID->"5459a704-5800-41da-a0fb-f47821e8af3f"],
Cell[4841, 159, 695, 21, 54, "Input",ExpressionUUID->"64e1ca5f-8cc1-48a8-a8f5-37d5ac280194"],
Cell[5539, 182, 208, 5, 32, "Input",ExpressionUUID->"57eb56a2-cce4-482c-8a08-baa44e99ea70"],
Cell[5750, 189, 233, 6, 32, "Input",ExpressionUUID->"9f0669e9-3a87-42f1-a921-ddce27c82334"],
Cell[5986, 197, 222, 5, 32, "Input",ExpressionUUID->"7aadd915-c91e-46d8-b062-2d7a35919dba"],
Cell[6211, 204, 1089, 30, 117, "Input",ExpressionUUID->"e11ba3e8-021d-4383-8d22-6bde03aae587"],
Cell[7303, 236, 220, 5, 32, "Input",ExpressionUUID->"e1bf3b75-53dc-41da-b4e0-c5ab9798c279"],
Cell[7526, 243, 1750, 48, 222, "Input",ExpressionUUID->"6e6a9415-03b4-4d54-82c6-b50e9696e65f"],
Cell[9279, 293, 206, 5, 32, "Input",ExpressionUUID->"7c643831-f186-403b-a3d3-a0ba55cc175c"],
Cell[9488, 300, 1775, 49, 222, "Input",ExpressionUUID->"7797e813-8c53-4f8c-b7f0-4238a92cf456"],
Cell[11266, 351, 191, 4, 32, "Input",ExpressionUUID->"37ff24c7-b581-4b8d-9bcb-39a048cde739"],
Cell[11460, 357, 1203, 34, 117, "Input",ExpressionUUID->"ea18407d-3265-46d8-997a-cf1b21d84b7a"],
Cell[12666, 393, 354, 9, 32, "Input",ExpressionUUID->"34280628-05a1-40f6-9616-534fa1e883ce"],
Cell[13023, 404, 685, 22, 32, "Input",ExpressionUUID->"92ea85cc-ec17-4b2c-894d-bd180aef4b2d"],
Cell[13711, 428, 384, 9, 75, "Input",ExpressionUUID->"10653bfe-34c6-4100-b1c0-497ecc5a35a6"],
Cell[14098, 439, 1183, 32, 180, "Input",ExpressionUUID->"c6b1c403-c3f8-4f24-8f3a-2cd8b265dffe"],
Cell[15284, 473, 765, 22, 54, "Input",ExpressionUUID->"add70c81-e895-44c6-9e3e-46458ac46d0e"],
Cell[16052, 497, 730, 24, 54, "Input",ExpressionUUID->"633261fa-7f5c-40db-869a-6338e04df5a8"],
Cell[16785, 523, 215, 5, 32, "Input",ExpressionUUID->"e961e991-d475-4555-b097-9b7b88246f04"],
Cell[17003, 530, 355, 11, 32, "Input",ExpressionUUID->"ceb05d3c-033c-4461-a8ec-82cfd9b899b9"],
Cell[17361, 543, 234, 6, 32, "Input",ExpressionUUID->"ccb772c6-b240-429c-b30b-ce169c2d93d5"],
Cell[17598, 551, 379, 8, 54, "Input",ExpressionUUID->"24d7ce60-ffcc-4c26-8acd-c281e25eca9b"],
Cell[17980, 561, 422, 12, 32, "Input",ExpressionUUID->"334e302b-2aea-48c7-9bbe-c6e591ac20d7"],
Cell[18405, 575, 409, 10, 75, "Input",ExpressionUUID->"12a76a72-a7a3-4a6b-8c0c-058d550aab39"],
Cell[18817, 587, 421, 12, 32, "Input",ExpressionUUID->"640b00e1-6492-41b0-932d-7c24f003b749"],
Cell[19241, 601, 742, 16, 96, "Input",ExpressionUUID->"18002f9e-8b92-4b6f-ad24-1356d987d550"],
Cell[19986, 619, 3136, 87, 264, "Input",ExpressionUUID->"28f636c8-02e1-48a9-b645-b0fa2532c505"],
Cell[23125, 708, 504, 15, 32, "Input",ExpressionUUID->"2157763e-0c67-4e72-b099-06bbc06cf193"]
}, Closed]],
Cell[CellGroupData[{
Cell[23666, 728, 82, 0, 38, "Subsection",ExpressionUUID->"6f305bf2-f207-4c4c-b5f3-5659799b7474"],
Cell[CellGroupData[{
Cell[23773, 732, 89, 0, 35, "Subsubsection",ExpressionUUID->"1feb8290-204c-42b6-9d27-c3f6954b3e4f"],
Cell[23865, 734, 1271, 38, 80, "Input",ExpressionUUID->"33486001-908e-4b4f-8bb0-78618f973c8c"],
Cell[25139, 774, 490, 14, 28, "Input",ExpressionUUID->"34f3fd72-b523-4680-aabc-e741c1c98baa"],
Cell[25632, 790, 198, 5, 28, "Input",ExpressionUUID->"297f6447-2f06-4e58-9807-dd86db630baa"],
Cell[25833, 797, 246, 6, 28, "Input",ExpressionUUID->"5d5a77f9-4c92-47e9-9f6a-17ce8130669b"],
Cell[26082, 805, 363, 10, 46, "Input",ExpressionUUID->"ad67bfc2-2496-4a4f-bf32-610588f46393"],
Cell[26448, 817, 195, 4, 28, "Input",ExpressionUUID->"6c683894-70c3-4f73-8814-18eeb5fd58fd"],
Cell[26646, 823, 247, 6, 28, "Input",ExpressionUUID->"4180c6bd-c888-41c3-aba3-03b63c3ad5bb"],
Cell[26896, 831, 363, 10, 46, "Input",ExpressionUUID->"d70cba4a-4d9e-42df-8902-214f93bdf6fb"],
Cell[27262, 843, 180, 4, 28, "Input",ExpressionUUID->"7515e263-5228-41c5-9ac3-5b221ec81adf"],
Cell[27445, 849, 333, 9, 28, "Input",ExpressionUUID->"81911c1e-f013-49f5-91c9-c423c8f43c7f"],
Cell[27781, 860, 363, 10, 46, "Input",ExpressionUUID->"ea18089f-202e-4356-864e-bc94e030f09e"],
Cell[28147, 872, 283, 6, 28, "Input",ExpressionUUID->"5a37f5c3-9c15-46c3-81d5-e68060f0e3fe"],
Cell[28433, 880, 486, 15, 46, "Input",ExpressionUUID->"0a10b057-8073-46fa-8b2b-c1aa15d61a8a"]
}, Closed]],
Cell[CellGroupData[{
Cell[28956, 900, 85, 0, 29, "Subsubsection",ExpressionUUID->"244af3c5-6742-4357-990e-e46dec4dba8f"],
Cell[29044, 902, 1397, 42, 88, "Input",ExpressionUUID->"ed8288e8-2eb1-4e7a-9f28-ef572823d16f"],
Cell[30444, 946, 152, 3, 27, "Input",ExpressionUUID->"f9131f8e-d4d1-48a0-bb80-02ca261b1db0"],
Cell[30599, 951, 368, 10, 27, "Input",ExpressionUUID->"8354716e-bf62-4f6a-9daa-40734e19b211"]
}, Closed]],
Cell[CellGroupData[{
Cell[31004, 966, 95, 0, 29, "Subsubsection",ExpressionUUID->"987b6b7e-9c18-4ba7-94b0-f943940ab0ae"],
Cell[31102, 968, 1869, 54, 88, "Input",ExpressionUUID->"acf67927-24b5-46db-96be-a9440d241a9d"],
Cell[32974, 1024, 366, 11, 27, "Input",ExpressionUUID->"2a38b9d6-c613-4580-a87b-40489f396d71"],
Cell[33343, 1037, 273, 8, 27, "Input",ExpressionUUID->"ea90714f-8333-4a0f-acdb-771a2343d27d"],
Cell[33619, 1047, 359, 10, 27, "Input",ExpressionUUID->"04e9cc9e-093d-408d-b608-4330cff5ebc8"],
Cell[33981, 1059, 361, 10, 27, "Input",ExpressionUUID->"075710b2-5905-40d6-919b-5e7fa623b96c"],
Cell[34345, 1071, 356, 10, 27, "Input",ExpressionUUID->"d9985734-a2b5-494a-97b9-c1e42457199a"],
Cell[34704, 1083, 391, 10, 27, "Input",ExpressionUUID->"25dca32f-f8f5-4c64-8ccb-5ec99d7fd8b6"],
Cell[35098, 1095, 485, 14, 27, "Input",ExpressionUUID->"0b9e9b0e-465a-4bd7-9741-df2980b3d36b"]
}, Closed]],
Cell[CellGroupData[{
Cell[35620, 1114, 89, 0, 29, "Subsubsection",ExpressionUUID->"b69d93e7-ac9a-4ec8-b58d-72ac1c6a0ef6"],
Cell[35712, 1116, 433, 14, 29, "Input",ExpressionUUID->"f5b687a0-458e-43f6-afe5-d4ec3e084ae6"]
}, Closed]]
}, Closed]],
Cell[CellGroupData[{
Cell[36194, 1136, 92, 0, 38, "Subsection",ExpressionUUID->"a5336527-b40a-4980-8b15-3b92f7a8bc37"],
Cell[CellGroupData[{
Cell[36311, 1140, 85, 0, 45, "Subsubsection",ExpressionUUID->"7bd5bda4-63ab-4267-a164-4d7c09c51741"],
Cell[36399, 1142, 621, 18, 54, "Input",ExpressionUUID->"440598dc-d450-4f0c-9f84-c4fec5f285aa"],
Cell[37023, 1162, 489, 16, 32, "Input",ExpressionUUID->"4c9c1ca4-5899-4340-9b00-846e72436d8b"],
Cell[37515, 1180, 411, 13, 32, "Input",ExpressionUUID->"f931e4cd-67b8-4557-a781-522392fc8462"],
Cell[37929, 1195, 2267, 72, 138, "Input",ExpressionUUID->"0c6ab4c4-7ff8-4c38-80b8-4a5e7020d75d"],
Cell[40199, 1269, 417, 12, 32, "Input",ExpressionUUID->"2575c46d-77b6-4a6e-bfd4-89ae7c2a97ae"],
Cell[40619, 1283, 562, 19, 54, "Input",ExpressionUUID->"a506e481-3845-48be-bf7b-188fedb83079"],
Cell[41184, 1304, 510, 14, 96, "Input",ExpressionUUID->"565c1c09-30c6-4487-b3da-7ff62503011f"],
Cell[41697, 1320, 339, 10, 32, "Input",ExpressionUUID->"a7cbe648-ad68-40cf-b71f-8cc930e792af"],
Cell[42039, 1332, 339, 10, 32, "Input",ExpressionUUID->"a6173c46-c0b8-4835-b335-3b014647fd5e"],
Cell[42381, 1344, 150, 3, 32, "Input",ExpressionUUID->"7f418713-625f-4c05-ac7f-86c3cc1d53af"],
Cell[42534, 1349, 648, 20, 54, "Input",ExpressionUUID->"ef9c48b2-3e04-4d2e-810f-2b881c9e87f3"],
Cell[43185, 1371, 272, 7, 32, "Input",ExpressionUUID->"31eb0a26-cef2-41cd-b883-5ab017da334a"],
Cell[43460, 1380, 269, 7, 32, "Input",ExpressionUUID->"cc9fa01d-7dfd-4d67-85aa-03a9a7b228b9"],
Cell[43732, 1389, 279, 7, 32, "Input",ExpressionUUID->"ec073cbd-f7e7-4e74-8c55-88315c0103ba"]
}, Closed]],
Cell[CellGroupData[{
Cell[44048, 1401, 89, 0, 37, "Subsubsection",ExpressionUUID->"a3480d78-5020-4349-b38f-9819ffdc39fd"],
Cell[44140, 1403, 432, 11, 73, "Input",ExpressionUUID->"c5a4c95f-48d9-4a84-a613-86c9e48fe7fc"],
Cell[44575, 1416, 407, 10, 52, "Input",ExpressionUUID->"9bbfb353-3bdf-4e78-8aa3-2affbf5e57d2"],
Cell[44985, 1428, 497, 12, 52, "Input",ExpressionUUID->"aaf4db23-3103-405b-8f04-defca3a9d55b"],
Cell[45485, 1442, 207, 5, 30, "Input",ExpressionUUID->"d77e622b-19df-43dd-ac46-d54b730c1cdf"],
Cell[45695, 1449, 786, 26, 52, "Input",ExpressionUUID->"5a8b8f9e-951c-460f-bbba-0d92518126c6"],
Cell[46484, 1477, 559, 17, 52, "Input",ExpressionUUID->"766ebe3e-d017-4c13-9c00-6d70dffa45bd"],
Cell[47046, 1496, 735, 24, 52, "Input",ExpressionUUID->"fbe5fcbb-fd76-41f4-b964-c7a856c41326"],
Cell[47784, 1522, 562, 17, 52, "Input",ExpressionUUID->"79af3e86-6eea-47d2-9abf-bccd18382bd4"],
Cell[48349, 1541, 313, 8, 30, "Input",ExpressionUUID->"89c75336-3ce4-4861-8bff-b6712692b962"],
Cell[48665, 1551, 501, 14, 73, "Input",ExpressionUUID->"985790b8-a78b-42fc-8afe-365954efb22b"],
Cell[49169, 1567, 585, 18, 54, "Input",ExpressionUUID->"7e61c093-1146-4f7e-b1fe-8e7e08ac19c2"],
Cell[49757, 1587, 935, 28, 75, "Input",ExpressionUUID->"b9b1d995-5232-4f16-a965-2f01f0c9d0aa"],
Cell[50695, 1617, 149, 3, 32, "Input",ExpressionUUID->"5b9f0000-5ef9-49fe-9df9-573fbc8d82b9"],
Cell[50847, 1622, 149, 3, 32, "Input",ExpressionUUID->"bdc77ccf-7c27-4762-bb79-383b9a46dc63"],
Cell[50999, 1627, 149, 3, 32, "Input",ExpressionUUID->"8a7cd75a-dbb3-4e40-b2bf-3eaaec91e6fb"],
Cell[51151, 1632, 324, 9, 32, "Input",ExpressionUUID->"663a8928-7834-488c-a94f-48955655bd56"],
Cell[51478, 1643, 206, 5, 32, "Input",ExpressionUUID->"53ca90d4-81b9-49e9-a8f0-b9b7009a924d"],
Cell[51687, 1650, 736, 24, 54, "Input",ExpressionUUID->"59cd5fe7-5681-4724-8d21-22530ccac0de"],
Cell[52426, 1676, 1318, 38, 180, "Input",ExpressionUUID->"364496a5-884d-4344-9bb9-df994d781290"],
Cell[53747, 1716, 179, 4, 32, "Input",ExpressionUUID->"0df022ce-e39c-4f1d-a419-df726ef931c1"],
Cell[53929, 1722, 607, 20, 32, "Input",ExpressionUUID->"9ca3c1e4-7cb6-4926-b623-e3c74d0321fa"],
Cell[54539, 1744, 663, 19, 75, "Input",ExpressionUUID->"815ce124-0859-495a-b5aa-8058bf1ee495"],
Cell[55205, 1765, 633, 21, 32, "Input",ExpressionUUID->"7d500472-7581-4215-aac0-8ce7d0ff0e27"],
Cell[55841, 1788, 668, 19, 75, "Input",ExpressionUUID->"6eef97b6-c09d-4892-be06-9ca1217ddae4"],
Cell[56512, 1809, 296, 7, 54, "Input",ExpressionUUID->"53bc0e14-fd89-4905-bf66-69523cc9c86c"],
Cell[56811, 1818, 341, 11, 32, "Input",ExpressionUUID->"3cfe0105-bd2e-4f4d-9e5f-c7c42e7b425d"],
Cell[57155, 1831, 877, 29, 54, "Input",ExpressionUUID->"13ed6650-83cc-42a3-b4ef-cbb58ead0c9c"],
Cell[58035, 1862, 418, 13, 32, "Input",ExpressionUUID->"845f53aa-8eba-4e47-886d-68a34bc14f4f"],
Cell[58456, 1877, 602, 18, 52, "Input",ExpressionUUID->"552a15c7-a731-40e5-8c99-0fa10da09669"],
Cell[59061, 1897, 559, 18, 52, "Input",ExpressionUUID->"a7859b31-2270-42e3-b057-8efdd35b4ff7"],
Cell[59623, 1917, 485, 15, 52, "Input",ExpressionUUID->"e4fbbb2f-49ef-4e62-a95a-bf47517be2d3"],
Cell[60111, 1934, 203, 5, 30, "Input",ExpressionUUID->"547028a9-b62a-4708-a61b-539a2ac19837"],
Cell[60317, 1941, 633, 21, 30, "Input",ExpressionUUID->"ad869f16-404e-4a5e-8f47-02ed59f99eb2"],
Cell[60953, 1964, 841, 25, 73, "Input",ExpressionUUID->"87c823b8-cd7b-4ebd-822b-d913b8d78282"],
Cell[61797, 1991, 203, 5, 30, "Input",ExpressionUUID->"b331d7e6-e229-4882-b77b-d3ebd4c862cc"],
Cell[62003, 1998, 1029, 33, 73, "Input",ExpressionUUID->"835549bf-5baa-41f9-bdc9-75bb500aa060"],
Cell[63035, 2033, 831, 25, 94, "Input",ExpressionUUID->"e8ccef15-ffa5-43e2-900b-327e401d40ad"],
Cell[63869, 2060, 182, 4, 30, "Input",ExpressionUUID->"9086a73f-d9ef-47f3-b401-a6ff5484805e"],
Cell[64054, 2066, 714, 22, 52, "Input",ExpressionUUID->"29f8160b-8c1c-4dd1-b1c3-447797a0cfba"],
Cell[64771, 2090, 631, 21, 30, "Input",ExpressionUUID->"2e3b6fc9-0b89-4d3f-9dd1-4c28325bfd62"],
Cell[65405, 2113, 181, 4, 30, "Input",ExpressionUUID->"acc0acf4-3be4-4c61-90bd-675520aea854"],
Cell[65589, 2119, 177, 4, 30, "Input",ExpressionUUID->"d7407db6-7f39-4507-9823-e55163667565"]
}, Closed]],
Cell[CellGroupData[{
Cell[65803, 2128, 85, 0, 37, "Subsubsection",ExpressionUUID->"c7c87f6a-2ee3-4be9-b2a1-bc7b6eafe6a2"],
Cell[65891, 2130, 263, 7, 30, "Input",ExpressionUUID->"05d8552a-006d-46f0-b302-4f38096408ad"],
Cell[66157, 2139, 840, 26, 52, "Input",ExpressionUUID->"57df554f-b7ab-49c5-824b-72f7eaa0f9c1"],
Cell[67000, 2167, 202, 5, 30, "Input",ExpressionUUID->"3987b307-4417-44cb-a070-2f27337871aa"],
Cell[67205, 2174, 254, 8, 30, "Input",ExpressionUUID->"fc21301a-14b2-41f3-b78a-95f399cbafd9"],
Cell[67462, 2184, 155, 3, 30, "Input",ExpressionUUID->"0a06a3f4-8b9d-4a6e-9443-b1f884dbfc8d"],
Cell[67620, 2189, 283, 7, 30, "Input",ExpressionUUID->"81539b55-4d1e-4ad1-829d-2c22ba661cf7"],
Cell[67906, 2198, 960, 29, 73, "Input",ExpressionUUID->"a1a49901-66af-4b33-b680-e6753c265420"],
Cell[68869, 2229, 160, 3, 30, "Input",ExpressionUUID->"b16f1f2f-584a-499a-b7fc-92c52a412310"],
Cell[69032, 2234, 159, 3, 30, "Input",ExpressionUUID->"8e124213-4d22-42e5-b837-c830bbc9e878"],
Cell[69194, 2239, 188, 4, 30, "Input",ExpressionUUID->"2a1499e9-8313-4b8a-b11b-fe4dabd03cd4"],
Cell[69385, 2245, 787, 23, 52, "Input",ExpressionUUID->"e36c6e8c-7101-49b4-998c-c76b9a2c50af"],
Cell[70175, 2270, 155, 3, 30, "Input",ExpressionUUID->"c95d50c9-6e1e-485b-abe1-b4bde5e2730d"],
Cell[70333, 2275, 200, 5, 30, "Input",ExpressionUUID->"68bd3bec-af3b-4908-9de2-3eaa528199d5"],
Cell[70536, 2282, 248, 6, 30, "Input",ExpressionUUID->"ede92f56-9099-47ed-a8ac-f15ed801beb6"],
Cell[70787, 2290, 338, 8, 52, "Input",ExpressionUUID->"6f0d9760-dd70-4b8c-bece-3912f1c59e03"],
Cell[71128, 2300, 2043, 63, 136, "Input",ExpressionUUID->"b43db246-46f3-401b-8fd5-b4e507042647"],
Cell[73174, 2365, 159, 3, 30, "Input",ExpressionUUID->"1c6145fb-1d82-4bb1-bc48-462c84c8d989"]
}, Closed]],
Cell[CellGroupData[{
Cell[73370, 2373, 89, 0, 37, "Subsubsection",ExpressionUUID->"7d3ad87e-0798-4953-a731-65d4bbe00a60"],
Cell[73462, 2375, 756, 18, 94, "Input",ExpressionUUID->"100f3d38-9f27-41f3-815c-2c097a40e538"],
Cell[74221, 2395, 4391, 131, 262, "Input",ExpressionUUID->"b9a4241c-baa1-4822-b1a7-3ec31a2641ac"],
Cell[78615, 2528, 1477, 43, 136, "Input",ExpressionUUID->"c278f4be-17cd-477a-80df-c768c7acd55a"],
Cell[80095, 2573, 155, 3, 30, "Input",ExpressionUUID->"8992c98c-783c-44b6-8178-c07df4d46425"],
Cell[80253, 2578, 434, 12, 30, "Input",ExpressionUUID->"0ab23921-23ac-4c15-9f56-2c2f99fe5da5"],
Cell[80690, 2592, 222, 5, 30, "Input",ExpressionUUID->"b8ca592c-e74e-41ad-bf9a-625500a7df47"],
Cell[80915, 2599, 294, 8, 30, "Input",ExpressionUUID->"7d096c03-898e-4ec2-8043-52d76189d403"],
Cell[81212, 2609, 294, 8, 30, "Input",ExpressionUUID->"a5775247-330f-4b19-a335-90564f213357"],
Cell[81509, 2619, 483, 12, 52, "Input",ExpressionUUID->"30ca033b-77e6-4bcb-bb16-54e95046722d"],
Cell[81995, 2633, 223, 5, 30, "Input",ExpressionUUID->"c6d74392-5c25-4fad-bf7c-ec0ccc7fa62a"],
Cell[82221, 2640, 295, 7, 52, "Input",ExpressionUUID->"115999e8-f4f0-41bb-a2c5-4963f6c2b18e"],
Cell[82519, 2649, 395, 12, 30, "Input",ExpressionUUID->"6fe91eed-d3a7-4d41-999e-2e33a21dc924"],
Cell[82917, 2663, 376, 12, 30, "Input",ExpressionUUID->"602fcee0-ed1d-4dbd-b909-96791395705e"],
Cell[83296, 2677, 304, 9, 30, "Input",ExpressionUUID->"6f2bbff9-47c1-4aaa-b2e9-7060e148f94b"],
Cell[83603, 2688, 218, 6, 30, "Input",ExpressionUUID->"b6b684ca-ac4a-4fa7-b81f-2f6cd3f567e6"],
Cell[83824, 2696, 238, 6, 30, "Input",ExpressionUUID->"b20200a6-bee7-4a88-a04e-670f8dd2e302"],
Cell[84065, 2704, 361, 10, 32, "Input",ExpressionUUID->"2a2b5870-09c4-4c3a-90e2-5d110fa941ee"],
Cell[84429, 2716, 558, 16, 75, "Input",ExpressionUUID->"4efe30f8-9296-43ed-9121-6025f673a932"],
Cell[84990, 2734, 860, 25, 96, "Input",ExpressionUUID->"58df900c-7c19-4aca-b288-0f6f2b103f59"],
Cell[85853, 2761, 262, 6, 32, "Input",ExpressionUUID->"ce47993e-9cc7-46d2-9991-77fd8210803a"],
Cell[86118, 2769, 310, 8, 54, "Input",ExpressionUUID->"64092e54-47df-483a-b784-d7d8e11fffc7"],
Cell[86431, 2779, 436, 13, 32, "Input",ExpressionUUID->"3317885c-7aca-4e46-beba-a243ad85e303"],
Cell[86870, 2794, 434, 13, 32, "Input",ExpressionUUID->"c40944fb-b6ba-4bb5-bbda-dfdef8dfd592"],
Cell[87307, 2809, 122, 2, 32, "Input",ExpressionUUID->"11dfc007-d62f-49cf-b0ac-adb3f6da5bd5"],
Cell[87432, 2813, 121, 2, 30, "Input",ExpressionUUID->"34ec589d-dd0f-41ce-a644-79e15d85e684"],
Cell[87556, 2817, 372, 9, 52, "Input",ExpressionUUID->"da9e5f9f-b7eb-4b03-9278-ccf5d2fdacb5"],
Cell[87931, 2828, 185, 4, 30, "Input",ExpressionUUID->"8e7db5b8-a048-47a5-a5d0-495458bcc8e8"],
Cell[88119, 2834, 184, 4, 30, "Input",ExpressionUUID->"42905a22-c06c-432e-9e11-de1715586f5e"],
Cell[88306, 2840, 367, 9, 52, "Input",ExpressionUUID->"68cb4233-8eae-4716-a44a-ecc6e9e235ff"],
Cell[88676, 2851, 303, 8, 30, "Input",ExpressionUUID->"3ce030e7-6b09-49c6-b352-918f86b0b5fc"],
Cell[88982, 2861, 301, 8, 30, "Input",ExpressionUUID->"55ad127b-9dac-4781-ac0c-a0c2e11b9d1d"],
Cell[89286, 2871, 301, 8, 30, "Input",ExpressionUUID->"01a68f4b-feee-4c13-80ad-bb6d47c1dbb5"],
Cell[89590, 2881, 301, 8, 30, "Input",ExpressionUUID->"bae6da94-5d67-46c4-9f75-3f42c4558c22"],
Cell[89894, 2891, 253, 7, 30, "Input",ExpressionUUID->"a54913ec-1a8c-4345-ae21-794454ba3e7f"]
}, Closed]]
}, Closed]]
}, Closed]],
Cell[CellGroupData[{
Cell[90208, 2905, 80, 0, 53, "Section",ExpressionUUID->"594baf13-3cb0-4d5d-a40e-e1ad023467ff"],
Cell[CellGroupData[{
Cell[90313, 2909, 82, 0, 54, "Subsection",ExpressionUUID->"9563e888-e8a1-432c-8408-61b66528730b"],
Cell[CellGroupData[{
Cell[90420, 2913, 101, 0, 45, "Subsubsection",ExpressionUUID->"02135073-646d-49d6-bff3-37891dbc10dd"],
Cell[90524, 2915, 461, 11, 75, "Input",ExpressionUUID->"d29a79ab-bf90-49ce-bd5e-ce3e3ddb753a"],
Cell[90988, 2928, 1456, 42, 138, "Input",ExpressionUUID->"4ddaf949-bb6d-486f-a63b-b51370e2ca8e"],
Cell[92447, 2972, 1335, 38, 138, "Input",ExpressionUUID->"d08ccdbc-7e37-4ed4-9d31-ad2da954d988"],
Cell[93785, 3012, 313, 8, 32, "Input",ExpressionUUID->"b23885b4-811a-43d9-b9e2-d61bba4d1cd5"],
Cell[94101, 3022, 1546, 45, 138, "Input",ExpressionUUID->"d04345ba-e390-4b66-8891-3111a723ab91"],
Cell[95650, 3069, 1629, 46, 138, "Input",ExpressionUUID->"2891504a-b570-4f7a-9e46-9a2502edc6a2"],
Cell[97282, 3117, 459, 12, 54, "Input",ExpressionUUID->"1a53ac45-3d17-4e67-9ee6-cd21ba988eb5"]
}, Closed]],
Cell[CellGroupData[{
Cell[97778, 3134, 106, 0, 37, "Subsubsection",ExpressionUUID->"696ef0d8-a346-4efe-9e66-8302d2ded5dc"],
Cell[97887, 3136, 521, 12, 75, "Input",ExpressionUUID->"046d0ad5-a026-47ad-b357-bdb30791f46d"],
Cell[98411, 3150, 1568, 44, 138, "Input",ExpressionUUID->"082839f8-8e12-463d-b4a4-82df89f397d1"],
Cell[99982, 3196, 2778, 79, 201, "Input",ExpressionUUID->"bbae3fc8-2842-457f-be23-f31a9af34ace"],
Cell[102763, 3277, 983, 29, 75, "Input",ExpressionUUID->"9f6fd66b-8249-488e-9fb8-0cc4b94c2be5"],
Cell[103749, 3308, 343, 9, 32, "Input",ExpressionUUID->"d7705b4d-138a-4e34-b5d5-88ffb31699aa"],
Cell[104095, 3319, 313, 8, 32, "Input",ExpressionUUID->"da989945-58cc-4c23-a414-0ff0538f89ae"]
}, Closed]],
Cell[CellGroupData[{
Cell[104445, 3332, 85, 0, 37, "Subsubsection",ExpressionUUID->"f8288bc0-a8e0-484a-8672-feabe8495fc5"],
Cell[104533, 3334, 463, 12, 73, "Input",ExpressionUUID->"f4cae326-9379-4201-bf3b-838e03fdb384"],
Cell[104999, 3348, 1800, 51, 157, "Input",ExpressionUUID->"c8fbc3c3-24f1-4bae-80c1-823c349d1b97"],
Cell[106802, 3401, 1717, 48, 157, "Input",ExpressionUUID->"f4e687c8-80eb-4d8f-aa18-3b045acf4c8c"],
Cell[108522, 3451, 2489, 69, 199, "Input",ExpressionUUID->"8f463335-882b-4b0c-89ed-798be711d1b2"],
Cell[111014, 3522, 2489, 69, 199, "Input",ExpressionUUID->"4a2ef17e-6a4c-4f45-963e-850a9a359534"]
}, Closed]],
Cell[CellGroupData[{
Cell[113540, 3596, 89, 0, 37, "Subsubsection",ExpressionUUID->"0b0737f3-e63a-4b23-b7ed-670ac9d5cf67"],
Cell[113632, 3598, 538, 14, 75, "Input",ExpressionUUID->"a850ba93-d68a-408c-93f5-24a8406282f9"],
Cell[114173, 3614, 2332, 66, 180, "Input",ExpressionUUID->"75928021-f05a-480a-9b3c-efdbc13e64f3"],
Cell[116508, 3682, 1931, 54, 180, "Input",ExpressionUUID->"469f7560-1090-47b0-b1b9-9a03991231d1"],
Cell[118442, 3738, 341, 9, 32, "Input",ExpressionUUID->"21d89791-5696-4243-b5b8-54ac7951e8b0"]
}, Closed]]
}, Closed]],
Cell[CellGroupData[{
Cell[118832, 3753, 92, 0, 38, "Subsection",ExpressionUUID->"ab2cfebc-8327-45af-8877-f8f9a88eeeeb"],
Cell[CellGroupData[{
Cell[118949, 3757, 99, 0, 45, "Subsubsection",ExpressionUUID->"5e91c0cc-5726-4cd6-9fea-74ed9360de51"],
Cell[119051, 3759, 877, 20, 136, "Input",ExpressionUUID->"c6f9e590-1e32-4b45-9578-15a2d4507371"],
Cell[119931, 3781, 274, 6, 30, "Input",ExpressionUUID->"b6f9d69b-3c2d-439a-b7bd-daee5eb19320"],
Cell[120208, 3789, 313, 10, 30, "Input",ExpressionUUID->"0360dc62-2b86-4ded-b200-4f98d6fc8b49"],
Cell[120524, 3801, 362, 11, 30, "Input",ExpressionUUID->"8bc4efd8-d9d4-44b8-8304-1e0c97d53d8a"],
Cell[120889, 3814, 362, 11, 30, "Input",ExpressionUUID->"3735351b-d80a-461c-8227-48ad0710e9be"],
Cell[121254, 3827, 362, 11, 30, "Input",ExpressionUUID->"081e3055-56f3-4712-b91f-711f43a4a94c"],
Cell[121619, 3840, 365, 11, 30, "Input",ExpressionUUID->"f93afacf-9701-4bcd-b5a9-875e868d5581"],
Cell[121987, 3853, 365, 11, 30, "Input",ExpressionUUID->"55ec6bbb-8522-46b3-8032-7017a4105c49"],
Cell[122355, 3866, 299, 9, 30, "Input",ExpressionUUID->"21da596c-a987-4363-8fdc-73e67084cfa7"],
Cell[122657, 3877, 241, 7, 30, "Input",ExpressionUUID->"0258c629-e28a-422f-9d68-176f204c5724"],
Cell[122901, 3886, 299, 9, 30, "Input",ExpressionUUID->"66c23abe-5fc4-44de-8d20-45bd4902b368"],
Cell[123203, 3897, 241, 7, 30, "Input",ExpressionUUID->"939226ec-7517-4aa6-8240-8c6accdea30b"],
Cell[123447, 3906, 298, 9, 30, "Input",ExpressionUUID->"cec21b43-9702-4d04-8316-18ec31b74ed3"],
Cell[123748, 3917, 298, 9, 30, "Input",ExpressionUUID->"c8b65514-790e-4d72-acba-e802956bdb28"],
Cell[124049, 3928, 239, 6, 30, "Input",ExpressionUUID->"97f29c25-34c7-43a9-9a52-e389ca83f792"],
Cell[124291, 3936, 424, 13, 30, "Input",ExpressionUUID->"fdb724cd-6a9a-4308-b52a-31dd539376a3"],
Cell[124718, 3951, 337, 10, 30, "Input",ExpressionUUID->"500d6e02-5681-4b6a-a348-ef75286bc778"],
Cell[125058, 3963, 393, 12, 30, "Input",ExpressionUUID->"a515aea1-e7ba-4d13-92fd-d987cb175f2d"],
Cell[125454, 3977, 507, 16, 30, "Input",ExpressionUUID->"c08c326f-4c03-4337-b096-7227bfdc31ca"],
Cell[125964, 3995, 721, 22, 73, "Input",ExpressionUUID->"6810484c-8ae5-4cbf-b6cd-8e6cff67bbe8"],
Cell[126688, 4019, 592, 18, 52, "Input",ExpressionUUID->"1fd2b621-54c2-437f-9469-c54d76b7295c"],
Cell[127283, 4039, 742, 24, 73, "Input",ExpressionUUID->"0884c15e-321a-47e0-a9c5-cc699eb06c74"],
Cell[128028, 4065, 206, 5, 30, "Input",ExpressionUUID->"6ea5cf51-ebc7-40cc-8406-f0c32652b3f6"],
Cell[128237, 4072, 5704, 149, 619, "Input",ExpressionUUID->"147c0c9d-bdd7-4c36-8a6f-e30f352a41a4"],
Cell[133944, 4223, 356, 10, 52, "Input",ExpressionUUID->"77a9c045-0746-428a-b908-200dc6c1619a"],
Cell[134303, 4235, 2931, 76, 283, "Input",ExpressionUUID->"bce94e5c-53e4-4838-bae7-9c4d0ac88472"],
Cell[137237, 4313, 359, 10, 30, "Input",ExpressionUUID->"2b668755-0c33-43a0-b6ed-8e1a811e9d87"],
Cell[137599, 4325, 140, 3, 30, "Input",ExpressionUUID->"7422f129-eed6-414f-8a32-90896942c799"],
Cell[137742, 4330, 155, 3, 30, "Input",ExpressionUUID->"07f5ab55-b76e-490d-9dc3-6eb415152153"],
Cell[137900, 4335, 3593, 91, 325, "Input",ExpressionUUID->"ce408c5e-5b3c-458e-90db-1dc22d824f01"],
Cell[141496, 4428, 374, 10, 30, "Input",ExpressionUUID->"c38051c4-7066-4a61-81f3-c84e7d56425d"],
Cell[141873, 4440, 146, 3, 30, "Input",ExpressionUUID->"371f9b7a-f66c-4678-81d2-2ca734f36b33"],
Cell[142022, 4445, 777, 22, 73, "Input",ExpressionUUID->"c9bd1305-79b9-4554-8ac0-5e47cfd0648e"],
Cell[142802, 4469, 335, 9, 52, "Input",ExpressionUUID->"0d1de2e3-e93f-4d90-bbff-84685226fc4b"],
Cell[143140, 4480, 602, 17, 73, "Input",ExpressionUUID->"e0c0e65b-0c08-46a6-a8db-22986e91d008"],
Cell[143745, 4499, 3272, 84, 283, "Input",ExpressionUUID->"15c13b60-d651-41d5-b63d-13f6b07287c8"],
Cell[147020, 4585, 885, 24, 115, "Input",ExpressionUUID->"3f62827a-06bf-4448-810f-5daf6e753278"],
Cell[147908, 4611, 388, 10, 52, "Input",ExpressionUUID->"03f02fcb-fc56-4895-b035-f5ec089013aa"]
}, Closed]],
Cell[CellGroupData[{
Cell[148333, 4626, 94, 0, 37, "Subsubsection",ExpressionUUID->"a7e245e9-96c9-42c8-b8e8-ef618db7dc86"],
Cell[148430, 4628, 745, 19, 96, "Input",ExpressionUUID->"e03cadf8-26ab-4590-9f40-81467821d66c"],
Cell[149178, 4649, 746, 19, 96, "Input",ExpressionUUID->"a0f8b9bc-d53b-4a2a-8222-04a0c9ad62e0"],
Cell[149927, 4670, 227, 5, 32, "Input",ExpressionUUID->"bd56d813-fec5-4ae3-9029-3dc2cae10121"],
Cell[150157, 4677, 913, 25, 117, "Input",ExpressionUUID->"fbb251fb-64c3-4506-b898-71b9022fe41c"],
Cell[151073, 4704, 182, 4, 32, "Input",ExpressionUUID->"08c88a8f-da5b-4bc7-bd01-338c0503160a"],
Cell[151258, 4710, 944, 26, 117, "Input",ExpressionUUID->"a3e53d42-cb92-42be-a64c-3beb6b63b261"],
Cell[152205, 4738, 280, 6, 32, "Input",ExpressionUUID->"2ec2c2e7-8179-4094-9105-787386203a3b"],
Cell[152488, 4746, 281, 6, 32, "Input",ExpressionUUID->"d3ea75e5-d47b-46d6-a1eb-62688f7e1209"]
}, Closed]],
Cell[CellGroupData[{
Cell[152806, 4757, 93, 0, 37, "Subsubsection",ExpressionUUID->"94b52595-33a4-40f1-9cdf-e3433e7b0036"],
Cell[152902, 4759, 2720, 73, 262, "Input",ExpressionUUID->"d0fe8ca9-5403-4b4c-be8c-7b57e90cffcd"],
Cell[155625, 4834, 328, 9, 30, "Input",ExpressionUUID->"8cd146e8-4ad3-4ac2-8a36-48a36a847f0c"],
Cell[155956, 4845, 2721, 73, 262, "Input",ExpressionUUID->"71a31246-06c5-469b-a430-55b0735b34f7"],
Cell[158680, 4920, 330, 9, 30, "Input",ExpressionUUID->"06b23642-30fe-40c2-a4ca-da578c171117"],
Cell[159013, 4931, 4060, 107, 346, "Input",ExpressionUUID->"5458d77c-9b64-443b-b1c3-ce5090245133"],
Cell[163076, 5040, 340, 9, 30, "Input",ExpressionUUID->"c86af811-7107-46f2-91e0-38f444f06b9a"]
}, Closed]],
Cell[CellGroupData[{
Cell[163453, 5054, 90, 0, 37, "Subsubsection",ExpressionUUID->"43826dcc-2681-4eee-bb33-a12a289de913"],
Cell[163546, 5056, 2781, 75, 283, "Input",ExpressionUUID->"2d3c8aa5-dcdd-478e-88f0-646e4a67dfba"],
Cell[166330, 5133, 3247, 87, 304, "Input",ExpressionUUID->"6e4357d1-d2e3-4615-9523-052ecb97a994"],
Cell[169580, 5222, 4935, 116, 472, "Input",ExpressionUUID->"cdc84a35-14fd-49c7-aa9b-53c0d2b743db"],
Cell[174518, 5340, 3543, 92, 325, "Input",ExpressionUUID->"2f65df4f-22e8-4ca6-bdfa-920060f75350"],
Cell[178064, 5434, 319, 8, 30, "Input",ExpressionUUID->"52e758ac-179b-4502-959a-33fc4b0092cd"],
Cell[178386, 5444, 6616, 167, 619, "Input",ExpressionUUID->"cd30f3bd-48c5-4b94-8c3e-086421773609"],
Cell[185005, 5613, 332, 9, 30, "Input",ExpressionUUID->"e87cf65c-8a41-4fe3-a402-82929815dfdd"],
Cell[185340, 5624, 625, 20, 52, "Input",ExpressionUUID->"957edeef-ad6d-4058-8b6d-14962ce9bbe9"]
}, Closed]],
Cell[CellGroupData[{
Cell[186002, 5649, 96, 0, 37, "Subsubsection",ExpressionUUID->"e9c16a55-3347-4251-99e3-fa3cbc231c17"],
Cell[186101, 5651, 3246, 84, 304, "Input",ExpressionUUID->"fdb4e6b4-2fd4-4f88-8d3b-0f50f1623376"],
Cell[189350, 5737, 10214, 281, 766, "Input",ExpressionUUID->"5ffbef42-18c0-4eb9-b417-cecc7c238f96"],
Cell[199567, 6020, 461, 12, 52, "Input",ExpressionUUID->"503a722b-c56a-4604-a540-fa69c250f2ec"]
}, Closed]],
Cell[CellGroupData[{
Cell[200065, 6037, 89, 0, 37, "Subsubsection",ExpressionUUID->"a201553b-2d37-4e46-bca1-a4a8e1119b57"],
Cell[200157, 6039, 1222, 32, 159, "Input",ExpressionUUID->"0747b300-f25b-4606-aa84-39194a44e0e9"],
Cell[201382, 6073, 2709, 73, 243, "Input",ExpressionUUID->"22ba124d-2224-4e80-a525-27a198f82173"],
Cell[204094, 6148, 5112, 129, 516, "Input",ExpressionUUID->"e37755ee-8872-49bf-b45b-403dae2022ad"],
Cell[209209, 6279, 2732, 73, 264, "Input",ExpressionUUID->"daf48ceb-fdce-48c7-8b8c-6b88d43139ee"],
Cell[211944, 6354, 5114, 129, 516, "Input",ExpressionUUID->"95eb6d9a-f35c-48e3-b3d0-35ddb0b4364c"],
Cell[217061, 6485, 6364, 163, 621, "Input",ExpressionUUID->"2ede95c5-9fea-48d8-b31d-7f2197ffd1c2"],
Cell[223428, 6650, 10524, 261, 957, "Input",ExpressionUUID->"a5597e2a-9685-47c5-9b2f-ee0d79dbea6f"]
}, Closed]],
Cell[CellGroupData[{
Cell[233989, 6916, 84, 0, 37, "Subsubsection",ExpressionUUID->"dd227e10-a214-4c22-8ec7-0001842e60b8"],
Cell[234076, 6918, 7434, 194, 787, "Input",ExpressionUUID->"d1d27070-0f7d-46ad-a09f-8bdbfba4b3dc"]
}, Closed]]
}, Closed]]
}, Closed]],
Cell[CellGroupData[{
Cell[241571, 7119, 82, 0, 53, "Section",ExpressionUUID->"9f39b2f3-6503-49ad-afc3-7460fa5aaca7"],
Cell[CellGroupData[{
Cell[241678, 7123, 82, 0, 54, "Subsection",ExpressionUUID->"a4fe0d83-6196-4604-bb54-290a711062ad"],
Cell[CellGroupData[{
Cell[241785, 7127, 87, 0, 45, "Subsubsection",ExpressionUUID->"24f1925a-801d-4d2d-96ef-cac6c5016211"],
Cell[241875, 7129, 164, 4, 32, "Input",ExpressionUUID->"49ac9349-e8d9-4d43-b313-c2761f6c4b4f"],
Cell[242042, 7135, 2296, 55, 243, "Input",ExpressionUUID->"c70afba9-40b0-4196-87d7-f530d51d51a4"],
Cell[244341, 7192, 145, 3, 32, "Input",ExpressionUUID->"5b76ff9b-6301-4abe-a26e-87f9376bafb4"]
}, Closed]],
Cell[CellGroupData[{
Cell[244523, 7200, 91, 0, 37, "Subsubsection",ExpressionUUID->"c4cccb37-53cc-489b-847d-fc0dc218d517"],
Cell[244617, 7202, 812, 25, 73, "Input",ExpressionUUID->"ca396b18-267d-4028-be61-f33218446436"],
Cell[245432, 7229, 1765, 49, 178, "Input",ExpressionUUID->"435a33e1-11af-4e98-9d58-65aa16ed1aea"]
}, Closed]]
}, Closed]],
Cell[CellGroupData[{
Cell[247246, 7284, 92, 0, 38, "Subsection",ExpressionUUID->"5e924064-95c6-4fd3-a290-3541e4e369d7"],
Cell[CellGroupData[{
Cell[247363, 7288, 87, 0, 45, "Subsubsection",ExpressionUUID->"8f6b49ce-3b3b-4f77-9059-0e48096deafe"],
Cell[247453, 7290, 679, 18, 52, "Input",ExpressionUUID->"095370fa-f85e-4864-9505-3a510da0e1c5"],
Cell[248135, 7310, 886, 22, 136, "Input",ExpressionUUID->"641334e3-b529-48eb-ae6e-1fecce642e96"],
Cell[249024, 7334, 514, 14, 73, "Input",ExpressionUUID->"10324467-83ff-4a7a-af73-f789f985ae87"],
Cell[249541, 7350, 684, 18, 73, "Input",ExpressionUUID->"221d87a2-cfa1-42eb-9978-a955196eb2b1"],
Cell[250228, 7370, 729, 18, 94, "Input",ExpressionUUID->"4f0befa0-4d27-437f-b014-7b9f472b6059"],
Cell[250960, 7390, 520, 14, 73, "Input",ExpressionUUID->"ec7854e0-1e35-41c0-b9df-5b1d7cb24fb7"],
Cell[251483, 7406, 750, 19, 94, "Input",ExpressionUUID->"dd061aa4-265e-4180-aea1-d731166f68c6"],
Cell[252236, 7427, 1521, 36, 157, "Input",ExpressionUUID->"3d77d784-dca6-40f2-aa6d-f0c22231d18b"],
Cell[253760, 7465, 2737, 67, 283, "Input",ExpressionUUID->"482c5223-e46d-443e-aa80-4f086c2084a7"],
Cell[256500, 7534, 454, 9, 73, "Input",ExpressionUUID->"16031b53-849c-4778-8d65-400a83c65325"],
Cell[256957, 7545, 1682, 44, 178, "Input",ExpressionUUID->"323e4ead-f3ac-4119-ac76-ee7a2e1290b4"],
Cell[258642, 7591, 3082, 78, 409, "Input",ExpressionUUID->"374383ed-fdf7-4446-85ef-971be9d4e399"],
Cell[261727, 7671, 3987, 103, 493, "Input",ExpressionUUID->"8698f7f9-0c1e-406a-8a87-46eb125b93e0"],
Cell[265717, 7776, 1079, 27, 199, "Input",ExpressionUUID->"f22cd3ed-cd2c-4d1c-a4b6-51207b53e90e"],
Cell[266799, 7805, 144, 3, 30, "Input",ExpressionUUID->"88370af9-8293-46c7-9a4e-cdac3cebfd61"],
Cell[266946, 7810, 145, 3, 30, "Input",ExpressionUUID->"a07ee79f-2627-4948-972d-739afc488738"],
Cell[267094, 7815, 146, 3, 30, "Input",ExpressionUUID->"f1c77784-6add-4305-981d-e5c324b77cb5"],
Cell[267243, 7820, 145, 3, 30, "Input",ExpressionUUID->"974b5e50-5d9f-4042-a26b-b37598143b24"],
Cell[267391, 7825, 145, 3, 30, "Input",ExpressionUUID->"ce68db5c-339f-4989-94a3-fdb0ced88cb4"],
Cell[267539, 7830, 146, 3, 30, "Input",ExpressionUUID->"080bec97-32f8-4115-85ec-232e81c30884"],
Cell[267688, 7835, 146, 3, 30, "Input",ExpressionUUID->"ab70f81d-9db7-44f3-bcf0-bb64eaed3c1e"],
Cell[267837, 7840, 145, 3, 30, "Input",ExpressionUUID->"6ba48970-fa53-45df-9efe-ed1d863f0052"],
Cell[267985, 7845, 145, 3, 30, "Input",ExpressionUUID->"f1e9e0a6-3cab-4b59-b928-0ab55276e09c"],
Cell[268133, 7850, 148, 3, 30, "Input",ExpressionUUID->"e9c97910-c1f5-4422-8c00-faa751d7387b"]
}, Closed]],
Cell[CellGroupData[{
Cell[268318, 7858, 91, 0, 37, "Subsubsection",ExpressionUUID->"319e95d1-dfb4-432d-b621-484921742311"],
Cell[268412, 7860, 785, 21, 94, "Input",ExpressionUUID->"9a910a9e-37e8-4540-83b7-67f07fd3928f"],
Cell[269200, 7883, 492, 14, 73, "Input",ExpressionUUID->"3f4e0cbb-c847-4a03-bc49-977b75192fc5"],
Cell[269695, 7899, 905, 27, 94, "Input",ExpressionUUID->"b5b6585b-6bf7-45a8-8fd4-b5b7569d5f94"],
Cell[270603, 7928, 604, 18, 52, "Input",ExpressionUUID->"7ce956c3-46fc-4224-95a8-ccd3d7eebcb7"],
Cell[271210, 7948, 804, 25, 52, "Input",ExpressionUUID->"28f19646-1cc9-4462-9b7e-c52fbefbe264"],
Cell[272017, 7975, 1093, 36, 73, "Input",ExpressionUUID->"f00987e2-c331-41a6-bf47-3f9eebaa9ea1"],
Cell[273113, 8013, 858, 28, 52, "Input",ExpressionUUID->"d4c051e3-3d11-454a-ac10-a83d0256c5eb"],
Cell[273974, 8043, 397, 11, 30, "Input",ExpressionUUID->"2151431a-7d1c-4331-871e-028b19b33079"],
Cell[274374, 8056, 373, 10, 30, "Input",ExpressionUUID->"617f815f-9e67-4b36-81ad-3d4a562ef8b2"],
Cell[274750, 8068, 767, 23, 52, "Input",ExpressionUUID->"b285c346-13e8-480c-b817-f8a60fcddf04"]
}, Closed]]
}, Closed]]
}, Closed]]
}
]
*)

