(* Content-type: application/vnd.wolfram.mathematica *)

(*** Wolfram Notebook File ***)
(* http://www.wolfram.com/nb *)

(* CreatedBy='Mathematica 9.0' *)

(*CacheID: 234*)
(* Internal cache information:
NotebookFileLineBreakTest
NotebookFileLineBreakTest
NotebookDataPosition[       157,          7]
NotebookDataLength[     96586,       2971]
NotebookOptionsPosition[     87718,       2683]
NotebookOutlinePosition[     88278,       2703]
CellTagsIndexPosition[     88235,       2700]
WindowFrame->Normal*)

(* Beginning of Notebook Content *)
Notebook[{
Cell["\<\
Regular-Polytope Points
Vertices, edges, faces, cells, ....

For points, lines, polygons, polyhedra, polychora, ...

Also, which ones are possible. This is done by finding their ratios of (half \
side length) to (circumscribed circle radius) The results are labeled with \
their Schl\[ADoubleDot]fli symbols.

s = (hsl/ccr). For n objects at one vertex, their combination has
s(next) = sqrt(1 - (cos(pi/n)/s)^2)

The 1D case is a line segment, with s = 1.
That makes the 2D case have s = sin(pi/n)

There are three infinite families of polytopes;

Simplex - triangle, tetrahedron, 5-cell, ...
3\[CloseCurlyQuote]s

Hypercube - square, cube (hexahedron), tesseract (8-cell), ...
4,3\[CloseCurlyQuote]s

Cross-polytope - square, octahedron, 16-cell, ...
3\[CloseCurlyQuote]s,4

Square lattice (cube, hypercube, etc.)
4,3\[CloseCurlyQuote]s,4

The lower numbers of dimensions have extra ones:

2D: n-sided polygon
n

3D: dodecahedron, icosahedron, 2D tilings: hexagonal, triangular
53, 35, 63, 36

4D: 24-cell, 120-cell, 600-cell
343, 533, 335

(5D) 4D tilings: 24-cells, 16-cells
3433, 3343


Parts of polytopes: vertices, edges, faces, cells, ...

My code surrounds the list of them with {zero}, a null part, and also {zero}, \
for the whole polytope. Functions for calculating the parts:

polygonparts[n] -- for a n-gon
simplexparts[n] -- for a n-D simplex (triangle, tetrahedron, ...)
Parts are all simplexes
hypcubparts[n] -- for a n-D hypercube (square, cube, tesseract, ...)
Parts are all hypercubes
crsptpparts[n] -- for a n-D cross-polytope (square, octahedron, ...)
Parts are all simplexes
d3f20parts[] -- for an icosahedron
Faces are triangles
d3f12parts[] -- for a dodecahedron
Faces are pentagons
d4c24parts[] -- for a 4D 24-cell
Faces are triangles, cells are octahedra
d4c120parts[] -- for a 4D 120-cell
Faces are triangles, cells are tetrahedra
d4c600parts[] -- for a 4D 600-cell
Faces are pentagons, cells are dodecahedra

Lattices:

For n dimensions:
Cubic: n-tuple of integers

Extra ones:

For 2 dimensions:
Triangular, hexagonal

For 4 dimensions:
4D cubic restricted to sums of values being even
24-cell, 16-cell (cross-polytope)\
\>", "Text",
 CellChangeTimes->{{3.70061401523489*^9, 3.700614068572865*^9}, {
  3.700614650842908*^9, 3.700614680867736*^9}, {3.700614834445006*^9, 
  3.7006148450694036`*^9}, {3.700617535474265*^9, 3.700617543658527*^9}, {
  3.700617592515081*^9, 3.700617597047151*^9}, {3.7006301111070232`*^9, 
  3.700630140238668*^9}, {3.7006302013382597`*^9, 3.700630344424996*^9}, {
  3.700630380696786*^9, 3.700630460482231*^9}, {3.700630494379108*^9, 
  3.700630519546709*^9}, {3.7006305566510067`*^9, 3.7006306296520777`*^9}, {
  3.7006306747336597`*^9, 3.700630694644307*^9}, {3.700709715588991*^9, 
  3.700709996801606*^9}, {3.700710038635353*^9, 3.700710045050024*^9}, {
  3.7007100956102943`*^9, 3.700710285021598*^9}, {3.700710322830443*^9, 
  3.7007103701158037`*^9}, {3.700813126319429*^9, 3.7008132635283537`*^9}, {
  3.700856305711595*^9, 3.70085631770656*^9}}],

Cell[CellGroupData[{

Cell["Possible Regular Polytopes", "Section",
 CellChangeTimes->{{3.700617344819008*^9, 3.7006173516397543`*^9}}],

Cell[CellGroupData[{

Cell["Functions", "Subsection",
 CellChangeTimes->{{3.700617397437538*^9, 3.7006173987289248`*^9}}],

Cell[BoxData[
 RowBox[{"(*", " ", 
  RowBox[{"Reducing", " ", "fractions", " ", "with", " ", "sqrt", 
   RowBox[{"(", "5", ")"}], " ", "in", " ", "their", " ", "denominators"}], 
  " ", "*)"}]], "Input",
 CellChangeTimes->{{3.7006140949359283`*^9, 3.7006141087664347`*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{"red5", "[", "x_", "]"}], " ", ":=", " ", 
  RowBox[{"Module", "[", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{"xs", ",", "xnd", ",", "xdx", ",", "xndx"}], "}"}], ",", 
    "\[IndentingNewLine]", 
    RowBox[{
     RowBox[{"xs", " ", "=", " ", 
      RowBox[{"Factor", "[", 
       RowBox[{"Expand", "[", "x", "]"}], "]"}]}], ";", "\[IndentingNewLine]", 
     RowBox[{"xnd", " ", "=", " ", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"Numerator", "[", "xs", "]"}], ",", 
        RowBox[{"Denominator", "[", "xs", "]"}]}], "}"}]}], ";", 
     "\[IndentingNewLine]", 
     RowBox[{"xdx", " ", "=", " ", 
      RowBox[{
       RowBox[{"xnd", "[", 
        RowBox[{"[", "2", "]"}], "]"}], " ", "/.", " ", 
       RowBox[{
        RowBox[{"Sqrt", "[", "5", "]"}], " ", "\[Rule]", " ", 
        RowBox[{"-", 
         RowBox[{"Sqrt", "[", "5", "]"}]}]}]}]}], ";", "\[IndentingNewLine]", 
     
     RowBox[{"xndx", " ", "=", " ", 
      RowBox[{"Expand", "[", 
       RowBox[{"xnd", "*", "xdx"}], "]"}]}], ";", "\[IndentingNewLine]", 
     RowBox[{"Factor", "[", 
      RowBox[{
       RowBox[{"xndx", "[", 
        RowBox[{"[", "1", "]"}], "]"}], "/", 
       RowBox[{"xndx", "[", 
        RowBox[{"[", "2", "]"}], "]"}]}], "]"}]}]}], "\[IndentingNewLine]", 
   "]"}]}]], "Input",
 CellChangeTimes->{{3.700614109905347*^9, 3.7006142148876343`*^9}}],

Cell[BoxData[
 RowBox[{"(*", " ", 
  RowBox[{
  "Find", " ", "all", " ", "the", " ", "possibilities", " ", "up", " ", "to", 
   " ", "an", " ", "arbitrary", " ", "number", " ", "of", " ", "dimensions"}],
   " ", "*)"}]], "Input",
 CellChangeTimes->{{3.700812210435195*^9, 3.700812224204303*^9}}],

Cell[BoxData[
 RowBox[{"(*", " ", 
  RowBox[{
   RowBox[{"Arg", ":", " ", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"label", ",", " ", 
       RowBox[{"hsl", "/", "ccr"}]}], "}"}], ".", " ", "Result"}], ":", " ", 
    RowBox[{
    "list", " ", "of", " ", "new", " ", "versions", " ", "of", " ", 
     "that"}]}], ",", " ", 
   RowBox[{
   "with", " ", "the", " ", "number", " ", "of", " ", "repeats", " ", 
    "prepended", " ", "onto", " ", "the", " ", "label"}]}], " ", 
  "*)"}]], "Input",
 CellChangeTimes->{{3.700814264927093*^9, 3.70081431214638*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{"nextdim", "[", "dhc_", "]"}], " ", ":=", " ", 
  RowBox[{"Module", "[", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{"d", ",", "hc", ",", "n", ",", "res"}], "}"}], ",", 
    "\[IndentingNewLine]", 
    RowBox[{
     RowBox[{
      RowBox[{"{", 
       RowBox[{"d", ",", "hc"}], "}"}], " ", "=", " ", "dhc"}], ";", 
     "\[IndentingNewLine]", 
     RowBox[{"(*", " ", 
      RowBox[{
      "No", " ", "continuing", " ", "past", " ", "a", " ", "planar", " ", 
       "case"}], " ", "*)"}], "\[IndentingNewLine]", 
     RowBox[{"If", "[", 
      RowBox[{
       RowBox[{"hc", " ", "\[Equal]", " ", "0"}], ",", 
       RowBox[{"Return", "[", 
        RowBox[{"{", "}"}], "]"}]}], "]"}], ";", "\[IndentingNewLine]", 
     RowBox[{"(*", " ", 
      RowBox[{
       RowBox[{"Don", "'"}], "t", " ", "do", " ", "sqrt", " ", "yet", " ", 
       "for", " ", "the", " ", "new", " ", 
       RowBox[{"hsl", "/", "ccr"}], " ", "value"}], " ", "*)"}], 
     "\[IndentingNewLine]", 
     RowBox[{"res", " ", "=", " ", 
      RowBox[{"Table", "[", 
       RowBox[{
        RowBox[{"{", 
         RowBox[{
          RowBox[{"Prepend", "[", 
           RowBox[{"d", ",", "n"}], "]"}], ",", 
          RowBox[{"red5", "[", 
           RowBox[{"1", " ", "-", " ", 
            RowBox[{
             RowBox[{"(", 
              RowBox[{
               RowBox[{"Cos", "[", 
                RowBox[{"Pi", "/", "n"}], "]"}], "/", "hc"}], ")"}], "^", 
             "2"}]}], "]"}]}], "}"}], ",", 
        RowBox[{"{", 
         RowBox[{"n", ",", "3", ",", "6"}], "}"}]}], "]"}]}], ";", 
     "\[IndentingNewLine]", 
     RowBox[{"(*", " ", 
      RowBox[{"Which", " ", "are", " ", "valid", " ", "possibilities"}], " ", 
      "*)"}], "\[IndentingNewLine]", 
     RowBox[{"res", " ", "=", " ", 
      RowBox[{"Select", "[", 
       RowBox[{"res", ",", 
        RowBox[{
         RowBox[{
          RowBox[{"#", "[", 
           RowBox[{"[", "2", "]"}], "]"}], "\[GreaterEqual]", "0"}], "&"}]}], 
       "]"}]}], ";", "\[IndentingNewLine]", 
     RowBox[{"(*", " ", 
      RowBox[{"sqrt", 
       RowBox[{"(", ")"}], " ", "time", " ", "for", " ", "the", " ", "new", 
       " ", 
       RowBox[{"hsl", "/", "ccr"}], " ", "value"}], " ", "*)"}], 
     "\[IndentingNewLine]", 
     RowBox[{
      RowBox[{
       RowBox[{"{", 
        RowBox[{
         RowBox[{"#", "[", 
          RowBox[{"[", "1", "]"}], "]"}], ",", 
         RowBox[{"Sqrt", "[", 
          RowBox[{"#", "[", 
           RowBox[{"[", "2", "]"}], "]"}], "]"}]}], "}"}], "&"}], " ", "/@", 
      " ", "res"}]}]}], "\[IndentingNewLine]", "]"}]}]], "Input",
 CellChangeTimes->{{3.700812469709976*^9, 3.700812491191264*^9}, {
  3.7008128558092546`*^9, 3.700812986918724*^9}, {3.700813056303927*^9, 
  3.700813068822178*^9}, {3.700814401868318*^9, 3.700814458509143*^9}}],

Cell[BoxData[
 RowBox[{"(*", 
  RowBox[{
   RowBox[{" ", 
    RowBox[{"Arg", ":", " ", 
     RowBox[{"list", " ", "of", " ", 
      RowBox[{"(", 
       RowBox[{"label", ",", " ", 
        RowBox[{"hsl", "/", "ccr"}]}]}]}]}], "}"}], " ", "combinations"}], 
  " ", "*)"}]], "Input",
 CellChangeTimes->{{3.700814346832549*^9, 3.700814364058948*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{"nextdimlst", "[", "dhclst_", "]"}], " ", ":=", " ", 
  RowBox[{"Flatten", "[", 
   RowBox[{
    RowBox[{"nextdim", " ", "/@", " ", "dhclst"}], ",", "1"}], 
   "]"}]}]], "Input",
 CellChangeTimes->{{3.7008130738937883`*^9, 3.7008130977573767`*^9}}],

Cell[BoxData[
 RowBox[{"(*", " ", 
  RowBox[{
  "All", " ", "the", " ", "way", " ", "up", " ", "to", " ", "n", " ", "label",
    " ", "members"}], " ", "*)"}]], "Input",
 CellChangeTimes->{{3.700814368546027*^9, 3.700814378298875*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{"mltdms", "[", "n_", "]"}], " ", ":=", " ", 
  RowBox[{"NestList", "[", 
   RowBox[{"nextdimlst", ",", 
    RowBox[{"{", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", "}"}], ",", "1"}], "}"}], "}"}], ",", "n"}], 
   "]"}]}]], "Input",
 CellChangeTimes->{{3.7008132839910192`*^9, 3.700813310143702*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"mltdms", "[", "6", "]"}]], "Input",
 CellChangeTimes->{{3.700813311568239*^9, 3.700813350224086*^9}}],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{"{", 
     RowBox[{
      RowBox[{"{", "}"}], ",", "1"}], "}"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", "3", "}"}], ",", 
       FractionBox[
        SqrtBox["3"], "2"]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", "4", "}"}], ",", 
       FractionBox["1", 
        SqrtBox["2"]]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", "5", "}"}], ",", 
       RowBox[{
        FractionBox["1", "2"], " ", 
        SqrtBox[
         RowBox[{
          FractionBox["1", "2"], " ", 
          RowBox[{"(", 
           RowBox[{"5", "-", 
            SqrtBox["5"]}], ")"}]}]]}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", "6", "}"}], ",", 
       FractionBox["1", "2"]}], "}"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"3", ",", "3"}], "}"}], ",", 
       SqrtBox[
        FractionBox["2", "3"]]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"4", ",", "3"}], "}"}], ",", 
       FractionBox["1", 
        SqrtBox["3"]]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"5", ",", "3"}], "}"}], ",", 
       SqrtBox[
        RowBox[{
         FractionBox["1", "6"], " ", 
         RowBox[{"(", 
          RowBox[{"3", "-", 
           SqrtBox["5"]}], ")"}]}]]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"6", ",", "3"}], "}"}], ",", "0"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"3", ",", "4"}], "}"}], ",", 
       FractionBox["1", 
        SqrtBox["2"]]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"4", ",", "4"}], "}"}], ",", "0"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"3", ",", "5"}], "}"}], ",", 
       SqrtBox[
        RowBox[{
         FractionBox["1", "10"], " ", 
         RowBox[{"(", 
          RowBox[{"5", "-", 
           SqrtBox["5"]}], ")"}]}]]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"3", ",", "6"}], "}"}], ",", "0"}], "}"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"3", ",", "3", ",", "3"}], "}"}], ",", 
       FractionBox[
        SqrtBox[
         FractionBox["5", "2"]], "2"]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"4", ",", "3", ",", "3"}], "}"}], ",", 
       FractionBox["1", "2"]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"5", ",", "3", ",", "3"}], "}"}], ",", 
       RowBox[{
        FractionBox["1", "4"], " ", 
        SqrtBox[
         RowBox[{"7", "-", 
          RowBox[{"3", " ", 
           SqrtBox["5"]}]}]]}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"3", ",", "4", ",", "3"}], "}"}], ",", 
       FractionBox["1", "2"]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"3", ",", "3", ",", "4"}], "}"}], ",", 
       FractionBox["1", 
        SqrtBox["2"]]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"4", ",", "3", ",", "4"}], "}"}], ",", "0"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"3", ",", "3", ",", "5"}], "}"}], ",", 
       RowBox[{
        FractionBox["1", "2"], " ", 
        SqrtBox[
         RowBox[{
          FractionBox["1", "2"], " ", 
          RowBox[{"(", 
           RowBox[{"3", "-", 
            SqrtBox["5"]}], ")"}]}]]}]}], "}"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"3", ",", "3", ",", "3", ",", "3"}], "}"}], ",", 
       SqrtBox[
        FractionBox["3", "5"]]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"4", ",", "3", ",", "3", ",", "3"}], "}"}], ",", 
       FractionBox["1", 
        SqrtBox["5"]]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"3", ",", "4", ",", "3", ",", "3"}], "}"}], ",", "0"}], "}"}],
      ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"3", ",", "3", ",", "4", ",", "3"}], "}"}], ",", "0"}], "}"}],
      ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"3", ",", "3", ",", "3", ",", "4"}], "}"}], ",", 
       FractionBox["1", 
        SqrtBox["2"]]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"4", ",", "3", ",", "3", ",", "4"}], "}"}], ",", "0"}], 
      "}"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"3", ",", "3", ",", "3", ",", "3", ",", "3"}], "}"}], ",", 
       FractionBox[
        SqrtBox[
         FractionBox["7", "3"]], "2"]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"4", ",", "3", ",", "3", ",", "3", ",", "3"}], "}"}], ",", 
       FractionBox["1", 
        SqrtBox["6"]]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"3", ",", "3", ",", "3", ",", "3", ",", "4"}], "}"}], ",", 
       FractionBox["1", 
        SqrtBox["2"]]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"4", ",", "3", ",", "3", ",", "3", ",", "4"}], "}"}], ",", 
       "0"}], "}"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"3", ",", "3", ",", "3", ",", "3", ",", "3", ",", "3"}], 
        "}"}], ",", 
       FractionBox["2", 
        SqrtBox["7"]]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"4", ",", "3", ",", "3", ",", "3", ",", "3", ",", "3"}], 
        "}"}], ",", 
       FractionBox["1", 
        SqrtBox["7"]]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"3", ",", "3", ",", "3", ",", "3", ",", "3", ",", "4"}], 
        "}"}], ",", 
       FractionBox["1", 
        SqrtBox["2"]]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"4", ",", "3", ",", "3", ",", "3", ",", "3", ",", "4"}], 
        "}"}], ",", "0"}], "}"}]}], "}"}]}], "}"}]], "Output",
 CellChangeTimes->{{3.700813314100768*^9, 3.700813350951371*^9}, 
   3.700814255289021*^9}]
}, Open  ]],

Cell[BoxData[
 RowBox[{"(*", " ", 
  RowBox[{
   RowBox[{
    RowBox[{"A", " ", "line", " ", "segment", " ", "is", " ", "one"}], "-", 
    "dimensional"}], ",", " ", 
   RowBox[{
    RowBox[{"with", " ", 
     RowBox[{"hsl", "/", "ccr"}]}], " ", "=", " ", "1"}]}], " ", 
  "*)"}]], "Input",
 CellChangeTimes->{{3.700812141443275*^9, 3.700812160355661*^9}}],

Cell[BoxData[
 RowBox[{"(*", " ", 
  RowBox[{
   RowBox[{
    RowBox[{"hsl", "/", "ccr"}], " ", "for", " ", "the", " ", "next", " ", 
    "polytope", " ", "up"}], ",", " ", 
   RowBox[{"using", " ", "the", " ", "existing", " ", 
    RowBox[{"one", "'"}], "s", " ", 
    RowBox[{"hsl", "/", "ccr"}], " ", "value", " ", "and", " ", "the", " ", 
    "number", " ", "of", " ", "repeats", " ", "n"}]}], " ", "*)"}]], "Input",
 CellChangeTimes->{{3.70061476634225*^9, 3.7006148133336077`*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{"hslccrnext", "[", 
   RowBox[{"n_", ",", "s_"}], "]"}], " ", ":=", " ", 
  RowBox[{"Sqrt", "[", 
   RowBox[{"red5", "[", 
    RowBox[{"1", " ", "-", " ", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{
        RowBox[{"Cos", "[", 
         RowBox[{"Pi", "/", "n"}], "]"}], "/", "s"}], ")"}], "^", "2"}]}], 
    "]"}], "]"}]}]], "Input",
 CellChangeTimes->{{3.700614818366419*^9, 3.7006148757183323`*^9}, {
  3.7006150938908863`*^9, 3.700615094464409*^9}}],

Cell[BoxData[
 RowBox[{"(*", " ", 
  RowBox[{
   RowBox[{"hsl", "/", "ccr"}], " ", "for", " ", "a", " ", "polygon", " ", 
   "with", " ", "n", " ", "sides"}], " ", "*)"}]], "Input",
 CellChangeTimes->{{3.700614740118019*^9, 3.700614756580966*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{"hslccrpgn", "[", "n_", "]"}], " ", ":=", " ", 
  RowBox[{"Sin", "[", 
   RowBox[{"Pi", "/", "n"}], "]"}]}]], "Input",
 CellChangeTimes->{{3.700614707628261*^9, 3.700614746447061*^9}}],

Cell[BoxData[
 RowBox[{"(*", " ", 
  RowBox[{"Check", " ", "that", " ", "it", " ", "fits"}], " ", 
  "*)"}]], "Input",
 CellChangeTimes->{{3.700813502202671*^9, 3.700813508401765*^9}, {
  3.7008142394434643`*^9, 3.700814245937538*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{
    RowBox[{"hslccrnext", "[", 
     RowBox[{"n", ",", "1"}], "]"}], "^", "2"}], " ", "-", " ", 
   RowBox[{
    RowBox[{"hslccrpgn", "[", "n", "]"}], "^", "2"}]}], " ", "//", " ", 
  "TrigReduce"}]], "Input",
 CellChangeTimes->{{3.7008134014140673`*^9, 3.700813434440998*^9}}],

Cell[BoxData["0"], "Output",
 CellChangeTimes->{{3.7008134118507633`*^9, 3.700813434953734*^9}}]
}, Open  ]]
}, Closed]],

Cell[CellGroupData[{

Cell["1D", "Subsection",
 CellChangeTimes->{{3.7008138378253927`*^9, 3.700813838558385*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"hslccr", "[", "\"\<\>\"", "]"}], " ", "=", " ", "1", " ", 
  RowBox[{"(*", " ", 
   RowBox[{"Line", " ", "segment"}], " ", "*)"}]}]], "Input",
 CellChangeTimes->{{3.700813849189816*^9, 3.700813862933566*^9}}],

Cell[BoxData["1"], "Output",
 CellChangeTimes->{3.700813863676306*^9}]
}, Open  ]]
}, Closed]],

Cell[CellGroupData[{

Cell["2D", "Subsection",
 CellChangeTimes->{{3.700617414925145*^9, 3.7006174152982616`*^9}}],

Cell[BoxData[
 RowBox[{"(*", " ", 
  RowBox[{
   RowBox[{
    RowBox[{"The", " ", "first", " ", "four", " ", "regular", " ", 
     RowBox[{"polygons", ".", " ", "For"}], " ", "n"}], " ", "\[Rule]", " ", 
    "infinity"}], ",", " ", 
   RowBox[{"one", " ", "gets", " ", "a", " ", "line", " ", "chain"}]}], " ", 
  "*)"}]], "Input",
 CellChangeTimes->{{3.7006149000601387`*^9, 3.700614914766685*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"hslccr", "[", "\"\<3\>\"", "]"}], " ", "=", " ", 
  RowBox[{"hslccrnext", "[", 
   RowBox[{"3", ",", 
    RowBox[{"hslccr", "[", "\"\<\>\"", "]"}]}], "]"}], " ", 
  RowBox[{"(*", " ", "Triangle", " ", "*)"}]}]], "Input",
 CellChangeTimes->{{3.700614921124804*^9, 3.700614938879013*^9}, {
  3.700813879450345*^9, 3.700813886477886*^9}}],

Cell[BoxData[
 FractionBox[
  SqrtBox["3"], "2"]], "Output",
 CellChangeTimes->{
  3.700614939488196*^9, {3.7006149748161507`*^9, 3.7006149868412027`*^9}, 
   3.700812166575135*^9, 3.7008138873836603`*^9, 3.700813922179943*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"hslccr", "[", "\"\<4\>\"", "]"}], " ", "=", " ", 
  RowBox[{"hslccrnext", "[", 
   RowBox[{"4", ",", 
    RowBox[{"hslccr", "[", "\"\<\>\"", "]"}]}], "]"}], " ", " ", 
  RowBox[{"(*", " ", "Square", " ", "*)"}]}]], "Input",
 CellChangeTimes->{{3.700614921124804*^9, 3.700614978336938*^9}, {
  3.700813894731292*^9, 3.700813916270135*^9}}],

Cell[BoxData[
 FractionBox["1", 
  SqrtBox["2"]]], "Output",
 CellChangeTimes->{
  3.700614939488196*^9, {3.700614974899646*^9, 3.7006149869645443`*^9}, 
   3.700812166624692*^9, 3.700813922230585*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"hslccr", "[", "\"\<5\>\"", "]"}], " ", "=", " ", 
  RowBox[{"hslccrnext", "[", 
   RowBox[{"5", ",", 
    RowBox[{"hslccr", "[", "\"\<\>\"", "]"}]}], "]"}], " ", " ", 
  RowBox[{"(*", " ", "Pentagon", " ", "*)"}]}]], "Input",
 CellChangeTimes->{{3.700614921124804*^9, 3.700614980487095*^9}, {
  3.700813902671872*^9, 3.700813913198082*^9}}],

Cell[BoxData[
 RowBox[{
  FractionBox["1", "2"], " ", 
  SqrtBox[
   RowBox[{
    FractionBox["1", "2"], " ", 
    RowBox[{"(", 
     RowBox[{"5", "-", 
      SqrtBox["5"]}], ")"}]}]]}]], "Output",
 CellChangeTimes->{
  3.700614939488196*^9, {3.7006149749507008`*^9, 3.700614987026037*^9}, 
   3.700812166675682*^9, 3.7008139222852783`*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"hslccr", "[", "\"\<6\>\"", "]"}], " ", "=", " ", 
  RowBox[{"hslccrnext", "[", 
   RowBox[{"6", ",", 
    RowBox[{"hslccr", "[", "\"\<\>\"", "]"}]}], "]"}], " ", " ", 
  RowBox[{"(*", " ", "Hexagon", " ", "*)"}]}]], "Input",
 CellChangeTimes->{{3.700614921124804*^9, 3.700614983351323*^9}, {
  3.700813906714437*^9, 3.700813918958192*^9}}],

Cell[BoxData[
 FractionBox["1", "2"]], "Output",
 CellChangeTimes->{
  3.700614939488196*^9, {3.700614975000811*^9, 3.700614987098392*^9}, 
   3.700812166725749*^9, 3.700813922351961*^9}]
}, Open  ]]
}, Closed]],

Cell[CellGroupData[{

Cell["3D", "Subsection",
 CellChangeTimes->{{3.700617427674466*^9, 3.700617428114274*^9}}],

Cell[BoxData[
 RowBox[{"(*", " ", 
  RowBox[{
  "The", " ", "regular", " ", "polyhedra", " ", "and", " ", "2", "D", " ", 
   "plane", " ", "tilings"}], " ", "*)"}]], "Input",
 CellChangeTimes->{{3.700615006865611*^9, 3.700615029312047*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"hslccr", "[", "\"\<33\>\"", "]"}], " ", "=", " ", 
  RowBox[{"hslccrnext", "[", 
   RowBox[{"3", ",", 
    RowBox[{"hslccr", "[", "\"\<3\>\"", "]"}]}], "]"}], " ", 
  RowBox[{"(*", " ", "Tetrahedron", " ", "*)"}]}]], "Input",
 CellChangeTimes->{{3.70061504496142*^9, 3.7006150685162687`*^9}}],

Cell[BoxData[
 SqrtBox[
  FractionBox["2", "3"]]], "Output",
 CellChangeTimes->{{3.7006150697098713`*^9, 3.7006150992186947`*^9}, 
   3.70081216685341*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"hslccr", "[", "\"\<43\>\"", "]"}], " ", "=", " ", 
  RowBox[{"hslccrnext", "[", 
   RowBox[{"4", ",", 
    RowBox[{"hslccr", "[", "\"\<3\>\"", "]"}]}], "]"}], " ", 
  RowBox[{"(*", " ", "Cube", " ", "*)"}]}]], "Input",
 CellChangeTimes->{{3.70061504496142*^9, 3.7006150685162687`*^9}, {
  3.700615112618712*^9, 3.700615118672906*^9}}],

Cell[BoxData[
 FractionBox["1", 
  SqrtBox["3"]]], "Output",
 CellChangeTimes->{{3.7006150697098713`*^9, 3.7006151223498383`*^9}, 
   3.7008121669091787`*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"hslccr", "[", "\"\<53\>\"", "]"}], " ", "=", " ", 
  RowBox[{"hslccrnext", "[", 
   RowBox[{"5", ",", 
    RowBox[{"hslccr", "[", "\"\<3\>\"", "]"}]}], "]"}], " ", 
  RowBox[{"(*", " ", "Dodecahedron", " ", "*)"}]}]], "Input",
 CellChangeTimes->{{3.70061504496142*^9, 3.7006150685162687`*^9}, {
  3.700615112618712*^9, 3.700615135384781*^9}}],

Cell[BoxData[
 SqrtBox[
  RowBox[{
   FractionBox["1", "6"], " ", 
   RowBox[{"(", 
    RowBox[{"3", "-", 
     SqrtBox["5"]}], ")"}]}]]], "Output",
 CellChangeTimes->{{3.7006150697098713`*^9, 3.700615135987183*^9}, 
   3.700812167163681*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"hslccr", "[", "\"\<63\>\"", "]"}], " ", "=", " ", 
  RowBox[{"hslccrnext", "[", 
   RowBox[{"6", ",", 
    RowBox[{"hslccr", "[", "\"\<3\>\"", "]"}]}], "]"}], " ", 
  RowBox[{"(*", " ", 
   RowBox[{"Hexagonal", " ", "Tiling"}], " ", "*)"}]}]], "Input",
 CellChangeTimes->{{3.70061504496142*^9, 3.7006150685162687`*^9}, {
  3.700615112618712*^9, 3.700615152093638*^9}}],

Cell[BoxData["0"], "Output",
 CellChangeTimes->{{3.7006150697098713`*^9, 3.700615146301055*^9}, 
   3.700615781413558*^9, 3.700812167444275*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"hslccr", "[", "\"\<34\>\"", "]"}], " ", "=", " ", 
  RowBox[{"hslccrnext", "[", 
   RowBox[{"3", ",", 
    RowBox[{"hslccr", "[", "\"\<4\>\"", "]"}]}], "]"}], " ", 
  RowBox[{"(*", " ", "Octahedron", " ", "*)"}]}]], "Input",
 CellChangeTimes->{{3.70061504496142*^9, 3.7006150685162687`*^9}, {
  3.700615272040442*^9, 3.700615277658223*^9}}],

Cell[BoxData[
 FractionBox["1", 
  SqrtBox["2"]]], "Output",
 CellChangeTimes->{{3.7006150697098713`*^9, 3.7006150992186947`*^9}, 
   3.700615278188579*^9, 3.700812167494829*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"hslccr", "[", "\"\<44\>\"", "]"}], " ", "=", " ", 
  RowBox[{"hslccrnext", "[", 
   RowBox[{"4", ",", 
    RowBox[{"hslccr", "[", "\"\<4\>\"", "]"}]}], "]"}], " ", 
  RowBox[{"(*", " ", 
   RowBox[{"Square", " ", "Tiling"}], " ", "*)"}]}]], "Input",
 CellChangeTimes->{{3.70061504496142*^9, 3.7006150685162687`*^9}, {
  3.700615272040442*^9, 3.7006152949864597`*^9}}],

Cell[BoxData["0"], "Output",
 CellChangeTimes->{{3.7006150697098713`*^9, 3.7006150992186947`*^9}, {
   3.700615278188579*^9, 3.7006152954125843`*^9}, 3.700812167562364*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"hslccr", "[", "\"\<35\>\"", "]"}], " ", "=", " ", 
  RowBox[{"hslccrnext", "[", 
   RowBox[{"3", ",", 
    RowBox[{"hslccr", "[", "\"\<5\>\"", "]"}]}], "]"}], " ", 
  RowBox[{"(*", " ", "Icosahedron", " ", "*)"}]}]], "Input",
 CellChangeTimes->{{3.70061504496142*^9, 3.7006150685162687`*^9}, {
  3.700615272040442*^9, 3.700615315583392*^9}}],

Cell[BoxData[
 SqrtBox[
  RowBox[{
   FractionBox["1", "10"], " ", 
   RowBox[{"(", 
    RowBox[{"5", "-", 
     SqrtBox["5"]}], ")"}]}]]], "Output",
 CellChangeTimes->{{3.7006150697098713`*^9, 3.7006150992186947`*^9}, 
   3.700615278188579*^9, {3.700615309223158*^9, 3.700615316260133*^9}, 
   3.700812167621726*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"hslccr", "[", "\"\<36\>\"", "]"}], " ", "=", " ", 
  RowBox[{"hslccrnext", "[", 
   RowBox[{"3", ",", 
    RowBox[{"hslccr", "[", "\"\<6\>\"", "]"}]}], "]"}], " ", 
  RowBox[{"(*", " ", 
   RowBox[{"Triangular", " ", "Tiling"}], " ", "*)"}]}]], "Input",
 CellChangeTimes->{{3.70061504496142*^9, 3.7006150685162687`*^9}, {
  3.700615272040442*^9, 3.700615315583392*^9}, {3.7006153996217327`*^9, 
  3.700615413172035*^9}}],

Cell[BoxData["0"], "Output",
 CellChangeTimes->{{3.7006150697098713`*^9, 3.7006150992186947`*^9}, 
   3.700615278188579*^9, {3.700615309223158*^9, 3.700615316260133*^9}, {
   3.700615407540104*^9, 3.7006154135053043`*^9}, 3.700812167658133*^9}]
}, Open  ]],

Cell[BoxData[
 RowBox[{"(*", " ", 
  RowBox[{"Pentagonal", "-", 
   RowBox[{"value", " ", "reduction"}]}], " ", "*)"}]], "Input",
 CellChangeTimes->{{3.7008139839646053`*^9, 3.7008139844153643`*^9}, {
  3.70081402583908*^9, 3.700814038719367*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{
    RowBox[{"hslccr", "[", "\"\<53\>\"", "]"}], "^", "2"}], " ", "-", " ", 
   RowBox[{
    RowBox[{"(", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{
        RowBox[{"Sqrt", "[", "5", "]"}], "-", "1"}], ")"}], "/", 
      RowBox[{"(", 
       RowBox[{"2", 
        RowBox[{"Sqrt", "[", "3", "]"}]}], ")"}]}], ")"}], "^", "2"}]}], " ", 
  "//", " ", "Factor"}]], "Input",
 CellChangeTimes->{{3.700814045246147*^9, 3.7008140698557653`*^9}}],

Cell[BoxData["0"], "Output",
 CellChangeTimes->{{3.7008140654634237`*^9, 3.7008140703834143`*^9}}]
}, Open  ]]
}, Closed]],

Cell[CellGroupData[{

Cell["4D", "Subsection",
 CellChangeTimes->{{3.700617440674865*^9, 3.700617441154354*^9}}],

Cell[BoxData[
 RowBox[{"(*", " ", 
  RowBox[{
  "The", " ", "regular", " ", "polychora", " ", "and", " ", "3", "D", " ", 
   "space", " ", "tilings"}], " ", "*)"}]], "Input",
 CellChangeTimes->{{3.70061536065923*^9, 3.7006153712434998`*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"hslccr", "[", "\"\<333\>\"", "]"}], " ", "=", " ", 
  RowBox[{"hslccrnext", "[", 
   RowBox[{"3", ",", 
    RowBox[{"hslccr", "[", "\"\<33\>\"", "]"}]}], "]"}], " ", 
  RowBox[{"(*", " ", 
   RowBox[{
    RowBox[{"4", "D", " ", 
     RowBox[{"Simplex", " ", "/", " ", "5"}]}], "-", "Cell"}], " ", 
   "*)"}]}]], "Input",
 CellChangeTimes->{{3.70061504496142*^9, 3.7006150685162687`*^9}, {
  3.700615802690482*^9, 3.700615811839979*^9}, {3.700630161375469*^9, 
  3.700630166647016*^9}}],

Cell[BoxData[
 FractionBox[
  SqrtBox[
   FractionBox["5", "2"]], "2"]], "Output",
 CellChangeTimes->{{3.7006150697098713`*^9, 3.7006150992186947`*^9}, 
   3.700615812359943*^9, 3.700812167745479*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"hslccr", "[", "\"\<433\>\"", "]"}], " ", "=", " ", 
  RowBox[{"hslccrnext", "[", 
   RowBox[{"4", ",", 
    RowBox[{"hslccr", "[", "\"\<33\>\"", "]"}]}], "]"}], " ", 
  RowBox[{"(*", " ", 
   RowBox[{
    RowBox[{"4", "D", " ", 
     RowBox[{
      RowBox[{"Hypercube", " ", "/", " ", "Tesseract"}], " ", "/", " ", 
      "8"}]}], "-", "Cell"}], "  ", "*)"}]}]], "Input",
 CellChangeTimes->{{3.70061504496142*^9, 3.7006150685162687`*^9}, {
  3.700615802690482*^9, 3.700615844169807*^9}, {3.700630150405622*^9, 
  3.700630153063035*^9}}],

Cell[BoxData[
 FractionBox["1", "2"]], "Output",
 CellChangeTimes->{{3.7006150697098713`*^9, 3.7006150992186947`*^9}, {
   3.700615812359943*^9, 3.700615845014903*^9}, 3.700812167796485*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"hslccr", "[", "\"\<533\>\"", "]"}], " ", "=", " ", 
  RowBox[{"hslccrnext", "[", 
   RowBox[{"5", ",", 
    RowBox[{"hslccr", "[", "\"\<33\>\"", "]"}]}], "]"}], " ", 
  RowBox[{"(*", " ", 
   RowBox[{"120", "-", "Cell"}], " ", "*)"}]}]], "Input",
 CellChangeTimes->{{3.70061504496142*^9, 3.7006150685162687`*^9}, {
  3.700615802690482*^9, 3.700615873832747*^9}, {3.7006161505801*^9, 
  3.7006161508119297`*^9}}],

Cell[BoxData[
 RowBox[{
  FractionBox["1", "4"], " ", 
  SqrtBox[
   RowBox[{"7", "-", 
    RowBox[{"3", " ", 
     SqrtBox["5"]}]}]]}]], "Output",
 CellChangeTimes->{{3.7006150697098713`*^9, 3.7006150992186947`*^9}, {
   3.700615812359943*^9, 3.7006158745885677`*^9}, 3.7006161515738583`*^9, 
   3.700812167848546*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"hslccr", "[", "\"\<343\>\"", "]"}], " ", "=", " ", 
  RowBox[{"hslccrnext", "[", 
   RowBox[{"3", ",", 
    RowBox[{"hslccr", "[", "\"\<43\>\"", "]"}]}], "]"}], " ", 
  RowBox[{"(*", " ", 
   RowBox[{"24", "-", "Cell"}], " ", "*)"}]}]], "Input",
 CellChangeTimes->{{3.70061504496142*^9, 3.7006150685162687`*^9}, {
  3.700615802690482*^9, 3.700615873832747*^9}, {3.70061590819564*^9, 
  3.700615914905445*^9}, {3.700616153950272*^9, 3.700616154212132*^9}}],

Cell[BoxData[
 FractionBox["1", "2"]], "Output",
 CellChangeTimes->{{3.7006150697098713`*^9, 3.7006150992186947`*^9}, {
   3.700615812359943*^9, 3.7006158745885677`*^9}, 3.700615915365254*^9, 
   3.7006161546005573`*^9, 3.700812167896709*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"hslccr", "[", "\"\<334\>\"", "]"}], " ", "=", " ", 
  RowBox[{"hslccrnext", "[", 
   RowBox[{"3", ",", 
    RowBox[{"hslccr", "[", "\"\<34\>\"", "]"}]}], "]"}], " ", 
  RowBox[{"(*", " ", 
   RowBox[{
    RowBox[{"4", "D", " ", "Cross"}], "-", 
    RowBox[{"polytope", " ", "/", " ", "16"}], "-", "Cell"}], " ", 
   "*)"}]}]], "Input",
 CellChangeTimes->{{3.70061504496142*^9, 3.7006150685162687`*^9}, {
  3.700615802690482*^9, 3.700615873832747*^9}, {3.70061590819564*^9, 
  3.700615914905445*^9}, {3.7006159548918743`*^9, 3.700615967599164*^9}, {
  3.700616165470928*^9, 3.700616165661784*^9}, {3.7006165927448273`*^9, 
  3.7006165929548817`*^9}, {3.700630156975367*^9, 3.7006301702474003`*^9}}],

Cell[BoxData[
 FractionBox["1", 
  SqrtBox["2"]]], "Output",
 CellChangeTimes->{{3.7006150697098713`*^9, 3.7006150992186947`*^9}, {
   3.700615812359943*^9, 3.7006158745885677`*^9}, 3.700615915365254*^9, {
   3.700615958532941*^9, 3.700615968658678*^9}, 3.7006161669635763`*^9, 
   3.700616593711031*^9, 3.700812167946535*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"hslccr", "[", "\"\<434\>\"", "]"}], " ", "=", " ", 
  RowBox[{"hslccrnext", "[", 
   RowBox[{"4", ",", 
    RowBox[{"hslccr", "[", "\"\<34\>\"", "]"}]}], "]"}], " ", 
  RowBox[{"(*", " ", 
   RowBox[{"Cube", " ", "space", " ", "tiling"}], " ", "*)"}]}]], "Input",
 CellChangeTimes->{{3.70061504496142*^9, 3.7006150685162687`*^9}, {
  3.700615802690482*^9, 3.700615873832747*^9}, {3.70061590819564*^9, 
  3.700615914905445*^9}, {3.7006159548918743`*^9, 3.700615988572187*^9}, {
  3.70061617073225*^9, 3.7006161735971317`*^9}}],

Cell[BoxData["0"], "Output",
 CellChangeTimes->{{3.7006150697098713`*^9, 3.7006150992186947`*^9}, {
   3.700615812359943*^9, 3.7006158745885677`*^9}, 3.700615915365254*^9, {
   3.700615958532941*^9, 3.700615989138486*^9}, 3.700616174654961*^9, 
   3.700812167997362*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"hslccr", "[", "\"\<335\>\"", "]"}], " ", "=", " ", 
  RowBox[{"hslccrnext", "[", 
   RowBox[{"3", ",", 
    RowBox[{"hslccr", "[", "\"\<35\>\"", "]"}]}], "]"}], " ", 
  RowBox[{"(*", " ", 
   RowBox[{"600", "-", "Cell"}], " ", "*)"}]}]], "Input",
 CellChangeTimes->{{3.70061504496142*^9, 3.7006150685162687`*^9}, {
  3.700615802690482*^9, 3.700615873832747*^9}, {3.70061590819564*^9, 
  3.700615914905445*^9}, {3.70061603744531*^9, 3.700616049851159*^9}, {
  3.700616160870274*^9, 3.700616161167815*^9}}],

Cell[BoxData[
 RowBox[{
  FractionBox["1", "2"], " ", 
  SqrtBox[
   RowBox[{
    FractionBox["1", "2"], " ", 
    RowBox[{"(", 
     RowBox[{"3", "-", 
      SqrtBox["5"]}], ")"}]}]]}]], "Output",
 CellChangeTimes->{{3.7006150697098713`*^9, 3.7006150992186947`*^9}, {
   3.700615812359943*^9, 3.7006158745885677`*^9}, 3.700615915365254*^9, 
   3.7006160507132874`*^9, 3.700616161590406*^9, 3.700812168046732*^9}]
}, Open  ]],

Cell[BoxData[
 RowBox[{"(*", " ", 
  RowBox[{"Pentagonal", "-", 
   RowBox[{"value", " ", "reduction"}]}], " ", "*)"}]], "Input",
 CellChangeTimes->{{3.7008139839646053`*^9, 3.7008139844153643`*^9}, {
  3.70081402583908*^9, 3.700814038719367*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{
    RowBox[{"hslccr", "[", "\"\<533\>\"", "]"}], "^", "2"}], " ", "-", " ", 
   RowBox[{
    RowBox[{"(", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{"3", "-", 
        RowBox[{"Sqrt", "[", "5", "]"}]}], ")"}], "/", 
      RowBox[{"(", 
       RowBox[{"4", 
        RowBox[{"Sqrt", "[", "2", "]"}]}], ")"}]}], ")"}], "^", "2"}]}], " ", 
  "//", " ", "Factor"}]], "Input",
 CellChangeTimes->{{3.700814113876327*^9, 3.700814145574232*^9}}],

Cell[BoxData["0"], "Output",
 CellChangeTimes->{3.700814146116556*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{
    RowBox[{"hslccr", "[", "\"\<335\>\"", "]"}], "^", "2"}], " ", "-", " ", 
   RowBox[{
    RowBox[{"(", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{
        RowBox[{"Sqrt", "[", "5", "]"}], "-", "1"}], ")"}], "/", "4"}], ")"}],
     "^", "2"}]}], " ", "//", " ", "Factor"}]], "Input",
 CellChangeTimes->{{3.700814045246147*^9, 3.7008141074818783`*^9}}],

Cell[BoxData["0"], "Output",
 CellChangeTimes->{{3.7008140654634237`*^9, 3.7008140703834143`*^9}, 
   3.7008141089683228`*^9}]
}, Open  ]]
}, Closed]],

Cell[CellGroupData[{

Cell["5D", "Subsection",
 CellChangeTimes->{{3.700617454928752*^9, 3.70061745564292*^9}}],

Cell[BoxData[
 RowBox[{"(*", " ", 
  RowBox[{"The", " ", "5", "D", " ", "polytopes"}], " ", "*)"}]], "Input",
 CellChangeTimes->{{3.70061612491821*^9, 3.700616128756652*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"hslccr", "[", "\"\<3333\>\"", "]"}], " ", "=", " ", 
  RowBox[{"hslccrnext", "[", 
   RowBox[{"3", ",", 
    RowBox[{"hslccr", "[", "\"\<333\>\"", "]"}]}], "]"}], " ", 
  RowBox[{"(*", " ", 
   RowBox[{"5", "D", " ", "Simplex"}], " ", "*)"}]}]], "Input",
 CellChangeTimes->{{3.70061504496142*^9, 3.7006150685162687`*^9}, {
  3.700615802690482*^9, 3.700615811839979*^9}, {3.700616244918948*^9, 
  3.7006162543090353`*^9}}],

Cell[BoxData[
 SqrtBox[
  FractionBox["3", "5"]]], "Output",
 CellChangeTimes->{{3.7006150697098713`*^9, 3.7006150992186947`*^9}, 
   3.700615812359943*^9, {3.700616250013953*^9, 3.7006162553999767`*^9}, 
   3.700812168130506*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"hslccr", "[", "\"\<4333\>\"", "]"}], " ", "=", " ", 
  RowBox[{"hslccrnext", "[", 
   RowBox[{"4", ",", 
    RowBox[{"hslccr", "[", "\"\<333\>\"", "]"}]}], "]"}], " ", 
  RowBox[{"(*", " ", 
   RowBox[{"5", "D", " ", "Hypercube"}], " ", "*)"}]}]], "Input",
 CellChangeTimes->{{3.700616355317829*^9, 3.700616366622031*^9}, {
  3.7006164105906277`*^9, 3.700616417982922*^9}}],

Cell[BoxData[
 FractionBox["1", 
  SqrtBox["5"]]], "Output",
 CellChangeTimes->{3.7006163559953947`*^9, 3.700616418726286*^9, 
  3.700812168209383*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"hslccr", "[", "\"\<3433\>\"", "]"}], " ", "=", " ", 
  RowBox[{"hslccrnext", "[", 
   RowBox[{"3", ",", 
    RowBox[{"hslccr", "[", "\"\<433\>\"", "]"}]}], "]"}], " ", 
  RowBox[{"(*", " ", 
   RowBox[{"a", " ", "lattice"}], " ", "*)"}]}]], "Input",
 CellChangeTimes->{{3.700616478921659*^9, 3.700616502175932*^9}}],

Cell[BoxData["0"], "Output",
 CellChangeTimes->{{3.7006164853289957`*^9, 3.700616502652135*^9}, 
   3.700812168280884*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"hslccr", "[", "\"\<3343\>\"", "]"}], " ", "=", " ", 
  RowBox[{"hslccrnext", "[", 
   RowBox[{"3", ",", 
    RowBox[{"hslccr", "[", "\"\<343\>\"", "]"}]}], "]"}], " ", 
  RowBox[{"(*", " ", 
   RowBox[{"a", " ", "lattice"}], " ", "*)"}]}]], "Input",
 CellChangeTimes->{{3.700616478921659*^9, 3.700616537632142*^9}}],

Cell[BoxData["0"], "Output",
 CellChangeTimes->{{3.7006164853289957`*^9, 3.700616502652135*^9}, 
   3.7006165392633257`*^9, 3.7008121683325872`*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"hslccr", "[", "\"\<3334\>\"", "]"}], " ", "=", " ", 
  RowBox[{"hslccrnext", "[", 
   RowBox[{"3", ",", 
    RowBox[{"hslccr", "[", "\"\<334\>\"", "]"}]}], "]"}], " ", 
  RowBox[{"(*", " ", 
   RowBox[{
    RowBox[{"5", "D", " ", "Cross"}], "-", "polytope"}], " ", 
   "*)"}]}]], "Input",
 CellChangeTimes->{{3.700616478921659*^9, 3.700616537632142*^9}, {
  3.7006165702661457`*^9, 3.700616585280857*^9}}],

Cell[BoxData[
 FractionBox["1", 
  SqrtBox["2"]]], "Output",
 CellChangeTimes->{{3.7006164853289957`*^9, 3.700616502652135*^9}, 
   3.7006165392633257`*^9, {3.700616575947979*^9, 3.7006165858640957`*^9}, 
   3.700812168381302*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"hslccr", "[", "\"\<4334\>\"", "]"}], " ", "=", " ", 
  RowBox[{"hslccrnext", "[", 
   RowBox[{"4", ",", 
    RowBox[{"hslccr", "[", "\"\<334\>\"", "]"}]}], "]"}], " ", 
  RowBox[{"(*", " ", 
   RowBox[{"a", " ", "lattice"}], " ", "*)"}]}]], "Input",
 CellChangeTimes->{{3.700616478921659*^9, 3.700616537632142*^9}, {
  3.7006165702661457`*^9, 3.700616585280857*^9}, {3.700616634547372*^9, 
  3.700616655905395*^9}}],

Cell[BoxData["0"], "Output",
 CellChangeTimes->{{3.7006164853289957`*^9, 3.700616502652135*^9}, 
   3.7006165392633257`*^9, {3.700616575947979*^9, 3.7006165858640957`*^9}, {
   3.700616642738858*^9, 3.7006166563560257`*^9}, 3.700812168431612*^9}]
}, Open  ]]
}, Closed]],

Cell[CellGroupData[{

Cell["More Dimensions", "Subsection",
 CellChangeTimes->{{3.700617468570792*^9, 3.7006174828573236`*^9}}],

Cell[BoxData[
 RowBox[{"(*", " ", 
  RowBox[{"General", " ", "for", " ", "higher", " ", "dimensions"}], " ", 
  "*)"}]], "Input",
 CellChangeTimes->{{3.700616754149165*^9, 3.700616759995515*^9}}],

Cell[BoxData[
 RowBox[{"(*", " ", 
  RowBox[{"All", " ", 
   RowBox[{"3", "'"}], "s"}], " ", "*)"}]], "Input",
 CellChangeTimes->{{3.700616769134932*^9, 3.7006167714508038`*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{"hcsimplex", "[", "n_", "]"}], " ", ":=", " ", 
  RowBox[{"Sqrt", "[", 
   RowBox[{
    RowBox[{"(", 
     RowBox[{"n", "+", "1"}], ")"}], "/", 
    RowBox[{"(", 
     RowBox[{"2", "n"}], ")"}]}], "]"}]}]], "Input",
 CellChangeTimes->{{3.70061679113702*^9, 3.700616802202976*^9}}],

Cell[BoxData[
 RowBox[{"(*", " ", 
  RowBox[{"4", ",", " ", 
   RowBox[{"then", " ", 
    RowBox[{"3", "'"}], "s"}]}], " ", "*)"}]], "Input",
 CellChangeTimes->{{3.700616818265212*^9, 3.700616821491075*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{"hchypcube", "[", "n_", "]"}], " ", ":=", " ", 
  RowBox[{"Sqrt", "[", 
   RowBox[{"1", "/", "n"}], "]"}]}]], "Input",
 CellChangeTimes->{{3.700616823614146*^9, 3.700616852339953*^9}, {
  3.700616895574367*^9, 3.7006169000359*^9}, {3.700616981583082*^9, 
  3.700616982391011*^9}}],

Cell[BoxData[
 RowBox[{"(*", " ", 
  RowBox[{
   RowBox[{
    RowBox[{"3", "'"}], "s"}], ",", " ", 
   RowBox[{"then", " ", "4"}]}], " ", "*)"}]], "Input",
 CellChangeTimes->{{3.7006168695984097`*^9, 3.700616872963718*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{"hccrosspoly", "[", "n_", "]"}], " ", ":=", " ", 
  RowBox[{"1", "/", 
   RowBox[{"Sqrt", "[", "2", "]"}]}]}]], "Input",
 CellChangeTimes->{{3.7006168741717873`*^9, 3.700616918422556*^9}, {
  3.70061698867115*^9, 3.700616989844759*^9}}],

Cell[BoxData[
 RowBox[{"(*", " ", 
  RowBox[{"Check", " ", "the", " ", "previous", " ", "results"}], " ", 
  "*)"}]], "Input",
 CellChangeTimes->{{3.7006170443778677`*^9, 3.700617049333396*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"(", 
   RowBox[{"hslccr", " ", "/@", " ", 
    RowBox[{"{", 
     RowBox[{
     "\"\<3\>\"", ",", "\"\<33\>\"", ",", "\"\<333\>\"", ",", 
      "\"\<3333\>\""}], "}"}]}], ")"}], " ", "-", " ", 
  RowBox[{"Table", "[", 
   RowBox[{
    RowBox[{"hcsimplex", "[", "n", "]"}], ",", 
    RowBox[{"{", 
     RowBox[{"n", ",", "2", ",", "5"}], "}"}]}], "]"}]}]], "Input",
 CellChangeTimes->{{3.7006169449755*^9, 3.7006169735164757`*^9}}],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"0", ",", "0", ",", "0", ",", "0"}], "}"}]], "Output",
 CellChangeTimes->{3.700616974322695*^9, 3.7008121686493063`*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"(", 
   RowBox[{"hslccr", " ", "/@", " ", 
    RowBox[{"{", 
     RowBox[{
     "\"\<4\>\"", ",", "\"\<43\>\"", ",", "\"\<433\>\"", ",", 
      "\"\<4333\>\""}], "}"}]}], ")"}], " ", "-", " ", 
  RowBox[{"Table", "[", 
   RowBox[{
    RowBox[{"hchypcube", "[", "n", "]"}], ",", 
    RowBox[{"{", 
     RowBox[{"n", ",", "2", ",", "5"}], "}"}]}], "]"}]}]], "Input",
 CellChangeTimes->{{3.7006169449755*^9, 3.7006170173269367`*^9}}],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"0", ",", "0", ",", "0", ",", "0"}], "}"}]], "Output",
 CellChangeTimes->{3.700616974322695*^9, 3.700617017865799*^9, 
  3.7008121686996727`*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"(", 
   RowBox[{"hslccr", " ", "/@", " ", 
    RowBox[{"{", 
     RowBox[{
     "\"\<4\>\"", ",", "\"\<34\>\"", ",", "\"\<334\>\"", ",", 
      "\"\<3334\>\""}], "}"}]}], ")"}], " ", "-", " ", 
  RowBox[{"Table", "[", 
   RowBox[{
    RowBox[{"hccrosspoly", "[", "n", "]"}], ",", 
    RowBox[{"{", 
     RowBox[{"n", ",", "2", ",", "5"}], "}"}]}], "]"}]}]], "Input",
 CellChangeTimes->{{3.7006169449755*^9, 3.7006169735164757`*^9}, {
  3.700617022449708*^9, 3.70061703032647*^9}}],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"0", ",", "0", ",", "0", ",", "0"}], "}"}]], "Output",
 CellChangeTimes->{3.700616974322695*^9, 3.700617030799986*^9, 
  3.700812168749773*^9}]
}, Open  ]],

Cell[BoxData[
 RowBox[{"(*", " ", 
  RowBox[{"Check", " ", "the", " ", "recurrences"}], " ", "*)"}]], "Input",
 CellChangeTimes->{{3.7006170520367107`*^9, 3.700617057813645*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"hslccrnext", "[", 
    RowBox[{"3", ",", 
     RowBox[{"hcsimplex", "[", "n", "]"}]}], "]"}], " ", "-", " ", 
   RowBox[{"hcsimplex", "[", 
    RowBox[{"n", "+", "1"}], "]"}]}], " ", "//", " ", "Factor"}]], "Input",
 CellChangeTimes->{{3.700617068407029*^9, 3.7006170939839773`*^9}}],

Cell[BoxData["0"], "Output",
 CellChangeTimes->{{3.7006170818202477`*^9, 3.700617094279532*^9}, 
   3.700812168850976*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"hslccrnext", "[", 
    RowBox[{"4", ",", 
     RowBox[{"hcsimplex", "[", "n", "]"}]}], "]"}], " ", "-", " ", 
   RowBox[{"hchypcube", "[", 
    RowBox[{"n", "+", "1"}], "]"}]}], " ", "//", " ", "Factor"}]], "Input",
 CellChangeTimes->{{3.700617119617448*^9, 3.700617130430591*^9}}],

Cell[BoxData["0"], "Output",
 CellChangeTimes->{3.700617130661421*^9, 3.7008121688887253`*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"hslccrnext", "[", 
    RowBox[{"3", ",", 
     RowBox[{"hccrosspoly", "[", "n", "]"}]}], "]"}], " ", "-", " ", 
   RowBox[{"hccrosspoly", "[", 
    RowBox[{"n", "+", "1"}], "]"}]}], " ", "//", " ", "Factor"}]], "Input",
 CellChangeTimes->{{3.700617068407029*^9, 3.7006170939839773`*^9}, {
  3.700617154363717*^9, 3.700617155347293*^9}}],

Cell[BoxData["0"], "Output",
 CellChangeTimes->{{3.7006170818202477`*^9, 3.700617094279532*^9}, 
   3.700617156000708*^9, 3.700812168935878*^9}]
}, Open  ]],

Cell[BoxData[
 RowBox[{"(*", " ", "Lattice", " ", "*)"}]], "Input",
 CellChangeTimes->{{3.700617181097879*^9, 3.700617183551189*^9}, 
   3.700617261471686*^9}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"hslccrnext", "[", 
  RowBox[{"4", ",", 
   RowBox[{"hccrosspoly", "[", "n", "]"}]}], "]"}]], "Input",
 CellChangeTimes->{{3.7006172556602573`*^9, 3.700617255761096*^9}}],

Cell[BoxData["0"], "Output",
 CellChangeTimes->{3.700617257509691*^9, 3.700812169064538*^9}]
}, Open  ]]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{

Cell["Polytope Points", "Section",
 CellChangeTimes->{{3.7006173680097322`*^9, 3.7006173708163633`*^9}}],

Cell[CellGroupData[{

Cell["Polygons", "Subsection",
 CellChangeTimes->{{3.70070755448982*^9, 3.700707556846685*^9}}],

Cell[BoxData[
 RowBox[{"(*", " ", 
  RowBox[{"For", " ", "n", " ", 
   RowBox[{"vertices", "/", 
    RowBox[{"sides", ":", " ", 
     RowBox[{"{", 
      RowBox[{
      "null", ",", " ", "vertices", ",", " ", "sides", ",", " ", "all"}], 
      "}"}]}]}]}], " ", "*)"}]], "Input",
 CellChangeTimes->{{3.7007075622888308`*^9, 3.700707580055973*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{"polygonparts", "[", "n_", "]"}], " ", ":=", " ", 
  RowBox[{"Module", "[", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{"k", ",", "a", ",", "vts", ",", "eds"}], "}"}], ",", 
    "\[IndentingNewLine]", 
    RowBox[{
     RowBox[{"vts", " ", "=", " ", 
      RowBox[{"Table", "[", 
       RowBox[{
        RowBox[{
         RowBox[{"a", " ", "=", " ", 
          RowBox[{
           RowBox[{"(", 
            RowBox[{"2", "Pi", "*", "k"}], ")"}], "/", "n"}]}], ";", 
         RowBox[{"{", 
          RowBox[{
           RowBox[{"Cos", "[", "a", "]"}], ",", 
           RowBox[{"Sin", "[", "a", "]"}]}], "}"}]}], ",", 
        RowBox[{"{", 
         RowBox[{"k", ",", "0", ",", 
          RowBox[{"n", "-", "1"}]}], "}"}]}], "]"}]}], ";", 
     "\[IndentingNewLine]", 
     RowBox[{"eds", " ", "=", " ", 
      RowBox[{"Table", "[", 
       RowBox[{
        RowBox[{
         RowBox[{"a", " ", "=", " ", 
          RowBox[{
           RowBox[{"(", 
            RowBox[{"2", "Pi", "*", 
             RowBox[{"(", 
              RowBox[{"k", "+", 
               RowBox[{"1", "/", "2"}]}], ")"}]}], ")"}], "/", "n"}]}], ";", 
         RowBox[{"{", 
          RowBox[{
           RowBox[{"Cos", "[", "a", "]"}], ",", 
           RowBox[{"Sin", "[", "a", "]"}]}], "}"}]}], ",", 
        RowBox[{"{", 
         RowBox[{"k", ",", "0", ",", 
          RowBox[{"n", "-", "1"}]}], "}"}]}], "]"}]}], ";", 
     "\[IndentingNewLine]", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"{", 
         RowBox[{"0", ",", "0"}], "}"}], "}"}], ",", "vts", ",", "eds", ",", 
       RowBox[{"{", 
        RowBox[{"{", 
         RowBox[{"0", ",", "0"}], "}"}], "}"}]}], "}"}]}]}], 
   "\[IndentingNewLine]", "]"}]}]], "Input",
 CellChangeTimes->{{3.700707581951985*^9, 3.700707629896721*^9}, {
  3.700707799093053*^9, 3.7007077995755463`*^9}, {3.7007078600215*^9, 
  3.7007078864382133`*^9}, {3.700708011594573*^9, 3.700708016125279*^9}}],

Cell[BoxData[
 RowBox[{"(*", " ", 
  RowBox[{
  "Closest", " ", "points", " ", "to", " ", "a", " ", "point", " ", "by", " ",
    "direction"}], " ", "*)"}]], "Input",
 CellChangeTimes->{{3.7007076476356077`*^9, 3.700707658658202*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{"ptngbr", "[", 
   RowBox[{"pts_", ",", "pt0_"}], "]"}], " ", ":=", " ", 
  RowBox[{"Module", "[", 
   RowBox[{
    RowBox[{"{", "dx", "}"}], ",", "\[IndentingNewLine]", 
    RowBox[{
     RowBox[{"dx", " ", "=", " ", 
      RowBox[{"Max", "[", 
       RowBox[{"Expand", "[", 
        RowBox[{"pts", ".", "pt0"}], "]"}], "]"}]}], ";", 
     "\[IndentingNewLine]", 
     RowBox[{"Select", "[", 
      RowBox[{"pts", ",", 
       RowBox[{
        RowBox[{
         RowBox[{"Expand", "[", 
          RowBox[{"#", ".", "pt0"}], "]"}], "\[Equal]", "dx"}], "&"}]}], 
      "]"}]}]}], "\[IndentingNewLine]", "]"}]}]], "Input",
 CellChangeTimes->{{3.700707664801016*^9, 3.70070769261703*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{"ptptnb", "[", "ptpts_", "]"}], " ", ":=", " ", 
  RowBox[{"Module", "[", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{"vts", ",", "hghr"}], "}"}], ",", "\[IndentingNewLine]", 
    RowBox[{
     RowBox[{"vts", " ", "=", " ", 
      RowBox[{"ptpts", "[", 
       RowBox[{"[", "2", "]"}], "]"}]}], ";", "\[IndentingNewLine]", 
     RowBox[{"hghr", " ", "=", " ", 
      RowBox[{"ptpts", "[", 
       RowBox[{"[", 
        RowBox[{
         RowBox[{"3", ";;", 
          RowBox[{"-", "2"}]}], ",", "1"}], "]"}], "]"}]}], ";", 
     "\[IndentingNewLine]", 
     RowBox[{
      RowBox[{
       RowBox[{"ptngbr", "[", 
        RowBox[{"vts", ",", "#"}], "]"}], "&"}], " ", "/@", " ", "hghr"}]}]}],
    "\[IndentingNewLine]", "]"}]}]], "Input",
 CellChangeTimes->{{3.700707697107624*^9, 3.700707778891096*^9}, {
  3.70070781739636*^9, 3.700707830780384*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{"ptnbln", "[", "ptpts_", "]"}], " ", ":=", " ", 
  RowBox[{"Length", " ", "/@", " ", 
   RowBox[{"ptptnb", "[", "ptpts", "]"}]}]}]], "Input",
 CellChangeTimes->{{3.700707697107624*^9, 3.700707778891096*^9}, {
  3.70070781739636*^9, 3.700707830780384*^9}, {3.700707961365677*^9, 
  3.7007079742741117`*^9}}]
}, Closed]],

Cell[CellGroupData[{

Cell["Simplex: triangle, tetrahedron, ...", "Subsection",
 CellChangeTimes->{{3.7006920072440233`*^9, 3.700692008222149*^9}, {
  3.700706050264872*^9, 3.7007060637150707`*^9}}],

Cell[BoxData[
 RowBox[{"(*", " ", 
  RowBox[{"Vertices", " ", "for", " ", "n", " ", "dimensions"}], " ", 
  "*)"}]], "Input",
 CellChangeTimes->{{3.7006921174059467`*^9, 3.700692135472031*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{"simplexverts", "[", "n_", "]"}], " ", ":=", " ", 
  RowBox[{"Append", "[", 
   RowBox[{
    RowBox[{"Expand", "[", 
     RowBox[{
      RowBox[{
       RowBox[{"IdentityMatrix", "[", "n", "]"}], "*", 
       RowBox[{"Sqrt", "[", 
        RowBox[{"n", "+", "1"}], "]"}]}], "-", 
      RowBox[{
       RowBox[{"(", 
        RowBox[{"1", "+", 
         RowBox[{"Sqrt", "[", 
          RowBox[{"n", "+", "1"}], "]"}]}], ")"}], "/", "n"}]}], "]"}], ",", 
    RowBox[{"Table", "[", 
     RowBox[{"1", ",", 
      RowBox[{"{", "n", "}"}]}], "]"}]}], "]"}]}]], "Input",
 CellChangeTimes->{{3.7006922472276297`*^9, 3.700692254477893*^9}}],

Cell[BoxData[
 RowBox[{"(*", " ", 
  RowBox[{
   RowBox[{"All", " ", "higher"}], "-", 
   RowBox[{
   "dimension", " ", "surfaces", " ", "are", " ", "all", " ", "combinations", 
    " ", "of", " ", "distinct", " ", 
    RowBox[{"vertices", ".", " ", "Each"}], " ", "one", " ", "of", " ", 
    "these", " ", "is", " ", "itself", " ", "a", " ", 
    RowBox[{"simplex", ".", " ", "The"}], " ", "second", " ", "one", " ", 
    "is", " ", "the", " ", "vertices", " ", "and", " ", "the", " ", "last", 
    " ", "one", " ", "the", " ", "simplex", " ", "as", " ", "a", " ", 
    RowBox[{"whole", ".", " ", "The"}], " ", "first", " ", "one", " ", "is", 
    " ", "a", " ", "null", " ", 
    RowBox[{"one", "."}]}]}], " ", "*)"}]], "Input",
 CellChangeTimes->{{3.700692862238365*^9, 3.700692880064043*^9}, {
  3.700693311883918*^9, 3.7006933174601173`*^9}, {3.700693459751274*^9, 
  3.700693501894039*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{"simplexparts", "[", "n_", "]"}], " ", ":=", " ", 
  RowBox[{"Module", "[", 
   RowBox[{
    RowBox[{"{", "verts", "}"}], ",", "\[IndentingNewLine]", 
    RowBox[{
     RowBox[{"verts", " ", "=", " ", 
      RowBox[{"simplexverts", "[", "n", "]"}]}], ";", "\[IndentingNewLine]", 
     RowBox[{"Map", "[", 
      RowBox[{
       RowBox[{
        RowBox[{"Expand", "[", 
         RowBox[{"#", ".", "verts"}], "]"}], "&"}], ",", 
       RowBox[{"SortBy", "[", 
        RowBox[{
         RowBox[{"GatherBy", "[", 
          RowBox[{
           RowBox[{"Tuples", "[", 
            RowBox[{
             RowBox[{"{", 
              RowBox[{"0", ",", "1"}], "}"}], ",", 
             RowBox[{"n", "+", "1"}]}], "]"}], ",", 
           RowBox[{
            RowBox[{"Total", "[", "#", "]"}], "&"}]}], "]"}], ",", 
         RowBox[{
          RowBox[{"Total", "[", 
           RowBox[{"First", "[", "#", "]"}], "]"}], "&"}]}], "]"}], ",", 
       RowBox[{"{", "2", "}"}]}], "]"}]}]}], "\[IndentingNewLine]", 
   "]"}]}]], "Input",
 CellChangeTimes->{{3.700692979355609*^9, 3.700693058081954*^9}, {
  3.700693633305822*^9, 3.700693647992063*^9}}],

Cell[BoxData[
 RowBox[{"(*", " ", 
  RowBox[{"Symmetry", "-", 
   RowBox[{
   "group", " ", "matrices", " ", "for", " ", "simplex", " ", "vertices"}]}], 
  " ", "*)"}]], "Input",
 CellChangeTimes->{{3.700692331205285*^9, 3.7006923452414722`*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{"simplexsymgrpmats", "[", "n_", "]"}], " ", ":=", " ", 
  RowBox[{"Module", "[", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{"sv", ",", "svt"}], "}"}], ",", "\[IndentingNewLine]", 
    RowBox[{
     RowBox[{"sv", " ", "=", " ", 
      RowBox[{"simplexverts", "[", "n", "]"}]}], ";", "\[IndentingNewLine]", 
     RowBox[{"svt", " ", "=", " ", 
      RowBox[{"Transpose", "[", "sv", "]"}]}], ";", "\[IndentingNewLine]", 
     RowBox[{
      RowBox[{
       RowBox[{"Expand", "[", 
        RowBox[{
         RowBox[{"(", 
          RowBox[{"svt", ".", "#", ".", "sv"}], ")"}], "/", 
         RowBox[{"(", 
          RowBox[{"n", "+", "1"}], ")"}]}], "]"}], "&"}], " ", "/@", " ", 
      RowBox[{"Permutations", "[", 
       RowBox[{"IdentityMatrix", "[", 
        RowBox[{"n", "+", "1"}], "]"}], "]"}]}]}]}], "\[IndentingNewLine]", 
   "]"}]}]], "Input",
 CellChangeTimes->{{3.700692328809313*^9, 3.700692373442691*^9}, {
  3.700692403786025*^9, 3.700692407876711*^9}, {3.700692587879634*^9, 
  3.700692588685587*^9}}],

Cell[BoxData[
 RowBox[{"(*", " ", 
  RowBox[{"Even", " ", "and", " ", "odd", " ", "permutations"}], " ", 
  "*)"}]], "Input",
 CellChangeTimes->{{3.7006953285519047`*^9, 3.7006953345045137`*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{"evenperms", "[", "xlst_", "]"}], " ", ":=", " ", 
  RowBox[{"Module", "[", 
   RowBox[{
    RowBox[{"{", "s", "}"}], ",", "\[IndentingNewLine]", 
    RowBox[{
     RowBox[{"s", " ", "=", " ", 
      RowBox[{"Signature", "[", "xlst", "]"}]}], ";", "\[IndentingNewLine]", 
     RowBox[{"Select", "[", 
      RowBox[{
       RowBox[{"Permutations", "[", "xlst", "]"}], ",", 
       RowBox[{
        RowBox[{
         RowBox[{"Signature", "[", "#", "]"}], "\[Equal]", "s"}], "&"}]}], 
      "]"}]}]}], "\[IndentingNewLine]", "]"}]}]], "Input",
 CellChangeTimes->{{3.700695387169878*^9, 3.7006954610422*^9}, {
   3.700695777063322*^9, 3.700695781319297*^9}, 3.7006958249635363`*^9, {
   3.700704712899856*^9, 3.700704719151621*^9}, {3.700704828468172*^9, 
   3.700704859176488*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{"oddperms", "[", "xlst_", "]"}], " ", ":=", " ", 
  RowBox[{"Module", "[", 
   RowBox[{
    RowBox[{"{", "s", "}"}], ",", "\[IndentingNewLine]", 
    RowBox[{
     RowBox[{"s", " ", "=", " ", 
      RowBox[{"Signature", "[", "xlst", "]"}]}], ";", "\[IndentingNewLine]", 
     RowBox[{"Select", "[", 
      RowBox[{
       RowBox[{"Permutations", "[", "xlst", "]"}], ",", 
       RowBox[{
        RowBox[{
         RowBox[{"Signature", "[", "#", "]"}], "\[Equal]", 
         RowBox[{"-", "s"}]}], "&"}]}], "]"}]}]}], "\[IndentingNewLine]", 
   "]"}]}]], "Input",
 CellChangeTimes->{{3.700695387169878*^9, 3.7006954610422*^9}, {
   3.700695777063322*^9, 3.700695781319297*^9}, 3.7006958249635363`*^9, {
   3.700704712899856*^9, 3.700704719151621*^9}, {3.700704828468172*^9, 
   3.700704870502572*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{"evenoddperms", "[", "xlst_", "]"}], " ", ":=", " ", 
  "\[IndentingNewLine]", 
  RowBox[{"Module", "[", 
   RowBox[{
    RowBox[{"{", "s", "}"}], ",", "\[IndentingNewLine]", 
    RowBox[{
     RowBox[{"s", " ", "=", " ", 
      RowBox[{"Signature", "[", "xlst", "]"}]}], ";", "\[IndentingNewLine]", 
     RowBox[{"SortBy", "[", 
      RowBox[{
       RowBox[{"GatherBy", "[", 
        RowBox[{
         RowBox[{"Permutations", "[", "xlst", "]"}], ",", "Signature"}], 
        "]"}], ",", 
       RowBox[{
        RowBox[{
         RowBox[{"-", 
          RowBox[{"Signature", "[", 
           RowBox[{"First", "[", "#", "]"}], "]"}]}], "*", "s"}], "&"}]}], 
      "]"}]}]}], "\[IndentingNewLine]", "]"}]}]], "Input",
 CellChangeTimes->{{3.700695387169878*^9, 3.700695511506589*^9}, {
  3.700695591996657*^9, 3.7006957558313723`*^9}, {3.7006957922715883`*^9, 
  3.700695796286067*^9}, {3.700695863334711*^9, 3.700695894543188*^9}, {
  3.700695949283688*^9, 3.7006959508638763`*^9}, {3.700704733763678*^9, 
  3.700704737736311*^9}, {3.700704908831211*^9, 3.700704949189763*^9}, {
  3.7007051180768957`*^9, 3.700705173648871*^9}}],

Cell[BoxData[
 RowBox[{"(*", " ", 
  RowBox[{"Alternating", " ", "group"}], " ", "*)"}]], "Input",
 CellChangeTimes->{{3.7006925061588087`*^9, 3.700692510219781*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{"simplexaltgrpmats", "[", "n_", "]"}], " ", ":=", " ", 
  RowBox[{"Module", "[", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{"sv", ",", "svt"}], "}"}], ",", "\[IndentingNewLine]", 
    RowBox[{
     RowBox[{"sv", " ", "=", " ", 
      RowBox[{"simplexverts", "[", "n", "]"}]}], ";", "\[IndentingNewLine]", 
     RowBox[{"svt", " ", "=", " ", 
      RowBox[{"Transpose", "[", "sv", "]"}]}], ";", "\[IndentingNewLine]", 
     RowBox[{
      RowBox[{
       RowBox[{"Expand", "[", 
        RowBox[{
         RowBox[{"(", 
          RowBox[{"svt", ".", "#", ".", "sv"}], ")"}], "/", 
         RowBox[{"(", 
          RowBox[{"n", "+", "1"}], ")"}]}], "]"}], "&"}], " ", "/@", " ", 
      RowBox[{"evenperms", "[", 
       RowBox[{"IdentityMatrix", "[", 
        RowBox[{"n", "+", "1"}], "]"}], "]"}]}]}]}], "\[IndentingNewLine]", 
   "]"}]}]], "Input",
 CellChangeTimes->{{3.700692328809313*^9, 3.700692373442691*^9}, {
  3.700692403786025*^9, 3.700692407876711*^9}, {3.700692587879634*^9, 
  3.700692603301241*^9}}]
}, Closed]],

Cell[CellGroupData[{

Cell["\<\
Hypercube and Cross-Polytope: square, cube, octahedron, tesseract, ...\
\>", "Subsection",
 CellChangeTimes->{{3.700692838871963*^9, 3.70069284491045*^9}, {
  3.7007060666476183`*^9, 3.700706078768386*^9}, {3.7007083221655893`*^9, 
  3.700708331390952*^9}}],

Cell[BoxData[
 RowBox[{"(*", " ", 
  RowBox[{
   RowBox[{"Cross", "-", 
    RowBox[{
     RowBox[{"polytope", ".", " ", "First"}], " ", 
     RowBox[{"one", ":", " ", "null"}]}]}], ",", " ", 
   RowBox[{"second", " ", 
    RowBox[{"one", ":", " ", "vertices"}]}], ",", " ", 
   RowBox[{"last", " ", 
    RowBox[{"one", ":", " ", 
     RowBox[{"the", " ", "polytope", " ", "as", " ", "a", " ", 
      RowBox[{"whole", ".", " ", "All"}], " ", "but", " ", "the", " ", "top", 
      " ", "parts", " ", "are", " ", 
      RowBox[{"simplexes", "."}]}]}]}]}], " ", "*)"}]], "Input",
 CellChangeTimes->{{3.700693524556171*^9, 3.700693545190441*^9}, {
  3.70069607835242*^9, 3.700696096240553*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{"crsptpparts", "[", "n_", "]"}], " ", ":=", " ", 
  RowBox[{"Append", "[", 
   RowBox[{
    RowBox[{"SortBy", "[", 
     RowBox[{
      RowBox[{"GatherBy", "[", 
       RowBox[{
        RowBox[{"Tuples", "[", 
         RowBox[{
          RowBox[{"{", 
           RowBox[{"1", ",", "0", ",", 
            RowBox[{"-", "1"}]}], "}"}], ",", "n"}], "]"}], ",", 
        RowBox[{
         RowBox[{"Total", "[", 
          RowBox[{"Abs", "[", "#", "]"}], "]"}], "&"}]}], "]"}], ",", 
      RowBox[{
       RowBox[{"Total", "[", 
        RowBox[{"Abs", "[", 
         RowBox[{"First", "[", "#", "]"}], "]"}], "]"}], "&"}]}], "]"}], ",", 
    
    RowBox[{"{", 
     RowBox[{"ConstantArray", "[", 
      RowBox[{"0", ",", "n"}], "]"}], "}"}]}], "]"}]}]], "Input",
 CellChangeTimes->{{3.700693181569017*^9, 3.700693185066557*^9}, {
  3.70069338739016*^9, 3.700693450669537*^9}, {3.700693689096538*^9, 
  3.7006937082079782`*^9}, {3.700699215738044*^9, 3.7006992175255547`*^9}}],

Cell[BoxData[
 RowBox[{"(*", " ", 
  RowBox[{"Duality", ":", " ", 
   RowBox[{"the", " ", 
    RowBox[{"hypercube", ".", " ", "All"}], " ", "parts", " ", "are", " ", 
    RowBox[{"hypercubes", "."}]}]}], " ", "*)"}]], "Input",
 CellChangeTimes->{{3.700693741292572*^9, 3.700693743296488*^9}, {
  3.700696086152203*^9, 3.70069610682264*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{"hypcubparts", "[", "n_", "]"}], " ", ":=", " ", 
  RowBox[{"Reverse", "[", 
   RowBox[{"crsptpparts", "[", "n", "]"}], "]"}]}]], "Input",
 CellChangeTimes->{{3.700693729523251*^9, 3.7006937387764053`*^9}}],

Cell[BoxData[
 RowBox[{"(*", " ", 
  RowBox[{
   RowBox[{"Alternate", " ", "approach"}], ",", " ", 
   RowBox[{
   "suitable", " ", "for", " ", "more", " ", "general", " ", "polytopes"}]}], 
  " ", "*)"}]], "Input",
 CellChangeTimes->{{3.700699408171376*^9, 3.7006994117236547`*^9}, {
  3.7006999049161777`*^9, 3.700699910696678*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{"addsigns", "[", "xlst_", "]"}], " ", ":=", " ", 
  RowBox[{
   RowBox[{
    RowBox[{"If", "[", 
     RowBox[{
      RowBox[{"#", "\[NotEqual]", "0"}], ",", 
      RowBox[{"{", 
       RowBox[{"#", ",", 
        RowBox[{"-", "#"}]}], "}"}], ",", 
      RowBox[{"{", "#", "}"}]}], "]"}], "&"}], " ", "/@", " ", 
   "xlst"}]}]], "Input",
 CellChangeTimes->{{3.7006994161383142`*^9, 3.700699437731736*^9}, 
   3.70069950658838*^9}],

Cell[BoxData[
 RowBox[{
  RowBox[{"addsgntpls", "[", "xlst_", "]"}], " ", ":=", " ", 
  RowBox[{"Tuples", "[", 
   RowBox[{"addsigns", "[", "xlst", "]"}], "]"}]}]], "Input",
 CellChangeTimes->{{3.700699441704135*^9, 3.7006994680114117`*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{"addsgntplpms", "[", "xlst_", "]"}], " ", ":=", " ", 
  RowBox[{"Union", "[", 
   RowBox[{"Flatten", "[", 
    RowBox[{
     RowBox[{"Permutations", " ", "/@", " ", 
      RowBox[{"addsgntpls", "[", "xlst", "]"}]}], ",", "1"}], "]"}], 
   "]"}]}]], "Input",
 CellChangeTimes->{{3.7006995696299562`*^9, 3.7006996371013403`*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{"addsgntpleps", "[", "xlst_", "]"}], " ", ":=", " ", 
  RowBox[{"Union", "[", 
   RowBox[{"Flatten", "[", 
    RowBox[{
     RowBox[{"evenperms", " ", "/@", " ", 
      RowBox[{"addsgntpls", "[", "xlst", "]"}]}], ",", "1"}], "]"}], 
   "]"}]}]], "Input",
 CellChangeTimes->{{3.7006995696299562`*^9, 3.7006996371013403`*^9}, {
  3.7006996812478943`*^9, 3.7006996855263453`*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{"crsptpprtsx", "[", "n_", "]"}], " ", ":=", " ", 
  RowBox[{"Module", "[", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{"k", ",", "m"}], "}"}], ",", "\[IndentingNewLine]", 
    RowBox[{"Append", "[", 
     RowBox[{
      RowBox[{"addsgntplpms", " ", "/@", " ", 
       RowBox[{"Table", "[", 
        RowBox[{
         RowBox[{"If", "[", 
          RowBox[{
           RowBox[{"m", "<", "k"}], ",", "1", ",", "0"}], "]"}], ",", 
         RowBox[{"{", 
          RowBox[{"k", ",", 
           RowBox[{"n", "+", "1"}]}], "}"}], ",", 
         RowBox[{"{", 
          RowBox[{"m", ",", "n"}], "}"}]}], "]"}]}], ",", 
      RowBox[{"{", 
       RowBox[{"{", 
        RowBox[{"0", ",", "0", ",", "0"}], "}"}], "}"}]}], "]"}]}], 
   "\[IndentingNewLine]", "]"}]}]], "Input",
 CellChangeTimes->{{3.700699735583912*^9, 3.7006998141197567`*^9}, {
  3.700699847993905*^9, 3.70069986617656*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{"hypcubprtsx", "[", "n_", "]"}], " ", ":=", " ", 
  RowBox[{"Reverse", "[", 
   RowBox[{"crsptpprtsx", "[", "n", "]"}], "]"}]}]], "Input",
 CellChangeTimes->{{3.700699877817596*^9, 3.700699889671981*^9}}],

Cell[BoxData[
 RowBox[{"(*", " ", 
  RowBox[{"Symmetry", " ", "group"}], " ", "*)"}]], "Input",
 CellChangeTimes->{{3.7006962914040003`*^9, 3.700696294691017*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{"hccpsymgropmats", "[", "n_", "]"}], " ", ":=", " ", 
  RowBox[{
   RowBox[{
    RowBox[{"(", 
     RowBox[{
      RowBox[{"#", "[", 
       RowBox[{"[", "1", "]"}], "]"}], "*", 
      RowBox[{"#", "[", 
       RowBox[{"[", "2", "]"}], "]"}]}], ")"}], "&"}], " ", "/@", " ", 
   RowBox[{"Tuples", "[", 
    RowBox[{"{", 
     RowBox[{
      RowBox[{"Tuples", "[", 
       RowBox[{
        RowBox[{"{", 
         RowBox[{"1", ",", 
          RowBox[{"-", "1"}]}], "}"}], ",", "n"}], "]"}], ",", 
      RowBox[{"Permutations", "[", 
       RowBox[{"IdentityMatrix", "[", "n", "]"}], "]"}]}], "}"}], 
    "]"}]}]}]], "Input",
 CellChangeTimes->{{3.7006962962828197`*^9, 3.7006963115272512`*^9}, {
  3.700696384453676*^9, 3.70069642756531*^9}}]
}, Closed]],

Cell[CellGroupData[{

Cell["4D: 24-Cell", "Subsection",
 CellChangeTimes->{{3.700696590224352*^9, 3.700696594485045*^9}}],

Cell[BoxData[
 RowBox[{"(*", " ", 
  RowBox[{
   RowBox[{"Halfway", " ", "between", " ", "a", " ", "hypercube", " ", 
    RowBox[{"(", 
     RowBox[{"8", "-", "cell"}], ")"}], " ", "and", " ", "a", " ", "cross"}], 
   "-", 
   RowBox[{"polytope", " ", 
    RowBox[{
     RowBox[{"(", 
      RowBox[{"16", "-", "cell"}], ")"}], ".", " ", "Faces"}], " ", "are", 
    " ", "triangles", " ", "and", " ", "cells", " ", "are", " ", 
    "octahedra"}]}], " ", "*)"}]], "Input",
 CellChangeTimes->{{3.7006969525621233`*^9, 3.7006969600497847`*^9}, {
  3.7006970572531967`*^9, 3.700697072043336*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{"d4c24parts", "[", "]"}], " ", ":=", " ", 
  RowBox[{
   RowBox[{
    RowBox[{"Sort", "[", 
     RowBox[{"Flatten", "[", 
      RowBox[{"#", ",", "1"}], "]"}], "]"}], "&"}], " ", "/@", " ", 
   RowBox[{"Map", "[", 
    RowBox[{"addsgntplpms", ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"{", 
         RowBox[{"0", ",", "0", ",", "0", ",", "0"}], "}"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"{", 
          RowBox[{"1", ",", "0", ",", "0", ",", "0"}], "}"}], ",", 
         RowBox[{"{", 
          RowBox[{
           RowBox[{"1", "/", "2"}], ",", 
           RowBox[{"1", "/", "2"}], ",", 
           RowBox[{"1", "/", "2"}], ",", 
           RowBox[{"1", "/", "2"}]}], "}"}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"{", 
          RowBox[{
           RowBox[{"3", "/", "4"}], ",", 
           RowBox[{"1", "/", "4"}], ",", 
           RowBox[{"1", "/", "4"}], ",", 
           RowBox[{"1", "/", "4"}]}], "}"}], ",", 
         RowBox[{"{", 
          RowBox[{
           RowBox[{"1", "/", "2"}], ",", 
           RowBox[{"1", "/", "2"}], ",", 
           RowBox[{"1", "/", "2"}], ",", "0"}], "}"}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"{", 
         RowBox[{
          RowBox[{"2", "/", "3"}], ",", 
          RowBox[{"1", "/", "3"}], ",", 
          RowBox[{"1", "/", "3"}], ",", "0"}], "}"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"{", 
         RowBox[{
          RowBox[{"1", "/", "2"}], ",", 
          RowBox[{"1", "/", "2"}], ",", "0", ",", "0"}], "}"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"{", 
         RowBox[{"0", ",", "0", ",", "0", ",", "0"}], "}"}], "}"}]}], "}"}], 
     ",", 
     RowBox[{"{", "2", "}"}]}], "]"}]}]}]], "Input",
 CellChangeTimes->{{3.700697080164472*^9, 3.70069712071682*^9}, {
   3.700697163877548*^9, 3.700697202696505*^9}, {3.7006999912609997`*^9, 
   3.700699997793936*^9}, {3.700700070994529*^9, 3.70070007277313*^9}, {
   3.700700103212665*^9, 3.700700107994844*^9}, {3.700700161227715*^9, 
   3.7007001619788*^9}, {3.700700237179824*^9, 3.7007004461428633`*^9}, {
   3.700700484407675*^9, 3.7007005104809427`*^9}, 3.70070550257104*^9}]
}, Closed]],

Cell[CellGroupData[{

Cell["3D: Dodecahedron and Icosahedron (12-Face and 20-Face)", "Subsection",
 CellChangeTimes->{{3.700700643200796*^9, 3.70070065305599*^9}, {
  3.700708781183298*^9, 3.700708785848297*^9}}],

Cell[BoxData[
 RowBox[{"(*", " ", 
  RowBox[{
  "From", " ", "the", " ", "quaternion", " ", "version", " ", "of", " ", 
   "the", " ", "icosahedral", " ", "group"}], " ", "*)"}]], "Input",
 CellChangeTimes->{{3.700703996905446*^9, 3.700704011579853*^9}}],

Cell[BoxData[
 RowBox[{"(*", " ", 
  RowBox[{"Icosahedron", " ", 
   RowBox[{"parts", ":", " ", 
    RowBox[{"faces", " ", "are", " ", "triangles"}]}]}], " ", "*)"}]], "Input",\

 CellChangeTimes->{{3.7007040994897947`*^9, 3.700704125533309*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{"d3f20parts", "[", "]"}], " ", ":=", " ", 
  RowBox[{"Module", "[", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{"icqts", ",", "sel", ",", "x"}], "}"}], ",", 
    "\[IndentingNewLine]", 
    RowBox[{
     RowBox[{"icqts", " ", "=", " ", 
      RowBox[{
       RowBox[{
        RowBox[{"Sort", "[", 
         RowBox[{"Flatten", "[", 
          RowBox[{"#", ",", "1"}], "]"}], "]"}], "&"}], " ", "@", " ", 
       RowBox[{"(", 
        RowBox[{"addsgntpleps", " ", "/@", " ", 
         RowBox[{"{", 
          RowBox[{
           RowBox[{"{", 
            RowBox[{"1", ",", "0", ",", "0", ",", "0"}], "}"}], ",", 
           RowBox[{"{", 
            RowBox[{
             RowBox[{"1", "/", "2"}], ",", 
             RowBox[{"1", "/", "2"}], ",", 
             RowBox[{"1", "/", "2"}], ",", 
             RowBox[{"1", "/", "2"}]}], "}"}], ",", 
           RowBox[{"{", 
            RowBox[{
             RowBox[{
              RowBox[{"(", 
               RowBox[{
                RowBox[{"Sqrt", "[", "5", "]"}], "+", "1"}], ")"}], "/", 
              "4"}], ",", 
             RowBox[{"1", "/", "2"}], ",", 
             RowBox[{
              RowBox[{"(", 
               RowBox[{
                RowBox[{"Sqrt", "[", "5", "]"}], "-", "1"}], ")"}], "/", 
              "4"}], ",", "0"}], "}"}]}], "}"}]}], ")"}]}]}], ";", 
     "\[IndentingNewLine]", 
     RowBox[{
      RowBox[{"sel", "[", "x_", "]"}], " ", ":=", " ", 
      RowBox[{"Most", " ", "/@", " ", 
       RowBox[{"Select", "[", 
        RowBox[{"icqts", ",", 
         RowBox[{
          RowBox[{
           RowBox[{"Last", "[", "#", "]"}], "\[Equal]", "x"}], "&"}]}], 
        "]"}]}]}], ";", "\[IndentingNewLine]", 
     RowBox[{"sel", " ", "/@", " ", 
      RowBox[{"{", 
       RowBox[{"1", ",", 
        RowBox[{
         RowBox[{"(", 
          RowBox[{
           RowBox[{"Sqrt", "[", "5", "]"}], "-", "1"}], ")"}], "/", "4"}], 
        ",", "0", ",", 
        RowBox[{"1", "/", "2"}], ",", "1"}], "}"}]}]}]}], 
   "\[IndentingNewLine]", "]"}]}]], "Input",
 CellChangeTimes->{{3.700700845533142*^9, 3.700700999188016*^9}, {
  3.700701132607781*^9, 3.700701134349308*^9}, {3.7007036243841143`*^9, 
  3.700703677219015*^9}, {3.70070380197931*^9, 3.700703900866816*^9}, {
  3.70070394934031*^9, 3.700703952404168*^9}, {3.7007040795515203`*^9, 
  3.7007040912365417`*^9}, {3.70070416208707*^9, 3.700704178368099*^9}, {
  3.700704589696864*^9, 3.700704609355137*^9}, {3.7007052182626343`*^9, 
  3.7007052238283243`*^9}, {3.7007052689662733`*^9, 3.700705310017494*^9}}],

Cell[BoxData[
 RowBox[{"(*", " ", 
  RowBox[{"Dodecahedron", " ", 
   RowBox[{"parts", ":", " ", 
    RowBox[{"faces", " ", "are", " ", "pentagons"}]}]}], " ", "*)"}]], "Input",\

 CellChangeTimes->{{3.7007040994897947`*^9, 3.7007041331728983`*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{"d3f12parts", "[", "]"}], " ", ":=", " ", 
  RowBox[{"Reverse", "[", 
   RowBox[{"d3f20parts", "[", "]"}], "]"}]}]], "Input",
 CellChangeTimes->{{3.7007039746178093`*^9, 3.700703986005929*^9}, {
  3.700704087322858*^9, 3.7007040952970753`*^9}}]
}, Closed]],

Cell[CellGroupData[{

Cell["4D: 120-Cell and 600-Cell", "Subsection",
 CellChangeTimes->{{3.7007043840344*^9, 3.700704432458499*^9}}],

Cell[BoxData[
 RowBox[{"(*", " ", 
  RowBox[{
   RowBox[{"600", "-", 
    RowBox[{"cell", " ", 
     RowBox[{"parts", ":", " ", 
      RowBox[{"faces", " ", "are", " ", "triangles"}]}]}]}], ",", " ", 
   RowBox[{"cells", " ", "are", " ", "tetrahedra"}]}], " ", "*)"}]], "Input",
 CellChangeTimes->{{3.700705695076964*^9, 3.700705705865209*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{"d4c600parts", "[", "]"}], " ", ":=", " ", 
  RowBox[{
   RowBox[{
    RowBox[{"Sort", "[", 
     RowBox[{"Flatten", "[", 
      RowBox[{"#", ",", "1"}], "]"}], "]"}], "&"}], " ", "/@", " ", 
   RowBox[{"Map", "[", 
    RowBox[{"addsgntpleps", ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"{", 
         RowBox[{"0", ",", "0", ",", "0", ",", "0"}], "}"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"{", 
          RowBox[{"1", ",", "0", ",", "0", ",", "0"}], "}"}], ",", 
         RowBox[{
          RowBox[{"{", 
           RowBox[{"1", ",", "1", ",", "1", ",", "1"}], "}"}], "/", "2"}], 
         ",", 
         RowBox[{"{", 
          RowBox[{
           RowBox[{
            RowBox[{"(", 
             RowBox[{
              RowBox[{"Sqrt", "[", "5", "]"}], "+", "1"}], ")"}], "/", "4"}], 
           ",", 
           RowBox[{"1", "/", "2"}], ",", 
           RowBox[{
            RowBox[{"(", 
             RowBox[{
              RowBox[{"Sqrt", "[", "5", "]"}], "-", "1"}], ")"}], "/", "4"}], 
           ",", "0"}], "}"}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"{", 
          RowBox[{
           RowBox[{
            RowBox[{"(", 
             RowBox[{
              RowBox[{"Sqrt", "[", "5", "]"}], "+", "5"}], ")"}], "/", "4"}], 
           ",", 
           RowBox[{
            RowBox[{"(", 
             RowBox[{
              RowBox[{"Sqrt", "[", "5", "]"}], "-", "1"}], ")"}], "/", "4"}], 
           ",", "0", ",", 
           RowBox[{"1", "/", "2"}]}], "}"}], ",", 
         RowBox[{"{", 
          RowBox[{
           RowBox[{
            RowBox[{"(", 
             RowBox[{
              RowBox[{"Sqrt", "[", "5", "]"}], "+", "3"}], ")"}], "/", "4"}], 
           ",", 
           RowBox[{
            RowBox[{"(", 
             RowBox[{
              RowBox[{"Sqrt", "[", "5", "]"}], "+", "3"}], ")"}], "/", "4"}], 
           ",", 
           RowBox[{
            RowBox[{"(", 
             RowBox[{
              RowBox[{"Sqrt", "[", "5", "]"}], "-", "1"}], ")"}], "/", "4"}], 
           ",", 
           RowBox[{
            RowBox[{"(", 
             RowBox[{
              RowBox[{"Sqrt", "[", "5", "]"}], "-", "1"}], ")"}], "/", 
            "4"}]}], "}"}], ",", 
         RowBox[{"{", 
          RowBox[{
           RowBox[{
            RowBox[{"(", 
             RowBox[{
              RowBox[{"Sqrt", "[", "5", "]"}], "+", "3"}], ")"}], "/", "4"}], 
           ",", 
           RowBox[{
            RowBox[{"(", 
             RowBox[{
              RowBox[{"Sqrt", "[", "5", "]"}], "+", "1"}], ")"}], "/", "4"}], 
           ",", 
           RowBox[{
            RowBox[{"Sqrt", "[", "5", "]"}], "/", "2"}], ",", "0"}], "}"}], 
         ",", 
         RowBox[{"{", 
          RowBox[{
           RowBox[{
            RowBox[{"(", 
             RowBox[{
              RowBox[{"Sqrt", "[", "5", "]"}], "+", "3"}], ")"}], "/", "4"}], 
           ",", 
           RowBox[{
            RowBox[{"(", 
             RowBox[{
              RowBox[{"Sqrt", "[", "5", "]"}], "+", "1"}], ")"}], "/", "4"}], 
           ",", 
           RowBox[{"1", "/", "2"}], ",", "1"}], "}"}], ",", 
         RowBox[{"{", 
          RowBox[{
           RowBox[{
            RowBox[{"(", 
             RowBox[{
              RowBox[{"Sqrt", "[", "5", "]"}], "+", "1"}], ")"}], "/", "2"}], 
           ",", 
           RowBox[{
            RowBox[{"(", 
             RowBox[{
              RowBox[{"Sqrt", "[", "5", "]"}], "+", "1"}], ")"}], "/", "4"}], 
           ",", 
           RowBox[{
            RowBox[{"(", 
             RowBox[{
              RowBox[{"Sqrt", "[", "5", "]"}], "-", "1"}], ")"}], "/", "4"}], 
           ",", 
           RowBox[{"1", "/", "2"}]}], "}"}], ",", 
         RowBox[{"{", 
          RowBox[{
           RowBox[{
            RowBox[{"(", 
             RowBox[{
              RowBox[{"Sqrt", "[", "5", "]"}], "+", "1"}], ")"}], "/", "2"}], 
           ",", "1", ",", "0", ",", "0"}], "}"}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"{", 
          RowBox[{
           RowBox[{
            RowBox[{"Sqrt", "[", "5", "]"}], "/", "2"}], ",", 
           RowBox[{
            RowBox[{"Sqrt", "[", "5", "]"}], "/", "2"}], ",", 
           RowBox[{"1", "/", "2"}], ",", 
           RowBox[{"1", "/", "2"}]}], "}"}], ",", 
         RowBox[{"{", 
          RowBox[{
           RowBox[{
            RowBox[{"Sqrt", "[", "5", "]"}], "/", "2"}], ",", 
           RowBox[{
            RowBox[{"(", 
             RowBox[{
              RowBox[{"Sqrt", "[", "5", "]"}], "+", "1"}], ")"}], "/", "4"}], 
           ",", "1", ",", 
           RowBox[{
            RowBox[{"(", 
             RowBox[{
              RowBox[{"Sqrt", "[", "5", "]"}], "-", "1"}], ")"}], "/", 
            "4"}]}], "}"}], ",", 
         RowBox[{"{", 
          RowBox[{
           RowBox[{
            RowBox[{"Sqrt", "[", "5", "]"}], "/", "2"}], ",", 
           RowBox[{
            RowBox[{"(", 
             RowBox[{
              RowBox[{"Sqrt", "[", "5", "]"}], "+", "3"}], ")"}], "/", "4"}], 
           ",", 
           RowBox[{
            RowBox[{"(", 
             RowBox[{
              RowBox[{"-", 
               RowBox[{"Sqrt", "[", "5", "]"}]}], "+", "3"}], ")"}], "/", 
            "4"}], ",", "0"}], "}"}], ",", 
         RowBox[{"{", 
          RowBox[{
           RowBox[{
            RowBox[{"(", 
             RowBox[{
              RowBox[{"Sqrt", "[", "5", "]"}], "+", "1"}], ")"}], "/", "2"}], 
           ",", 
           RowBox[{"1", "/", "2"}], ",", 
           RowBox[{
            RowBox[{"(", 
             RowBox[{
              RowBox[{"-", 
               RowBox[{"Sqrt", "[", "5", "]"}]}], "+", "3"}], ")"}], "/", 
            "4"}], ",", 
           RowBox[{
            RowBox[{"(", 
             RowBox[{
              RowBox[{"Sqrt", "[", "5", "]"}], "-", "1"}], ")"}], "/", 
            "4"}]}], "}"}], ",", 
         RowBox[{"{", 
          RowBox[{
           RowBox[{
            RowBox[{"(", 
             RowBox[{
              RowBox[{"Sqrt", "[", "5", "]"}], "+", "1"}], ")"}], "/", "2"}], 
           ",", 
           RowBox[{
            RowBox[{"(", 
             RowBox[{
              RowBox[{"Sqrt", "[", "5", "]"}], "-", "1"}], ")"}], "/", "2"}], 
           ",", "0", ",", "0"}], "}"}], ",", 
         RowBox[{"{", 
          RowBox[{
           RowBox[{
            RowBox[{"(", 
             RowBox[{
              RowBox[{"Sqrt", "[", "5", "]"}], "+", "1"}], ")"}], "/", "4"}], 
           ",", 
           RowBox[{
            RowBox[{"(", 
             RowBox[{
              RowBox[{"Sqrt", "[", "5", "]"}], "+", "3"}], ")"}], "/", "4"}], 
           ",", 
           RowBox[{
            RowBox[{"(", 
             RowBox[{
              RowBox[{"Sqrt", "[", "5", "]"}], "-", "1"}], ")"}], "/", "2"}], 
           ",", 
           RowBox[{"1", "/", "2"}]}], "}"}], ",", 
         RowBox[{"{", 
          RowBox[{
           RowBox[{
            RowBox[{"(", 
             RowBox[{
              RowBox[{"Sqrt", "[", "5", "]"}], "+", "1"}], ")"}], "/", "4"}], 
           ",", 
           RowBox[{"3", "/", "2"}], ",", 
           RowBox[{
            RowBox[{"(", 
             RowBox[{
              RowBox[{"Sqrt", "[", "5", "]"}], "-", "1"}], ")"}], "/", "4"}], 
           ",", "0"}], "}"}], ",", 
         RowBox[{"{", 
          RowBox[{
           RowBox[{
            RowBox[{"(", 
             RowBox[{
              RowBox[{"Sqrt", "[", "5", "]"}], "+", "3"}], ")"}], "/", "4"}], 
           ",", "1", ",", 
           RowBox[{
            RowBox[{"(", 
             RowBox[{
              RowBox[{"-", 
               RowBox[{"Sqrt", "[", "5", "]"}]}], "+", "3"}], ")"}], "/", 
            "4"}], ",", 
           RowBox[{"1", "/", "2"}]}], "}"}], ",", 
         RowBox[{"{", 
          RowBox[{
           RowBox[{"3", "/", "2"}], ",", 
           RowBox[{"1", "/", "2"}], ",", 
           RowBox[{"1", "/", "2"}], ",", 
           RowBox[{"1", "/", "2"}]}], "}"}], ",", 
         RowBox[{"{", 
          RowBox[{"1", ",", "1", ",", "1", ",", "0"}], "}"}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"{", 
          RowBox[{
           RowBox[{
            RowBox[{"(", 
             RowBox[{
              RowBox[{"Sqrt", "[", "5", "]"}], "+", "3"}], ")"}], "/", "4"}], 
           ",", 
           RowBox[{"1", "/", "2"}], ",", "0", ",", 
           RowBox[{
            RowBox[{"(", 
             RowBox[{
              RowBox[{"-", 
               RowBox[{"Sqrt", "[", "5", "]"}]}], "+", "3"}], ")"}], "/", 
            "4"}]}], "}"}], ",", 
         RowBox[{"{", 
          RowBox[{
           RowBox[{
            RowBox[{"(", 
             RowBox[{
              RowBox[{"Sqrt", "[", "5", "]"}], "+", "3"}], ")"}], "/", "4"}], 
           ",", 
           RowBox[{
            RowBox[{"(", 
             RowBox[{
              RowBox[{"Sqrt", "[", "5", "]"}], "-", "1"}], ")"}], "/", "4"}], 
           ",", 
           RowBox[{
            RowBox[{"(", 
             RowBox[{
              RowBox[{"Sqrt", "[", "5", "]"}], "-", "1"}], ")"}], "/", "4"}], 
           ",", 
           RowBox[{
            RowBox[{"(", 
             RowBox[{
              RowBox[{"Sqrt", "[", "5", "]"}], "-", "1"}], ")"}], "/", 
            "4"}]}], "}"}], ",", 
         RowBox[{"{", 
          RowBox[{
           RowBox[{
            RowBox[{"Sqrt", "[", "5", "]"}], "/", "2"}], ",", 
           RowBox[{"1", "/", "2"}], ",", 
           RowBox[{"1", "/", "2"}], ",", 
           RowBox[{"1", "/", "2"}]}], "}"}], ",", 
         RowBox[{"{", 
          RowBox[{
           RowBox[{
            RowBox[{"Sqrt", "[", "5", "]"}], "/", "2"}], ",", 
           RowBox[{
            RowBox[{"(", 
             RowBox[{
              RowBox[{"Sqrt", "[", "5", "]"}], "+", "1"}], ")"}], "/", "4"}], 
           ",", "0", ",", 
           RowBox[{
            RowBox[{"(", 
             RowBox[{
              RowBox[{"Sqrt", "[", "5", "]"}], "-", "1"}], ")"}], "/", 
            "4"}]}], "}"}], ",", 
         RowBox[{"{", 
          RowBox[{"1", ",", "1", ",", "0", ",", "0"}], "}"}], ",", 
         RowBox[{"{", 
          RowBox[{"1", ",", 
           RowBox[{"1", "/", "2"}], ",", 
           RowBox[{
            RowBox[{"(", 
             RowBox[{
              RowBox[{"Sqrt", "[", "5", "]"}], "+", "1"}], ")"}], "/", "4"}], 
           ",", 
           RowBox[{
            RowBox[{"(", 
             RowBox[{
              RowBox[{"Sqrt", "[", "5", "]"}], "-", "1"}], ")"}], "/", 
            "4"}]}], "}"}], ",", 
         RowBox[{"{", 
          RowBox[{
           RowBox[{
            RowBox[{"(", 
             RowBox[{
              RowBox[{"Sqrt", "[", "5", "]"}], "+", "1"}], ")"}], "/", "4"}], 
           ",", 
           RowBox[{
            RowBox[{"(", 
             RowBox[{
              RowBox[{"Sqrt", "[", "5", "]"}], "+", "1"}], ")"}], "/", "4"}], 
           ",", 
           RowBox[{
            RowBox[{"(", 
             RowBox[{
              RowBox[{"Sqrt", "[", "5", "]"}], "+", "1"}], ")"}], "/", "4"}], 
           ",", 
           RowBox[{
            RowBox[{"(", 
             RowBox[{
              RowBox[{"-", 
               RowBox[{"Sqrt", "[", "5", "]"}]}], "+", "3"}], ")"}], "/", 
            "4"}]}], "}"}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"{", 
         RowBox[{"0", ",", "0", ",", "0", ",", "0"}], "}"}], "}"}]}], "}"}], 
     ",", 
     RowBox[{"{", "2", "}"}]}], "]"}]}]}]], "Input",
 CellChangeTimes->{{3.700705521009997*^9, 3.70070556261329*^9}, {
  3.700705595361493*^9, 3.700705638870846*^9}, {3.7007056785919313`*^9, 
  3.700705689064596*^9}}],

Cell[BoxData[
 RowBox[{"(*", " ", 
  RowBox[{
   RowBox[{"120", "-", 
    RowBox[{"cell", " ", 
     RowBox[{"parts", ":", " ", 
      RowBox[{"faces", " ", "are", " ", "pentagons"}]}]}]}], ",", " ", 
   RowBox[{"cells", " ", "are", " ", "dodecahedra"}]}], "  ", "*)"}]], "Input",\

 CellChangeTimes->{{3.700705731015174*^9, 3.7007057325921593`*^9}, {
  3.70070588769663*^9, 3.700705916743223*^9}, {3.700708181718149*^9, 
  3.700708196390232*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{"d4c120parts", "[", "]"}], " ", ":=", " ", 
  RowBox[{"Reverse", "[", 
   RowBox[{"d4c600parts", "[", "]"}], "]"}]}]], "Input",
 CellChangeTimes->{{3.700708158871439*^9, 3.7007081651991177`*^9}}]
}, Closed]]
}, Closed]]
},
WindowSize->{639, 746},
WindowMargins->{{Automatic, 16}, {Automatic, 0}},
FrontEndVersion->"11.0 for Mac OS X x86 (32-bit, 64-bit Kernel) (September \
21, 2016)",
StyleDefinitions->"Default.nb",
MacintoshSystemPageSetup -> \
"00<0001804P000000]P2:?oQon82n@960dL5:0?l0080001804P000000]P2:001\n\
0000I00000400`<300000BL?00400@0000000000000006P801T1T00000000000\n\
00000000000000000000000000000000"
]
(* End of Notebook Content *)

(* Internal cache information *)
(*CellTagsOutline
CellTagsIndex->{}
*)
(*CellTagsIndex
CellTagsIndex->{}
*)
(*NotebookFileOutline
Notebook[{
Cell[557, 20, 3023, 93, 1512, "Text"],
Cell[CellGroupData[{
Cell[3605, 117, 113, 1, 64, "Section"],
Cell[CellGroupData[{
Cell[3743, 122, 99, 1, 44, "Subsection"],
Cell[3845, 125, 273, 5, 32, "Input"],
Cell[4121, 132, 1387, 37, 159, "Input"],
Cell[5511, 171, 295, 6, 54, "Input"],
Cell[5809, 179, 562, 15, 54, "Input"],
Cell[6374, 196, 2839, 75, 264, "Input"],
Cell[9216, 273, 347, 10, 32, "Input"],
Cell[9566, 285, 282, 7, 32, "Input"],
Cell[9851, 294, 235, 5, 32, "Input"],
Cell[10089, 301, 345, 10, 32, "Input"],
Cell[CellGroupData[{
Cell[10459, 315, 125, 2, 32, "Input"],
Cell[10587, 319, 6603, 227, 605, "Output"]
}, Open  ]],
Cell[17205, 549, 356, 10, 54, "Input"],
Cell[17564, 561, 487, 10, 75, "Input"],
Cell[18054, 573, 493, 14, 32, "Input"],
Cell[18550, 589, 247, 5, 32, "Input"],
Cell[18800, 596, 218, 5, 32, "Input"],
Cell[19021, 603, 235, 5, 32, "Input"],
Cell[CellGroupData[{
Cell[19281, 612, 324, 9, 32, "Input"],
Cell[19608, 623, 96, 1, 32, "Output"]
}, Open  ]]
}, Closed]],
Cell[CellGroupData[{
Cell[19753, 630, 92, 1, 36, "Subsection"],
Cell[CellGroupData[{
Cell[19870, 635, 243, 5, 32, "Input"],
Cell[20116, 642, 70, 1, 32, "Output"]
}, Open  ]]
}, Closed]],
Cell[CellGroupData[{
Cell[20235, 649, 92, 1, 36, "Subsection"],
Cell[20330, 652, 398, 9, 54, "Input"],
Cell[CellGroupData[{
Cell[20753, 665, 370, 8, 32, "Input"],
Cell[21126, 675, 227, 5, 48, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[21390, 685, 373, 8, 32, "Input"],
Cell[21766, 695, 201, 5, 48, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[22004, 705, 375, 8, 32, "Input"],
Cell[22382, 715, 340, 11, 55, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[22759, 731, 374, 8, 32, "Input"],
Cell[23136, 741, 187, 4, 44, "Output"]
}, Open  ]]
}, Closed]],
Cell[CellGroupData[{
Cell[23372, 751, 90, 1, 36, "Subsection"],
Cell[23465, 754, 240, 5, 32, "Input"],
Cell[CellGroupData[{
Cell[23730, 763, 327, 7, 32, "Input"],
Cell[24060, 772, 155, 4, 55, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[24252, 781, 369, 8, 32, "Input"],
Cell[24624, 791, 158, 4, 48, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[24819, 800, 377, 8, 32, "Input"],
Cell[25199, 810, 242, 8, 55, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[25478, 823, 403, 9, 32, "Input"],
Cell[25884, 834, 144, 2, 32, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[26065, 841, 375, 8, 32, "Input"],
Cell[26443, 851, 178, 4, 48, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[26658, 860, 402, 9, 32, "Input"],
Cell[27063, 871, 172, 2, 32, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[27272, 878, 376, 8, 32, "Input"],
Cell[27651, 888, 317, 9, 55, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[28005, 902, 455, 10, 32, "Input"],
Cell[28463, 914, 244, 3, 32, "Output"]
}, Open  ]],
Cell[28722, 920, 247, 5, 32, "Input"],
Cell[CellGroupData[{
Cell[28994, 929, 491, 15, 32, "Input"],
Cell[29488, 946, 98, 1, 32, "Output"]
}, Open  ]]
}, Closed]],
Cell[CellGroupData[{
Cell[29635, 953, 90, 1, 36, "Subsection"],
Cell[29728, 956, 241, 5, 32, "Input"],
Cell[CellGroupData[{
Cell[29994, 965, 520, 13, 54, "Input"],
Cell[30517, 980, 200, 5, 69, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[30754, 990, 571, 14, 54, "Input"],
Cell[31328, 1006, 190, 3, 44, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[31555, 1014, 446, 10, 32, "Input"],
Cell[32004, 1026, 319, 9, 45, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[32360, 1040, 490, 10, 32, "Input"],
Cell[32853, 1052, 242, 4, 44, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[33132, 1061, 732, 15, 54, "Input"],
Cell[33867, 1078, 326, 6, 48, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[34230, 1089, 560, 11, 54, "Input"],
Cell[34793, 1102, 270, 4, 32, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[35100, 1111, 539, 11, 32, "Input"],
Cell[35642, 1124, 413, 11, 55, "Output"]
}, Open  ]],
Cell[36070, 1138, 247, 5, 32, "Input"],
Cell[CellGroupData[{
Cell[36342, 1147, 490, 15, 32, "Input"],
Cell[36835, 1164, 70, 1, 32, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[36942, 1170, 407, 12, 32, "Input"],
Cell[37352, 1184, 126, 2, 32, "Output"]
}, Open  ]]
}, Closed]],
Cell[CellGroupData[{
Cell[37527, 1192, 89, 1, 36, "Subsection"],
Cell[37619, 1195, 174, 3, 32, "Input"],
Cell[CellGroupData[{
Cell[37818, 1202, 456, 10, 32, "Input"],
Cell[38277, 1214, 230, 5, 55, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[38544, 1224, 408, 9, 32, "Input"],
Cell[38955, 1235, 151, 4, 48, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[39143, 1244, 350, 8, 32, "Input"],
Cell[39496, 1254, 122, 2, 32, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[39655, 1261, 350, 8, 32, "Input"],
Cell[40008, 1271, 148, 2, 32, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[40193, 1278, 440, 11, 54, "Input"],
Cell[40636, 1291, 230, 5, 48, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[40903, 1301, 450, 10, 32, "Input"],
Cell[41356, 1313, 246, 3, 32, "Output"]
}, Open  ]]
}, Closed]],
Cell[CellGroupData[{
Cell[41651, 1322, 105, 1, 36, "Subsection"],
Cell[41759, 1325, 195, 4, 32, "Input"],
Cell[41957, 1331, 178, 4, 32, "Input"],
Cell[42138, 1337, 314, 9, 32, "Input"],
Cell[42455, 1348, 207, 5, 32, "Input"],
Cell[42665, 1355, 314, 7, 32, "Input"],
Cell[42982, 1364, 223, 6, 32, "Input"],
Cell[43208, 1372, 270, 6, 32, "Input"],
Cell[43481, 1380, 194, 4, 32, "Input"],
Cell[CellGroupData[{
Cell[43700, 1388, 465, 13, 54, "Input"],
Cell[44168, 1403, 159, 3, 32, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[44364, 1411, 465, 13, 54, "Input"],
Cell[44832, 1426, 184, 4, 32, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[45053, 1435, 515, 14, 54, "Input"],
Cell[45571, 1451, 182, 4, 32, "Output"]
}, Open  ]],
Cell[45768, 1458, 178, 3, 32, "Input"],
Cell[CellGroupData[{
Cell[45971, 1465, 330, 8, 32, "Input"],
Cell[46304, 1475, 122, 2, 32, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[46463, 1482, 328, 8, 32, "Input"],
Cell[46794, 1492, 94, 1, 32, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[46925, 1498, 383, 9, 32, "Input"],
Cell[47311, 1509, 144, 2, 32, "Output"]
}, Open  ]],
Cell[47470, 1514, 159, 3, 32, "Input"],
Cell[CellGroupData[{
Cell[47654, 1521, 193, 4, 32, "Input"],
Cell[47850, 1527, 92, 1, 32, "Output"]
}, Open  ]]
}, Closed]]
}, Closed]],
Cell[CellGroupData[{
Cell[48003, 1535, 104, 1, 50, "Section"],
Cell[CellGroupData[{
Cell[48132, 1540, 95, 1, 44, "Subsection"],
Cell[48230, 1543, 347, 9, 32, "Input"],
Cell[48580, 1554, 1972, 55, 159, "Input"],
Cell[50555, 1611, 234, 5, 32, "Input"],
Cell[50792, 1618, 718, 20, 96, "Input"],
Cell[51513, 1640, 884, 24, 117, "Input"],
Cell[52400, 1666, 340, 7, 32, "Input"]
}, Closed]],
Cell[CellGroupData[{
Cell[52777, 1678, 176, 2, 36, "Subsection"],
Cell[52956, 1682, 193, 4, 32, "Input"],
Cell[53152, 1688, 664, 19, 75, "Input"],
Cell[53819, 1709, 896, 17, 96, "Input"],
Cell[54718, 1728, 1169, 31, 138, "Input"],
Cell[55890, 1761, 246, 6, 32, "Input"],
Cell[56139, 1769, 1049, 26, 138, "Input"],
Cell[57191, 1797, 195, 4, 32, "Input"],
Cell[57389, 1803, 812, 19, 96, "Input"],
Cell[58204, 1824, 833, 20, 96, "Input"],
Cell[59040, 1846, 1162, 27, 138, "Input"],
Cell[60205, 1875, 166, 3, 32, "Input"],
Cell[60374, 1880, 1046, 26, 117, "Input"]
}, Closed]],
Cell[CellGroupData[{
Cell[61457, 1911, 267, 5, 61, "Subsection"],
Cell[61727, 1918, 689, 16, 75, "Input"],
Cell[62419, 1936, 1002, 27, 75, "Input"],
Cell[63424, 1965, 340, 7, 32, "Input"],
Cell[63767, 1974, 240, 5, 32, "Input"],
Cell[64010, 1981, 334, 8, 54, "Input"],
Cell[64347, 1991, 462, 14, 32, "Input"],
Cell[64812, 2007, 241, 5, 32, "Input"],
Cell[65056, 2014, 361, 9, 54, "Input"],
Cell[65420, 2025, 411, 10, 54, "Input"],
Cell[65834, 2037, 916, 25, 96, "Input"],
Cell[66753, 2064, 238, 5, 32, "Input"],
Cell[66994, 2071, 163, 3, 32, "Input"],
Cell[67160, 2076, 774, 23, 75, "Input"]
}, Closed]],
Cell[CellGroupData[{
Cell[67971, 2104, 99, 1, 36, "Subsection"],
Cell[68073, 2107, 591, 14, 75, "Input"],
Cell[68667, 2123, 2248, 59, 138, "Input"]
}, Closed]],
Cell[CellGroupData[{
Cell[70952, 2187, 190, 2, 36, "Subsection"],
Cell[71145, 2191, 254, 5, 32, "Input"],
Cell[71402, 2198, 246, 6, 32, "Input"],
Cell[71651, 2206, 2567, 66, 159, "Input"],
Cell[74221, 2274, 249, 6, 32, "Input"],
Cell[74473, 2282, 278, 6, 32, "Input"]
}, Closed]],
Cell[CellGroupData[{
Cell[74788, 2293, 111, 1, 36, "Subsection"],
Cell[74902, 2296, 344, 8, 54, "Input"],
Cell[75249, 2306, 11759, 353, 558, "Input"],
Cell[87011, 2661, 447, 11, 54, "Input"],
Cell[87461, 2674, 229, 5, 32, "Input"]
}, Closed]]
}, Closed]]
}
]
*)

