(* Content-type: application/vnd.wolfram.mathematica *)

(*** Wolfram Notebook File ***)
(* http://www.wolfram.com/nb *)

(* CreatedBy='Mathematica 9.0' *)

(*CacheID: 234*)
(* Internal cache information:
NotebookFileLineBreakTest
NotebookFileLineBreakTest
NotebookDataPosition[       157,          7]
NotebookDataLength[     18497,        650]
NotebookOptionsPosition[     16057,        576]
NotebookOutlinePosition[     16416,        592]
CellTagsIndexPosition[     16373,        589]
WindowFrame->Normal*)

(* Beginning of Notebook Content *)
Notebook[{
Cell["\<\
Side Counts for Regular Polytopes, done with generating functions.

For number of space dimensions dim, the generating function with generating \
variable t has the form
1 + t^(dim+1) + sum for k = 1 to dim of (number of (k-1)-dimensional \
sides/faces) * t^k

The function here is genf, and its args are
t (generating variable)
dim (number of space dimensions)
(optional) (number of (dim-1) faces or family name)

For t = -1, genf = 0 (Euler\[CloseCurlyQuote]s theorem)

0 = point, 1 = line, 2 = regular polygon

The regular polygons have two additional arguments, \
\[OpenCurlyDoubleQuote]pgn\[CloseCurlyDoubleQuote] and the number of sides

The five 3D regular polyhedra (polyhedron) and the six 4D regular polychora \
(polychoron) are denoted by their numbers of (2D) faces or (3D) cells.

All the polytopes in more than 4 space dimensions fall into these three \
infinite families.
\[OpenCurlyDoubleQuote]spx\[CloseCurlyDoubleQuote] - simplex
\[OpenCurlyDoubleQuote]hpc\[CloseCurlyDoubleQuote] -- hypercube
\[OpenCurlyDoubleQuote]csp\[CloseCurlyDoubleQuote] -- cross polytope

These reduce to points (0D), lines (1D), two of the polygons (2D), and three \
each of the polyhedra (3D) and polychora (4D).\
\>", "Text"],

Cell[CellGroupData[{

Cell["Generating-Function Definitions", "Section"],

Cell[BoxData[
 RowBox[{
  RowBox[{"genf", "[", 
   RowBox[{"t_", ",", "0"}], "]"}], " ", ":=", " ", 
  RowBox[{"1", " ", "+", " ", "t"}]}]], "Input"],

Cell[BoxData[
 RowBox[{
  RowBox[{"genf", "[", 
   RowBox[{"t_", ",", "1"}], "]"}], " ", ":=", " ", 
  RowBox[{"1", " ", "+", " ", 
   RowBox[{"2", "t"}], " ", "+", " ", 
   RowBox[{"t", "^", "2"}]}]}]], "Input"],

Cell[BoxData[
 RowBox[{
  RowBox[{"genf", "[", 
   RowBox[{"t_", ",", "2", ",", "\"\<pgn\>\"", ",", "n_"}], "]"}], " ", ":=", 
  " ", 
  RowBox[{"1", " ", "+", " ", 
   RowBox[{"n", "*", "t"}], " ", "+", " ", 
   RowBox[{"n", "*", 
    RowBox[{"t", "^", "2"}]}], " ", "+", " ", 
   RowBox[{"t", "^", "3"}]}]}]], "Input"],

Cell[BoxData[
 RowBox[{
  RowBox[{"genf", "[", 
   RowBox[{"t_", ",", "3", ",", "4"}], "]"}], " ", " ", ":=", " ", 
  RowBox[{"1", "+", 
   RowBox[{"4", "t"}], "+", 
   RowBox[{"6", 
    RowBox[{"t", "^", "2"}]}], "+", 
   RowBox[{"4", 
    RowBox[{"t", "^", "3"}]}], "+", 
   RowBox[{"t", "^", "4"}]}]}]], "Input"],

Cell[BoxData[
 RowBox[{
  RowBox[{"genf", "[", 
   RowBox[{"t_", ",", "3", ",", "6"}], "]"}], "  ", ":=", " ", 
  RowBox[{"1", "+", 
   RowBox[{"8", "t"}], "+", 
   RowBox[{"12", 
    RowBox[{"t", "^", "2"}]}], "+", 
   RowBox[{"6", 
    RowBox[{"t", "^", "3"}]}], "+", 
   RowBox[{"t", "^", "4"}]}]}]], "Input"],

Cell[BoxData[
 RowBox[{
  RowBox[{"genf", "[", 
   RowBox[{"t_", ",", "3", ",", "8"}], "]"}], "  ", ":=", " ", 
  RowBox[{"1", "+", 
   RowBox[{"6", "t"}], "+", 
   RowBox[{"12", 
    RowBox[{"t", "^", "2"}]}], "+", 
   RowBox[{"8", 
    RowBox[{"t", "^", "3"}]}], "+", 
   RowBox[{"t", "^", "4"}]}]}]], "Input"],

Cell[BoxData[
 RowBox[{
  RowBox[{"genf", "[", 
   RowBox[{"t_", ",", "3", ",", "12"}], "]"}], "  ", ":=", " ", 
  RowBox[{"1", "+", 
   RowBox[{"20", "t"}], "+", 
   RowBox[{"30", 
    RowBox[{"t", "^", "2"}]}], "+", 
   RowBox[{"12", 
    RowBox[{"t", "^", "3"}]}], "+", 
   RowBox[{"t", "^", "4"}]}]}]], "Input"],

Cell[BoxData[
 RowBox[{
  RowBox[{"genf", "[", 
   RowBox[{"t_", ",", "3", ",", "20"}], "]"}], "  ", ":=", " ", 
  RowBox[{"1", "+", 
   RowBox[{"12", "t"}], "+", 
   RowBox[{"30", 
    RowBox[{"t", "^", "2"}]}], "+", 
   RowBox[{"20", 
    RowBox[{"t", "^", "3"}]}], "+", 
   RowBox[{"t", "^", "4"}]}]}]], "Input"],

Cell[BoxData[
 RowBox[{
  RowBox[{"genf", "[", 
   RowBox[{"t_", ",", "4", ",", "5"}], "]"}], " ", ":=", " ", 
  RowBox[{"1", "+", 
   RowBox[{"5", "t"}], "+", 
   RowBox[{"10", 
    RowBox[{"t", "^", "2"}]}], "+", 
   RowBox[{"10", 
    RowBox[{"t", "^", "3"}]}], "+", 
   RowBox[{"5", 
    RowBox[{"t", "^", "4"}]}], "+", 
   RowBox[{"t", "^", "5"}]}]}]], "Input"],

Cell[BoxData[
 RowBox[{
  RowBox[{"genf", "[", 
   RowBox[{"t_", ",", "4", ",", "8"}], "]"}], " ", ":=", " ", 
  RowBox[{"1", "+", 
   RowBox[{"16", "t"}], "+", 
   RowBox[{"32", 
    RowBox[{"t", "^", "2"}]}], "+", 
   RowBox[{"24", 
    RowBox[{"t", "^", "3"}]}], "+", 
   RowBox[{"8", 
    RowBox[{"t", "^", "4"}]}], "+", 
   RowBox[{"t", "^", "5"}]}]}]], "Input"],

Cell[BoxData[
 RowBox[{
  RowBox[{"genf", "[", 
   RowBox[{"t_", ",", "4", ",", "16"}], "]"}], " ", ":=", " ", 
  RowBox[{"1", "+", 
   RowBox[{"8", "t"}], "+", 
   RowBox[{"24", 
    RowBox[{"t", "^", "2"}]}], "+", 
   RowBox[{"32", 
    RowBox[{"t", "^", "3"}]}], "+", 
   RowBox[{"16", 
    RowBox[{"t", "^", "4"}]}], "+", 
   RowBox[{"t", "^", "5"}]}]}]], "Input"],

Cell[BoxData[
 RowBox[{
  RowBox[{"genf", "[", 
   RowBox[{"t_", ",", "4", ",", "24"}], "]"}], " ", ":=", " ", 
  RowBox[{"1", "+", 
   RowBox[{"24", "t"}], "+", 
   RowBox[{"96", 
    RowBox[{"t", "^", "2"}]}], "+", 
   RowBox[{"96", 
    RowBox[{"t", "^", "3"}]}], "+", 
   RowBox[{"24", 
    RowBox[{"t", "^", "4"}]}], "+", 
   RowBox[{"t", "^", "5"}]}]}]], "Input"],

Cell[BoxData[
 RowBox[{
  RowBox[{"genf", "[", 
   RowBox[{"t_", ",", "4", ",", "120"}], "]"}], " ", ":=", 
  RowBox[{"1", "+", 
   RowBox[{"600", "t"}], "+", 
   RowBox[{"1200", 
    RowBox[{"t", "^", "2"}]}], "+", 
   RowBox[{"720", 
    RowBox[{"t", "^", "3"}]}], "+", 
   RowBox[{"120", 
    RowBox[{"t", "^", "4"}]}], "+", 
   RowBox[{"t", "^", "5"}]}]}]], "Input"],

Cell[BoxData[
 RowBox[{
  RowBox[{"genf", "[", 
   RowBox[{"t_", ",", "4", ",", "600"}], "]"}], " ", ":=", 
  RowBox[{"1", "+", 
   RowBox[{"120", "t"}], "+", 
   RowBox[{"720", 
    RowBox[{"t", "^", "2"}]}], "+", 
   RowBox[{"1200", 
    RowBox[{"t", "^", "3"}]}], "+", 
   RowBox[{"600", 
    RowBox[{"t", "^", "4"}]}], "+", 
   RowBox[{"t", "^", "5"}]}]}]], "Input"],

Cell[BoxData[
 RowBox[{
  RowBox[{"genf", "[", 
   RowBox[{"t_", ",", "n_", ",", "\"\<spx\>\""}], "]"}], " ", ":=", " ", 
  RowBox[{
   RowBox[{"(", 
    RowBox[{"1", " ", "+", " ", "t"}], ")"}], "^", 
   RowBox[{"(", 
    RowBox[{"n", " ", "+", " ", "1"}], ")"}]}]}]], "Input"],

Cell[BoxData[
 RowBox[{
  RowBox[{"genf", "[", 
   RowBox[{"t_", ",", "n_", ",", "\"\<hpc\>\""}], "]"}], " ", ":=", " ", 
  RowBox[{"1", " ", "+", " ", 
   RowBox[{"t", "*", 
    RowBox[{
     RowBox[{"(", 
      RowBox[{"t", " ", "+", " ", "2"}], ")"}], "^", "n"}]}]}]}]], "Input"],

Cell[BoxData[
 RowBox[{
  RowBox[{"genf", "[", 
   RowBox[{"t_", ",", "n_", ",", "\"\<csp\>\""}], "]"}], " ", ":=", " ", 
  RowBox[{
   RowBox[{
    RowBox[{"(", 
     RowBox[{"1", " ", "+", " ", 
      RowBox[{"2", "t"}]}], ")"}], "^", "n"}], " ", "+", " ", 
   RowBox[{"t", "^", 
    RowBox[{"(", 
     RowBox[{"n", " ", "+", " ", "1"}], ")"}]}]}]}]], "Input"]
}, Closed]],

Cell[CellGroupData[{

Cell["Duals", "Section"],

Cell[BoxData[
 RowBox[{
  RowBox[{"dual", "[", 
   RowBox[{"t_", ",", "dim_", ",", "f_"}], "]"}], " ", ":=", " ", 
  RowBox[{
   RowBox[{"t", "^", 
    RowBox[{"(", 
     RowBox[{"dim", "+", "1"}], ")"}]}], "*", 
   RowBox[{"f", "[", 
    RowBox[{"1", "/", "t"}], "]"}]}]}]], "Input"],

Cell[BoxData[
 RowBox[{"(*", " ", 
  RowBox[{
  "The", " ", "dual", " ", "of", " ", "the", " ", "dual", " ", "of", " ", "a",
    " ", "function", " ", "is", " ", "itself"}], " ", "*)"}]], "Input"],

Cell[BoxData[
 RowBox[{"Refine", "[", 
  RowBox[{
   RowBox[{"dual", "[", 
    RowBox[{"t", ",", "dim", ",", 
     RowBox[{
      RowBox[{"dual", "[", 
       RowBox[{"#", ",", "dim", ",", "f"}], "]"}], "&"}]}], "]"}], ",", 
   RowBox[{"t", ">", "0"}]}], "]"}]], "Input"],

Cell[BoxData[
 RowBox[{"(*", " ", 
  RowBox[{"Dual", " ", "of", " ", "the", " ", "generating", " ", "function"}],
   " ", "*)"}]], "Input"],

Cell[BoxData[
 RowBox[{
  RowBox[{"genfdual", "[", 
   RowBox[{"t_", ",", "dim_", ",", "args___"}], "]"}], " ", ":=", " ", 
  RowBox[{"dual", "[", 
   RowBox[{"t", ",", "dim", ",", 
    RowBox[{
     RowBox[{"genf", "[", 
      RowBox[{"#", ",", "dim", ",", "args"}], "]"}], "&"}]}], 
   "]"}]}]], "Input"],

Cell[BoxData[
 RowBox[{"(*", " ", 
  RowBox[{
   RowBox[{"Self", "-", 
    RowBox[{"dual", " ", "for", " ", "dimensions", " ", "0"}]}], ",", " ", 
   "1", ",", " ", "2"}], " ", "*)"}]], "Input"],

Cell[BoxData[
 RowBox[{
  RowBox[{"isgenfselfdual", "[", 
   RowBox[{"t_", ",", "dim_", ",", "args___"}], "]"}], " ", ":=", " ", 
  RowBox[{
   RowBox[{"genfdual", "[", 
    RowBox[{"t", ",", "dim", ",", "args"}], "]"}], " ", "-", " ", 
   RowBox[{"genf", "[", 
    RowBox[{"t", ",", "dim", ",", "args"}], "]"}]}]}]], "Input"],

Cell[BoxData[
 RowBox[{"Table", "[", 
  RowBox[{
   RowBox[{"Expand", "[", 
    RowBox[{"isgenfselfdual", "[", 
     RowBox[{"t", ",", "dim"}], "]"}], "]"}], ",", 
   RowBox[{"{", 
    RowBox[{"dim", ",", "0", ",", "1"}], "}"}]}], "]"}]], "Input"],

Cell[BoxData[
 RowBox[{"Expand", "[", 
  RowBox[{"isgenfselfdual", "[", 
   RowBox[{"t", ",", "2", ",", "\"\<pgn\>\"", ",", "n"}], "]"}], 
  "]"}]], "Input"],

Cell[BoxData[
 RowBox[{"(*", " ", 
  RowBox[{
   RowBox[{"Duality", " ", "for", " ", "dimensions", " ", "3"}], ",", " ", 
   "4", ",", " ", 
   RowBox[{"and", " ", "general"}]}], " ", "*)"}]], "Input"],

Cell[BoxData[
 RowBox[{
  RowBox[{"nfcd3", " ", "=", " ", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"4", ",", "6", ",", "8", ",", "12", ",", "20"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"4", ",", "8", ",", "6", ",", "20", ",", "12"}], "}"}]}], 
    "}"}]}], ";"}]], "Input"],

Cell[BoxData[
 RowBox[{
  RowBox[{"nfcd4", " ", "=", " ", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"5", ",", "8", ",", "16", ",", "24", ",", "120", ",", "600"}], 
      "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"5", ",", "16", ",", "8", ",", "24", ",", "600", ",", "120"}], 
      "}"}]}], "}"}]}], ";"}]], "Input"],

Cell[BoxData[
 RowBox[{
  RowBox[{"nfcdx", " ", "=", " ", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"\"\<spx\>\"", ",", "\"\<hpc\>\"", ",", "\"\<csp\>\""}], "}"}], 
     ",", 
     RowBox[{"{", 
      RowBox[{"\"\<spx\>\"", ",", "\"\<csp\>\"", ",", "\"\<hpc\>\""}], 
      "}"}]}], "}"}]}], ";"}]], "Input"],

Cell[BoxData[
 RowBox[{"TableForm", "[", "nfcd3", "]"}]], "Input"],

Cell[BoxData[
 RowBox[{"TableForm", "[", "nfcd4", "]"}]], "Input"],

Cell[BoxData[
 RowBox[{"TableForm", "[", "nfcdx", "]"}]], "Input"],

Cell[BoxData[
 RowBox[{
  RowBox[{"isgenfpairdual", "[", 
   RowBox[{"t_", ",", "dim_", ",", "tpair_"}], "]"}], " ", ":=", " ", 
  RowBox[{
   RowBox[{"genfdual", "[", 
    RowBox[{"t", ",", "dim", ",", 
     RowBox[{"tpair", "[", 
      RowBox[{"[", "1", "]"}], "]"}]}], "]"}], " ", "-", " ", 
   RowBox[{"genf", "[", 
    RowBox[{"t", ",", "dim", ",", 
     RowBox[{"tpair", "[", 
      RowBox[{"[", "2", "]"}], "]"}]}], "]"}]}]}]], "Input"],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{
    RowBox[{"isgenfpairdual", "[", 
     RowBox[{"t", ",", "3", ",", "#"}], "]"}], "&"}], " ", "/@", " ", 
   RowBox[{"Transpose", "[", "nfcd3", "]"}]}], " ", "//", " ", 
  "Expand"}]], "Input"],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{
    RowBox[{"isgenfpairdual", "[", 
     RowBox[{"t", ",", "4", ",", "#"}], "]"}], "&"}], " ", "/@", " ", 
   RowBox[{"Transpose", "[", "nfcd4", "]"}]}], " ", "//", " ", 
  "Expand"}]], "Input"],

Cell[BoxData[
 RowBox[{
  RowBox[{"(", 
   RowBox[{
    RowBox[{
     RowBox[{
      RowBox[{
       RowBox[{"isgenfpairdual", "[", 
        RowBox[{"t", ",", "dim", ",", "#"}], "]"}], "&"}], "/@", " ", 
      RowBox[{"Transpose", "[", "nfcdx", "]"}]}], " ", "//", " ", 
     RowBox[{
      RowBox[{"MapAll", "[", 
       RowBox[{"Factor", ",", "#"}], "]"}], "&"}]}], " ", "//", " ", 
    "Expand"}], ")"}], " ", "//.", " ", 
  RowBox[{"{", 
   RowBox[{
    RowBox[{
     RowBox[{
      RowBox[{"(", 
       RowBox[{"x_", "^", "a_"}], ")"}], "^", "b_"}], "\[Rule]", 
     RowBox[{"x", "^", 
      RowBox[{"(", 
       RowBox[{"a", "*", "b"}], ")"}]}]}], ",", 
    RowBox[{
     RowBox[{
      RowBox[{"(", 
       RowBox[{"x_", "*", "y_"}], ")"}], "^", "a_"}], "\[Rule]", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{"x", "^", "a"}], ")"}], "*", 
      RowBox[{"(", 
       RowBox[{"y", "^", "a"}], ")"}]}]}]}], "}"}]}]], "Input"]
}, Closed]],

Cell[CellGroupData[{

Cell["Special Cases of the General Families", "Section"],

Cell[BoxData[
 RowBox[{"(*", " ", 
  RowBox[{"Points", " ", "and", " ", "lines"}], " ", "*)"}]], "Input"],

Cell[BoxData[
 RowBox[{
  RowBox[{"Table", "[", 
   RowBox[{
    RowBox[{
     RowBox[{"genf", "[", 
      RowBox[{"t", ",", "dim", ",", "fam"}], "]"}], " ", "-", " ", 
     RowBox[{"genf", "[", 
      RowBox[{"t", ",", "dim"}], "]"}]}], ",", 
    RowBox[{"{", 
     RowBox[{"fam", ",", 
      RowBox[{"{", 
       RowBox[{"\"\<spx\>\"", ",", "\"\<hpc\>\"", ",", "\"\<csp\>\""}], 
       "}"}]}], "}"}], ",", 
    RowBox[{"{", 
     RowBox[{"dim", ",", "0", ",", "1"}], "}"}]}], "]"}], " ", "//", " ", 
  "Expand"}]], "Input"],

Cell[BoxData[
 RowBox[{"(*", " ", 
  RowBox[{"2", "D"}], " ", "*)"}]], "Input"],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"genf", "[", 
    RowBox[{"t", ",", "2", ",", "\"\<spx\>\""}], "]"}], " ", "-", " ", 
   RowBox[{"genf", "[", 
    RowBox[{"t", ",", "2", ",", "\"\<pgn\>\"", ",", "3"}], "]"}]}], " ", "//",
   " ", "Expand"}]], "Input"],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"genf", "[", 
    RowBox[{"t", ",", "2", ",", "\"\<hpc\>\""}], "]"}], " ", "-", " ", 
   RowBox[{"genf", "[", 
    RowBox[{"t", ",", "2", ",", "\"\<pgn\>\"", ",", "4"}], "]"}]}], " ", "//",
   " ", "Expand"}]], "Input"],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"genf", "[", 
    RowBox[{"t", ",", "2", ",", "\"\<csp\>\""}], "]"}], " ", "-", " ", 
   RowBox[{"genf", "[", 
    RowBox[{"t", ",", "2", ",", "\"\<pgn\>\"", ",", "4"}], "]"}]}], " ", "//",
   " ", "Expand"}]], "Input"],

Cell[BoxData[
 RowBox[{"(*", " ", 
  RowBox[{"3", "D"}], " ", "*)"}]], "Input"],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"genf", "[", 
    RowBox[{"t", ",", "3", ",", "\"\<spx\>\""}], "]"}], " ", "-", " ", 
   RowBox[{"genf", "[", 
    RowBox[{"t", ",", "3", ",", "4"}], "]"}]}], " ", "//", " ", 
  "Expand"}]], "Input"],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"genf", "[", 
    RowBox[{"t", ",", "3", ",", "\"\<hpc\>\""}], "]"}], " ", "-", " ", 
   RowBox[{"genf", "[", 
    RowBox[{"t", ",", "3", ",", "6"}], "]"}]}], " ", "//", " ", 
  "Expand"}]], "Input"],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"genf", "[", 
    RowBox[{"t", ",", "3", ",", "\"\<csp\>\""}], "]"}], " ", "-", " ", 
   RowBox[{"genf", "[", 
    RowBox[{"t", ",", "3", ",", "8"}], "]"}]}], " ", "//", " ", 
  "Expand"}]], "Input"],

Cell[BoxData[
 RowBox[{"(*", " ", 
  RowBox[{"4", "D"}], " ", "*)"}]], "Input"],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"genf", "[", 
    RowBox[{"t", ",", "4", ",", "\"\<spx\>\""}], "]"}], " ", "-", " ", 
   RowBox[{"genf", "[", 
    RowBox[{"t", ",", "4", ",", "5"}], "]"}]}], " ", "//", " ", 
  "Expand"}]], "Input"],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"genf", "[", 
    RowBox[{"t", ",", "4", ",", "\"\<hpc\>\""}], "]"}], " ", "-", " ", 
   RowBox[{"genf", "[", 
    RowBox[{"t", ",", "4", ",", "8"}], "]"}]}], " ", "//", " ", 
  "Expand"}]], "Input"],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"genf", "[", 
    RowBox[{"t", ",", "4", ",", "\"\<csp\>\""}], "]"}], " ", "-", " ", 
   RowBox[{"genf", "[", 
    RowBox[{"t", ",", "4", ",", "16"}], "]"}]}], " ", "//", " ", 
  "Expand"}]], "Input"]
}, Closed]]
},
WindowSize->{743, 748},
WindowMargins->{{Automatic, 106}, {Automatic, 0}},
FrontEndVersion->"11.0 for Mac OS X x86 (32-bit, 64-bit Kernel) (September \
21, 2016)",
StyleDefinitions->"Default.nb"
]
(* End of Notebook Content *)

(* Internal cache information *)
(*CellTagsOutline
CellTagsIndex->{}
*)
(*CellTagsIndex
CellTagsIndex->{}
*)
(*NotebookFileOutline
Notebook[{
Cell[557, 20, 1231, 31, 505, "Text"],
Cell[CellGroupData[{
Cell[1813, 55, 50, 0, 64, "Section"],
Cell[1866, 57, 149, 4, 32, "Input"],
Cell[2018, 63, 212, 6, 32, "Input"],
Cell[2233, 71, 320, 9, 32, "Input"],
Cell[2556, 82, 315, 10, 32, "Input"],
Cell[2874, 94, 312, 10, 32, "Input"],
Cell[3189, 106, 312, 10, 32, "Input"],
Cell[3504, 118, 315, 10, 32, "Input"],
Cell[3822, 130, 315, 10, 32, "Input"],
Cell[4140, 142, 366, 12, 32, "Input"],
Cell[4509, 156, 367, 12, 32, "Input"],
Cell[4879, 170, 368, 12, 32, "Input"],
Cell[5250, 184, 369, 12, 32, "Input"],
Cell[5622, 198, 370, 12, 32, "Input"],
Cell[5995, 212, 370, 12, 32, "Input"],
Cell[6368, 226, 278, 8, 32, "Input"],
Cell[6649, 236, 282, 8, 32, "Input"],
Cell[6934, 246, 362, 11, 32, "Input"]
}, Closed]],
Cell[CellGroupData[{
Cell[7333, 262, 24, 0, 50, "Section"],
Cell[7360, 264, 284, 9, 32, "Input"],
Cell[7647, 275, 196, 4, 32, "Input"],
Cell[7846, 281, 271, 8, 32, "Input"],
Cell[8120, 291, 139, 3, 32, "Input"],
Cell[8262, 296, 306, 9, 32, "Input"],
Cell[8571, 307, 194, 5, 32, "Input"],
Cell[8768, 314, 326, 8, 32, "Input"],
Cell[9097, 324, 247, 7, 32, "Input"],
Cell[9347, 333, 157, 4, 32, "Input"],
Cell[9507, 339, 201, 5, 32, "Input"],
Cell[9711, 346, 305, 9, 32, "Input"],
Cell[10019, 357, 342, 10, 32, "Input"],
Cell[10364, 369, 329, 10, 32, "Input"],
Cell[10696, 381, 66, 1, 32, "Input"],
Cell[10765, 384, 66, 1, 32, "Input"],
Cell[10834, 387, 66, 1, 32, "Input"],
Cell[10903, 390, 443, 12, 54, "Input"],
Cell[11349, 404, 241, 7, 32, "Input"],
Cell[11593, 413, 241, 7, 32, "Input"],
Cell[11837, 422, 935, 31, 54, "Input"]
}, Closed]],
Cell[CellGroupData[{
Cell[12809, 458, 56, 0, 50, "Section"],
Cell[12868, 460, 105, 2, 32, "Input"],
Cell[12976, 464, 526, 16, 54, "Input"],
Cell[13505, 482, 79, 2, 32, "Input"],
Cell[13587, 486, 265, 7, 32, "Input"],
Cell[13855, 495, 265, 7, 32, "Input"],
Cell[14123, 504, 265, 7, 32, "Input"],
Cell[14391, 513, 79, 2, 32, "Input"],
Cell[14473, 517, 245, 7, 32, "Input"],
Cell[14721, 526, 245, 7, 32, "Input"],
Cell[14969, 535, 245, 7, 32, "Input"],
Cell[15217, 544, 79, 2, 32, "Input"],
Cell[15299, 548, 245, 7, 32, "Input"],
Cell[15547, 557, 245, 7, 32, "Input"],
Cell[15795, 566, 246, 7, 32, "Input"]
}, Closed]]
}
]
*)

