(*CacheID: 234*)
(* Internal cache information:
NotebookFileLineBreakTest
NotebookFileLineBreakTest
NotebookDataPosition[         0,          0]
NotebookDataLength[    206025,       5716]
NotebookOptionsPosition[    178077,       5374]
NotebookOutlinePosition[    178450,       5391]
CellTagsIndexPosition[    178407,       5388]
WindowFrame->Normal*)

(* Beginning of Notebook Content *)
Notebook[{

Cell[CellGroupData[{
Cell["Introduction", "Section",ExpressionUUID->"0b36d350-b0b9-4652-9b48-4b98bffb0746"],

Cell["\<\
Here are expressions for quaternions, and of rotation and reflection matrices \
for two, three, and four dimensions.

Rotations and reflections combined are often called rotoreflections or \
improper rotations, though here they will be called plain reflections.

Quaternions:
quatmultiply[q1_, q2_] -- the usual quaternion multiply
quatidentity = {1,0,0,0}
quatinvunnorm[q_] -- unnormalized, q * {1,-1,-1,-1}
quatnorm[q_] -- norm (abs val squared)
quatinverse[q_] -- proper inverse
quatpauli[q_]  -- to 2*2 Pauli-matrix form
pauliquat[m_] -- from Pauli-matrix form back to quaternions

With diagonal metric met as a vector and mdsc = square root of the product of \
met\[CloseCurlyQuote]s elements these additional ones:
quatmultiply[met_,mdsc,q1_, q2_] 
quatnorm[met_, q_] - norm (abs val squared)
quatinverse[met_, q_] - proper inverse

Also, real versions of Pauli matrices, associated with quaternions with met = \
{-1,1,-1} and mdsc = -1
realpauli -- array of real Pauli matrices 1, 2, 3
quatrealpauli[q_]
realpauliquat[q_]


Rotation and reflection matrices:
rrmat[type_, size parameter(s)_]
The type includes dimension and signature information, and whether rotation \
or reflection. It is a text string.

Rotations and reflections are done over different metric signatures:
2 ++, 11 +-, 3 +++, 21 ++-, 4 ++++, 31 +++-, 22 ++--
The parameters and matrix elements are all real here unless explicitly \
stated. Using complex ones would remove the distinction between the signatures.

The metric signatures are either n (all the same sign) or n1,n2 (n1 one sign, \
n2 the other sign). They correspond to Lie groups O(n) and O(n1,n2), with for \
pure rotations, SO(n) and SO(n1,n2).

Notice that multiplication by -1 is a reflection only in an odd number of \
dimensions. In an even number, it is a rotation.

1D:
Trivial: {{1}}, {{-1}}
Types: 1r, 1s

2D:
2 ++, 11 +-
Parameter: trigonometric argument or 2-vector
Algebras: U(1) and GL(1,R+)
Types:
Trig arguments: 2r, 2s, 11rr, 11rs,11sr, 11ss
Vectors unnormalized: 2rv, 2sv, 11rv, 11sv
Vectors normalized: 2rn, 2sn, 11rn, 11sn

3D:
3 +++, 21 +--
Parameter: quaternion (4-vector)
Algebras: SU(2) and SL(2,R)
Types:
Vectors unnormalized: 3rv, 3sv, 21rrv, 21rsv, 21srv, 21ssv
Vectors normalized: 3rn, 3sn, 21rrn, 21rsn, 21srn, 21ssn

4D:
4 ++++, 31 +++-, 22 ++--
Parameter: pair of quaternions (2*4-matrix)
Algebras: SU(2) * SU(2) and SL(2,C) and SL(2,R) * SL(2,R)
Types:
Quaternion with sign: 4rp, 31rp, 22rp
Vectors unnormalized: 4rv, 4sv, 31rrv, 31rsv, 31srv, 31ssv, 22rrv, 22rsv, \
22srv, 22ssv
Vectors normalized: 4rn, 4sn, 31rrn, 31rsn, 31srn, 31ssn, 22rrn, 22rsn, \
22srn, 22ssn

Parameter norm, metric:
norm[type_, parameter(s)_]
metric[type_]
Types: 2, 11, 3, 21, 4, 31, 22 as character strings

I've included derivatives of rotation matrices, since these are useful in \
dynamical problems.\
\>", "Text",ExpressionUUID->"340aebc8-df4b-41a1-aca1-e1cb7b9732ee"]
}, Open  ]],

Cell[CellGroupData[{

Cell["Setup", "Section",ExpressionUUID->"ce06a749-45b9-4dec-9ec9-ab5452adf62e"],

Cell[BoxData[
 RowBox[{
  RowBox[{"abssqr", "[", 
   RowBox[{"x_", ",", "n_"}], "]"}], " ", ":=", " ", 
  RowBox[{"Total", "[", 
   RowBox[{
    RowBox[{"Take", "[", 
     RowBox[{"x", ",", "n"}], "]"}], "^", "2"}], "]"}]}]], "Input",ExpressionU\
UID->"d40a8e20-24a9-483e-a286-2acb6da76ed2"],

Cell[BoxData[
 RowBox[{
  RowBox[{"abssqrmet", "[", 
   RowBox[{"x_", ",", "met_"}], "]"}], " ", ":=", " ", 
  RowBox[{"Total", "[", 
   RowBox[{"met", "*", 
    RowBox[{
     RowBox[{"Take", "[", 
      RowBox[{"x", ",", 
       RowBox[{"Length", "[", "met", "]"}]}], "]"}], "^", "2"}]}], 
   "]"}]}]], "Input",ExpressionUUID->"0b12b223-0070-435f-b2a2-cabe7a1caae0"],

Cell[BoxData[
 RowBox[{
  RowBox[{"dyad", "[", 
   RowBox[{"x_", ",", "y_"}], "]"}], " ", ":=", " ", 
  RowBox[{
   RowBox[{"Transpose", "[", 
    RowBox[{"{", "x", "}"}], "]"}], ".", 
   RowBox[{"{", "y", "}"}]}]}]], "Input",ExpressionUUID->"0624d7f7-479b-4c78-\
8467-6af8ccb128a5"],

Cell[BoxData[
 RowBox[{
  RowBox[{"asymvt", "[", "x_", "]"}], " ", ":=", " ", 
  RowBox[{"Table", "[", 
   RowBox[{
    RowBox[{"Sum", "[", 
     RowBox[{
      RowBox[{
       RowBox[{"Signature", "[", 
        RowBox[{"{", 
         RowBox[{"i", ",", "j", ",", "k"}], "}"}], "]"}], "*", 
       RowBox[{"x", "[", 
        RowBox[{"[", "k", "]"}], "]"}]}], ",", 
      RowBox[{"{", 
       RowBox[{"k", ",", "3"}], "}"}]}], "]"}], ",", 
    RowBox[{"{", 
     RowBox[{"i", ",", "3"}], "}"}], ",", 
    RowBox[{"{", 
     RowBox[{"j", ",", "3"}], "}"}]}], "]"}]}]], "Input",ExpressionUUID->\
"d4c076d3-0133-49fa-9164-daff26c08db6"],

Cell[BoxData[
 RowBox[{
  RowBox[{"secondprod", "[", 
   RowBox[{"v_", ",", "m_"}], "]"}], " ", ":=", " ", 
  RowBox[{
   RowBox[{
    RowBox[{"(", 
     RowBox[{"v", "*", "#"}], ")"}], "&"}], " ", "/@", " ", "m"}]}]], "Input",\
ExpressionUUID->"0e16d25b-df90-4b28-b379-5fcf01fd7168"],

Cell[BoxData[
 RowBox[{
  RowBox[{"commut", "[", 
   RowBox[{"x_", ",", "y_"}], "]"}], " ", ":=", " ", 
  RowBox[{
   RowBox[{"x", ".", "y"}], " ", "-", " ", 
   RowBox[{"y", ".", "x"}]}]}]], "Input",ExpressionUUID->"7bdf2796-adb8-49e2-\
aaee-e9d26c838b33"],

Cell[BoxData[
 RowBox[{"(*", " ", 
  RowBox[{"Setup", " ", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"Tensor", ",", " ", "Vector1"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"Vector2", ",", " ", "Scalar"}], "}"}]}], "}"}]}], " ", 
  "*)"}]], "Input",ExpressionUUID->"bc42c5ed-6b2b-4e18-b5d5-7073dd4f0149"],

Cell[BoxData[
 RowBox[{
  RowBox[{"assembletvvs", "[", 
   RowBox[{"t_", ",", "v1_", ",", "v2_", ",", "s_"}], "]"}], " ", ":=", " ", 
  RowBox[{"ArrayFlatten", "[", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"t", ",", 
       RowBox[{"Transpose", "[", 
        RowBox[{"{", "v1", "}"}], "]"}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", "v2", "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"{", "s", "}"}], "}"}]}], "}"}]}], "}"}], "]"}]}]], "Input",Ex\
pressionUUID->"b68e47aa-a96b-4ee2-a832-258b7f582f16"],

Cell[BoxData[
 RowBox[{"(*", " ", 
  RowBox[{"For", " ", "derivs"}], " ", "*)"}]], "Input",ExpressionUUID->\
"a992c9b5-d1a6-4397-bd7c-6f2790d03949"],

Cell[BoxData[
 RowBox[{
  RowBox[{"asymtens", "[", "n_", "]"}], " ", ":=", " ", 
  RowBox[{"SparseArray", "[", 
   RowBox[{
    RowBox[{
     RowBox[{
      RowBox[{"#", "\[Rule]", 
       RowBox[{"Signature", "[", "#", "]"}]}], "&"}], " ", "/@", " ", 
     RowBox[{"Permutations", "[", 
      RowBox[{"Range", "[", "n", "]"}], "]"}]}], ",", 
    RowBox[{"ConstantArray", "[", 
     RowBox[{"n", ",", "n"}], "]"}]}], "]"}]}]], "Input",ExpressionUUID->\
"75971ee8-7259-468e-9bcb-da2859ebf0e1"],

Cell[BoxData[
 RowBox[{
  RowBox[{"eps2d", " ", "=", " ", 
   RowBox[{"Normal", "[", 
    RowBox[{"asymtens", "[", "2", "]"}], "]"}]}], ";"}]], "Input",ExpressionUU\
ID->"26de9118-9fb6-4968-8910-f5ea10a59365"],

Cell[BoxData[
 RowBox[{
  RowBox[{"eps3d", " ", "=", " ", 
   RowBox[{"Normal", "[", 
    RowBox[{"asymtens", "[", "3", "]"}], "]"}]}], ";"}]], "Input",ExpressionUU\
ID->"bde18fed-a93b-4c9e-9ea5-842edf762bd8"],

Cell[BoxData[
 RowBox[{"(*", " ", "Verification", " ", "*)"}]], "Input",ExpressionUUID->"83da2f33-f6df-4a5a-be17-10cccdafacb7"],

Cell[BoxData[
 RowBox[{
  RowBox[{"verifyrrmd", "[", "verfdata_", "]"}], " ", ":=", " ", 
  RowBox[{"Module", "[", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{
     "mt", ",", "var", ",", "tds", ",", "td", ",", "type", ",", "det", ",", 
      "rr"}], "}"}], ",", "\[IndentingNewLine]", 
    RowBox[{
     RowBox[{
      RowBox[{"{", 
       RowBox[{"mt", ",", "tds", ",", "var"}], "}"}], " ", "=", " ", 
      "verfdata"}], ";", "\[IndentingNewLine]", 
     RowBox[{"Table", "[", 
      RowBox[{
       RowBox[{
        RowBox[{
         RowBox[{"{", 
          RowBox[{"type", ",", "det"}], "}"}], " ", "=", " ", "td"}], ";", 
        "\[IndentingNewLine]", 
        RowBox[{"rr", " ", "=", " ", 
         RowBox[{"rrmat", "[", 
          RowBox[{"type", ",", "var"}], "]"}]}], ";", "\[IndentingNewLine]", 
        RowBox[{"{", 
         RowBox[{
          RowBox[{
           RowBox[{
            RowBox[{"Transpose", "[", "rr", "]"}], ".", 
            RowBox[{"metric", "[", "mt", "]"}], ".", "rr"}], " ", "-", " ", 
           RowBox[{"metric", "[", "mt", "]"}]}], ",", " ", 
          RowBox[{
           RowBox[{"Det", "[", "rr", "]"}], " ", "-", " ", "det"}]}], "}"}]}],
        ",", 
       RowBox[{"{", 
        RowBox[{"td", ",", "tds"}], "}"}]}], "]"}]}]}], "\[IndentingNewLine]",
    "]"}]}]], "Input",ExpressionUUID->"d4805336-e9a1-467c-a9bc-01c2cc5efae7"],

Cell[BoxData[
 RowBox[{
  RowBox[{"verifyrrprod", "[", "verfdata_", "]"}], " ", ":=", " ", 
  RowBox[{"Module", "[", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{
     "types", ",", "vars", ",", "prods", ",", "var1", ",", "var2", ",", "n", 
      ",", "i", ",", "j", ",", "tc", ",", "vc"}], "}"}], ",", 
    "\[IndentingNewLine]", 
    RowBox[{
     RowBox[{
      RowBox[{"{", 
       RowBox[{"types", ",", "vars", ",", "prods"}], "}"}], " ", "=", " ", 
      "verfdata"}], ";", "\[IndentingNewLine]", 
     RowBox[{
      RowBox[{"{", 
       RowBox[{"var1", ",", "var2"}], "}"}], " ", "=", " ", "vars"}], ";", 
     "\[IndentingNewLine]", 
     RowBox[{"n", " ", "=", " ", 
      RowBox[{"Length", "[", "types", "]"}]}], ";", "\[IndentingNewLine]", 
     RowBox[{"Table", "[", 
      RowBox[{
       RowBox[{
        RowBox[{
         RowBox[{"{", 
          RowBox[{"tc", ",", "vc"}], "}"}], " ", "=", " ", 
         RowBox[{"prods", "[", 
          RowBox[{"[", 
           RowBox[{"i", ",", "j"}], "]"}], "]"}]}], ";", 
        RowBox[{
         RowBox[{
          RowBox[{"rrmat", "[", 
           RowBox[{
            RowBox[{"types", "[", 
             RowBox[{"[", "i", "]"}], "]"}], ",", "var1"}], "]"}], ".", 
          RowBox[{"rrmat", "[", 
           RowBox[{
            RowBox[{"types", "[", 
             RowBox[{"[", "j", "]"}], "]"}], ",", "var2"}], "]"}]}], "-", 
         RowBox[{"rrmat", "[", 
          RowBox[{"tc", ",", "vc"}], "]"}]}]}], ",", 
       RowBox[{"{", 
        RowBox[{"i", ",", "n"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"j", ",", "n"}], "}"}]}], "]"}]}]}], "\[IndentingNewLine]", 
   "]"}]}]], "Input",ExpressionUUID->"dfdd2641-995b-4b6c-8431-a77d17e5620e"]
}, Closed]],

Cell[CellGroupData[{

Cell["Quaternions", "Section",ExpressionUUID->"ac69234d-9679-409c-abb4-08c4b8d8952a"],

Cell[CellGroupData[{

Cell["Ordinary", "Subsection",ExpressionUUID->"b76d344e-b33c-4df6-9256-5a92e5faa01e"],

Cell[BoxData[
 RowBox[{"(*", " ", 
  RowBox[{"Quaternion", " ", "definitions", " ", "and", " ", 
   RowBox[{"verification", ".", " ", "Quaternions"}], " ", "have", " ", 
   "form", " ", 
   RowBox[{"{", 
    RowBox[{
    "scalar", ",", " ", "vector1", ",", " ", "vector2", ",", " ", "vector3"}],
     "}"}]}], " ", "*)"}]], "Input",ExpressionUUID->"0b1679ba-69d4-4922-b8c4-\
a68d128c4d83"],

Cell[BoxData[
 RowBox[{
  RowBox[{"quatmultiply", "[", 
   RowBox[{"q1_", ",", "q2_"}], "]"}], " ", ":=", " ", 
  RowBox[{"Module", "[", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{
     "qs1", ",", "qv1", ",", "qs2", ",", "qv2", ",", "qs", ",", "qv"}], "}"}],
     ",", "\[IndentingNewLine]", 
    RowBox[{
     RowBox[{"qs1", " ", "=", " ", 
      RowBox[{"q1", "[", 
       RowBox[{"[", "1", "]"}], "]"}]}], ";", " ", 
     RowBox[{"qv1", " ", "=", " ", 
      RowBox[{"Take", "[", 
       RowBox[{"q1", ",", 
        RowBox[{"{", 
         RowBox[{"2", ",", "4"}], "}"}]}], "]"}]}], ";", " ", 
     RowBox[{"qs2", " ", "=", " ", 
      RowBox[{"q2", "[", 
       RowBox[{"[", "1", "]"}], "]"}]}], ";", " ", 
     RowBox[{"qv2", " ", "=", " ", 
      RowBox[{"Take", "[", 
       RowBox[{"q2", ",", 
        RowBox[{"{", 
         RowBox[{"2", ",", "4"}], "}"}]}], "]"}]}], ";", 
     "\[IndentingNewLine]", 
     RowBox[{"qs", " ", "=", " ", 
      RowBox[{
       RowBox[{"qs1", "*", "qs2"}], " ", "-", " ", 
       RowBox[{"qv1", ".", "qv2"}]}]}], ";", "\[IndentingNewLine]", 
     RowBox[{"qv", " ", "=", " ", 
      RowBox[{
       RowBox[{"qs1", "*", "qv2"}], " ", "+", " ", 
       RowBox[{"qs2", "*", "qv1"}], " ", "-", " ", 
       RowBox[{"Cross", "[", 
        RowBox[{"qv1", ",", "qv2"}], "]"}]}]}], ";", "\[IndentingNewLine]", 
     RowBox[{"Prepend", "[", 
      RowBox[{"qv", ",", "qs"}], "]"}]}]}], "]"}]}]], "Input",ExpressionUUID->\
"a9f36f73-bed6-4848-ae76-a9e59a70b19c"],

Cell[BoxData[
 RowBox[{
  RowBox[{"quatidentity", " ", "=", " ", 
   RowBox[{"{", 
    RowBox[{"1", ",", "0", ",", "0", ",", "0"}], "}"}]}], ";"}]], "Input",Expr\
essionUUID->"cfe8b4d5-4056-46ee-bfa1-2181f7dd066f"],

Cell[BoxData[
 RowBox[{
  RowBox[{"quatinvunnorm", "[", "q_", "]"}], " ", ":=", " ", 
  RowBox[{"Prepend", "[", 
   RowBox[{
    RowBox[{"-", 
     RowBox[{"Take", "[", 
      RowBox[{"q", ",", 
       RowBox[{"{", 
        RowBox[{"2", ",", "4"}], "}"}]}], "]"}]}], ",", 
    RowBox[{"q", "[", 
     RowBox[{"[", "1", "]"}], "]"}]}], "]"}]}]], "Input",ExpressionUUID->\
"b60d99da-e6e6-44f2-ad1d-5c99bdf8b73a"],

Cell[BoxData[
 RowBox[{
  RowBox[{"quatnorm", "[", "q_", "]"}], " ", ":=", 
  RowBox[{"abssqr", "[", 
   RowBox[{"q", ",", "4"}], "]"}]}]], "Input",ExpressionUUID->"93860a73-7420-\
4fbc-9ffa-d46b66e9c9e4"],

Cell[BoxData[
 RowBox[{
  RowBox[{"quatinverse", "[", "q_", "]"}], " ", ":=", " ", 
  RowBox[{
   RowBox[{"quatinvunnorm", "[", "q", "]"}], "/", 
   RowBox[{"quatnorm", "[", "q", "]"}]}]}]], "Input",ExpressionUUID->\
"cc4791a6-2a5a-4352-a66e-29a650aa9c00"],

Cell[BoxData[
 RowBox[{"(*", " ", 
  RowBox[{"Pauli", "-", 
   RowBox[{"matrix", " ", 
    RowBox[{"form", ":", " ", 
     RowBox[{"U", 
      RowBox[{
       RowBox[{"(", "2", ")"}], " ", "/", " ", "SU"}], 
      RowBox[{"(", "2", ")"}]}]}]}]}], " ", "*)"}]], "Input",ExpressionUUID->\
"546aa2af-b97d-4da2-9a3b-b30d77db11f8"],

Cell[BoxData[
 RowBox[{
  RowBox[{"quatpauli", "[", "q_", "]"}], " ", ":=", " ", 
  RowBox[{"Module", "[", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{"qs", ",", "qv", ",", "k"}], "}"}], ",", "\[IndentingNewLine]", 
    RowBox[{
     RowBox[{"qs", " ", "=", " ", 
      RowBox[{"q", "[", 
       RowBox[{"[", "1", "]"}], "]"}]}], ";", " ", 
     RowBox[{"qv", " ", "=", " ", 
      RowBox[{"Take", "[", 
       RowBox[{"q", ",", 
        RowBox[{"{", 
         RowBox[{"2", ",", "4"}], "}"}]}], "]"}]}], ";", 
     "\[IndentingNewLine]", 
     RowBox[{
      RowBox[{"qs", "*", 
       RowBox[{"IdentityMatrix", "[", "2", "]"}]}], " ", "+", " ", 
      RowBox[{"I", "*", 
       RowBox[{"Sum", "[", 
        RowBox[{
         RowBox[{
          RowBox[{"qv", "[", 
           RowBox[{"[", "k", "]"}], "]"}], "*", 
          RowBox[{"PauliMatrix", "[", "k", "]"}]}], ",", 
         RowBox[{"{", 
          RowBox[{"k", ",", "3"}], "}"}]}], "]"}]}]}]}]}], 
   "\[IndentingNewLine]", "]"}]}]], "Input",ExpressionUUID->"2c186919-3f99-\
4367-a0ec-2a0b65a829a7"],

Cell[BoxData[
 RowBox[{
  RowBox[{"pauliquat", "[", "m_", "]"}], " ", ":=", " ", 
  RowBox[{
   RowBox[{"(", 
    RowBox[{"1", "/", "2"}], ")"}], "*", 
   RowBox[{"Prepend", "[", 
    RowBox[{
     RowBox[{
      RowBox[{"-", "I"}], "*", 
      RowBox[{"Table", "[", 
       RowBox[{
        RowBox[{"Tr", "[", 
         RowBox[{"m", ".", 
          RowBox[{"PauliMatrix", "[", "k", "]"}]}], "]"}], ",", 
        RowBox[{"{", 
         RowBox[{"k", ",", "3"}], "}"}]}], "]"}]}], ",", 
     RowBox[{"Tr", "[", "m", "]"}]}], "]"}]}]}]], "Input",ExpressionUUID->\
"217247d1-0bc8-4451-bcda-94796bdf1ac3"],

Cell[BoxData[
 RowBox[{"(*", " ", "Verification", " ", "*)"}]], "Input",ExpressionUUID->"b4f8937b-6ec5-460e-9bdf-a74abc7c2211"],

Cell[BoxData[
 RowBox[{
  RowBox[{"quatverify", "[", "q_", "]"}], " ", ":=", " ", 
  RowBox[{"Module", "[", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{"q1", ",", "q2", ",", "q3", ",", 
      RowBox[{"res", "=", 
       RowBox[{"{", "}"}]}]}], "}"}], ",", "\[IndentingNewLine]", 
    RowBox[{
     RowBox[{"q1", " ", "=", " ", 
      RowBox[{"Array", "[", 
       RowBox[{
        RowBox[{"q", "[", "1", "]"}], ",", "4"}], "]"}]}], ";", " ", 
     RowBox[{"q2", " ", "=", " ", 
      RowBox[{"Array", "[", 
       RowBox[{
        RowBox[{"q", "[", "2", "]"}], ",", "4"}], "]"}]}], ";", " ", 
     RowBox[{"q3", " ", "=", " ", 
      RowBox[{"Array", "[", 
       RowBox[{
        RowBox[{"q", "[", "3", "]"}], ",", "4"}], "]"}]}], ";", 
     "\[IndentingNewLine]", 
     RowBox[{"(*", " ", "Associative", " ", "*)"}], "\[IndentingNewLine]", 
     RowBox[{"AppendTo", "[", 
      RowBox[{"res", ",", 
       RowBox[{
        RowBox[{"quatmultiply", "[", 
         RowBox[{
          RowBox[{"quatmultiply", "[", 
           RowBox[{"q1", ",", "q2"}], "]"}], ",", "q3"}], "]"}], "-", 
        RowBox[{"quatmultiply", "[", 
         RowBox[{"q1", ",", 
          RowBox[{"quatmultiply", "[", 
           RowBox[{"q2", ",", "q3"}], "]"}]}], "]"}]}]}], "]"}], ";", 
     "\[IndentingNewLine]", 
     RowBox[{"(*", " ", "Identity", " ", "*)"}], "\[IndentingNewLine]", 
     RowBox[{"AppendTo", "[", 
      RowBox[{"res", ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{
          RowBox[{"quatmultiply", "[", 
           RowBox[{"q1", ",", "quatidentity"}], "]"}], "-", "q1"}], ",", 
         RowBox[{
          RowBox[{"quatmultiply", "[", 
           RowBox[{"quatidentity", ",", "q1"}], "]"}], "-", "q1"}]}], "}"}]}],
       "]"}], ";", "\[IndentingNewLine]", 
     RowBox[{"(*", " ", "Norm", " ", "*)"}], "\[IndentingNewLine]", 
     RowBox[{"AppendTo", "[", 
      RowBox[{"res", ",", 
       RowBox[{
        RowBox[{"quatnorm", "[", 
         RowBox[{"quatmultiply", "[", 
          RowBox[{"q1", ",", "q2"}], "]"}], "]"}], "-", 
        RowBox[{
         RowBox[{"quatnorm", "[", "q1", "]"}], "*", 
         RowBox[{"quatnorm", "[", "q2", "]"}]}]}]}], "]"}], ";", 
     "\[IndentingNewLine]", 
     RowBox[{"(*", " ", "Inverse", " ", "*)"}], "\[IndentingNewLine]", 
     RowBox[{"AppendTo", "[", 
      RowBox[{"res", ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{
          RowBox[{"quatmultiply", "[", 
           RowBox[{"q1", ",", 
            RowBox[{"quatinverse", "[", "q1", "]"}]}], "]"}], "-", 
          "quatidentity"}], ",", 
         RowBox[{
          RowBox[{"quatmultiply", "[", 
           RowBox[{
            RowBox[{"quatinverse", "[", "q1", "]"}], ",", "q1"}], "]"}], "-", 
          "quatidentity"}]}], "}"}]}], "]"}], ";", "\[IndentingNewLine]", 
     RowBox[{"(*", " ", 
      RowBox[{"Pauli", " ", "Multiplication"}], " ", "*)"}], 
     "\[IndentingNewLine]", 
     RowBox[{"AppendTo", "[", 
      RowBox[{"res", ",", 
       RowBox[{
        RowBox[{"quatpauli", "[", 
         RowBox[{"quatmultiply", "[", 
          RowBox[{"q1", ",", "q2"}], "]"}], "]"}], "-", 
        RowBox[{
         RowBox[{"quatpauli", "[", "q1", "]"}], ".", 
         RowBox[{"quatpauli", "[", "q2", "]"}]}]}]}], "]"}], ";", 
     "\[IndentingNewLine]", 
     RowBox[{"(*", " ", 
      RowBox[{"Pauli", " ", "to", " ", "Quaternion"}], " ", "*)"}], 
     "\[IndentingNewLine]", 
     RowBox[{"AppendTo", "[", 
      RowBox[{"res", ",", 
       RowBox[{
        RowBox[{"pauliquat", "[", 
         RowBox[{"quatpauli", "[", "q1", "]"}], "]"}], "-", "q1"}]}], "]"}], 
     ";", "\[IndentingNewLine]", 
     RowBox[{
      RowBox[{
       RowBox[{"res", " ", "//", " ", "Flatten"}], " ", "//", " ", "Factor"}],
       " ", "//", " ", "Union"}]}]}], "]"}]}]], "Input",ExpressionUUID->\
"7467229d-9501-4971-a546-4d7ebdf6c6cf"],

Cell[BoxData[
 RowBox[{"quatverify", "[", "q", "]"}]], "Input",ExpressionUUID->"036323aa-4c26-40a5-b230-9e07c4880d26"]
}, Closed]],

Cell[CellGroupData[{

Cell["Diagonal Metric", "Subsection",ExpressionUUID->"d12c71d3-0338-4586-a799-360cb6a3d62b"],

Cell[BoxData[
 RowBox[{"(*", " ", 
  RowBox[{
   RowBox[{"mdsc", "^", "2"}], " ", "=", " ", 
   RowBox[{
    RowBox[{"Times", " ", "@@", " ", 
     RowBox[{"m", " ", "--"}]}], " ", "a", " ", "separate", " ", "parameter", 
    " ", "so", " ", "that", " ", "we", " ", "can", " ", "control", " ", "the",
     " ", "sign", " ", "of", " ", "the", " ", "square", " ", "root"}]}], " ", 
  "*)"}]], "Input",ExpressionUUID->"0b5f0abc-ea6c-4553-96c8-aa6c3f2e3f62"],

Cell[BoxData[
 RowBox[{
  RowBox[{"quatmultiply", "[", 
   RowBox[{"met_", ",", "mdsc_", ",", "q1_", ",", "q2_"}], "]"}], " ", ":=", 
  " ", 
  RowBox[{"Module", "[", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{
     "qs1", ",", "qv1", ",", "qs2", ",", "qv2", ",", "qs", ",", "qv"}], "}"}],
     ",", "\[IndentingNewLine]", 
    RowBox[{
     RowBox[{"qs1", " ", "=", " ", 
      RowBox[{"q1", "[", 
       RowBox[{"[", "1", "]"}], "]"}]}], ";", " ", 
     RowBox[{"qv1", " ", "=", " ", 
      RowBox[{"Take", "[", 
       RowBox[{"q1", ",", 
        RowBox[{"{", 
         RowBox[{"2", ",", "4"}], "}"}]}], "]"}]}], ";", " ", 
     RowBox[{"qs2", " ", "=", " ", 
      RowBox[{"q2", "[", 
       RowBox[{"[", "1", "]"}], "]"}]}], ";", " ", 
     RowBox[{"qv2", " ", "=", " ", 
      RowBox[{"Take", "[", 
       RowBox[{"q2", ",", 
        RowBox[{"{", 
         RowBox[{"2", ",", "4"}], "}"}]}], "]"}]}], ";", 
     "\[IndentingNewLine]", 
     RowBox[{"qs", " ", "=", " ", 
      RowBox[{
       RowBox[{"qs1", "*", "qs2"}], " ", "-", " ", 
       RowBox[{"qv1", ".", 
        RowBox[{"(", 
         RowBox[{"met", "*", "qv2"}], ")"}]}]}]}], ";", "\[IndentingNewLine]", 
     RowBox[{"qv", " ", "=", " ", 
      RowBox[{
       RowBox[{"qs1", "*", "qv2"}], " ", "+", " ", 
       RowBox[{"qs2", "*", "qv1"}], " ", "-", " ", 
       RowBox[{
        RowBox[{"(", 
         RowBox[{"mdsc", "/", "met"}], ")"}], "*", 
        RowBox[{"Cross", "[", 
         RowBox[{"qv1", ",", "qv2"}], "]"}]}]}]}], ";", "\[IndentingNewLine]", 
     RowBox[{"Prepend", "[", 
      RowBox[{"qv", ",", "qs"}], "]"}]}]}], "]"}]}]], "Input",ExpressionUUID->\
"7b7b68dc-8e73-40b0-bc8d-fd2cedcfabf4"],

Cell[BoxData[
 RowBox[{
  RowBox[{"quatnorm", "[", 
   RowBox[{"met_", ",", "q_"}], "]"}], " ", ":=", " ", 
  RowBox[{"Module", "[", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{"qs", ",", "qv"}], "}"}], ",", "\[IndentingNewLine]", 
    RowBox[{
     RowBox[{"qs", " ", "=", " ", 
      RowBox[{"q", "[", 
       RowBox[{"[", "1", "]"}], "]"}]}], ";", " ", 
     RowBox[{"qv", " ", "=", " ", 
      RowBox[{"Take", "[", 
       RowBox[{"q", ",", 
        RowBox[{"{", 
         RowBox[{"2", ",", "4"}], "}"}]}], "]"}]}], ";", 
     "\[IndentingNewLine]", 
     RowBox[{
      RowBox[{"qs", "^", "2"}], " ", "+", " ", 
      RowBox[{"qv", ".", 
       RowBox[{"(", 
        RowBox[{"met", "*", "qv"}], ")"}]}]}]}]}], "\[IndentingNewLine]", 
   "]"}]}]], "Input",ExpressionUUID->"fb72502f-63d3-4bb5-87ff-2c4e98f1e626"],

Cell[BoxData[
 RowBox[{
  RowBox[{"quatinverse", "[", 
   RowBox[{"met_", ",", "q_"}], "]"}], " ", ":=", " ", 
  RowBox[{
   RowBox[{"quatinvunnorm", "[", "q", "]"}], "/", 
   RowBox[{"quatnorm", "[", 
    RowBox[{"met", ",", "q"}], "]"}]}]}]], "Input",ExpressionUUID->"0b5fb012-\
4108-4ec7-9efc-bd4eec2df0a3"],

Cell[BoxData[
 RowBox[{"(*", " ", "Verification", " ", "*)"}]], "Input",ExpressionUUID->"d0dcd466-012d-4a53-9876-3f759c40665a"],

Cell[BoxData[
 RowBox[{
  RowBox[{"quatverify", "[", 
   RowBox[{"m_", ",", "q_"}], "]"}], " ", ":=", " ", 
  RowBox[{"Module", "[", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{"met", ",", "mdsc", ",", "q1", ",", "q2", ",", "q3", ",", 
      RowBox[{"res", "=", 
       RowBox[{"{", "}"}]}]}], "}"}], ",", "\[IndentingNewLine]", 
    RowBox[{
     RowBox[{"met", " ", "=", " ", 
      RowBox[{"Array", "[", 
       RowBox[{"m", ",", "3"}], "]"}]}], ";", "\[IndentingNewLine]", 
     RowBox[{"mdsc", " ", "=", " ", 
      RowBox[{"Sqrt", "[", 
       RowBox[{"Times", " ", "@@", " ", "met"}], "]"}]}], ";", 
     "\[IndentingNewLine]", 
     RowBox[{"q1", " ", "=", " ", 
      RowBox[{"Array", "[", 
       RowBox[{
        RowBox[{"q", "[", "1", "]"}], ",", "4"}], "]"}]}], ";", " ", 
     RowBox[{"q2", " ", "=", " ", 
      RowBox[{"Array", "[", 
       RowBox[{
        RowBox[{"q", "[", "2", "]"}], ",", "4"}], "]"}]}], ";", " ", 
     RowBox[{"q3", " ", "=", " ", 
      RowBox[{"Array", "[", 
       RowBox[{
        RowBox[{"q", "[", "3", "]"}], ",", "4"}], "]"}]}], ";", 
     "\[IndentingNewLine]", 
     RowBox[{"(*", " ", "Associative", " ", "*)"}], "\[IndentingNewLine]", 
     RowBox[{"AppendTo", "[", 
      RowBox[{"res", ",", 
       RowBox[{
        RowBox[{"quatmultiply", "[", 
         RowBox[{"met", ",", "mdsc", ",", 
          RowBox[{"quatmultiply", "[", 
           RowBox[{"met", ",", "mdsc", ",", "q1", ",", "q2"}], "]"}], ",", 
          "q3"}], "]"}], "-", 
        RowBox[{"quatmultiply", "[", 
         RowBox[{"met", ",", "mdsc", ",", "q1", ",", 
          RowBox[{"quatmultiply", "[", 
           RowBox[{"met", ",", "mdsc", ",", "q2", ",", "q3"}], "]"}]}], 
         "]"}]}]}], "]"}], ";", "\[IndentingNewLine]", 
     RowBox[{"(*", " ", "Identity", " ", "*)"}], "\[IndentingNewLine]", 
     RowBox[{"AppendTo", "[", 
      RowBox[{"res", ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{
          RowBox[{"quatmultiply", "[", 
           RowBox[{"met", ",", "mdsc", ",", "q1", ",", "quatidentity"}], 
           "]"}], "-", "q1"}], ",", 
         RowBox[{
          RowBox[{"quatmultiply", "[", 
           RowBox[{"met", ",", "mdsc", ",", "quatidentity", ",", "q1"}], 
           "]"}], "-", "q1"}]}], "}"}]}], "]"}], ";", "\[IndentingNewLine]", 
     RowBox[{"(*", " ", "Norm", " ", "*)"}], "\[IndentingNewLine]", 
     RowBox[{"AppendTo", "[", 
      RowBox[{"res", ",", 
       RowBox[{
        RowBox[{"quatnorm", "[", 
         RowBox[{"met", ",", 
          RowBox[{"quatmultiply", "[", 
           RowBox[{"met", ",", "mdsc", ",", "q1", ",", "q2"}], "]"}]}], "]"}],
         "-", 
        RowBox[{
         RowBox[{"quatnorm", "[", 
          RowBox[{"met", ",", "q1"}], "]"}], "*", 
         RowBox[{"quatnorm", "[", 
          RowBox[{"met", ",", "q2"}], "]"}]}]}]}], "]"}], ";", 
     "\[IndentingNewLine]", 
     RowBox[{"(*", " ", "Inverse", " ", "*)"}], "\[IndentingNewLine]", 
     RowBox[{"AppendTo", "[", 
      RowBox[{"res", ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{
          RowBox[{"quatmultiply", "[", 
           RowBox[{"met", ",", "mdsc", ",", "q1", ",", 
            RowBox[{"quatinverse", "[", 
             RowBox[{"met", ",", "q1"}], "]"}]}], "]"}], "-", 
          "quatidentity"}], ",", 
         RowBox[{
          RowBox[{"quatmultiply", "[", 
           RowBox[{"met", ",", "mdsc", ",", 
            RowBox[{"quatinverse", "[", 
             RowBox[{"met", ",", "q1"}], "]"}], ",", "q1"}], "]"}], "-", 
          "quatidentity"}]}], "}"}]}], "]"}], ";", "\[IndentingNewLine]", 
     RowBox[{
      RowBox[{
       RowBox[{
        RowBox[{"res", " ", "//", " ", "Flatten"}], " ", "//", " ", 
        "Expand"}], " ", "//", " ", "Factor"}], " ", "//", " ", "Union"}]}]}],
    "]"}]}]], "Input",ExpressionUUID->"7791be20-54cc-4505-b351-fb77dfe27c1d"],

Cell[BoxData[
 RowBox[{"(*", " ", 
  RowBox[{
   RowBox[{"Real", " ", "Pauli"}], "-", 
   RowBox[{"matrix", " ", 
    RowBox[{"form", ":", " ", 
     RowBox[{"GL", 
      RowBox[{
       RowBox[{"(", 
        RowBox[{"2", ",", "R"}], ")"}], " ", "/", " ", "SL"}], 
      RowBox[{"(", 
       RowBox[{"2", ",", "R"}], ")"}]}]}]}]}], " ", "*)"}]], "Input",Expressio\
nUUID->"008f6c2f-006d-477d-8880-a32203b5be9f"],

Cell[BoxData[
 RowBox[{
  RowBox[{"realpauli", " ", "=", " ", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{"1", ",", "I", ",", "1"}], "}"}], "*", 
    RowBox[{"Array", "[", 
     RowBox[{"PauliMatrix", ",", "3"}], "]"}]}]}], ";"}]], "Input",ExpressionU\
UID->"07406eec-7ee7-4657-95f3-36addd185266"],

Cell[BoxData[
 RowBox[{
  RowBox[{"quatrealpauli", "[", "q_", "]"}], " ", ":=", " ", 
  RowBox[{"Module", "[", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{"qs", ",", "qv", ",", "k"}], "}"}], ",", "\[IndentingNewLine]", 
    RowBox[{
     RowBox[{"qs", " ", "=", " ", 
      RowBox[{"q", "[", 
       RowBox[{"[", "1", "]"}], "]"}]}], ";", " ", 
     RowBox[{"qv", " ", "=", " ", 
      RowBox[{"Take", "[", 
       RowBox[{"q", ",", 
        RowBox[{"{", 
         RowBox[{"2", ",", "4"}], "}"}]}], "]"}]}], ";", 
     "\[IndentingNewLine]", 
     RowBox[{
      RowBox[{"qs", "*", 
       RowBox[{"IdentityMatrix", "[", "2", "]"}]}], " ", "+", " ", 
      RowBox[{"Sum", "[", 
       RowBox[{
        RowBox[{
         RowBox[{"qv", "[", 
          RowBox[{"[", "k", "]"}], "]"}], "*", 
         RowBox[{"RealPauli", "[", 
          RowBox[{"[", "k", "]"}], "]"}]}], ",", 
        RowBox[{"{", 
         RowBox[{"k", ",", "3"}], "}"}]}], "]"}]}]}]}], "\[IndentingNewLine]",
    "]"}]}]], "Input",ExpressionUUID->"9a4e0f0b-eafd-4904-9879-487c875bc4b7"],

Cell[BoxData[
 RowBox[{
  RowBox[{"realpauliquat", "[", "m_", "]"}], " ", ":=", " ", 
  RowBox[{
   RowBox[{"(", 
    RowBox[{"1", "/", "2"}], ")"}], "*", 
   RowBox[{"Prepend", "[", 
    RowBox[{
     RowBox[{"Table", "[", 
      RowBox[{
       RowBox[{"Tr", "[", 
        RowBox[{"m", ".", 
         RowBox[{"Transpose", "[", 
          RowBox[{"RealPauli", "[", 
           RowBox[{"[", "k", "]"}], "]"}], "]"}]}], "]"}], ",", 
       RowBox[{"{", 
        RowBox[{"k", ",", "3"}], "}"}]}], "]"}], ",", 
     RowBox[{"Tr", "[", "m", "]"}]}], "]"}]}]}]], "Input",ExpressionUUID->\
"d4a6e11c-2434-4493-acac-4da8b1a065ed"],

Cell[BoxData[
 RowBox[{"(*", " ", "Verification", " ", "*)"}]], "Input",ExpressionUUID->"8b345d42-2d0d-4e60-adbe-d58d2e2a8b61"],

Cell[BoxData[
 RowBox[{
  RowBox[{"realpauliverify", "[", "q_", "]"}], " ", ":=", " ", 
  RowBox[{"Module", "[", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{"q1", ",", "q2", ",", "q3", ",", 
      RowBox[{"res", "=", 
       RowBox[{"{", "}"}]}]}], "}"}], ",", "\[IndentingNewLine]", 
    RowBox[{
     RowBox[{"q1", " ", "=", " ", 
      RowBox[{"Array", "[", 
       RowBox[{
        RowBox[{"q", "[", "1", "]"}], ",", "4"}], "]"}]}], ";", " ", 
     RowBox[{"q2", " ", "=", " ", 
      RowBox[{"Array", "[", 
       RowBox[{
        RowBox[{"q", "[", "2", "]"}], ",", "4"}], "]"}]}], ";", 
     "\[IndentingNewLine]", 
     RowBox[{"(*", " ", 
      RowBox[{"Pauli", " ", "Multiplication"}], " ", "*)"}], 
     "\[IndentingNewLine]", 
     RowBox[{"AppendTo", "[", 
      RowBox[{"res", ",", 
       RowBox[{
        RowBox[{"quatrealpauli", "[", 
         RowBox[{"quatmultiply", "[", 
          RowBox[{
           RowBox[{"{", 
            RowBox[{
             RowBox[{"-", "1"}], ",", "1", ",", 
             RowBox[{"-", "1"}]}], "}"}], ",", 
           RowBox[{"-", "1"}], ",", "q1", ",", "q2"}], "]"}], "]"}], "-", 
        RowBox[{
         RowBox[{"quatrealpauli", "[", "q1", "]"}], ".", 
         RowBox[{"quatrealpauli", "[", "q2", "]"}]}]}]}], "]"}], ";", 
     "\[IndentingNewLine]", 
     RowBox[{"(*", " ", 
      RowBox[{"Pauli", " ", "to", " ", "Quaternion"}], " ", "*)"}], 
     "\[IndentingNewLine]", 
     RowBox[{"AppendTo", "[", 
      RowBox[{"res", ",", 
       RowBox[{
        RowBox[{"realpauliquat", "[", 
         RowBox[{"quatrealpauli", "[", "q1", "]"}], "]"}], "-", "q1"}]}], 
      "]"}], ";", "\[IndentingNewLine]", 
     RowBox[{
      RowBox[{
       RowBox[{"res", " ", "//", " ", "Flatten"}], " ", "//", " ", "Factor"}],
       " ", "//", " ", "Union"}]}]}], "]"}]}]], "Input",ExpressionUUID->\
"b1b66a05-ab16-45bc-82de-5e63b8d6bc38"],

Cell[BoxData[
 RowBox[{
  RowBox[{"realpauliverify", "[", "q_", "]"}], " ", ":=", " ", 
  RowBox[{"Module", "[", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{"q1", ",", "q2", ",", "q3", ",", 
      RowBox[{"res", "=", 
       RowBox[{"{", "}"}]}]}], "}"}], ",", "\[IndentingNewLine]", 
    RowBox[{
     RowBox[{"q1", " ", "=", " ", 
      RowBox[{"Array", "[", 
       RowBox[{
        RowBox[{"q", "[", "1", "]"}], ",", "4"}], "]"}]}], ";", " ", 
     RowBox[{"q2", " ", "=", " ", 
      RowBox[{"Array", "[", 
       RowBox[{
        RowBox[{"q", "[", "2", "]"}], ",", "4"}], "]"}]}], ";", 
     "\[IndentingNewLine]", 
     RowBox[{"(*", " ", 
      RowBox[{"Pauli", " ", "Multiplication"}], " ", "*)"}], 
     "\[IndentingNewLine]", 
     RowBox[{"AppendTo", "[", 
      RowBox[{"res", ",", 
       RowBox[{
        RowBox[{"quatrealpauli", "[", 
         RowBox[{"quatmultiply", "[", 
          RowBox[{
           RowBox[{"{", 
            RowBox[{
             RowBox[{"-", "1"}], ",", "1", ",", 
             RowBox[{"-", "1"}]}], "}"}], ",", 
           RowBox[{"-", "1"}], ",", "q1", ",", "q2"}], "]"}], "]"}], "-", 
        RowBox[{
         RowBox[{"quatrealpauli", "[", "q1", "]"}], ".", 
         RowBox[{"quatrealpauli", "[", "q2", "]"}]}]}]}], "]"}], ";", 
     "\[IndentingNewLine]", 
     RowBox[{"(*", " ", 
      RowBox[{"Pauli", " ", "to", " ", "Quaternion"}], " ", "*)"}], 
     "\[IndentingNewLine]", 
     RowBox[{"AppendTo", "[", 
      RowBox[{"res", ",", 
       RowBox[{
        RowBox[{"realpauliquat", "[", 
         RowBox[{"quatrealpauli", "[", "q1", "]"}], "]"}], "-", "q1"}]}], 
      "]"}], ";", "\[IndentingNewLine]", 
     RowBox[{
      RowBox[{
       RowBox[{"res", " ", "//", " ", "Flatten"}], " ", "//", " ", "Factor"}],
       " ", "//", " ", "Union"}]}]}], "]"}]}]], "Input",ExpressionUUID->\
"8149fddb-62cb-404c-aeed-ab445bd3e065"],

Cell[BoxData[
 RowBox[{"quatverify", "[", 
  RowBox[{"m", ",", "q"}], "]"}]], "Input",ExpressionUUID->"525cad80-1a54-\
425b-8e79-bbf0ecd8a328"]
}, Closed]],

Cell[CellGroupData[{

Cell["General Metric", "Subsection",ExpressionUUID->"4e527a71-ad45-4898-9c0b-fc11a31ab738"],

Cell[BoxData[
 RowBox[{"(*", " ", 
  RowBox[{
  "Uses", " ", "an", " ", "arbitrary", " ", "symmetric", " ", "matrix", " ", 
   "for", " ", "its", " ", "metric"}], " ", "*)"}]], "Input",ExpressionUUID->\
"52193444-47e8-4ab6-8a88-3bec4e80c4d9"],

Cell[BoxData[
 RowBox[{
  RowBox[{"quatmultiply", "[", 
   RowBox[{"\"\<x\>\"", ",", "met_", ",", "mdsc_", ",", "q1_", ",", "q2_"}], 
   "]"}], " ", ":=", " ", 
  RowBox[{"Module", "[", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{
     "mts", ",", "mti", ",", "qs1", ",", "qv1", ",", "qs2", ",", "qv2", ",", 
      "qs", ",", "qv"}], "}"}], ",", "\[IndentingNewLine]", 
    RowBox[{
     RowBox[{"mts", " ", "=", " ", 
      RowBox[{
       RowBox[{"(", 
        RowBox[{"met", "+", 
         RowBox[{"Transpose", "[", "met", "]"}]}], ")"}], "/", "2"}]}], ";", 
     "\[IndentingNewLine]", 
     RowBox[{"mti", " ", "=", " ", 
      RowBox[{"Inverse", "[", "mts", "]"}]}], ";", "\[IndentingNewLine]", 
     RowBox[{"qs1", " ", "=", " ", 
      RowBox[{"q1", "[", 
       RowBox[{"[", "1", "]"}], "]"}]}], ";", " ", 
     RowBox[{"qv1", " ", "=", " ", 
      RowBox[{"Take", "[", 
       RowBox[{"q1", ",", 
        RowBox[{"{", 
         RowBox[{"2", ",", "4"}], "}"}]}], "]"}]}], ";", " ", 
     RowBox[{"qs2", " ", "=", " ", 
      RowBox[{"q2", "[", 
       RowBox[{"[", "1", "]"}], "]"}]}], ";", " ", 
     RowBox[{"qv2", " ", "=", " ", 
      RowBox[{"Take", "[", 
       RowBox[{"q2", ",", 
        RowBox[{"{", 
         RowBox[{"2", ",", "4"}], "}"}]}], "]"}]}], ";", 
     "\[IndentingNewLine]", 
     RowBox[{"qs", " ", "=", " ", 
      RowBox[{
       RowBox[{"qs1", "*", "qs2"}], " ", "-", " ", 
       RowBox[{"qv1", ".", "mts", ".", "qv2"}]}]}], ";", 
     "\[IndentingNewLine]", 
     RowBox[{"qv", " ", "=", " ", 
      RowBox[{
       RowBox[{"qs1", "*", "qv2"}], " ", "+", " ", 
       RowBox[{"qs2", "*", "qv1"}], " ", "-", " ", 
       RowBox[{"mdsc", "*", 
        RowBox[{"(", 
         RowBox[{"mti", ".", 
          RowBox[{"Cross", "[", 
           RowBox[{"qv1", ",", "qv2"}], "]"}]}], ")"}]}]}]}], ";", 
     "\[IndentingNewLine]", 
     RowBox[{"Prepend", "[", 
      RowBox[{"qv", ",", "qs"}], "]"}]}]}], "]"}]}]], "Input",ExpressionUUID->\
"4580a087-3dcc-42f8-bf78-0a785ec6f213"],

Cell[BoxData[
 RowBox[{
  RowBox[{"quatnorm", "[", 
   RowBox[{"\"\<x\>\"", ",", "met_", ",", "q_"}], "]"}], " ", ":=", " ", 
  RowBox[{"Module", "[", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{"mts", ",", "qs", ",", "qv"}], "}"}], ",", "\[IndentingNewLine]", 
    RowBox[{
     RowBox[{"mts", " ", "=", " ", 
      RowBox[{
       RowBox[{"(", 
        RowBox[{"met", "+", 
         RowBox[{"Transpose", "[", "met", "]"}]}], ")"}], "/", "2"}]}], ";", 
     "\[IndentingNewLine]", 
     RowBox[{"qs", " ", "=", " ", 
      RowBox[{"q", "[", 
       RowBox[{"[", "1", "]"}], "]"}]}], ";", " ", 
     RowBox[{"qv", " ", "=", " ", 
      RowBox[{"Take", "[", 
       RowBox[{"q", ",", 
        RowBox[{"{", 
         RowBox[{"2", ",", "4"}], "}"}]}], "]"}]}], ";", 
     "\[IndentingNewLine]", 
     RowBox[{
      RowBox[{"qs", "^", "2"}], " ", "+", " ", 
      RowBox[{"qv", ".", 
       RowBox[{"(", 
        RowBox[{"mts", ".", "qv"}], ")"}]}]}]}]}], "\[IndentingNewLine]", 
   "]"}]}]], "Input",ExpressionUUID->"0bf1c7d7-417f-4e41-be94-46c604d0469c"],

Cell[BoxData[
 RowBox[{
  RowBox[{"quatinverse", "[", 
   RowBox[{"\"\<x\>\"", ",", "met_", ",", "q_"}], "]"}], " ", ":=", " ", 
  RowBox[{
   RowBox[{"quatinvunnorm", "[", "q", "]"}], "/", 
   RowBox[{"quatnorm", "[", 
    RowBox[{"\"\<x\>\"", ",", "met", ",", "q"}], "]"}]}]}]], "Input",Expressio\
nUUID->"aa9e80dc-90af-4465-8c96-f10db16766e2"],

Cell[BoxData[
 RowBox[{"(*", " ", "Verification", " ", "*)"}]], "Input",ExpressionUUID->"d4c2a215-4811-4c3c-aa2c-f6a5145fc4ce"],

Cell[BoxData[
 RowBox[{
  RowBox[{"quatverify", "[", 
   RowBox[{"\"\<x\>\"", ",", "m_", ",", "q_"}], "]"}], " ", ":=", " ", 
  RowBox[{"Module", "[", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{"met", ",", "mdsc", ",", "q1", ",", "q2", ",", "q3", ",", 
      RowBox[{"res", "=", 
       RowBox[{"{", "}"}]}]}], "}"}], ",", "\[IndentingNewLine]", 
    RowBox[{
     RowBox[{"met", " ", "=", " ", 
      RowBox[{"Array", "[", 
       RowBox[{
        RowBox[{
         RowBox[{"m", " ", "@@", " ", 
          RowBox[{"Sort", "[", 
           RowBox[{"List", "[", "##", "]"}], "]"}]}], "&"}], ",", 
        RowBox[{"{", 
         RowBox[{"3", ",", "3"}], "}"}]}], "]"}]}], ";", 
     "\[IndentingNewLine]", 
     RowBox[{"mdsc", " ", "=", " ", 
      RowBox[{"Sqrt", "[", 
       RowBox[{"Det", "[", "met", "]"}], "]"}]}], ";", "\[IndentingNewLine]", 
     
     RowBox[{"q1", " ", "=", " ", 
      RowBox[{"Array", "[", 
       RowBox[{
        RowBox[{"q", "[", "1", "]"}], ",", "4"}], "]"}]}], ";", " ", 
     RowBox[{"q2", " ", "=", " ", 
      RowBox[{"Array", "[", 
       RowBox[{
        RowBox[{"q", "[", "2", "]"}], ",", "4"}], "]"}]}], ";", " ", 
     RowBox[{"q3", " ", "=", " ", 
      RowBox[{"Array", "[", 
       RowBox[{
        RowBox[{"q", "[", "3", "]"}], ",", "4"}], "]"}]}], ";", 
     "\[IndentingNewLine]", 
     RowBox[{"(*", " ", "Associative", " ", "*)"}], "\[IndentingNewLine]", 
     RowBox[{"AppendTo", "[", 
      RowBox[{"res", ",", 
       RowBox[{
        RowBox[{"quatmultiply", "[", 
         RowBox[{"\"\<x\>\"", ",", "met", ",", "mdsc", ",", 
          RowBox[{"quatmultiply", "[", 
           RowBox[{
           "\"\<x\>\"", ",", "met", ",", "mdsc", ",", "q1", ",", "q2"}], 
           "]"}], ",", "q3"}], "]"}], "-", 
        RowBox[{"quatmultiply", "[", 
         RowBox[{"\"\<x\>\"", ",", "met", ",", "mdsc", ",", "q1", ",", 
          RowBox[{"quatmultiply", "[", 
           RowBox[{
           "\"\<x\>\"", ",", "met", ",", "mdsc", ",", "q2", ",", "q3"}], 
           "]"}]}], "]"}]}]}], "]"}], ";", "\[IndentingNewLine]", 
     RowBox[{"(*", " ", "Identity", " ", "*)"}], "\[IndentingNewLine]", 
     RowBox[{"AppendTo", "[", 
      RowBox[{"res", ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{
          RowBox[{"quatmultiply", "[", 
           RowBox[{
           "\"\<x\>\"", ",", "met", ",", "mdsc", ",", "q1", ",", 
            "quatidentity"}], "]"}], "-", "q1"}], ",", 
         RowBox[{
          RowBox[{"quatmultiply", "[", 
           RowBox[{
           "\"\<x\>\"", ",", "met", ",", "mdsc", ",", "quatidentity", ",", 
            "q1"}], "]"}], "-", "q1"}]}], "}"}]}], "]"}], ";", 
     "\[IndentingNewLine]", 
     RowBox[{"(*", " ", "Norm", " ", "*)"}], "\[IndentingNewLine]", 
     RowBox[{"AppendTo", "[", 
      RowBox[{"res", ",", 
       RowBox[{
        RowBox[{"quatnorm", "[", 
         RowBox[{"\"\<x\>\"", ",", "met", ",", 
          RowBox[{"quatmultiply", "[", 
           RowBox[{
           "\"\<x\>\"", ",", "met", ",", "mdsc", ",", "q1", ",", "q2"}], 
           "]"}]}], "]"}], "-", 
        RowBox[{
         RowBox[{"quatnorm", "[", 
          RowBox[{"\"\<x\>\"", ",", "met", ",", "q1"}], "]"}], "*", 
         RowBox[{"quatnorm", "[", 
          RowBox[{"\"\<x\>\"", ",", "met", ",", "q2"}], "]"}]}]}]}], "]"}], 
     ";", "\[IndentingNewLine]", 
     RowBox[{"(*", " ", "Inverse", " ", "*)"}], "\[IndentingNewLine]", 
     RowBox[{"AppendTo", "[", 
      RowBox[{"res", ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{
          RowBox[{"quatmultiply", "[", 
           RowBox[{"\"\<x\>\"", ",", "met", ",", "mdsc", ",", "q1", ",", 
            RowBox[{"quatinverse", "[", 
             RowBox[{"\"\<x\>\"", ",", "met", ",", "q1"}], "]"}]}], "]"}], 
          "-", "quatidentity"}], ",", 
         RowBox[{
          RowBox[{"quatmultiply", "[", 
           RowBox[{"\"\<x\>\"", ",", "met", ",", "mdsc", ",", 
            RowBox[{"quatinverse", "[", 
             RowBox[{"\"\<x\>\"", ",", "met", ",", "q1"}], "]"}], ",", "q1"}],
            "]"}], "-", "quatidentity"}]}], "}"}]}], "]"}], ";", 
     "\[IndentingNewLine]", 
     RowBox[{
      RowBox[{
       RowBox[{
        RowBox[{"res", " ", "//", " ", "Flatten"}], " ", "//", " ", 
        "Expand"}], " ", "//", " ", "Factor"}], " ", "//", " ", "Union"}]}]}],
    "]"}]}]], "Input",ExpressionUUID->"dc71cc44-a35b-4e7a-8f12-1739e8e5c5c8"]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{

Cell["1D", "Section",ExpressionUUID->"eea65186-dca8-4b00-b6dc-a006c2ed764b"],

Cell[BoxData[
 RowBox[{"(*", " ", 
  RowBox[{"This", " ", "is", " ", "trivial"}], " ", "*)"}]], "Input",Expressio\
nUUID->"412925b5-892c-4ff1-8449-9a9a176f1b0e"],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"rrmat", "[", "\"\<1r\>\"", "]"}], " ", ":=", " ", 
   RowBox[{"{", 
    RowBox[{"{", "1", "}"}], "}"}]}], ";", " ", 
  RowBox[{
   RowBox[{"rrmat", "[", "\"\<1s\>\"", "]"}], " ", ":=", " ", 
   RowBox[{"{", 
    RowBox[{"{", 
     RowBox[{"-", "1"}], "}"}], "}"}]}], ";"}]], "Input",ExpressionUUID->\
"4e726229-b7a6-4b02-8bfb-8ff098714c79"]
}, Closed]],

Cell[CellGroupData[{

Cell["2D", "Section",ExpressionUUID->"cd97f825-46cd-4cc9-b349-0f2ef9ab66d1"],

Cell[CellGroupData[{

Cell["Metric 2, ++", "Subsection",ExpressionUUID->"b61fed81-3593-4ba6-a0de-aef03539bac8"],

Cell[BoxData[
 RowBox[{"(*", " ", 
  RowBox[{"Uses", " ", "trig", " ", "functions"}], " ", "*)"}]], "Input",Expre\
ssionUUID->"56ed7e7c-edae-435b-9bc2-4765233469e3"],

Cell[BoxData[
 RowBox[{
  RowBox[{"rrmat", "[", 
   RowBox[{"\"\<2r\>\"", ",", "a_"}], "]"}], " ", ":=", " ", 
  RowBox[{"{", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{
      RowBox[{"Cos", "[", "a", "]"}], ",", 
      RowBox[{"-", 
       RowBox[{"Sin", "[", "a", "]"}]}]}], "}"}], ",", 
    RowBox[{"{", 
     RowBox[{
      RowBox[{"Sin", "[", "a", "]"}], ",", 
      RowBox[{"Cos", "[", "a", "]"}]}], "}"}]}], "}"}]}]], "Input",ExpressionU\
UID->"296ac48f-7ce0-4a5d-990e-c3120401407a"],

Cell[BoxData[
 RowBox[{
  RowBox[{"rrmat", "[", 
   RowBox[{"\"\<2s\>\"", ",", "a_"}], "]"}], " ", ":=", " ", 
  RowBox[{"{", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{
      RowBox[{"Cos", "[", "a", "]"}], ",", 
      RowBox[{"Sin", "[", "a", "]"}]}], "}"}], ",", 
    RowBox[{"{", 
     RowBox[{
      RowBox[{"Sin", "[", "a", "]"}], ",", 
      RowBox[{"-", 
       RowBox[{"Cos", "[", "a", "]"}]}]}], "}"}]}], "}"}]}]], "Input",Expressi\
onUUID->"928dee44-b2dc-44a7-8cc3-dd980177a1b4"],

Cell[BoxData[
 RowBox[{"(*", " ", 
  RowBox[{
   RowBox[{"Uses", " ", "2"}], "-", "vectors"}], " ", "*)"}]], "Input",Express\
ionUUID->"a0c23613-1f2b-4aa2-ba36-9168e27a25a3"],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"rrmat", "[", 
    RowBox[{"\"\<2rv\>\"", ",", "q_"}], "]"}], " ", ":=", " ", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{"q", "[", 
        RowBox[{"[", "1", "]"}], "]"}], ",", 
       RowBox[{"-", 
        RowBox[{"q", "[", 
         RowBox[{"[", "2", "]"}], "]"}]}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"q", "[", 
        RowBox[{"[", "2", "]"}], "]"}], ",", 
       RowBox[{"q", "[", 
        RowBox[{"[", "1", "]"}], "]"}]}], "}"}]}], "}"}]}], ";"}]], "Input",Ex\
pressionUUID->"1956f33e-c20a-483a-9d1c-31c91919a015"],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"rrmat", "[", 
    RowBox[{"\"\<2sv\>\"", ",", "q_"}], "]"}], " ", ":=", " ", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{"q", "[", 
        RowBox[{"[", "1", "]"}], "]"}], ",", 
       RowBox[{"q", "[", 
        RowBox[{"[", "2", "]"}], "]"}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"q", "[", 
        RowBox[{"[", "2", "]"}], "]"}], ",", 
       RowBox[{"-", 
        RowBox[{"q", "[", 
         RowBox[{"[", "1", "]"}], "]"}]}]}], "}"}]}], "}"}]}], ";"}]], "Input",\
ExpressionUUID->"cd7cd00b-81cc-4c8f-9795-fa961f62d91f"],

Cell[BoxData[
 RowBox[{
  RowBox[{"rrnorm", "[", 
   RowBox[{"\"\<2\>\"", ",", "q_"}], "]"}], " ", ":=", " ", 
  RowBox[{"abssqr", "[", 
   RowBox[{"q", ",", "2"}], "]"}]}]], "Input",ExpressionUUID->"78d79170-affb-\
4faa-aaf0-e946018e49d4"],

Cell[BoxData[
 RowBox[{
  RowBox[{"rrmat", "[", 
   RowBox[{"\"\<2rn\>\"", ",", "q_"}], "]"}], " ", ":=", " ", 
  RowBox[{
   RowBox[{"rrmat", "[", 
    RowBox[{"\"\<2rv\>\"", ",", "q"}], "]"}], "/", 
   RowBox[{"Sqrt", "[", 
    RowBox[{"rrnorm", "[", 
     RowBox[{"\"\<2\>\"", ",", "q"}], "]"}], "]"}]}]}]], "Input",ExpressionUUI\
D->"8754761b-4de7-4717-b17a-60c81e32a8b8"],

Cell[BoxData[
 RowBox[{
  RowBox[{"rrmat", "[", 
   RowBox[{"\"\<2sn\>\"", ",", "q_"}], "]"}], " ", ":=", " ", 
  RowBox[{
   RowBox[{"rrmat", "[", 
    RowBox[{"\"\<2sv\>\"", ",", "q"}], "]"}], "/", 
   RowBox[{"Sqrt", "[", 
    RowBox[{"rrnorm", "[", 
     RowBox[{"\"\<2\>\"", ",", "q"}], "]"}], "]"}]}]}]], "Input",ExpressionUUI\
D->"e4a1b35b-2b9f-466f-ab51-bec21b718dc5"],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"metric", "[", "\"\<2\>\"", "]"}], " ", ":=", " ", 
   RowBox[{"IdentityMatrix", "[", "2", "]"}]}], ";"}]], "Input",ExpressionUUID\
->"5657f54c-159c-424b-98ee-c89900095e8f"],

Cell[BoxData[
 RowBox[{"(*", " ", "Verification", " ", "*)"}]], "Input",ExpressionUUID->"19371a42-e9cd-4abe-9d4d-7b3d4a3919ac"],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"{", 
    RowBox[{
     RowBox[{
      RowBox[{"rrmat", "[", 
       RowBox[{"\"\<2r\>\"", ",", "a"}], "]"}], " ", "-", " ", 
      RowBox[{"rrmat", "[", 
       RowBox[{"\"\<2rv\>\"", ",", 
        RowBox[{"{", 
         RowBox[{
          RowBox[{"Cos", "[", "a", "]"}], ",", 
          RowBox[{"Sin", "[", "a", "]"}]}], "}"}]}], "]"}]}], ",", 
     RowBox[{
      RowBox[{"rrmat", "[", 
       RowBox[{"\"\<2s\>\"", ",", "a"}], "]"}], " ", "-", " ", 
      RowBox[{"rrmat", "[", 
       RowBox[{"\"\<2sv\>\"", ",", 
        RowBox[{"{", 
         RowBox[{
          RowBox[{"Cos", "[", "a", "]"}], ",", 
          RowBox[{"Sin", "[", "a", "]"}]}], "}"}]}], "]"}]}]}], "}"}], " ", "//",
    " ", "Flatten"}], " ", "//", " ", "Union"}]], "Input",ExpressionUUID->\
"b3f6c182-0e53-420c-95b7-7c3b8584ec08"],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{
    RowBox[{"verifyrrmd", "[", 
     RowBox[{"{", 
      RowBox[{"\"\<2\>\"", ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"{", 
          RowBox[{"\"\<2r\>\"", ",", "1"}], "}"}], ",", 
         RowBox[{"{", 
          RowBox[{"\"\<2s\>\"", ",", 
           RowBox[{"-", "1"}]}], "}"}]}], "}"}], ",", "a"}], "}"}], "]"}], 
    " ", "//", " ", "TrigReduce"}], " ", "//", " ", "Flatten"}], " ", "//", 
  " ", "Union"}]], "Input",ExpressionUUID->"e56b59ee-8bc2-4d76-9851-\
2f962a3c9e45"],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{
    RowBox[{"verifyrrmd", "[", 
     RowBox[{"{", 
      RowBox[{"\"\<2\>\"", ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"{", 
          RowBox[{"\"\<2rn\>\"", ",", "1"}], "}"}], ",", 
         RowBox[{"{", 
          RowBox[{"\"\<2sn\>\"", ",", 
           RowBox[{"-", "1"}]}], "}"}]}], "}"}], ",", 
       RowBox[{"Array", "[", 
        RowBox[{"a", ",", "2"}], "]"}]}], "}"}], "]"}], " ", "//", " ", 
    "Factor"}], " ", "//", " ", "Flatten"}], " ", "//", " ", 
  "Union"}]], "Input",ExpressionUUID->"1b070750-67ce-4cda-a350-dc8866307e2d"],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{
    RowBox[{"verifyrrprod", "[", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"\"\<2r\>\"", ",", "\"\<2s\>\""}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"a", ",", "b"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"{", 
          RowBox[{
           RowBox[{"{", 
            RowBox[{"\"\<2r\>\"", ",", 
             RowBox[{"a", "+", "b"}]}], "}"}], ",", 
           RowBox[{"{", 
            RowBox[{"\"\<2s\>\"", ",", 
             RowBox[{"a", "+", "b"}]}], "}"}]}], "}"}], ",", 
         RowBox[{"{", 
          RowBox[{
           RowBox[{"{", 
            RowBox[{"\"\<2s\>\"", ",", 
             RowBox[{"a", "-", "b"}]}], "}"}], ",", 
           RowBox[{"{", 
            RowBox[{"\"\<2r\>\"", ",", 
             RowBox[{"a", "-", "b"}]}], "}"}]}], "}"}]}], "}"}]}], "}"}], 
     "]"}], " ", "//", " ", "TrigReduce"}], " ", "//", " ", "Flatten"}], " ", 
  "//", " ", "Union"}]], "Input",ExpressionUUID->"ab1237b6-d1d9-4951-9eb3-\
76ecf9b89a07"],

Cell[BoxData[
 RowBox[{
  RowBox[{"avt", " ", "=", " ", 
   RowBox[{"Array", "[", 
    RowBox[{"a", ",", "2"}], "]"}]}], ";", " ", 
  RowBox[{"bvt", " ", "=", " ", 
   RowBox[{"Array", "[", 
    RowBox[{"b", ",", "2"}], "]"}]}], ";", " ", 
  RowBox[{"abvtsm", " ", "=", " ", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{
      RowBox[{
       RowBox[{"avt", "[", 
        RowBox[{"[", "1", "]"}], "]"}], "*", 
       RowBox[{"bvt", "[", 
        RowBox[{"[", "1", "]"}], "]"}]}], "-", 
      RowBox[{
       RowBox[{"avt", "[", 
        RowBox[{"[", "2", "]"}], "]"}], "*", 
       RowBox[{"bvt", "[", 
        RowBox[{"[", "2", "]"}], "]"}]}]}], ",", 
     RowBox[{
      RowBox[{
       RowBox[{"avt", "[", 
        RowBox[{"[", "1", "]"}], "]"}], "*", 
       RowBox[{"bvt", "[", 
        RowBox[{"[", "2", "]"}], "]"}]}], "+", 
      RowBox[{
       RowBox[{"avt", "[", 
        RowBox[{"[", "2", "]"}], "]"}], "*", 
       RowBox[{"bvt", "[", 
        RowBox[{"[", "1", "]"}], "]"}]}]}]}], "}"}]}], ";", 
  RowBox[{"abvtdf", " ", "=", " ", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{
      RowBox[{
       RowBox[{"avt", "[", 
        RowBox[{"[", "1", "]"}], "]"}], "*", 
       RowBox[{"bvt", "[", 
        RowBox[{"[", "1", "]"}], "]"}]}], "+", 
      RowBox[{
       RowBox[{"avt", "[", 
        RowBox[{"[", "2", "]"}], "]"}], "*", 
       RowBox[{"bvt", "[", 
        RowBox[{"[", "2", "]"}], "]"}]}]}], ",", 
     RowBox[{
      RowBox[{
       RowBox[{"-", 
        RowBox[{"avt", "[", 
         RowBox[{"[", "1", "]"}], "]"}]}], "*", 
       RowBox[{"bvt", "[", 
        RowBox[{"[", "2", "]"}], "]"}]}], "+", 
      RowBox[{
       RowBox[{"avt", "[", 
        RowBox[{"[", "2", "]"}], "]"}], "*", 
       RowBox[{"bvt", "[", 
        RowBox[{"[", "1", "]"}], "]"}]}]}]}], "}"}]}], ";"}]], "Input",Express\
ionUUID->"c98a5b10-eb83-43cc-8b19-1e03abca6361"],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{
    RowBox[{"verifyrrprod", "[", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"\"\<2rv\>\"", ",", "\"\<2sv\>\""}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"avt", ",", "bvt"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"{", 
          RowBox[{
           RowBox[{"{", 
            RowBox[{"\"\<2rv\>\"", ",", "abvtsm"}], "}"}], ",", 
           RowBox[{"{", 
            RowBox[{"\"\<2sv\>\"", ",", "abvtsm"}], "}"}]}], "}"}], ",", 
         RowBox[{"{", 
          RowBox[{
           RowBox[{"{", 
            RowBox[{"\"\<2sv\>\"", ",", "abvtdf"}], "}"}], ",", 
           RowBox[{"{", 
            RowBox[{"\"\<2rv\>\"", ",", "abvtdf"}], "}"}]}], "}"}]}], "}"}]}],
       "}"}], "]"}], " ", "//", " ", "Factor"}], " ", "//", " ", "Flatten"}], 
  " ", "//", " ", "Union"}]], "Input",ExpressionUUID->"53786ebb-0a9e-4ec7-\
a411-70eed51740ac"]
}, Closed]],

Cell[CellGroupData[{

Cell["Metric 1+1, +-", "Subsection",ExpressionUUID->"fbabf29c-050e-4ad9-a050-0ac535b59515"],

Cell[BoxData[
 RowBox[{"(*", " ", 
  RowBox[{"Uses", " ", "hyperbolic", " ", "trig", " ", "functions"}], " ", 
  "*)"}]], "Input",ExpressionUUID->"ff6ea8ac-f643-4b42-8ccf-9b36f44d3e88"],

Cell[BoxData[
 RowBox[{
  RowBox[{"rrmat", "[", 
   RowBox[{"\"\<11rr\>\"", ",", "a_"}], "]"}], " ", ":=", " ", 
  RowBox[{"{", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{
      RowBox[{"Cosh", "[", "a", "]"}], ",", 
      RowBox[{"Sinh", "[", "a", "]"}]}], "}"}], ",", 
    RowBox[{"{", 
     RowBox[{
      RowBox[{"Sinh", "[", "a", "]"}], ",", 
      RowBox[{"Cosh", "[", "a", "]"}]}], "}"}]}], "}"}]}]], "Input",Expression\
UUID->"757621b0-732c-4f0c-85fc-9dd581cd1f92"],

Cell[BoxData[
 RowBox[{
  RowBox[{"rrmat", "[", 
   RowBox[{"\"\<11rs\>\"", ",", "a_"}], "]"}], " ", ":=", " ", 
  RowBox[{"{", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{
      RowBox[{"Cosh", "[", "a", "]"}], ",", 
      RowBox[{"Sinh", "[", "a", "]"}]}], "}"}], ",", 
    RowBox[{"{", 
     RowBox[{
      RowBox[{"-", 
       RowBox[{"Sinh", "[", "a", "]"}]}], ",", 
      RowBox[{"-", 
       RowBox[{"Cosh", "[", "a", "]"}]}]}], "}"}]}], "}"}]}]], "Input",Express\
ionUUID->"fc515b88-cb1e-46e8-93a3-c8b81a1926b8"],

Cell[BoxData[
 RowBox[{
  RowBox[{"rrmat", "[", 
   RowBox[{"\"\<11sr\>\"", ",", "a_"}], "]"}], " ", ":=", " ", 
  RowBox[{"{", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{
      RowBox[{"-", 
       RowBox[{"Cosh", "[", "a", "]"}]}], ",", 
      RowBox[{"-", 
       RowBox[{"Sinh", "[", "a", "]"}]}]}], "}"}], ",", 
    RowBox[{"{", 
     RowBox[{
      RowBox[{"Sinh", "[", "a", "]"}], ",", 
      RowBox[{"Cosh", "[", "a", "]"}]}], "}"}]}], "}"}]}]], "Input",Expression\
UUID->"fdd0a35c-be8e-48c9-9f41-809658564a71"],

Cell[BoxData[
 RowBox[{
  RowBox[{"rrmat", "[", 
   RowBox[{"\"\<11ss\>\"", ",", "a_"}], "]"}], " ", ":=", " ", 
  RowBox[{"{", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{
      RowBox[{"-", 
       RowBox[{"Cosh", "[", "a", "]"}]}], ",", 
      RowBox[{"-", 
       RowBox[{"Sinh", "[", "a", "]"}]}]}], "}"}], ",", 
    RowBox[{"{", 
     RowBox[{
      RowBox[{"-", 
       RowBox[{"Sinh", "[", "a", "]"}]}], ",", 
      RowBox[{"-", 
       RowBox[{"Cosh", "[", "a", "]"}]}]}], "}"}]}], "}"}]}]], "Input",Express\
ionUUID->"566c1965-0b71-4304-8ec7-1e7b7749c699"],

Cell[BoxData[
 RowBox[{"(*", " ", 
  RowBox[{"2", "-", "vectors"}], " ", "*)"}]], "Input",ExpressionUUID->\
"1c78ed17-0c1b-4984-b391-5ff22d63b05d"],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"rrmat", "[", 
    RowBox[{"\"\<11rv\>\"", ",", "q_"}], "]"}], " ", ":=", " ", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{"q", "[", 
        RowBox[{"[", "1", "]"}], "]"}], ",", 
       RowBox[{"q", "[", 
        RowBox[{"[", "2", "]"}], "]"}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"q", "[", 
        RowBox[{"[", "2", "]"}], "]"}], ",", 
       RowBox[{"q", "[", 
        RowBox[{"[", "1", "]"}], "]"}]}], "}"}]}], "}"}]}], ";"}]], "Input",Ex\
pressionUUID->"adb92e55-99ac-41c5-9a9a-da30bc73608f"],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"rrmat", "[", 
    RowBox[{"\"\<11sv\>\"", ",", "q_"}], "]"}], " ", ":=", " ", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{"q", "[", 
        RowBox[{"[", "1", "]"}], "]"}], ",", 
       RowBox[{"q", "[", 
        RowBox[{"[", "2", "]"}], "]"}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"-", 
        RowBox[{"q", "[", 
         RowBox[{"[", "2", "]"}], "]"}]}], ",", 
       RowBox[{"-", 
        RowBox[{"q", "[", 
         RowBox[{"[", "1", "]"}], "]"}]}]}], "}"}]}], "}"}]}], ";"}]], "Input",\
ExpressionUUID->"f919a115-e7e8-472c-af8b-8d61f795b482"],

Cell[BoxData[
 RowBox[{
  RowBox[{"rrnorm", "[", 
   RowBox[{"\"\<11\>\"", ",", "q_"}], "]"}], " ", ":=", " ", 
  RowBox[{"abssqrmet", "[", 
   RowBox[{"q", ",", 
    RowBox[{"{", 
     RowBox[{"1", ",", 
      RowBox[{"-", "1"}]}], "}"}]}], "]"}]}]], "Input",ExpressionUUID->\
"03ed2364-654b-4d22-a83f-853b084a8f42"],

Cell[BoxData[
 RowBox[{
  RowBox[{"rrmat", "[", 
   RowBox[{"\"\<11rn\>\"", ",", "q_"}], "]"}], " ", ":=", " ", 
  RowBox[{
   RowBox[{"rrmat", "[", 
    RowBox[{"\"\<11rv\>\"", ",", "q"}], "]"}], "/", 
   RowBox[{"Sqrt", "[", 
    RowBox[{"rrnorm", "[", 
     RowBox[{"\"\<11\>\"", ",", "q"}], "]"}], "]"}]}]}]], "Input",ExpressionUU\
ID->"b9d77b97-10e9-45cf-9585-8199627149d5"],

Cell[BoxData[
 RowBox[{
  RowBox[{"rrmat", "[", 
   RowBox[{"\"\<11sn\>\"", ",", "q_"}], "]"}], " ", ":=", " ", 
  RowBox[{
   RowBox[{"rrmat", "[", 
    RowBox[{"\"\<11sv\>\"", ",", "q"}], "]"}], "/", 
   RowBox[{"Sqrt", "[", 
    RowBox[{"rrnorm", "[", 
     RowBox[{"\"\<11\>\"", ",", "q"}], "]"}], "]"}]}]}]], "Input",ExpressionUU\
ID->"18a01007-efe4-48a2-85dc-70f6fc43d5a7"],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"metric", "[", "\"\<11\>\"", "]"}], " ", "=", " ", 
   RowBox[{"DiagonalMatrix", "[", 
    RowBox[{"{", 
     RowBox[{"1", ",", 
      RowBox[{"-", "1"}]}], "}"}], "]"}]}], ";"}]], "Input",ExpressionUUID->\
"f3dec7c7-1de5-4c6b-86b6-899b64721af0"],

Cell[BoxData[
 RowBox[{"(*", " ", "Verification", " ", "*)"}]], "Input",ExpressionUUID->"f25ca4f8-eb43-49c7-90fe-171857966878"],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"{", 
    RowBox[{
     RowBox[{
      RowBox[{"rrmat", "[", 
       RowBox[{"\"\<11rr\>\"", ",", "a"}], "]"}], " ", "-", " ", 
      RowBox[{"rrmat", "[", 
       RowBox[{"\"\<11rv\>\"", ",", 
        RowBox[{"{", 
         RowBox[{
          RowBox[{"Cosh", "[", "a", "]"}], ",", 
          RowBox[{"Sinh", "[", "a", "]"}]}], "}"}]}], "]"}]}], ",", 
     RowBox[{
      RowBox[{"rrmat", "[", 
       RowBox[{"\"\<11rs\>\"", ",", "a"}], "]"}], " ", "-", " ", 
      RowBox[{"rrmat", "[", 
       RowBox[{"\"\<11sv\>\"", ",", 
        RowBox[{"{", 
         RowBox[{
          RowBox[{"Cosh", "[", "a", "]"}], ",", 
          RowBox[{"Sinh", "[", "a", "]"}]}], "}"}]}], "]"}]}], ",", 
     RowBox[{
      RowBox[{"rrmat", "[", 
       RowBox[{"\"\<11sr\>\"", ",", "a"}], "]"}], " ", "-", " ", 
      RowBox[{"rrmat", "[", 
       RowBox[{"\"\<11sv\>\"", ",", 
        RowBox[{"-", 
         RowBox[{"{", 
          RowBox[{
           RowBox[{"Cosh", "[", "a", "]"}], ",", 
           RowBox[{"Sinh", "[", "a", "]"}]}], "}"}]}]}], "]"}]}], ",", 
     RowBox[{
      RowBox[{"rrmat", "[", 
       RowBox[{"\"\<11ss\>\"", ",", "a"}], "]"}], " ", "-", " ", 
      RowBox[{"rrmat", "[", 
       RowBox[{"\"\<11rv\>\"", ",", 
        RowBox[{"-", 
         RowBox[{"{", 
          RowBox[{
           RowBox[{"Cosh", "[", "a", "]"}], ",", 
           RowBox[{"Sinh", "[", "a", "]"}]}], "}"}]}]}], "]"}]}]}], "}"}], 
   " ", "//", " ", "Flatten"}], " ", "//", " ", "Union"}]], "Input",Expression\
UUID->"805549f8-9c2e-409d-b865-50d5ff520f6b"],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{
    RowBox[{"verifyrrprod", "[", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "\"\<11rr\>\"", ",", "\"\<11rs\>\"", ",", "\"\<11sr\>\"", ",", 
         "\"\<11ss\>\""}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"a", ",", "b"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"{", 
          RowBox[{
           RowBox[{"{", 
            RowBox[{"\"\<11rr\>\"", ",", 
             RowBox[{"a", "+", "b"}]}], "}"}], ",", 
           RowBox[{"{", 
            RowBox[{"\"\<11rs\>\"", ",", 
             RowBox[{
              RowBox[{"-", "a"}], "+", "b"}]}], "}"}], ",", 
           RowBox[{"{", 
            RowBox[{"\"\<11sr\>\"", ",", 
             RowBox[{
              RowBox[{"-", "a"}], "+", "b"}]}], "}"}], ",", 
           RowBox[{"{", 
            RowBox[{"\"\<11ss\>\"", ",", 
             RowBox[{"a", "+", "b"}]}], "}"}]}], "}"}], ",", 
         RowBox[{"{", 
          RowBox[{
           RowBox[{"{", 
            RowBox[{"\"\<11rs\>\"", ",", 
             RowBox[{"a", "+", "b"}]}], "}"}], ",", 
           RowBox[{"{", 
            RowBox[{"\"\<11rr\>\"", ",", 
             RowBox[{
              RowBox[{"-", "a"}], "+", "b"}]}], "}"}], ",", 
           RowBox[{"{", 
            RowBox[{"\"\<11ss\>\"", ",", 
             RowBox[{
              RowBox[{"-", "a"}], "+", "b"}]}], "}"}], ",", 
           RowBox[{"{", 
            RowBox[{"\"\<11sr\>\"", ",", 
             RowBox[{"a", "+", "b"}]}], "}"}]}], "}"}], ",", 
         RowBox[{"{", 
          RowBox[{
           RowBox[{"{", 
            RowBox[{"\"\<11sr\>\"", ",", 
             RowBox[{"a", "+", "b"}]}], "}"}], ",", 
           RowBox[{"{", 
            RowBox[{"\"\<11ss\>\"", ",", 
             RowBox[{
              RowBox[{"-", "a"}], "+", "b"}]}], "}"}], ",", 
           RowBox[{"{", 
            RowBox[{"\"\<11rr\>\"", ",", 
             RowBox[{
              RowBox[{"-", "a"}], "+", "b"}]}], "}"}], ",", 
           RowBox[{"{", 
            RowBox[{"\"\<11rs\>\"", ",", 
             RowBox[{"a", "+", "b"}]}], "}"}]}], "}"}], ",", 
         RowBox[{"{", 
          RowBox[{
           RowBox[{"{", 
            RowBox[{"\"\<11ss\>\"", ",", 
             RowBox[{"a", "+", "b"}]}], "}"}], ",", 
           RowBox[{"{", 
            RowBox[{"\"\<11sr\>\"", ",", 
             RowBox[{
              RowBox[{"-", "a"}], "+", "b"}]}], "}"}], ",", 
           RowBox[{"{", 
            RowBox[{"\"\<11rs\>\"", ",", 
             RowBox[{
              RowBox[{"-", "a"}], "+", "b"}]}], "}"}], ",", 
           RowBox[{"{", 
            RowBox[{"\"\<11rr\>\"", ",", 
             RowBox[{"a", "+", "b"}]}], "}"}]}], "}"}]}], "}"}]}], "}"}], 
     "]"}], " ", "//", " ", "TrigReduce"}], " ", "//", " ", "Flatten"}], " ", 
  "//", " ", "Union"}]], "Input",ExpressionUUID->"05a8b081-6d84-4aeb-a604-\
1f19da1217ae"]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{

Cell["3D", "Section",ExpressionUUID->"18fa306d-6ea5-45c2-8747-886bf9b50d3e"],

Cell[CellGroupData[{

Cell["Metric 3, +++", "Subsection",ExpressionUUID->"0f342b70-c894-4a25-8ad3-fd3a7ae3db16"],

Cell[BoxData[
 RowBox[{"(*", " ", 
  RowBox[{
   RowBox[{"Uses", " ", "4"}], "-", 
   RowBox[{"vectors", ":", " ", "quaternions"}]}], " ", "*)"}]], "Input",Expre\
ssionUUID->"ab68d7d3-9ecd-4d99-84f8-cfde77db47e8"],

Cell[BoxData[
 RowBox[{
  RowBox[{"rrmat", "[", 
   RowBox[{"\"\<3rv\>\"", ",", "q_"}], "]"}], " ", ":=", "  ", 
  RowBox[{"Module", "[", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{"qs", ",", "qv"}], "}"}], ",", "\[IndentingNewLine]", 
    RowBox[{
     RowBox[{"qs", " ", "=", " ", 
      RowBox[{"q", "[", 
       RowBox[{"[", "1", "]"}], "]"}]}], ";", " ", 
     RowBox[{"qv", " ", "=", " ", 
      RowBox[{"Take", "[", 
       RowBox[{"q", ",", 
        RowBox[{"{", 
         RowBox[{"2", ",", "4"}], "}"}]}], "]"}]}], ";", 
     "\[IndentingNewLine]", 
     RowBox[{
      RowBox[{
       RowBox[{"(", 
        RowBox[{
         RowBox[{"qs", "^", "2"}], "-", 
         RowBox[{"abssqr", "[", 
          RowBox[{"qv", ",", "3"}], "]"}]}], ")"}], "*", 
       RowBox[{"IdentityMatrix", "[", "3", "]"}]}], " ", "+", " ", 
      RowBox[{"2", "*", 
       RowBox[{"dyad", "[", 
        RowBox[{"qv", ",", "qv"}], "]"}]}], " ", "+", 
      RowBox[{"2", "*", "qs", "*", 
       RowBox[{"asymvt", "[", "qv", "]"}]}]}]}]}], "]"}]}]], "Input",Expressio\
nUUID->"dfa76282-0145-4418-ade6-eb5088fcd83e"],

Cell[BoxData[
 RowBox[{
  RowBox[{"rrmat", "[", 
   RowBox[{"\"\<3sv\>\"", ",", "q_"}], "]"}], " ", ":=", " ", 
  RowBox[{"-", " ", 
   RowBox[{"rrmat", "[", 
    RowBox[{"\"\<3rv\>\"", ",", "q"}], "]"}]}]}]], "Input",ExpressionUUID->\
"030798f1-ff54-42b0-a827-397adf39c11c"],

Cell[BoxData[
 RowBox[{
  RowBox[{"rrnorm", "[", 
   RowBox[{"\"\<3\>\"", ",", "q_"}], "]"}], " ", ":=", " ", 
  RowBox[{"quatnorm", "[", "q", "]"}]}]], "Input",ExpressionUUID->"89eceb2a-\
2efd-4cdc-a99b-6a7cd3aadbd6"],

Cell[BoxData[
 RowBox[{
  RowBox[{"rrmat", "[", 
   RowBox[{"\"\<3rn\>\"", ",", "q_"}], "]"}], " ", ":=", " ", 
  RowBox[{
   RowBox[{"rrmat", "[", 
    RowBox[{"\"\<3rv\>\"", ",", "q"}], "]"}], "/", 
   RowBox[{"rrnorm", "[", 
    RowBox[{"\"\<3\>\"", ",", "q"}], "]"}]}]}]], "Input",ExpressionUUID->\
"261b28c7-8e94-4424-b15f-4951bba2d8de"],

Cell[BoxData[
 RowBox[{
  RowBox[{"rrmat", "[", 
   RowBox[{"\"\<3sn\>\"", ",", "q_"}], "]"}], " ", ":=", " ", 
  RowBox[{
   RowBox[{"rrmat", "[", 
    RowBox[{"\"\<3sv\>\"", ",", "q"}], "]"}], "/", 
   RowBox[{"rrnorm", "[", 
    RowBox[{"\"\<3\>\"", ",", "q"}], "]"}]}]}]], "Input",ExpressionUUID->\
"02f2a414-de8b-4ea4-bd2d-23f9f8d643e6"],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"metric", "[", "\"\<3\>\"", "]"}], " ", "=", " ", 
   RowBox[{"IdentityMatrix", "[", "3", "]"}]}], ";"}]], "Input",ExpressionUUID\
->"6c5783f4-c460-4e08-87a6-64326e83bf56"],

Cell[BoxData[
 RowBox[{"(*", " ", "Verification", " ", "*)"}]], "Input",ExpressionUUID->"5db3e26b-9b98-48da-931a-a4119cce5659"],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{
    RowBox[{"verifyrrmd", "[", 
     RowBox[{"{", 
      RowBox[{"\"\<3\>\"", ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"{", 
          RowBox[{"\"\<3rn\>\"", ",", "1"}], "}"}], ",", 
         RowBox[{"{", 
          RowBox[{"\"\<3sn\>\"", ",", 
           RowBox[{"-", "1"}]}], "}"}]}], "}"}], ",", 
       RowBox[{"Array", "[", 
        RowBox[{"a", ",", "4"}], "]"}]}], "}"}], "]"}], " ", "//", " ", 
    "Factor"}], " ", "//", " ", "Flatten"}], " ", "//", " ", 
  "Union"}]], "Input",ExpressionUUID->"17902363-650a-483e-9349-114506379a85"],

Cell[BoxData[
 RowBox[{
  RowBox[{"aqt", " ", "=", " ", 
   RowBox[{"Array", "[", 
    RowBox[{"a", ",", "4"}], "]"}]}], ";", " ", 
  RowBox[{"bqt", " ", "=", " ", 
   RowBox[{"Array", "[", 
    RowBox[{"b", ",", "4"}], "]"}]}], ";", " ", 
  RowBox[{"abqt", " ", "=", " ", 
   RowBox[{"quatmultiply", "[", 
    RowBox[{"aqt", ",", "bqt"}], "]"}]}], ";"}]], "Input",ExpressionUUID->\
"b74e88c3-dda3-47aa-96ea-ffd6552ed508"],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{
    RowBox[{"verifyrrprod", "[", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"\"\<3rv\>\"", ",", "\"\<3sv\>\""}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"aqt", ",", "bqt"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"{", 
          RowBox[{
           RowBox[{"{", 
            RowBox[{"\"\<3rv\>\"", ",", "abqt"}], "}"}], ",", 
           RowBox[{"{", 
            RowBox[{"\"\<3sv\>\"", ",", "abqt"}], "}"}]}], "}"}], ",", 
         RowBox[{"{", 
          RowBox[{
           RowBox[{"{", 
            RowBox[{"\"\<3sv\>\"", ",", "abqt"}], "}"}], ",", 
           RowBox[{"{", 
            RowBox[{"\"\<3rv\>\"", ",", "abqt"}], "}"}]}], "}"}]}], "}"}]}], 
      "}"}], "]"}], "//", " ", "Factor"}], " ", "//", " ", "Flatten"}], " ", "//",
   " ", "Union"}]], "Input",ExpressionUUID->"67e3bb78-f18c-4b00-bedd-\
11845dff6ae3"]
}, Closed]],

Cell[CellGroupData[{

Cell["Metric 2+1, ++-", "Subsection",ExpressionUUID->"340b63ea-ccae-45cb-a242-19c4909ff717"],

Cell[BoxData[
 RowBox[{
  RowBox[{"rr21metbase", " ", "=", " ", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"-", "1"}], ",", 
     RowBox[{"-", "1"}], ",", "1"}], "}"}]}], ";"}]], "Input",ExpressionUUID->\
"5ad0cd05-0862-427a-a72d-e912e26dea4a"],

Cell[BoxData[
 RowBox[{
  RowBox[{"rrmat", "[", 
   RowBox[{"\"\<21rrv\>\"", ",", "q_"}], "]"}], " ", ":=", " ", 
  RowBox[{"Module", "[", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{"qs", ",", "qv"}], "}"}], ",", "\[IndentingNewLine]", 
    RowBox[{
     RowBox[{"qs", " ", "=", " ", 
      RowBox[{"q", "[", 
       RowBox[{"[", "1", "]"}], "]"}]}], ";", " ", 
     RowBox[{"qv", " ", "=", " ", 
      RowBox[{"Take", "[", 
       RowBox[{"q", ",", 
        RowBox[{"{", 
         RowBox[{"2", ",", "4"}], "}"}]}], "]"}]}], ";", 
     "\[IndentingNewLine]", 
     RowBox[{
      RowBox[{
       RowBox[{"(", 
        RowBox[{
         RowBox[{"qs", "^", "2"}], "-", 
         RowBox[{"(", 
          RowBox[{"qv", ".", 
           RowBox[{"(", 
            RowBox[{"rr21metbase", "*", "qv"}], ")"}]}], ")"}]}], ")"}], "*", 
       
       RowBox[{"IdentityMatrix", "[", "3", "]"}]}], " ", "+", " ", 
      RowBox[{"2", "*", "rr21metbase", "*", 
       RowBox[{"dyad", "[", 
        RowBox[{"qv", ",", "qv"}], "]"}]}], " ", "+", " ", 
      RowBox[{"2", "*", "qs", "*", 
       RowBox[{"secondprod", "[", 
        RowBox[{"rr21metbase", ",", 
         RowBox[{"asymvt", "[", "qv", "]"}]}], "]"}]}]}]}]}], 
   "\[IndentingNewLine]", "]"}]}]], "Input",ExpressionUUID->"1f929c31-48c7-\
48d2-8390-9b21230b1f59"],

Cell[BoxData[
 RowBox[{
  RowBox[{"rrmat", "[", 
   RowBox[{"\"\<21rsv\>\"", ",", "q_"}], "]"}], " ", ":=", " ", 
  RowBox[{"secondprod", "[", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{"1", ",", "1", ",", 
      RowBox[{"-", "1"}]}], "}"}], ",", 
    RowBox[{"rrmat", "[", 
     RowBox[{"\"\<21rrv\>\"", ",", "q"}], "]"}]}], "]"}]}]], "Input",Expressio\
nUUID->"71c6a46a-a5b8-42bb-a5b9-62efe173a5c0"],

Cell[BoxData[
 RowBox[{
  RowBox[{"rrmat", "[", 
   RowBox[{"\"\<21srv\>\"", ",", "q_"}], "]"}], " ", ":=", " ", 
  RowBox[{"secondprod", "[", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{"1", ",", 
      RowBox[{"-", "1"}], ",", "1"}], "}"}], ",", 
    RowBox[{"rrmat", "[", 
     RowBox[{"\"\<21rrv\>\"", ",", "q"}], "]"}]}], "]"}]}]], "Input",Expressio\
nUUID->"9a7b849b-2148-4f01-96b6-c0c241c22b52"],

Cell[BoxData[
 RowBox[{
  RowBox[{"rrmat", "[", 
   RowBox[{"\"\<21ssv\>\"", ",", "q_"}], "]"}], " ", ":=", " ", 
  RowBox[{"secondprod", "[", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{"1", ",", 
      RowBox[{"-", "1"}], ",", 
      RowBox[{"-", "1"}]}], "}"}], ",", 
    RowBox[{"rrmat", "[", 
     RowBox[{"\"\<21rrv\>\"", ",", "q"}], "]"}]}], "]"}]}]], "Input",Expressio\
nUUID->"12a4c7e4-901a-473a-a881-566fd4e0c01b"],

Cell[BoxData[
 RowBox[{
  RowBox[{"rrnorm", "[", 
   RowBox[{"\"\<21\>\"", ",", "q_"}], "]"}], " ", ":=", " ", 
  RowBox[{"quatnorm", "[", 
   RowBox[{"rr21metbase", ",", "q"}], "]"}]}]], "Input",ExpressionUUID->\
"b2c5b941-26a0-406e-bb07-d017cc5599c7"],

Cell[BoxData[
 RowBox[{
  RowBox[{"rrmat", "[", 
   RowBox[{"\"\<21rrn\>\"", ",", "q_"}], "]"}], " ", ":=", " ", 
  RowBox[{
   RowBox[{"rrmat", "[", 
    RowBox[{"\"\<21rrv\>\"", ",", "q"}], "]"}], "/", 
   RowBox[{"rrnorm", "[", 
    RowBox[{"\"\<21\>\"", ",", "q"}], "]"}]}]}]], "Input",ExpressionUUID->\
"00ae7e13-0b2b-43d4-8daf-940124e63b8f"],

Cell[BoxData[
 RowBox[{
  RowBox[{"rrmat", "[", 
   RowBox[{"\"\<21rsn\>\"", ",", "q_"}], "]"}], " ", ":=", " ", 
  RowBox[{
   RowBox[{"rrmat", "[", 
    RowBox[{"\"\<21rsv\>\"", ",", "q"}], "]"}], "/", 
   RowBox[{"rrnorm", "[", 
    RowBox[{"\"\<21\>\"", ",", "q"}], "]"}]}]}]], "Input",ExpressionUUID->\
"8627bff3-8c55-4257-a9ff-d2299cc5996b"],

Cell[BoxData[
 RowBox[{
  RowBox[{"rrmat", "[", 
   RowBox[{"\"\<21srn\>\"", ",", "q_"}], "]"}], " ", ":=", " ", 
  RowBox[{
   RowBox[{"rrmat", "[", 
    RowBox[{"\"\<21srv\>\"", ",", "q"}], "]"}], "/", 
   RowBox[{"rrnorm", "[", 
    RowBox[{"\"\<21\>\"", ",", "q"}], "]"}]}]}]], "Input",ExpressionUUID->\
"4303771b-6f28-46bd-9cfc-f675198e0fcd"],

Cell[BoxData[
 RowBox[{
  RowBox[{"rrmat", "[", 
   RowBox[{"\"\<21ssn\>\"", ",", "q_"}], "]"}], " ", ":=", " ", 
  RowBox[{
   RowBox[{"rrmat", "[", 
    RowBox[{"\"\<21ssv\>\"", ",", "q"}], "]"}], "/", 
   RowBox[{"rrnorm", "[", 
    RowBox[{"\"\<21\>\"", ",", "q"}], "]"}]}]}]], "Input",ExpressionUUID->\
"6137371e-b606-4085-8eff-59e79ee8924e"],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"metric", "[", "\"\<21\>\"", "]"}], " ", "=", " ", 
   RowBox[{"-", " ", 
    RowBox[{"DiagonalMatrix", "[", "rr21metbase", "]"}]}]}], ";"}]], "Input",E\
xpressionUUID->"62f8354e-dc3f-4627-a7a1-7007168348d2"],

Cell[BoxData[
 RowBox[{"(*", " ", "Verification", " ", "*)"}]], "Input",ExpressionUUID->"e8379159-5e01-4ef0-ae7a-31ca045f3924"],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{
    RowBox[{"verifyrrmd", "[", 
     RowBox[{"{", 
      RowBox[{"\"\<21\>\"", ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"{", 
          RowBox[{"\"\<21rrn\>\"", ",", "1"}], "}"}], ",", 
         RowBox[{"{", 
          RowBox[{"\"\<21rsn\>\"", ",", 
           RowBox[{"-", "1"}]}], "}"}], ",", 
         RowBox[{"{", 
          RowBox[{"\"\<21srn\>\"", ",", 
           RowBox[{"-", "1"}]}], "}"}], ",", 
         RowBox[{"{", 
          RowBox[{"\"\<21ssn\>\"", ",", "1"}], "}"}]}], "}"}], ",", 
       RowBox[{"Array", "[", 
        RowBox[{"a", ",", "4"}], "]"}]}], "}"}], "]"}], " ", "//", " ", 
    "Factor"}], " ", "//", " ", "Flatten"}], " ", "//", " ", 
  "Union"}]], "Input",ExpressionUUID->"196dbb26-3e91-41a9-806b-395a18fe6606"],

Cell[BoxData[
 RowBox[{
  RowBox[{"abqtx1", " ", "=", " ", 
   RowBox[{"quatmultiply", "[", 
    RowBox[{"rr21metbase", ",", "1", ",", "aqt", ",", "bqt"}], "]"}]}], 
  ";"}]], "Input",ExpressionUUID->"627c99de-2125-408a-b174-26969780d86a"],

Cell[BoxData[
 RowBox[{
  RowBox[{"abqtx2", " ", "=", " ", 
   RowBox[{"quatmultiply", "[", 
    RowBox[{"rr21metbase", ",", "1", ",", "aqt", ",", 
     RowBox[{
      RowBox[{"{", 
       RowBox[{"1", ",", 
        RowBox[{"-", "1"}], ",", 
        RowBox[{"-", "1"}], ",", "1"}], "}"}], "*", "bqt"}]}], "]"}]}], 
  ";"}]], "Input",ExpressionUUID->"0f82b827-49ef-4215-9dc7-6b4f71ef1b47"],

Cell[BoxData[
 RowBox[{
  RowBox[{"abqtx3", " ", "=", " ", 
   RowBox[{"quatmultiply", "[", 
    RowBox[{"rr21metbase", ",", "1", ",", "aqt", ",", 
     RowBox[{
      RowBox[{"{", 
       RowBox[{"1", ",", 
        RowBox[{"-", "1"}], ",", "1", ",", 
        RowBox[{"-", "1"}]}], "}"}], "*", "bqt"}]}], "]"}]}], ";"}]], "Input",\
ExpressionUUID->"c63dbe9c-3b8a-4cbd-b64a-480e4b1ff688"],

Cell[BoxData[
 RowBox[{
  RowBox[{"abqtx4", " ", "=", " ", 
   RowBox[{"quatmultiply", "[", 
    RowBox[{"rr21metbase", ",", "1", ",", "aqt", ",", 
     RowBox[{
      RowBox[{"{", 
       RowBox[{"1", ",", "1", ",", 
        RowBox[{"-", "1"}], ",", 
        RowBox[{"-", "1"}]}], "}"}], "*", "bqt"}]}], "]"}]}], ";"}]], "Input",\
ExpressionUUID->"fd4f2964-24ef-47e7-b933-9aedda122f4e"],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{
    RowBox[{"verifyrrprod", "[", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "\"\<21rrv\>\"", ",", "\"\<21rsv\>\"", ",", "\"\<21srv\>\"", ",", 
         "\"\<21ssv\>\""}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"aqt", ",", "bqt"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"{", 
          RowBox[{
           RowBox[{"{", 
            RowBox[{"\"\<21rrv\>\"", ",", "abqtx1"}], "}"}], ",", 
           RowBox[{"{", 
            RowBox[{"\"\<21rsv\>\"", ",", "abqtx1"}], "}"}], ",", 
           RowBox[{"{", 
            RowBox[{"\"\<21srv\>\"", ",", "abqtx1"}], "}"}], ",", 
           RowBox[{"{", 
            RowBox[{"\"\<21ssv\>\"", ",", "abqtx1"}], "}"}]}], "}"}], ",", 
         RowBox[{"{", 
          RowBox[{
           RowBox[{"{", 
            RowBox[{"\"\<21rsv\>\"", ",", "abqtx2"}], "}"}], ",", 
           RowBox[{"{", 
            RowBox[{"\"\<21rrv\>\"", ",", "abqtx2"}], "}"}], ",", 
           RowBox[{"{", 
            RowBox[{"\"\<21ssv\>\"", ",", "abqtx2"}], "}"}], ",", 
           RowBox[{"{", 
            RowBox[{"\"\<21srv\>\"", ",", "abqtx2"}], "}"}]}], "}"}], ",", 
         RowBox[{"{", 
          RowBox[{
           RowBox[{"{", 
            RowBox[{"\"\<21srv\>\"", ",", "abqtx3"}], "}"}], ",", 
           RowBox[{"{", 
            RowBox[{"\"\<21ssv\>\"", ",", "abqtx3"}], "}"}], ",", 
           RowBox[{"{", 
            RowBox[{"\"\<21rrv\>\"", ",", "abqtx3"}], "}"}], ",", 
           RowBox[{"{", 
            RowBox[{"\"\<21rsv\>\"", ",", "abqtx3"}], "}"}]}], "}"}], ",", 
         RowBox[{"{", 
          RowBox[{
           RowBox[{"{", 
            RowBox[{"\"\<21ssv\>\"", ",", "abqtx4"}], "}"}], ",", 
           RowBox[{"{", 
            RowBox[{"\"\<21srv\>\"", ",", "abqtx4"}], "}"}], ",", 
           RowBox[{"{", 
            RowBox[{"\"\<21rsv\>\"", ",", "abqtx4"}], "}"}], ",", 
           RowBox[{"{", 
            RowBox[{"\"\<21rrv\>\"", ",", "abqtx4"}], "}"}]}], "}"}]}], 
        "}"}]}], "}"}], "]"}], " ", "//", " ", "Factor"}], " ", "//", " ", 
   "Flatten"}], " ", "//", " ", "Union"}]], "Input",ExpressionUUID->"fceb4c27-\
81a3-43ff-9353-628459cae856"]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{

Cell["4D", "Section",ExpressionUUID->"b39ad13b-68b9-433c-8356-0e8b85c955f3"],

Cell[CellGroupData[{

Cell["Metric 4, ++++", "Subsection",ExpressionUUID->"d8c52f81-b96b-41ea-8680-909c8e771199"],

Cell[BoxData[
 RowBox[{"(*", " ", 
  RowBox[{
   RowBox[{"Pair", " ", "of", " ", "quaternions"}], ",", " ", 
   RowBox[{
    RowBox[{"one", " ", "of", " ", "them"}], " ", "+", " ", 
    RowBox[{"and", " ", "one", " ", "of", " ", "them"}], " ", "-"}]}], " ", 
  "*)"}]], "Input",ExpressionUUID->"56212ca7-7745-4651-883f-76f09ad8eb3f"],

Cell[BoxData[
 RowBox[{
  RowBox[{"rrmat", "[", 
   RowBox[{"\"\<4rp\>\"", ",", "qp_"}], "]"}], " ", ":=", "  ", 
  RowBox[{"Module", "[", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{"q", ",", "p", ",", "qs", ",", "qv", ",", "s"}], "}"}], ",", 
    "\[IndentingNewLine]", 
    RowBox[{
     RowBox[{
      RowBox[{"{", 
       RowBox[{"q", ",", "p"}], "}"}], " ", "=", " ", "qp"}], ";", 
     "\[IndentingNewLine]", 
     RowBox[{"qs", " ", "=", " ", 
      RowBox[{"q", "[", 
       RowBox[{"[", "1", "]"}], "]"}]}], ";", " ", 
     RowBox[{"qv", " ", "=", " ", 
      RowBox[{"Take", "[", 
       RowBox[{"q", ",", 
        RowBox[{"{", 
         RowBox[{"2", ",", "4"}], "}"}]}], "]"}]}], ";", 
     "\[IndentingNewLine]", 
     RowBox[{"s", " ", "=", " ", 
      RowBox[{"If", "[", 
       RowBox[{
        RowBox[{"p", "\[GreaterEqual]", "0"}], ",", "1", ",", 
        RowBox[{"-", "1"}]}], "]"}]}], ";", "\[IndentingNewLine]", 
     RowBox[{
      RowBox[{"qs", "*", 
       RowBox[{"IdentityMatrix", "[", "4", "]"}]}], "+", " ", 
      RowBox[{"assembletvvs", "[", 
       RowBox[{
        RowBox[{"asymvt", "[", "qv", "]"}], ",", 
        RowBox[{
         RowBox[{"-", "s"}], "*", "qv"}], ",", 
        RowBox[{"s", "*", "qv"}], ",", "0"}], "]"}]}]}]}], 
   "\[IndentingNewLine]", "]"}]}]], "Input",ExpressionUUID->"6d3d82b2-63f4-\
420e-9f16-b88e51d105ab"],

Cell[BoxData[
 RowBox[{
  RowBox[{"rrmat", "[", 
   RowBox[{"\"\<4rv\>\"", ",", "qset_"}], "]"}], " ", ":=", " ", 
  RowBox[{"Module", "[", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{
     "q1", ",", "q2", ",", "qs1", ",", "qs2", ",", "qv1", ",", "qv2", ",", 
      "vv", ",", "vs", ",", "sv", ",", "ss"}], "}"}], ",", 
    "\[IndentingNewLine]", 
    RowBox[{
     RowBox[{"q1", " ", "=", " ", 
      RowBox[{"qset", "[", 
       RowBox[{"[", "1", "]"}], "]"}]}], ";", " ", 
     RowBox[{"q2", " ", "=", " ", 
      RowBox[{"qset", "[", 
       RowBox[{"[", "2", "]"}], "]"}]}], ";", "\[IndentingNewLine]", 
     RowBox[{"qs1", " ", "=", " ", 
      RowBox[{"q1", "[", 
       RowBox[{"[", "1", "]"}], "]"}]}], ";", " ", 
     RowBox[{"qv1", " ", "=", " ", 
      RowBox[{"Take", "[", 
       RowBox[{"q1", ",", 
        RowBox[{"{", 
         RowBox[{"2", ",", "4"}], "}"}]}], "]"}]}], ";", 
     "\[IndentingNewLine]", 
     RowBox[{"qs2", " ", "=", " ", 
      RowBox[{"q2", "[", 
       RowBox[{"[", "1", "]"}], "]"}]}], ";", " ", 
     RowBox[{"qv2", " ", "=", " ", 
      RowBox[{"Take", "[", 
       RowBox[{"q2", ",", 
        RowBox[{"{", 
         RowBox[{"2", ",", "4"}], "}"}]}], "]"}]}], ";", 
     "\[IndentingNewLine]", 
     RowBox[{"vv", " ", "=", " ", 
      RowBox[{
       RowBox[{"qs1", "*", 
        RowBox[{"asymvt", "[", "qv2", "]"}]}], "+", 
       RowBox[{"qs2", "*", 
        RowBox[{"asymvt", "[", "qv1", "]"}]}], " ", "+", " ", 
       RowBox[{"dyad", "[", 
        RowBox[{"qv1", ",", "qv2"}], "]"}], "+", " ", 
       RowBox[{"dyad", "[", 
        RowBox[{"qv2", ",", "qv1"}], "]"}], " ", "-", " ", 
       RowBox[{
        RowBox[{"IdentityMatrix", "[", "3", "]"}], "*", 
        RowBox[{"(", 
         RowBox[{"qv1", ".", "qv2"}], ")"}]}]}]}], ";", "\[IndentingNewLine]", 
     RowBox[{"sv", " ", "=", " ", 
      RowBox[{
       RowBox[{"qs1", "*", "qv2"}], " ", "-", 
       RowBox[{"qs2", "*", "qv1"}], "-", 
       RowBox[{"Cross", "[", 
        RowBox[{"qv1", ",", "qv2"}], "]"}]}]}], ";", "\[IndentingNewLine]", 
     RowBox[{"vs", " ", "=", " ", 
      RowBox[{
       RowBox[{
        RowBox[{"-", "qs1"}], "*", "qv2"}], " ", "+", " ", 
       RowBox[{"qs2", "*", "qv1"}], "-", 
       RowBox[{"Cross", "[", 
        RowBox[{"qv1", ",", "qv2"}], "]"}]}]}], ";", "\[IndentingNewLine]", 
     RowBox[{"ss", " ", "=", " ", 
      RowBox[{"(", 
       RowBox[{"qv1", ".", "qv2"}], ")"}]}], ";", "\[IndentingNewLine]", 
     RowBox[{
      RowBox[{"qs1", "*", "qs2", "*", 
       RowBox[{"IdentityMatrix", "[", "4", "]"}]}], " ", "+", " ", 
      RowBox[{"assembletvvs", "[", 
       RowBox[{"vv", ",", "sv", ",", "vs", ",", "ss"}], "]"}]}]}]}], 
   "\[IndentingNewLine]", "]"}]}]], "Input",ExpressionUUID->"db9afb74-3f99-\
4133-afa2-b7e3dc47fd36"],

Cell[BoxData[
 RowBox[{
  RowBox[{"rrmat", "[", 
   RowBox[{"\"\<4sv\>\"", ",", "qset_"}], "]"}], " ", ":=", " ", 
  RowBox[{"secondprod", "[", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{"1", ",", "1", ",", "1", ",", 
      RowBox[{"-", "1"}]}], "}"}], ",", 
    RowBox[{"rrmat", "[", 
     RowBox[{"\"\<4rv\>\"", ",", "qset"}], "]"}]}], "]"}]}]], "Input",Expressi\
onUUID->"2499b577-83fd-4bb5-bc33-cf76e53d2c20"],

Cell[BoxData[
 RowBox[{
  RowBox[{"rrnorm", "[", 
   RowBox[{"\"\<4\>\"", ",", "qset_"}], "]"}], " ", ":=", " ", 
  RowBox[{"Times", " ", "@@", " ", 
   RowBox[{"(", 
    RowBox[{"quatnorm", " ", "/@", " ", "qset"}], ")"}]}]}]], "Input",Expressi\
onUUID->"c4036183-1e22-4167-8173-a68d29bfe35c"],

Cell[BoxData[
 RowBox[{
  RowBox[{"rrmat", "[", 
   RowBox[{"\"\<4rn\>\"", ",", "qset_"}], "]"}], " ", ":=", " ", 
  RowBox[{
   RowBox[{"rrmat", "[", 
    RowBox[{"\"\<4rv\>\"", ",", "qset"}], "]"}], "/", 
   RowBox[{"Sqrt", "[", 
    RowBox[{"rrnorm", "[", 
     RowBox[{"\"\<4\>\"", ",", "qset"}], "]"}], "]"}]}]}]], "Input",Expression\
UUID->"23a4e973-d45d-4264-a3e1-c41009a82d24"],

Cell[BoxData[
 RowBox[{
  RowBox[{"rrmat", "[", 
   RowBox[{"\"\<4sn\>\"", ",", "qset_"}], "]"}], " ", ":=", " ", 
  RowBox[{
   RowBox[{"rrmat", "[", 
    RowBox[{"\"\<4sv\>\"", ",", "qset"}], "]"}], "/", 
   RowBox[{"Sqrt", "[", 
    RowBox[{"rrnorm", "[", 
     RowBox[{"\"\<4\>\"", ",", "qset"}], "]"}], "]"}]}]}]], "Input",Expression\
UUID->"b57c9703-190e-4419-9e3b-71f9e72218b4"],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"metric", "[", "\"\<4\>\"", "]"}], " ", "=", " ", 
   RowBox[{"IdentityMatrix", "[", "4", "]"}]}], ";"}]], "Input",ExpressionUUID\
->"61c9d7da-4711-456e-8056-b2011d05aeab"],

Cell[BoxData[
 RowBox[{"(*", " ", "Verification", " ", "*)"}]], "Input",ExpressionUUID->"58a364e3-84ca-4695-90c7-5df63df98c6b"],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{
    RowBox[{"commut", "[", 
     RowBox[{
      RowBox[{"rrmat", "[", 
       RowBox[{"\"\<4rp\>\"", ",", 
        RowBox[{"{", 
         RowBox[{"aqt", ",", "1"}], "}"}]}], "]"}], ",", 
      RowBox[{"rrmat", "[", 
       RowBox[{"\"\<4rp\>\"", ",", 
        RowBox[{"{", 
         RowBox[{"bqt", ",", 
          RowBox[{"-", "1"}]}], "}"}]}], "]"}]}], "]"}], " ", "//", " ", 
    "Factor"}], "//", " ", "Flatten"}], " ", "//", " ", "Union"}]], "Input",Ex\
pressionUUID->"ffd41782-0dd5-4868-8dbf-ef788be9f535"],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{
    RowBox[{
     RowBox[{"rrmat", "[", 
      RowBox[{"\"\<4rv\>\"", ",", 
       RowBox[{"{", 
        RowBox[{"aqt", ",", "bqt"}], "}"}]}], "]"}], " ", "-", " ", 
     RowBox[{
      RowBox[{"rrmat", "[", 
       RowBox[{"\"\<4rp\>\"", ",", 
        RowBox[{"{", 
         RowBox[{"aqt", ",", "1"}], "}"}]}], "]"}], ".", 
      RowBox[{"rrmat", "[", 
       RowBox[{"\"\<4rp\>\"", ",", 
        RowBox[{"{", 
         RowBox[{"bqt", ",", 
          RowBox[{"-", "1"}]}], "}"}]}], "]"}]}]}], " ", "//", " ", 
    "Factor"}], "//", " ", "Flatten"}], " ", "//", " ", "Union"}]], "Input",Ex\
pressionUUID->"9b6a4b7b-e0b2-4c57-bd3d-7e1f0eb89d77"],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{
    RowBox[{"verifyrrmd", "[", 
     RowBox[{"{", 
      RowBox[{"\"\<4\>\"", ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"{", 
          RowBox[{"\"\<4rn\>\"", ",", "1"}], "}"}], ",", 
         RowBox[{"{", 
          RowBox[{"\"\<4sn\>\"", ",", 
           RowBox[{"-", "1"}]}], "}"}]}], "}"}], ",", 
       RowBox[{"Array", "[", 
        RowBox[{"a", ",", 
         RowBox[{"{", 
          RowBox[{"2", ",", "4"}], "}"}]}], "]"}]}], "}"}], "]"}], " ", "//", 
    " ", "Factor"}], " ", "//", " ", "Flatten"}], " ", "//", " ", 
  "Union"}]], "Input",ExpressionUUID->"ea08d2bd-a700-4189-9dd2-20487b24e448"],

Cell[BoxData[
 RowBox[{
  RowBox[{"aqpt", " ", "=", " ", 
   RowBox[{"Array", "[", 
    RowBox[{"a", ",", 
     RowBox[{"{", 
      RowBox[{"2", ",", "4"}], "}"}]}], "]"}]}], ";", " ", 
  RowBox[{"bqpt", " ", "=", " ", 
   RowBox[{"Array", "[", 
    RowBox[{"b", ",", 
     RowBox[{"{", 
      RowBox[{"2", ",", "4"}], "}"}]}], "]"}]}], ";", " ", 
  RowBox[{"abqpt", " ", "=", " ", 
   RowBox[{"Table", "[", 
    RowBox[{
     RowBox[{"quatmultiply", "[", 
      RowBox[{
       RowBox[{"aqpt", "[", 
        RowBox[{"[", "i", "]"}], "]"}], ",", 
       RowBox[{"bqpt", "[", 
        RowBox[{"[", "i", "]"}], "]"}]}], "]"}], ",", 
     RowBox[{"{", 
      RowBox[{"i", ",", "2"}], "}"}]}], "]"}]}], ";", 
  RowBox[{"abqptrv", " ", "=", " ", 
   RowBox[{"Table", "[", 
    RowBox[{
     RowBox[{"quatmultiply", "[", 
      RowBox[{
       RowBox[{"aqpt", "[", 
        RowBox[{"[", "i", "]"}], "]"}], ",", 
       RowBox[{"bqpt", "[", 
        RowBox[{"[", 
         RowBox[{"3", "-", "i"}], "]"}], "]"}]}], "]"}], ",", 
     RowBox[{"{", 
      RowBox[{"i", ",", "2"}], "}"}]}], "]"}]}], ";"}]], "Input",ExpressionUUI\
D->"ae126da9-18bf-43ea-a6f6-1322901567cb"],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{
    RowBox[{"verifyrrprod", "[", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"\"\<4rv\>\"", ",", "\"\<4sv\>\""}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"aqpt", ",", "bqpt"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"{", 
          RowBox[{
           RowBox[{"{", 
            RowBox[{"\"\<4rv\>\"", ",", "abqpt"}], "}"}], ",", 
           RowBox[{"{", 
            RowBox[{"\"\<4sv\>\"", ",", "abqpt"}], "}"}]}], "}"}], ",", 
         RowBox[{"{", 
          RowBox[{
           RowBox[{"{", 
            RowBox[{"\"\<4sv\>\"", ",", "abqptrv"}], "}"}], ",", 
           RowBox[{"{", 
            RowBox[{"\"\<4rv\>\"", ",", "abqptrv"}], "}"}]}], "}"}]}], 
        "}"}]}], "}"}], "]"}], "//", " ", "Factor"}], " ", "//", " ", 
   "Flatten"}], " ", "//", " ", "Union"}]], "Input",ExpressionUUID->"3be07755-\
1307-4690-afb8-5649b4a1463b"]
}, Closed]],

Cell[CellGroupData[{

Cell["Metric 3+1, +++- ", "Subsection",ExpressionUUID->"c7d72349-6851-46de-afc9-d771bd189d8b"],

Cell[BoxData[
 RowBox[{"(*", " ", 
  RowBox[{
   RowBox[{
    RowBox[{
    "Requires", " ", "some", " ", "fancy", " ", "footwork", " ", "with", " ", 
     "complex", " ", 
     RowBox[{"quaternions", ".", " ", "The"}], " ", "quaternions", " ", "of", 
     " ", "the", " ", "two", " ", "parts", " ", "are", " ", "q1"}], "+", 
    RowBox[{"I", "*", "q2", " ", "and", " ", "q1"}], "-", 
    RowBox[{"I", "*", "q2"}]}], ",", " ", 
   RowBox[{
   "so", " ", "one", " ", "has", " ", "to", " ", "adjust", " ", "their", " ", 
    "multiplication", " ", "law", " ", "and", " ", "norm", " ", 
    "accordingly"}]}], " ", "*)"}]], "Input",ExpressionUUID->"807d58f5-7efa-\
4b26-ac05-e0a11a91ee9f"],

Cell[BoxData[
 RowBox[{
  RowBox[{"rrmat", "[", 
   RowBox[{"\"\<31rp\>\"", ",", "qp_"}], "]"}], " ", ":=", "  ", 
  RowBox[{"Module", "[", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{"q", ",", "p", ",", "qs", ",", "qv", ",", "s"}], "}"}], ",", 
    "\[IndentingNewLine]", 
    RowBox[{
     RowBox[{
      RowBox[{"{", 
       RowBox[{"q", ",", "p"}], "}"}], " ", "=", " ", "qp"}], ";", 
     "\[IndentingNewLine]", 
     RowBox[{"qs", " ", "=", " ", 
      RowBox[{"q", "[", 
       RowBox[{"[", "1", "]"}], "]"}]}], ";", " ", 
     RowBox[{"qv", " ", "=", " ", 
      RowBox[{"Take", "[", 
       RowBox[{"q", ",", 
        RowBox[{"{", 
         RowBox[{"2", ",", "4"}], "}"}]}], "]"}]}], ";", 
     "\[IndentingNewLine]", 
     RowBox[{"s", " ", "=", " ", 
      RowBox[{"If", "[", 
       RowBox[{
        RowBox[{"p", "\[GreaterEqual]", "0"}], ",", "1", ",", 
        RowBox[{"-", "1"}]}], "]"}]}], ";", "\[IndentingNewLine]", 
     RowBox[{
      RowBox[{"qs", "*", 
       RowBox[{"IdentityMatrix", "[", "4", "]"}]}], "+", " ", 
      RowBox[{"assembletvvs", "[", 
       RowBox[{
        RowBox[{"asymvt", "[", "qv", "]"}], ",", 
        RowBox[{"I", "*", "s", "*", "qv"}], ",", 
        RowBox[{"I", "*", "s", "*", "qv"}], ",", "0"}], "]"}]}]}]}], 
   "\[IndentingNewLine]", "]"}]}]], "Input",ExpressionUUID->"e674ae9b-74e3-\
4a1d-b5f5-319dc4aad53c"],

Cell[BoxData[
 RowBox[{
  RowBox[{"complexquatmult", "[", 
   RowBox[{"qset1_", ",", "qset2_"}], "]"}], " ", ":=", " ", 
  RowBox[{"{", 
   RowBox[{
    RowBox[{
     RowBox[{"quatmultiply", "[", 
      RowBox[{
       RowBox[{"qset1", "[", 
        RowBox[{"[", "1", "]"}], "]"}], ",", 
       RowBox[{"qset2", "[", 
        RowBox[{"[", "1", "]"}], "]"}]}], "]"}], "-", 
     RowBox[{"quatmultiply", "[", 
      RowBox[{
       RowBox[{"qset1", "[", 
        RowBox[{"[", "2", "]"}], "]"}], ",", 
       RowBox[{"qset2", "[", 
        RowBox[{"[", "2", "]"}], "]"}]}], "]"}]}], ",", 
    RowBox[{
     RowBox[{"quatmultiply", "[", 
      RowBox[{
       RowBox[{"qset1", "[", 
        RowBox[{"[", "1", "]"}], "]"}], ",", 
       RowBox[{"qset2", "[", 
        RowBox[{"[", "2", "]"}], "]"}]}], "]"}], "+", 
     RowBox[{"quatmultiply", "[", 
      RowBox[{
       RowBox[{"qset1", "[", 
        RowBox[{"[", "2", "]"}], "]"}], ",", 
       RowBox[{"qset2", "[", 
        RowBox[{"[", "1", "]"}], "]"}]}], "]"}]}]}], "}"}]}]], "Input",Express\
ionUUID->"9b8a0445-b63c-4033-86d5-683f2e21b409"],

Cell[BoxData[
 RowBox[{
  RowBox[{"complexquatnorm", "[", "qset_", "]"}], " ", ":=", " ", 
  RowBox[{
   RowBox[{
    RowBox[{"(", 
     RowBox[{
      RowBox[{"quatnorm", "[", 
       RowBox[{"qset", "[", 
        RowBox[{"[", "1", "]"}], "]"}], "]"}], "-", 
      RowBox[{"quatnorm", "[", 
       RowBox[{"qset", "[", 
        RowBox[{"[", "2", "]"}], "]"}], "]"}]}], ")"}], "^", "2"}], " ", "+", 
   " ", 
   RowBox[{
    RowBox[{"(", 
     RowBox[{"2", "*", 
      RowBox[{
       RowBox[{"qset", "[", 
        RowBox[{"[", "1", "]"}], "]"}], ".", 
       RowBox[{"qset", "[", 
        RowBox[{"[", "2", "]"}], "]"}]}]}], ")"}], "^", "2"}]}]}]], "Input",Ex\
pressionUUID->"2610fc31-0571-4ce3-a45f-fdce578ee01f"],

Cell[BoxData[
 RowBox[{
  RowBox[{"rrmat", "[", 
   RowBox[{"\"\<31rrv\>\"", ",", "qset_"}], "]"}], " ", ":=", " ", 
  RowBox[{"Module", "[", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{
     "q1", ",", "q2", ",", "qs1", ",", "qs2", ",", "qv1", ",", "qv2", ",", 
      "vv", ",", "vs", ",", "sv", ",", "ss"}], "}"}], ",", 
    "\[IndentingNewLine]", 
    RowBox[{
     RowBox[{"q1", " ", "=", " ", 
      RowBox[{"qset", "[", 
       RowBox[{"[", "1", "]"}], "]"}]}], ";", " ", 
     RowBox[{"q2", " ", "=", " ", 
      RowBox[{"qset", "[", 
       RowBox[{"[", "2", "]"}], "]"}]}], ";", "\[IndentingNewLine]", 
     RowBox[{"qs1", " ", "=", " ", 
      RowBox[{"q1", "[", 
       RowBox[{"[", "1", "]"}], "]"}]}], ";", " ", 
     RowBox[{"qv1", " ", "=", " ", 
      RowBox[{"Take", "[", 
       RowBox[{"q1", ",", 
        RowBox[{"{", 
         RowBox[{"2", ",", "4"}], "}"}]}], "]"}]}], ";", 
     "\[IndentingNewLine]", 
     RowBox[{"qs2", " ", "=", " ", 
      RowBox[{"q2", "[", 
       RowBox[{"[", "1", "]"}], "]"}]}], ";", " ", 
     RowBox[{"qv2", " ", "=", " ", 
      RowBox[{"Take", "[", 
       RowBox[{"q2", ",", 
        RowBox[{"{", 
         RowBox[{"2", ",", "4"}], "}"}]}], "]"}]}], ";", 
     "\[IndentingNewLine]", 
     RowBox[{"vv", " ", "=", " ", 
      RowBox[{
       RowBox[{"2", "*", "qs1", "*", 
        RowBox[{"asymvt", "[", "qv1", "]"}]}], "+", 
       RowBox[{"2", "*", "qs2", "*", 
        RowBox[{"asymvt", "[", "qv2", "]"}]}], " ", "+", " ", 
       RowBox[{"2", "*", 
        RowBox[{"dyad", "[", 
         RowBox[{"qv1", ",", "qv1"}], "]"}]}], "+", " ", 
       RowBox[{"2", "*", 
        RowBox[{"dyad", "[", 
         RowBox[{"qv2", ",", "qv2"}], "]"}]}], " ", "-", " ", 
       RowBox[{
        RowBox[{"IdentityMatrix", "[", "3", "]"}], "*", 
        RowBox[{"(", 
         RowBox[{
          RowBox[{"qv1", ".", "qv1"}], "+", 
          RowBox[{"qv2", ".", "qv2"}]}], ")"}]}]}]}], ";", 
     "\[IndentingNewLine]", 
     RowBox[{"sv", " ", "=", " ", 
      RowBox[{
       RowBox[{
        RowBox[{"-", "2"}], "*", "qs1", "*", "qv2"}], " ", "+", " ", 
       RowBox[{"2", "*", "qs2", "*", "qv1"}], " ", "+", " ", 
       RowBox[{"2", "*", 
        RowBox[{"Cross", "[", 
         RowBox[{"qv1", ",", "qv2"}], "]"}]}]}]}], ";", "\[IndentingNewLine]", 
     RowBox[{"vs", " ", "=", " ", 
      RowBox[{
       RowBox[{
        RowBox[{"-", "2"}], "*", "qs1", "*", "qv2"}], " ", "+", " ", 
       RowBox[{"2", "*", "qs2", "*", "qv1"}], " ", "-", " ", 
       RowBox[{"2", "*", 
        RowBox[{"Cross", "[", 
         RowBox[{"qv1", ",", "qv2"}], "]"}]}]}]}], ";", "\[IndentingNewLine]", 
     RowBox[{"ss", " ", "=", " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{"qv1", ".", "qv1"}], "+", 
        RowBox[{"qv2", ".", "qv2"}]}], ")"}]}], ";", "\[IndentingNewLine]", 
     RowBox[{
      RowBox[{
       RowBox[{"(", 
        RowBox[{
         RowBox[{"qs1", "^", "2"}], "+", 
         RowBox[{"qs2", "^", "2"}]}], ")"}], "*", 
       RowBox[{"IdentityMatrix", "[", "4", "]"}]}], " ", "+", " ", 
      RowBox[{"assembletvvs", "[", 
       RowBox[{"vv", ",", "sv", ",", "vs", ",", "ss"}], "]"}]}]}]}], 
   "\[IndentingNewLine]", "]"}]}]], "Input",ExpressionUUID->"825d16a6-0061-\
4c4c-a049-86799a07b8f3"],

Cell[BoxData[
 RowBox[{
  RowBox[{"rrmat", "[", 
   RowBox[{"\"\<31rsv\>\"", ",", "q_"}], "]"}], " ", ":=", " ", 
  RowBox[{"secondprod", "[", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{"1", ",", "1", ",", "1", ",", 
      RowBox[{"-", "1"}]}], "}"}], ",", 
    RowBox[{"rrmat", "[", 
     RowBox[{"\"\<31rrv\>\"", ",", "q"}], "]"}]}], "]"}]}]], "Input",Expressio\
nUUID->"956a01d8-9124-4650-a847-0374e08615df"],

Cell[BoxData[
 RowBox[{
  RowBox[{"rrmat", "[", 
   RowBox[{"\"\<31srv\>\"", ",", "q_"}], "]"}], " ", ":=", " ", 
  RowBox[{"secondprod", "[", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{
      RowBox[{"-", "1"}], ",", 
      RowBox[{"-", "1"}], ",", 
      RowBox[{"-", "1"}], ",", "1"}], "}"}], ",", 
    RowBox[{"rrmat", "[", 
     RowBox[{"\"\<31rrv\>\"", ",", "q"}], "]"}]}], "]"}]}]], "Input",Expressio\
nUUID->"3ceda1d0-e130-4e20-b014-7cb751864994"],

Cell[BoxData[
 RowBox[{
  RowBox[{"rrmat", "[", 
   RowBox[{"\"\<31ssv\>\"", ",", "q_"}], "]"}], " ", ":=", " ", 
  RowBox[{"secondprod", "[", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{
      RowBox[{"-", "1"}], ",", 
      RowBox[{"-", "1"}], ",", 
      RowBox[{"-", "1"}], ",", 
      RowBox[{"-", "1"}]}], "}"}], ",", 
    RowBox[{"rrmat", "[", 
     RowBox[{"\"\<31rrv\>\"", ",", "q"}], "]"}]}], "]"}]}]], "Input",Expressio\
nUUID->"b2ba165a-448c-4c1a-b0ac-58af63977b22"],

Cell[BoxData[
 RowBox[{
  RowBox[{"rrnorm", "[", 
   RowBox[{"\"\<31\>\"", ",", "qset_"}], "]"}], " ", ":=", " ", 
  RowBox[{"complexquatnorm", "[", "qset", "]"}]}]], "Input",ExpressionUUID->\
"3ff088ed-fec9-4530-857a-805bddc108aa"],

Cell[BoxData[
 RowBox[{
  RowBox[{"rrmat", "[", 
   RowBox[{"\"\<31rrn\>\"", ",", "q_"}], "]"}], " ", ":=", " ", 
  RowBox[{
   RowBox[{"rrmat", "[", 
    RowBox[{"\"\<31rrv\>\"", ",", "q"}], "]"}], "/", 
   RowBox[{"Sqrt", "[", 
    RowBox[{"rrnorm", "[", 
     RowBox[{"\"\<31\>\"", ",", "q"}], "]"}], "]"}]}]}]], "Input",ExpressionUU\
ID->"dde3a5ad-b4d7-4c85-8a62-ea14822c7652"],

Cell[BoxData[
 RowBox[{
  RowBox[{"rrmat", "[", 
   RowBox[{"\"\<31rsn\>\"", ",", "q_"}], "]"}], " ", ":=", " ", 
  RowBox[{
   RowBox[{"rrmat", "[", 
    RowBox[{"\"\<31rsv\>\"", ",", "q"}], "]"}], "/", 
   RowBox[{"Sqrt", "[", 
    RowBox[{"rrnorm", "[", 
     RowBox[{"\"\<31\>\"", ",", "q"}], "]"}], "]"}]}]}]], "Input",ExpressionUU\
ID->"745810f1-4e7d-4e75-9e78-2b2e3da5d0ed"],

Cell[BoxData[
 RowBox[{
  RowBox[{"rrmat", "[", 
   RowBox[{"\"\<31srn\>\"", ",", "q_"}], "]"}], " ", ":=", " ", 
  RowBox[{
   RowBox[{"rrmat", "[", 
    RowBox[{"\"\<31srv\>\"", ",", "q"}], "]"}], "/", 
   RowBox[{"Sqrt", "[", 
    RowBox[{"rrnorm", "[", 
     RowBox[{"\"\<31\>\"", ",", "q"}], "]"}], "]"}]}]}]], "Input",ExpressionUU\
ID->"7885f5f3-e789-466e-a2c9-d1fa7924cf2b"],

Cell[BoxData[
 RowBox[{
  RowBox[{"rrmat", "[", 
   RowBox[{"\"\<31ssn\>\"", ",", "q_"}], "]"}], " ", ":=", " ", 
  RowBox[{
   RowBox[{"rrmat", "[", 
    RowBox[{"\"\<31ssv\>\"", ",", "q"}], "]"}], "/", 
   RowBox[{"Sqrt", "[", 
    RowBox[{"rrnorm", "[", 
     RowBox[{"\"\<31\>\"", ",", "q"}], "]"}], "]"}]}]}]], "Input",ExpressionUU\
ID->"d1ebf2b7-57d3-4c16-80d3-affd7e9dfaea"],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"metric", "[", "\"\<31\>\"", "]"}], " ", "=", " ", 
   RowBox[{"DiagonalMatrix", "[", 
    RowBox[{"{", 
     RowBox[{"1", ",", "1", ",", "1", ",", 
      RowBox[{"-", "1"}]}], "}"}], "]"}]}], ";"}]], "Input",ExpressionUUID->\
"3870284b-0819-498e-91ca-11f5af5fdc31"],

Cell[BoxData[
 RowBox[{"(*", " ", "Verification", " ", "*)"}]], "Input",ExpressionUUID->"2217b6e2-4b51-4329-bd9f-c487fee5d5b7"],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{
    RowBox[{"commut", "[", 
     RowBox[{
      RowBox[{"rrmat", "[", 
       RowBox[{"\"\<31rp\>\"", ",", 
        RowBox[{"{", 
         RowBox[{"aqt", ",", "1"}], "}"}]}], "]"}], ",", 
      RowBox[{"rrmat", "[", 
       RowBox[{"\"\<31rp\>\"", ",", 
        RowBox[{"{", 
         RowBox[{"bqt", ",", 
          RowBox[{"-", "1"}]}], "}"}]}], "]"}]}], "]"}], " ", "//", " ", 
    "Factor"}], "//", " ", "Flatten"}], " ", "//", " ", "Union"}]], "Input",Ex\
pressionUUID->"28e0e85f-ce88-468a-b997-f3893ac7c647"],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{
    RowBox[{
     RowBox[{"rrmat", "[", 
      RowBox[{"\"\<31rrv\>\"", ",", 
       RowBox[{"{", 
        RowBox[{"aqt", ",", "bqt"}], "}"}]}], "]"}], " ", "-", " ", 
     RowBox[{
      RowBox[{"rrmat", "[", 
       RowBox[{"\"\<31rp\>\"", ",", 
        RowBox[{"{", 
         RowBox[{
          RowBox[{"aqt", "+", 
           RowBox[{"I", "*", "bqt"}]}], ",", "1"}], "}"}]}], "]"}], ".", 
      RowBox[{"rrmat", "[", 
       RowBox[{"\"\<31rp\>\"", ",", 
        RowBox[{"{", 
         RowBox[{
          RowBox[{"aqt", "-", 
           RowBox[{"I", "*", "bqt"}]}], ",", 
          RowBox[{"-", "1"}]}], "}"}]}], "]"}]}]}], " ", "//", " ", 
    "Factor"}], "//", " ", "Flatten"}], " ", "//", " ", "Union"}]], "Input",Ex\
pressionUUID->"605f79f2-f500-4a72-9e99-94ad924b19d7"],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{
    RowBox[{"verifyrrmd", "[", 
     RowBox[{"{", 
      RowBox[{"\"\<31\>\"", ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"{", 
          RowBox[{"\"\<31rrn\>\"", ",", "1"}], "}"}], ",", 
         RowBox[{"{", 
          RowBox[{"\"\<31rsn\>\"", ",", 
           RowBox[{"-", "1"}]}], "}"}], ",", 
         RowBox[{"{", 
          RowBox[{"\"\<31srn\>\"", ",", 
           RowBox[{"-", "1"}]}], "}"}], ",", 
         RowBox[{"{", 
          RowBox[{"\"\<31ssn\>\"", ",", "1"}], "}"}]}], "}"}], ",", 
       RowBox[{"Array", "[", 
        RowBox[{"a", ",", 
         RowBox[{"{", 
          RowBox[{"2", ",", "4"}], "}"}]}], "]"}]}], "}"}], "]"}], " ", "//", 
    " ", "Factor"}], " ", "//", " ", "Flatten"}], " ", "//", " ", 
  "Union"}]], "Input",ExpressionUUID->"0ef5d3eb-8dc9-4553-b191-b316981b6f17"],

Cell[BoxData[
 RowBox[{
  RowBox[{"abqptz1", " ", "=", " ", 
   RowBox[{"complexquatmult", "[", 
    RowBox[{"aqpt", ",", "bqpt"}], "]"}]}], ";"}]], "Input",ExpressionUUID->\
"cdc9670f-60fb-42fa-b2e4-f1549112a91c"],

Cell[BoxData[
 RowBox[{
  RowBox[{"abqptz2", " ", "=", " ", 
   RowBox[{"complexquatmult", "[", 
    RowBox[{"aqpt", ",", 
     RowBox[{
      RowBox[{"{", 
       RowBox[{"1", ",", 
        RowBox[{"-", "1"}]}], "}"}], "*", "bqpt"}]}], "]"}]}], ";"}]], "Input",\
ExpressionUUID->"72a6a0b5-ad71-4d02-a455-bd95d65518c4"],

Cell[BoxData[
 RowBox[{
  RowBox[{"abqptz3", " ", "=", " ", "abqptz2"}], ";"}]], "Input",ExpressionUUI\
D->"a73ce790-7789-4b86-b4a3-6beac8b85f7d"],

Cell[BoxData[
 RowBox[{
  RowBox[{"abqptz4", " ", "=", " ", "abqptz1"}], ";"}]], "Input",ExpressionUUI\
D->"71fcb0c7-f5ac-47fb-91d7-2663f4a44934"],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{
    RowBox[{"verifyrrprod", "[", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "\"\<31rrv\>\"", ",", "\"\<31rsv\>\"", ",", "\"\<31srv\>\"", ",", 
         "\"\<31ssv\>\""}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"aqpt", ",", "bqpt"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"{", 
          RowBox[{
           RowBox[{"{", 
            RowBox[{"\"\<31rrv\>\"", ",", "abqptz1"}], "}"}], ",", 
           RowBox[{"{", 
            RowBox[{"\"\<31rsv\>\"", ",", "abqptz1"}], "}"}], ",", 
           RowBox[{"{", 
            RowBox[{"\"\<31srv\>\"", ",", "abqptz1"}], "}"}], ",", 
           RowBox[{"{", 
            RowBox[{"\"\<31ssv\>\"", ",", "abqptz1"}], "}"}]}], "}"}], ",", 
         RowBox[{"{", 
          RowBox[{
           RowBox[{"{", 
            RowBox[{"\"\<31rsv\>\"", ",", "abqptz2"}], "}"}], ",", 
           RowBox[{"{", 
            RowBox[{"\"\<31rrv\>\"", ",", "abqptz2"}], "}"}], ",", 
           RowBox[{"{", 
            RowBox[{"\"\<31ssv\>\"", ",", "abqptz2"}], "}"}], ",", 
           RowBox[{"{", 
            RowBox[{"\"\<31srv\>\"", ",", "abqptz2"}], "}"}]}], "}"}], ",", 
         RowBox[{"{", 
          RowBox[{
           RowBox[{"{", 
            RowBox[{"\"\<31srv\>\"", ",", "abqptz3"}], "}"}], ",", 
           RowBox[{"{", 
            RowBox[{"\"\<31ssv\>\"", ",", "abqptz3"}], "}"}], ",", 
           RowBox[{"{", 
            RowBox[{"\"\<31rrv\>\"", ",", "abqptz3"}], "}"}], ",", 
           RowBox[{"{", 
            RowBox[{"\"\<31rsv\>\"", ",", "abqptz3"}], "}"}]}], "}"}], ",", 
         RowBox[{"{", 
          RowBox[{
           RowBox[{"{", 
            RowBox[{"\"\<31ssv\>\"", ",", "abqptz4"}], "}"}], ",", 
           RowBox[{"{", 
            RowBox[{"\"\<31srv\>\"", ",", "abqptz4"}], "}"}], ",", 
           RowBox[{"{", 
            RowBox[{"\"\<31rsv\>\"", ",", "abqptz4"}], "}"}], ",", 
           RowBox[{"{", 
            RowBox[{"\"\<31rrv\>\"", ",", "abqptz4"}], "}"}]}], "}"}]}], 
        "}"}]}], "}"}], "]"}], " ", "//", " ", "Factor"}], " ", "//", " ", 
   "Flatten"}], " ", "//", " ", "Union"}]], "Input",ExpressionUUID->"6f3bf535-\
2f5f-41a4-9515-76036e1674e7"],

Cell[BoxData[
 RowBox[{"(*", " ", 
  RowBox[{"Relation", " ", "to", " ", "SL", 
   RowBox[{"(", 
    RowBox[{"2", ",", "C"}], ")"}]}], " ", "*)"}]], "Input",ExpressionUUID->\
"b9cc857d-e383-4b54-a7a4-7842031aad30"],

Cell[BoxData[
 RowBox[{
  RowBox[{"VerifyPauli31D", "[", 
   RowBox[{"q_", ",", "x_"}], "]"}], " ", ":=", " ", 
  RowBox[{"Module", "[", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{"qset", ",", "xvec", ",", "xvres", ",", "qsp1", ",", "qsp2"}], 
     "}"}], ",", "\[IndentingNewLine]", 
    RowBox[{
     RowBox[{"qset", " ", "=", " ", 
      RowBox[{"Array", "[", 
       RowBox[{"q", ",", 
        RowBox[{"{", 
         RowBox[{"2", ",", "4"}], "}"}]}], "]"}]}], ";", 
     "\[IndentingNewLine]", 
     RowBox[{"xvec", " ", "=", " ", 
      RowBox[{"Array", "[", 
       RowBox[{"x", ",", "4"}], "]"}]}], ";", "\[IndentingNewLine]", 
     RowBox[{"(*", " ", 
      RowBox[{
      "Move", " ", "1", " ", "to", " ", "4", " ", "and", " ", "then", " ", 
       "back", " ", "to", " ", "1"}], " ", "*)"}], "\[IndentingNewLine]", 
     RowBox[{"xvres", " ", "=", " ", 
      RowBox[{
       RowBox[{"(", 
        RowBox[{
         RowBox[{"rrmat", "[", 
          RowBox[{"\"\<31rrv\>\"", ",", "qset"}], "]"}], ".", 
         RowBox[{"xvec", "[", 
          RowBox[{"[", 
           RowBox[{"{", 
            RowBox[{"2", ",", "3", ",", "4", ",", "1"}], "}"}], "]"}], 
          "]"}]}], ")"}], "[", 
       RowBox[{"[", 
        RowBox[{"{", 
         RowBox[{"4", ",", "1", ",", "2", ",", "3"}], "}"}], "]"}], "]"}]}], 
     ";", "\[IndentingNewLine]", 
     RowBox[{"qsp1", " ", "=", " ", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"1", ",", "I"}], "}"}], ".", "qset"}]}], ";", 
     "\[IndentingNewLine]", 
     RowBox[{"qsp2", " ", "=", " ", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"1", ",", 
         RowBox[{"-", "I"}]}], "}"}], ".", "qset"}]}], ";", 
     "\[IndentingNewLine]", 
     RowBox[{
      RowBox[{
       RowBox[{
        RowBox[{"quatpauli", "[", "qsp1", "]"}], ".", 
        RowBox[{"quatpauli", "[", 
         RowBox[{
          RowBox[{"{", 
           RowBox[{"1", ",", 
            RowBox[{"-", "I"}], ",", 
            RowBox[{"-", "I"}], ",", 
            RowBox[{"-", "I"}]}], "}"}], "*", "xvec"}], "]"}], ".", 
        RowBox[{"quatpauli", "[", 
         RowBox[{
          RowBox[{"{", 
           RowBox[{"1", ",", 
            RowBox[{"-", "1"}], ",", 
            RowBox[{"-", "1"}], ",", 
            RowBox[{"-", "1"}]}], "}"}], "*", "qsp2"}], "]"}]}], " ", "-", 
       " ", 
       RowBox[{"quatpauli", "[", 
        RowBox[{
         RowBox[{"{", 
          RowBox[{"1", ",", 
           RowBox[{"-", "I"}], ",", 
           RowBox[{"-", "I"}], ",", 
           RowBox[{"-", "I"}]}], "}"}], "*", "xvres"}], "]"}]}], " ", "//", 
      " ", "Factor"}]}]}], "\[IndentingNewLine]", "]"}]}]], "Input",Expression\
UUID->"5c5517cb-5334-4271-a945-243dff32aece"],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"VerifyPauli31D", "[", 
    RowBox[{"q", ",", "x"}], "]"}], " ", "//", " ", "Flatten"}], " ", "//", 
  " ", "Union"}]], "Input",ExpressionUUID->"a66ecf16-264c-4b63-9685-\
00b973ff2c22"],

Cell[BoxData[
 RowBox[{"(*", " ", 
  RowBox[{"Special", " ", "cases", " ", "of", " ", "pure", " ", "rotations"}],
   "  ", "*)"}]], "Input",ExpressionUUID->"a634fc38-d90d-41c1-8f30-\
02fc07af7403"],

Cell[BoxData[
 RowBox[{"(*", " ", 
  RowBox[{"Can", " ", "reduce", " ", "qset", " ", "to", " ", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"q00", ",", "q01", ",", "0", ",", "0"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"q10", ",", "0", ",", "q11", ",", "0"}], "}"}]}], "}"}], " ", 
   "with", " ", "rotations", " ", "and", " ", "mulitplication", " ", "by", 
   " ", "complex", " ", "phases"}], " ", "*)"}]], "Input",ExpressionUUID->\
"5cb12620-defc-4a4c-bb5a-1db64c848073"],

Cell[BoxData[
 RowBox[{"(*", " ", 
  RowBox[{
   RowBox[{
    RowBox[{
     RowBox[{"Elliptic", " ", "--"}], " ", "rotation", " ", "angle", " ", 
     RowBox[{"a", " ", "--"}], " ", "2", "D", " ", "rotation"}], " ", "+", 
    " ", 
    RowBox[{"2", "D", " ", 
     RowBox[{"identity", ":", " ", "qset"}]}]}], " ", "=", " ", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{"Cos", "[", 
        RowBox[{"a", "/", "2"}], "]"}], ",", "0", ",", "0", ",", 
       RowBox[{"-", 
        RowBox[{"Sin", "[", 
         RowBox[{"a", "/", "2"}], "]"}]}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"0", ",", "0", ",", "0", ",", "0"}], "}"}]}], "}"}]}], " ", 
  "*)"}]], "Input",ExpressionUUID->"f6bed398-e92c-41db-9eb1-1b9b56c4f69f"],

Cell[BoxData[
 RowBox[{"(*", " ", 
  RowBox[{
   RowBox[{
    RowBox[{
     RowBox[{"Hyperbolic", " ", "--"}], " ", "boost", " ", "rapidity", " ", 
     RowBox[{"b", " ", "--"}], " ", "2", "D", " ", "boost"}], " ", "+", " ", 
    RowBox[{"2", "D", " ", 
     RowBox[{"identity", ":", " ", "qset"}]}]}], " ", "=", " ", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"0", ",", "0", ",", "0", ",", 
       RowBox[{"Sinh", "[", 
        RowBox[{"b", "/", "2"}], "]"}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"Cosh", "[", 
        RowBox[{"b", "/", "2"}], "]"}], ",", "0", ",", "0", ",", "0"}], 
      "}"}]}], "}"}]}], " ", "*)"}]], "Input",ExpressionUUID->"47405e61-7b0e-\
45bf-8313-f8e0cbfb8cab"],

Cell[BoxData[
 RowBox[{"(*", " ", 
  RowBox[{
   RowBox[{
    RowBox[{
     RowBox[{"Loxodromic", " ", "--"}], " ", "rotation", " ", "and", " ", 
     "boost", " ", 
     RowBox[{"together", " ", "--"}], " ", "2", "D", " ", "rotation"}], " ", 
    "+", " ", 
    RowBox[{"2", "D", " ", 
     RowBox[{"boost", ":", " ", "qset"}]}]}], " ", "=", " ", 
   RowBox[{
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", 
          RowBox[{"Sin", "[", "a", "]"}]}], ",", "0", ",", "0", ",", 
         RowBox[{
          RowBox[{"Cosh", "[", "b", "]"}], "-", 
          RowBox[{"Cos", "[", "a", "]"}]}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"Sinh", "[", "b", "]"}], ",", "0", ",", "0", ",", "0"}], 
        "}"}]}], "}"}], "\[IndentingNewLine]", "\[IndentingNewLine]", 
     "qset"}], " ", "=", " ", 
    RowBox[{"{", 
     RowBox[{
      RowBox[{"{", 
       RowBox[{
        RowBox[{
         RowBox[{"-", 
          RowBox[{"Cos", "[", 
           RowBox[{"a", "/", "2"}], "]"}]}], "*", 
         RowBox[{"Cosh", "[", 
          RowBox[{"b", "/", "2"}], "]"}]}], ",", "0", ",", "0", ",", 
        RowBox[{
         RowBox[{"Sin", "[", 
          RowBox[{"a", "/", "2"}], "]"}], "*", 
         RowBox[{"Cosh", "[", 
          RowBox[{"b", "/", "2"}], "]"}]}]}], "}"}], ",", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{
         RowBox[{"Sin", "[", 
          RowBox[{"a", "/", "2"}], "]"}], "*", 
         RowBox[{"Sinh", "[", 
          RowBox[{"b", "/", "2"}], "]"}]}], ",", "0", ",", "0", ",", 
        RowBox[{
         RowBox[{"Cos", "[", 
          RowBox[{"a", "/", "2"}], "]"}], "*", 
         RowBox[{"Sinh", "[", 
          RowBox[{"b", "/", "2"}], "]"}]}]}], "}"}]}], "}"}]}]}], 
  "\[IndentingNewLine]", " ", "*)"}]], "Input",ExpressionUUID->"357b2c67-571a-\
4366-beac-ef66b4b91806"],

Cell[BoxData[
 RowBox[{"(*", " ", 
  RowBox[{
   RowBox[{"Parabolic", ":", " ", "qset"}], " ", "=", " ", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"q0", ",", "q", ",", "0", ",", "0"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"q1", ",", "0", ",", "q", ",", "0"}], "}"}]}], "}"}]}], " ", 
  "*)"}]], "Input",ExpressionUUID->"d640c4b9-3590-4f28-8209-dc7803a003e7"],

Cell[BoxData[
 RowBox[{"(*", " ", 
  RowBox[{"Reflection", ":", " ", 
   RowBox[{
    RowBox[{
    "2", "D", " ", "rotation", " ", "or", " ", "2", "D", " ", "boost"}], " ", 
    "+", " ", 
    RowBox[{"2", "D", " ", "reflection"}]}]}], " ", "*)"}]], "Input",Expressio\
nUUID->"fe0ee5e5-e99c-4840-bdd0-197d8bd83c4a"]
}, Closed]],

Cell[CellGroupData[{

Cell["Metric 2+2, ++--", "Subsection",ExpressionUUID->"aa5e6424-4905-4d25-80a0-a72114dc0697"],

Cell[BoxData[
 RowBox[{
  RowBox[{"rr22metbase", " ", "=", " ", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"-", "1"}], ",", 
     RowBox[{"-", "1"}], ",", "1"}], "}"}]}], ";"}]], "Input",ExpressionUUID->\
"b1c86a59-6e4e-432d-afb4-06259d261ca8"],

Cell[BoxData[
 RowBox[{
  RowBox[{"rrmat", "[", 
   RowBox[{"\"\<22rp\>\"", ",", "qp_"}], "]"}], " ", ":=", " ", 
  RowBox[{"Module", "[", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{"q", ",", "p", ",", "qs", ",", "qv", ",", "s"}], "}"}], ",", 
    "\[IndentingNewLine]", 
    RowBox[{
     RowBox[{
      RowBox[{"{", 
       RowBox[{"q", ",", "p"}], "}"}], " ", "=", " ", "qp"}], ";", 
     "\[IndentingNewLine]", 
     RowBox[{"qs", " ", "=", " ", 
      RowBox[{"q", "[", 
       RowBox[{"[", "1", "]"}], "]"}]}], ";", " ", 
     RowBox[{"qv", " ", "=", " ", 
      RowBox[{"Take", "[", 
       RowBox[{"q", ",", 
        RowBox[{"{", 
         RowBox[{"2", ",", "4"}], "}"}]}], "]"}]}], ";", 
     "\[IndentingNewLine]", 
     RowBox[{"s", " ", "=", " ", 
      RowBox[{"If", "[", 
       RowBox[{
        RowBox[{"p", "\[GreaterEqual]", "0"}], ",", "1", ",", 
        RowBox[{"-", "1"}]}], "]"}]}], ";", "\[IndentingNewLine]", 
     RowBox[{
      RowBox[{"qs", "*", 
       RowBox[{"IdentityMatrix", "[", "4", "]"}]}], "+", " ", 
      RowBox[{"assembletvvs", "[", 
       RowBox[{
        RowBox[{"rr22metbase", "*", 
         RowBox[{"asymvt", "[", "qv", "]"}]}], ",", 
        RowBox[{
         RowBox[{"-", "s"}], "*", "qv"}], ",", 
        RowBox[{"s", "*", "rr22metbase", "*", "qv"}], ",", "0"}], "]"}]}]}]}],
    "\[IndentingNewLine]", "]"}]}]], "Input",ExpressionUUID->"354c442d-763e-\
47cd-9496-1d5192be8ac0"],

Cell[BoxData[
 RowBox[{
  RowBox[{"rrmat", "[", 
   RowBox[{"\"\<22rrv\>\"", ",", "qset_"}], "]"}], " ", ":=", " ", 
  RowBox[{"Module", "[", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{
     "q1", ",", "q2", ",", "qs1", ",", "qs2", ",", "qv1", ",", "qv2", ",", 
      "vv", ",", "vs", ",", "sv", ",", "ss"}], "}"}], ",", 
    "\[IndentingNewLine]", 
    RowBox[{
     RowBox[{"q1", " ", "=", " ", 
      RowBox[{"qset", "[", 
       RowBox[{"[", "1", "]"}], "]"}]}], ";", " ", 
     RowBox[{"q2", " ", "=", " ", 
      RowBox[{"qset", "[", 
       RowBox[{"[", "2", "]"}], "]"}]}], ";", "\[IndentingNewLine]", 
     RowBox[{"qs1", " ", "=", " ", 
      RowBox[{"q1", "[", 
       RowBox[{"[", "1", "]"}], "]"}]}], ";", " ", 
     RowBox[{"qv1", " ", "=", " ", 
      RowBox[{"Take", "[", 
       RowBox[{"q1", ",", 
        RowBox[{"{", 
         RowBox[{"2", ",", "4"}], "}"}]}], "]"}]}], ";", 
     "\[IndentingNewLine]", 
     RowBox[{"qs2", " ", "=", " ", 
      RowBox[{"q2", "[", 
       RowBox[{"[", "1", "]"}], "]"}]}], ";", " ", 
     RowBox[{"qv2", " ", "=", " ", 
      RowBox[{"Take", "[", 
       RowBox[{"q2", ",", 
        RowBox[{"{", 
         RowBox[{"2", ",", "4"}], "}"}]}], "]"}]}], ";", 
     "\[IndentingNewLine]", 
     RowBox[{"vv", " ", "=", " ", 
      RowBox[{
       RowBox[{"rr22metbase", "*", 
        RowBox[{"(", 
         RowBox[{
          RowBox[{"qs1", "*", 
           RowBox[{"asymvt", "[", "qv2", "]"}]}], "+", " ", 
          RowBox[{"qs2", "*", 
           RowBox[{"asymvt", "[", "qv1", "]"}]}]}], ")"}]}], " ", "+", " ", 
       RowBox[{"secondprod", "[", 
        RowBox[{"rr22metbase", ",", 
         RowBox[{
          RowBox[{"dyad", "[", 
           RowBox[{"qv1", ",", "qv2"}], "]"}], "+", " ", 
          RowBox[{"dyad", "[", 
           RowBox[{"qv2", ",", "qv1"}], "]"}]}]}], "]"}], " ", "-", " ", 
       RowBox[{
        RowBox[{"IdentityMatrix", "[", "3", "]"}], "*", 
        RowBox[{"(", 
         RowBox[{"qv1", ".", 
          RowBox[{"(", 
           RowBox[{"rr22metbase", "*", "qv2"}], ")"}]}], ")"}]}]}]}], ";", 
     "\[IndentingNewLine]", 
     RowBox[{"sv", " ", "=", " ", 
      RowBox[{
       RowBox[{"(", 
        RowBox[{
         RowBox[{"qs1", "*", "qv2"}], " ", "-", " ", 
         RowBox[{"qs2", "*", "qv1"}]}], ")"}], "-", 
       RowBox[{"rr22metbase", "*", 
        RowBox[{"Cross", "[", 
         RowBox[{"qv1", ",", "qv2"}], "]"}]}]}]}], ";", "\[IndentingNewLine]", 
     RowBox[{"vs", " ", "=", " ", 
      RowBox[{
       RowBox[{"rr22metbase", "*", 
        RowBox[{"(", 
         RowBox[{
          RowBox[{
           RowBox[{"-", "qs1"}], "*", "qv2"}], " ", "+", " ", 
          RowBox[{"qs2", "*", "qv1"}]}], ")"}]}], "-", 
       RowBox[{"Cross", "[", 
        RowBox[{"qv1", ",", "qv2"}], "]"}]}]}], ";", "\[IndentingNewLine]", 
     RowBox[{"ss", " ", "=", " ", 
      RowBox[{"(", 
       RowBox[{"qv1", ".", 
        RowBox[{"(", 
         RowBox[{"rr22metbase", "*", "qv2"}], ")"}]}], ")"}]}], ";", 
     "\[IndentingNewLine]", 
     RowBox[{
      RowBox[{"qs1", "*", "qs2", "*", 
       RowBox[{"IdentityMatrix", "[", "4", "]"}]}], " ", "+", " ", 
      RowBox[{"assembletvvs", "[", 
       RowBox[{"vv", ",", "sv", ",", "vs", ",", "ss"}], "]"}]}]}]}], 
   "\[IndentingNewLine]", "]"}]}]], "Input",ExpressionUUID->"e9cf02e0-c6cd-\
4c1c-b20a-0333f467ffb7"],

Cell[BoxData[
 RowBox[{
  RowBox[{"rrmat", "[", 
   RowBox[{"\"\<22rsv\>\"", ",", "q_"}], "]"}], " ", ":=", " ", 
  RowBox[{"secondprod", "[", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{"1", ",", "1", ",", "1", ",", 
      RowBox[{"-", "1"}]}], "}"}], ",", 
    RowBox[{"rrmat", "[", 
     RowBox[{"\"\<22rrv\>\"", ",", "q"}], "]"}]}], "]"}]}]], "Input",Expressio\
nUUID->"6783eb6c-43da-40a9-ad9f-a308e081772b"],

Cell[BoxData[
 RowBox[{
  RowBox[{"rrmat", "[", 
   RowBox[{"\"\<22srv\>\"", ",", "q_"}], "]"}], " ", ":=", " ", 
  RowBox[{"secondprod", "[", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{"1", ",", 
      RowBox[{"-", "1"}], ",", "1", ",", "1"}], "}"}], ",", 
    RowBox[{"rrmat", "[", 
     RowBox[{"\"\<22rrv\>\"", ",", "q"}], "]"}]}], "]"}]}]], "Input",Expressio\
nUUID->"614e4e49-147c-4ec3-b217-b16ec13bd03e"],

Cell[BoxData[
 RowBox[{
  RowBox[{"rrmat", "[", 
   RowBox[{"\"\<22ssv\>\"", ",", "q_"}], "]"}], " ", ":=", " ", 
  RowBox[{"secondprod", "[", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{"1", ",", 
      RowBox[{"-", "1"}], ",", "1", ",", 
      RowBox[{"-", "1"}]}], "}"}], ",", 
    RowBox[{"rrmat", "[", 
     RowBox[{"\"\<22rrv\>\"", ",", "q"}], "]"}]}], "]"}]}]], "Input",Expressio\
nUUID->"3f91974e-efbb-4273-9898-ca14ec803c52"],

Cell[BoxData[
 RowBox[{
  RowBox[{"rrnorm", "[", 
   RowBox[{"\"\<22\>\"", ",", "qset_"}], "]"}], " ", ":=", " ", 
  RowBox[{"Times", " ", "@@", " ", 
   RowBox[{"(", 
    RowBox[{
     RowBox[{
      RowBox[{"quatnorm", "[", 
       RowBox[{"rr22metbase", ",", "#"}], "]"}], "&"}], " ", "/@", " ", 
     "qset"}], ")"}]}]}]], "Input",ExpressionUUID->"a8e5cb74-14ae-4154-bfa8-\
588026c29724"],

Cell[BoxData[
 RowBox[{
  RowBox[{"rrmat", "[", 
   RowBox[{"\"\<22rrn\>\"", ",", "q_"}], "]"}], " ", ":=", " ", 
  RowBox[{
   RowBox[{"rrmat", "[", 
    RowBox[{"\"\<22rrv\>\"", ",", "q"}], "]"}], "/", 
   RowBox[{"Sqrt", "[", 
    RowBox[{"rrnorm", "[", 
     RowBox[{"\"\<22\>\"", ",", "q"}], "]"}], "]"}]}]}]], "Input",ExpressionUU\
ID->"fe3b519c-b158-43ad-a67b-5a385bb9d511"],

Cell[BoxData[
 RowBox[{
  RowBox[{"rrmat", "[", 
   RowBox[{"\"\<22rsn\>\"", ",", "q_"}], "]"}], " ", ":=", " ", 
  RowBox[{
   RowBox[{"rrmat", "[", 
    RowBox[{"\"\<22rsv\>\"", ",", "q"}], "]"}], "/", 
   RowBox[{"Sqrt", "[", 
    RowBox[{"rrnorm", "[", 
     RowBox[{"\"\<22\>\"", ",", "q"}], "]"}], "]"}]}]}]], "Input",ExpressionUU\
ID->"78ee862e-7b9b-472b-9fd4-21097321da82"],

Cell[BoxData[
 RowBox[{
  RowBox[{"rrmat", "[", 
   RowBox[{"\"\<22srn\>\"", ",", "q_"}], "]"}], " ", ":=", " ", 
  RowBox[{
   RowBox[{"rrmat", "[", 
    RowBox[{"\"\<22srv\>\"", ",", "q"}], "]"}], "/", 
   RowBox[{"Sqrt", "[", 
    RowBox[{"rrnorm", "[", 
     RowBox[{"\"\<22\>\"", ",", "q"}], "]"}], "]"}]}]}]], "Input",ExpressionUU\
ID->"0fa0b3ca-698e-41bf-9710-72b6dfb15e36"],

Cell[BoxData[
 RowBox[{
  RowBox[{"rrmat", "[", 
   RowBox[{"\"\<22ssn\>\"", ",", "q_"}], "]"}], " ", ":=", " ", 
  RowBox[{
   RowBox[{"rrmat", "[", 
    RowBox[{"\"\<22ssv\>\"", ",", "q"}], "]"}], "/", 
   RowBox[{"Sqrt", "[", 
    RowBox[{"rrnorm", "[", 
     RowBox[{"\"\<22\>\"", ",", "q"}], "]"}], "]"}]}]}]], "Input",ExpressionUU\
ID->"e4d72fa6-39ab-4c3c-82b8-04fda70a798e"],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"metric", "[", "\"\<22\>\"", "]"}], " ", "=", " ", 
   RowBox[{"DiagonalMatrix", "[", 
    RowBox[{"{", 
     RowBox[{"1", ",", "1", ",", 
      RowBox[{"-", "1"}], ",", 
      RowBox[{"-", "1"}]}], "}"}], "]"}]}], ";"}]], "Input",ExpressionUUID->\
"35ff49cc-03e9-4318-ab40-e840458493d2"],

Cell[BoxData[
 RowBox[{"(*", " ", "Verification", " ", "*)"}]], "Input",ExpressionUUID->"2c888828-34c7-4b23-9826-56635153b82d"],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{
    RowBox[{"commut", "[", 
     RowBox[{
      RowBox[{"rrmat", "[", 
       RowBox[{"\"\<22rp\>\"", ",", 
        RowBox[{"{", 
         RowBox[{"aqt", ",", "1"}], "}"}]}], "]"}], ",", 
      RowBox[{"rrmat", "[", 
       RowBox[{"\"\<22rp\>\"", ",", 
        RowBox[{"{", 
         RowBox[{"bqt", ",", 
          RowBox[{"-", "1"}]}], "}"}]}], "]"}]}], "]"}], " ", "//", " ", 
    "Factor"}], "//", " ", "Flatten"}], " ", "//", " ", "Union"}]], "Input",Ex\
pressionUUID->"b010b95b-0f7e-4243-bf9d-04ab781f6312"],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{
    RowBox[{
     RowBox[{"rrmat", "[", 
      RowBox[{"\"\<22rrv\>\"", ",", 
       RowBox[{"{", 
        RowBox[{"aqt", ",", "bqt"}], "}"}]}], "]"}], " ", "-", " ", 
     RowBox[{
      RowBox[{"rrmat", "[", 
       RowBox[{"\"\<22rp\>\"", ",", 
        RowBox[{"{", 
         RowBox[{"aqt", ",", "1"}], "}"}]}], "]"}], ".", 
      RowBox[{"rrmat", "[", 
       RowBox[{"\"\<22rp\>\"", ",", 
        RowBox[{"{", 
         RowBox[{"bqt", ",", 
          RowBox[{"-", "1"}]}], "}"}]}], "]"}]}]}], " ", "//", " ", 
    "Factor"}], "//", " ", "Flatten"}], " ", "//", " ", "Union"}]], "Input",Ex\
pressionUUID->"0df99362-fc54-4712-bd49-7e4b16417cec"],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{
    RowBox[{"verifyrrmd", "[", 
     RowBox[{"{", 
      RowBox[{"\"\<22\>\"", ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"{", 
          RowBox[{"\"\<22rrn\>\"", ",", "1"}], "}"}], ",", 
         RowBox[{"{", 
          RowBox[{"\"\<22rsn\>\"", ",", 
           RowBox[{"-", "1"}]}], "}"}], ",", 
         RowBox[{"{", 
          RowBox[{"\"\<22srn\>\"", ",", 
           RowBox[{"-", "1"}]}], "}"}], ",", 
         RowBox[{"{", 
          RowBox[{"\"\<22ssn\>\"", ",", "1"}], "}"}]}], "}"}], ",", 
       RowBox[{"Array", "[", 
        RowBox[{"a", ",", 
         RowBox[{"{", 
          RowBox[{"2", ",", "4"}], "}"}]}], "]"}]}], "}"}], "]"}], " ", "//", 
    " ", "Factor"}], " ", "//", " ", "Flatten"}], " ", "//", " ", 
  "Union"}]], "Input",ExpressionUUID->"5e1044aa-addd-4ab9-a955-a40c074ff89c"],

Cell[BoxData[
 RowBox[{
  RowBox[{"abqptx1", " ", "=", " ", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"quatmultiply", "[", 
      RowBox[{"rr22metbase", ",", "1", ",", 
       RowBox[{"aqpt", "[", 
        RowBox[{"[", "1", "]"}], "]"}], ",", 
       RowBox[{"bqpt", "[", 
        RowBox[{"[", "1", "]"}], "]"}]}], "]"}], ",", 
     RowBox[{"quatmultiply", "[", 
      RowBox[{"rr22metbase", ",", "1", ",", 
       RowBox[{"aqpt", "[", 
        RowBox[{"[", "2", "]"}], "]"}], ",", 
       RowBox[{"bqpt", "[", 
        RowBox[{"[", "2", "]"}], "]"}]}], "]"}]}], "}"}]}], ";"}]], "Input",Ex\
pressionUUID->"ad9d4807-659e-4ebf-9925-a82b4f2dc807"],

Cell[BoxData[
 RowBox[{
  RowBox[{"abqptx2", " ", "=", " ", 
   RowBox[{"Table", "[", 
    RowBox[{
     RowBox[{"quatmultiply", "[", 
      RowBox[{"rr22metbase", ",", "1", ",", 
       RowBox[{"aqpt", "[", 
        RowBox[{"[", "i", "]"}], "]"}], ",", 
       RowBox[{"bqpt", "[", 
        RowBox[{"[", 
         RowBox[{"3", "-", "i"}], "]"}], "]"}]}], "]"}], ",", 
     RowBox[{"{", 
      RowBox[{"i", ",", "2"}], "}"}]}], "]"}]}], ";"}]], "Input",ExpressionUUI\
D->"db9ebd0a-888a-49fa-a1c2-be8da7eacb4c"],

Cell[BoxData[
 RowBox[{
  RowBox[{"abqptx3", " ", "=", " ", 
   RowBox[{"Table", "[", 
    RowBox[{
     RowBox[{"quatmultiply", "[", 
      RowBox[{"rr22metbase", ",", "1", ",", 
       RowBox[{"aqpt", "[", 
        RowBox[{"[", "i", "]"}], "]"}], ",", 
       RowBox[{
        RowBox[{"{", 
         RowBox[{"1", ",", 
          RowBox[{"-", "1"}], ",", "1", ",", 
          RowBox[{"-", "1"}]}], "}"}], "*", 
        RowBox[{"bqpt", "[", 
         RowBox[{"[", 
          RowBox[{"3", "-", "i"}], "]"}], "]"}]}]}], "]"}], ",", 
     RowBox[{"{", 
      RowBox[{"i", ",", "2"}], "}"}]}], "]"}]}], ";"}]], "Input",ExpressionUUI\
D->"7d95b1aa-d62e-42d5-bb4a-ec22eee122fe"],

Cell[BoxData[
 RowBox[{
  RowBox[{"abqptx4", " ", "=", " ", 
   RowBox[{"Table", "[", 
    RowBox[{
     RowBox[{"quatmultiply", "[", 
      RowBox[{"rr22metbase", ",", "1", ",", 
       RowBox[{"aqpt", "[", 
        RowBox[{"[", "i", "]"}], "]"}], ",", 
       RowBox[{
        RowBox[{"{", 
         RowBox[{"1", ",", 
          RowBox[{"-", "1"}], ",", "1", ",", 
          RowBox[{"-", "1"}]}], "}"}], "*", 
        RowBox[{"bqpt", "[", 
         RowBox[{"[", "i", "]"}], "]"}]}]}], "]"}], ",", 
     RowBox[{"{", 
      RowBox[{"i", ",", "2"}], "}"}]}], "]"}]}], ";"}]], "Input",ExpressionUUI\
D->"a0586318-b6ef-4e1d-a598-7fbaba6195fb"],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{
    RowBox[{"verifyrrprod", "[", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "\"\<22rrv\>\"", ",", "\"\<22rsv\>\"", ",", "\"\<22srv\>\"", ",", 
         "\"\<22ssv\>\""}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"aqpt", ",", "bqpt"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"{", 
          RowBox[{
           RowBox[{"{", 
            RowBox[{"\"\<22rrv\>\"", ",", "abqptx1"}], "}"}], ",", 
           RowBox[{"{", 
            RowBox[{"\"\<22rsv\>\"", ",", "abqptx1"}], "}"}], ",", 
           RowBox[{"{", 
            RowBox[{"\"\<22srv\>\"", ",", "abqptx1"}], "}"}], ",", 
           RowBox[{"{", 
            RowBox[{"\"\<22ssv\>\"", ",", "abqptx1"}], "}"}]}], "}"}], ",", 
         RowBox[{"{", 
          RowBox[{
           RowBox[{"{", 
            RowBox[{"\"\<22rsv\>\"", ",", "abqptx2"}], "}"}], ",", 
           RowBox[{"{", 
            RowBox[{"\"\<22rrv\>\"", ",", "abqptx2"}], "}"}], ",", 
           RowBox[{"{", 
            RowBox[{"\"\<22ssv\>\"", ",", "abqptx2"}], "}"}], ",", 
           RowBox[{"{", 
            RowBox[{"\"\<22srv\>\"", ",", "abqptx2"}], "}"}]}], "}"}], ",", 
         RowBox[{"{", 
          RowBox[{
           RowBox[{"{", 
            RowBox[{"\"\<22srv\>\"", ",", "abqptx3"}], "}"}], ",", 
           RowBox[{"{", 
            RowBox[{"\"\<22ssv\>\"", ",", "abqptx3"}], "}"}], ",", 
           RowBox[{"{", 
            RowBox[{"\"\<22rrv\>\"", ",", "abqptx3"}], "}"}], ",", 
           RowBox[{"{", 
            RowBox[{"\"\<22rsv\>\"", ",", "abqptx3"}], "}"}]}], "}"}], ",", 
         RowBox[{"{", 
          RowBox[{
           RowBox[{"{", 
            RowBox[{"\"\<22ssv\>\"", ",", "abqptx4"}], "}"}], ",", 
           RowBox[{"{", 
            RowBox[{"\"\<22srv\>\"", ",", "abqptx4"}], "}"}], ",", 
           RowBox[{"{", 
            RowBox[{"\"\<22rsv\>\"", ",", "abqptx4"}], "}"}], ",", 
           RowBox[{"{", 
            RowBox[{"\"\<22rrv\>\"", ",", "abqptx4"}], "}"}]}], "}"}]}], 
        "}"}]}], "}"}], "]"}], " ", "//", " ", "Factor"}], " ", "//", " ", 
   "Flatten"}], " ", "//", " ", "Union"}]], "Input",ExpressionUUID->"2f19d703-\
2a36-45ef-9999-015c0686d64e"]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{

Cell["Derivatives of the Matrices", "Section",ExpressionUUID->"c549e920-35d2-48b2-8eb2-620f8914212b"],

Cell[BoxData[
 RowBox[{"(*", " ", 
  RowBox[{"2", 
   RowBox[{"D", " ", "--"}], " ", "can", " ", "multiply", " ", "either", " ", 
   "side", " ", "of", " ", "the", " ", "rotation", " ", "matrix"}], " ", 
  "*)"}]], "Input",ExpressionUUID->"05aca496-3efb-4424-9ac4-73d074f47b54"],

Cell[BoxData[
 RowBox[{
  RowBox[{"RotateDeriv2D", "[", 
   RowBox[{"q_", ",", "t_"}], "]"}], " ", ":=", " ", 
  RowBox[{
   RowBox[{"-", " ", "eps2d"}], "*", 
   RowBox[{
    RowBox[{"(", 
     RowBox[{"q", ".", "eps2d", ".", 
      RowBox[{"D", "[", 
       RowBox[{"q", ",", "t"}], "]"}]}], ")"}], "/", 
    RowBox[{"abssqr", "[", 
     RowBox[{"q", ",", "2"}], "]"}]}]}]}]], "Input",ExpressionUUID->"dbb94a8c-\
c9f8-450c-8192-0619653e7cb3"],

Cell[BoxData[
 RowBox[{"(*", " ", 
  RowBox[{
   RowBox[{"3", 
    RowBox[{"D", " ", "--"}], " ", "left"}], "-", 
   RowBox[{"side", " ", "and", " ", "right"}], "-", 
   RowBox[{
   "side", " ", "different", " ", "for", " ", "multiplication", " ", "by", 
    " ", "the", " ", "rotation", " ", "matrix"}]}], " ", "*)"}]], "Input",Expr\
essionUUID->"40486093-53dc-489a-853d-1255ffc914af"],

Cell[BoxData[
 RowBox[{
  RowBox[{"RotateDerivLeft3D", "[", 
   RowBox[{"q_", ",", "t_"}], "]"}], " ", ":=", " ", 
  RowBox[{"Module", "[", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{"qs", ",", "qv", ",", "qd"}], "}"}], ",", "\[IndentingNewLine]", 
    
    RowBox[{
     RowBox[{"qs", " ", "=", " ", 
      RowBox[{"q", "[", 
       RowBox[{"[", "1", "]"}], "]"}]}], ";", " ", 
     RowBox[{"qv", " ", "=", " ", 
      RowBox[{"Take", "[", 
       RowBox[{"q", ",", 
        RowBox[{"{", 
         RowBox[{"2", ",", "4"}], "}"}]}], "]"}]}], ";", 
     "\[IndentingNewLine]", 
     RowBox[{"qd", " ", "=", " ", 
      RowBox[{"2", 
       RowBox[{
        RowBox[{"(", 
         RowBox[{
          RowBox[{"qs", "*", 
           RowBox[{"D", "[", 
            RowBox[{"qv", ",", "t"}], "]"}]}], "-", 
          RowBox[{"qv", "*", 
           RowBox[{"D", "[", 
            RowBox[{"qs", ",", "t"}], "]"}]}], "-", 
          RowBox[{"Cross", "[", 
           RowBox[{"qv", ",", 
            RowBox[{"D", "[", 
             RowBox[{"qv", ",", "t"}], "]"}]}], "]"}]}], ")"}], "/", 
        RowBox[{"quatnorm", "[", "q", "]"}]}]}]}], ";", "\[IndentingNewLine]", 
     RowBox[{"asymvt", "[", "qd", "]"}]}]}], "\[IndentingNewLine]", 
   "]"}]}]], "Input",ExpressionUUID->"b851c4bb-d0e8-439b-b130-e80332df74bf"],

Cell[BoxData[
 RowBox[{
  RowBox[{"RotateDerivRight3D", "[", 
   RowBox[{"q_", ",", "t_"}], "]"}], " ", ":=", " ", 
  RowBox[{"Module", "[", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{"qs", ",", "qv", ",", "qd"}], "}"}], ",", "\[IndentingNewLine]", 
    
    RowBox[{
     RowBox[{"qs", " ", "=", " ", 
      RowBox[{"q", "[", 
       RowBox[{"[", "1", "]"}], "]"}]}], ";", " ", 
     RowBox[{"qv", " ", "=", " ", 
      RowBox[{"Take", "[", 
       RowBox[{"q", ",", 
        RowBox[{"{", 
         RowBox[{"2", ",", "4"}], "}"}]}], "]"}]}], ";", 
     "\[IndentingNewLine]", 
     RowBox[{"qd", " ", "=", " ", 
      RowBox[{"2", 
       RowBox[{
        RowBox[{"(", 
         RowBox[{
          RowBox[{"qs", "*", 
           RowBox[{"D", "[", 
            RowBox[{"qv", ",", "t"}], "]"}]}], "-", 
          RowBox[{"qv", "*", 
           RowBox[{"D", "[", 
            RowBox[{"qs", ",", "t"}], "]"}]}], "+", 
          RowBox[{"Cross", "[", 
           RowBox[{"qv", ",", 
            RowBox[{"D", "[", 
             RowBox[{"qv", ",", "t"}], "]"}]}], "]"}]}], ")"}], "/", 
        RowBox[{"quatnorm", "[", "q", "]"}]}]}]}], ";", "\[IndentingNewLine]", 
     RowBox[{"asymvt", "[", "qd", "]"}]}]}], "\[IndentingNewLine]", 
   "]"}]}]], "Input",ExpressionUUID->"45bad37c-9e8d-4690-b5cb-a3b743f25051"],

Cell[BoxData[
 RowBox[{"(*", " ", "Verification", " ", "*)"}]], "Input",ExpressionUUID->"27fb6f47-7beb-49b6-9014-c72fe258558a"],

Cell[BoxData[
 RowBox[{
  RowBox[{"RotMatDerivVerify", "[", 
   RowBox[{"q_", ",", "t_"}], "]"}], " ", ":=", " ", 
  RowBox[{"Module", "[", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{"qv2", ",", "qv3"}], "}"}], ",", "\[IndentingNewLine]", 
    RowBox[{
     RowBox[{"qv2", " ", "=", " ", 
      RowBox[{"Array", "[", 
       RowBox[{
        RowBox[{
         RowBox[{"q", "[", 
          RowBox[{"t", ",", "#"}], "]"}], "&"}], ",", "2"}], "]"}]}], ";", 
     "\[IndentingNewLine]", 
     RowBox[{"qv3", " ", "=", " ", 
      RowBox[{"Array", "[", 
       RowBox[{
        RowBox[{
         RowBox[{"q", "[", 
          RowBox[{"t", ",", "#"}], "]"}], "&"}], ",", "4"}], "]"}]}], ";", 
     "\[IndentingNewLine]", 
     RowBox[{
      RowBox[{"{", 
       RowBox[{
        RowBox[{
         RowBox[{"D", "[", 
          RowBox[{
           RowBox[{"rrmat", "[", 
            RowBox[{"\"\<2rn\>\"", ",", "qv2"}], "]"}], ",", "t"}], "]"}], 
         " ", "-", " ", 
         RowBox[{
          RowBox[{"RotateDeriv2D", "[", 
           RowBox[{"qv2", ",", "t"}], "]"}], ".", 
          RowBox[{"rrmat", "[", 
           RowBox[{"\"\<2rn\>\"", ",", "qv2"}], "]"}]}]}], ",", 
        RowBox[{
         RowBox[{"D", "[", 
          RowBox[{
           RowBox[{"rrmat", "[", 
            RowBox[{"\"\<2rn\>\"", ",", "qv2"}], "]"}], ",", "t"}], "]"}], 
         " ", "-", " ", 
         RowBox[{
          RowBox[{"rrmat", "[", 
           RowBox[{"\"\<2rn\>\"", ",", "qv2"}], "]"}], ".", 
          RowBox[{"RotateDeriv2D", "[", 
           RowBox[{"qv2", ",", "t"}], "]"}]}]}], ",", 
        RowBox[{
         RowBox[{"D", "[", 
          RowBox[{
           RowBox[{"rrmat", "[", 
            RowBox[{"\"\<3rn\>\"", ",", "qv3"}], "]"}], ",", "t"}], "]"}], 
         " ", "-", " ", 
         RowBox[{
          RowBox[{"RotateDerivLeft3D", "[", 
           RowBox[{"qv3", ",", "t"}], "]"}], ".", 
          RowBox[{"rrmat", "[", 
           RowBox[{"\"\<3rn\>\"", ",", "qv3"}], "]"}]}]}], ",", 
        RowBox[{
         RowBox[{"D", "[", 
          RowBox[{
           RowBox[{"rrmat", "[", 
            RowBox[{"\"\<3rn\>\"", ",", "qv3"}], "]"}], ",", "t"}], "]"}], 
         " ", "-", " ", 
         RowBox[{
          RowBox[{"rrmat", "[", 
           RowBox[{"\"\<3rn\>\"", ",", "qv3"}], "]"}], ".", 
          RowBox[{"RotateDerivRight3D", "[", 
           RowBox[{"qv3", ",", "t"}], "]"}]}]}]}], " ", "}"}], " ", "//", " ",
       "Factor"}]}]}], "\[IndentingNewLine]", "]"}]}]], "Input",ExpressionUUID\
->"dc11a7f2-8ad3-4ea3-b97e-b4310c253e7d"],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"RotMatDerivVerify", "[", 
    RowBox[{"q", ",", "t"}], "]"}], " ", "//", " ", "Flatten"}], " ", "//", 
  " ", "Union"}]], "Input",ExpressionUUID->"3c491c61-48c5-4c23-b7c7-\
6ef5f4b74d83"]
}, Closed]],

Cell[CellGroupData[{

Cell["Eigenvalues of the Matrices", "Section",ExpressionUUID->"74b6b812-0bb8-4504-99a7-0335172c8327"],

Cell[CellGroupData[{

Cell["Characteristic Polynomials", "Subsection",ExpressionUUID->"69d22f95-b13f-47ab-a71a-558b5ef39424"],

Cell[BoxData[
 RowBox[{
  RowBox[{"pairvec", " ", "=", " ", 
   RowBox[{"{", 
    RowBox[{"q0", ",", "q1"}], "}"}]}], ";", 
  RowBox[{"quatvec", " ", "=", " ", 
   RowBox[{"{", 
    RowBox[{"q0", ",", "q1", ",", "q2", ",", "q3"}], "}"}]}], ";", " ", 
  RowBox[{"quatvecpair", " ", "=", " ", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"q10", ",", "q11", ",", "q12", ",", "q13"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"q20", ",", "q21", ",", "q22", ",", "q23"}], "}"}]}], "}"}]}], 
  ";"}]], "Input",ExpressionUUID->"1e226e12-72cd-4442-8e9e-e7baaf447ac5"],

Cell[BoxData[
 RowBox[{"(*", " ", 
  RowBox[{"Quaternions", " ", "as", " ", "Pauli", " ", "matrices"}], " ", 
  "*)"}]], "Input",ExpressionUUID->"effdfc4e-a792-43d0-af13-c0d8eeaa3f70"],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"CharacteristicPolynomial", "[", 
    RowBox[{
     RowBox[{
      RowBox[{"quatpauli", "[", "quatvec", "]"}], "/", 
      RowBox[{"Sqrt", "[", 
       RowBox[{"quatnorm", "[", "quatvec", "]"}], "]"}]}], ",", "x"}], "]"}], 
   " ", "-", " ", 
   RowBox[{"(", 
    RowBox[{"1", " ", "-", " ", 
     RowBox[{"2", 
      RowBox[{
       RowBox[{"First", "[", "quatvec", "]"}], "/", 
       RowBox[{"Sqrt", "[", 
        RowBox[{"quatnorm", "[", "quatvec", "]"}], "]"}]}], "*", "x"}], " ", 
     "+", " ", 
     RowBox[{"x", "^", "2"}]}], ")"}]}], "//", " ", "Factor"}]], "Input",Expre\
ssionUUID->"7276c7d5-b584-4929-9390-9045b10dbfd0"],

Cell[BoxData[
 RowBox[{"(*", " ", 
  RowBox[{"2", "D"}], " ", "*)"}]], "Input",ExpressionUUID->"b5f31a8c-9b1b-4bf8-86a5-a55cd6066c60"],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"CharacteristicPolynomial", "[", 
    RowBox[{
     RowBox[{"rrmat", "[", 
      RowBox[{"\"\<2rn\>\"", ",", "pairvec"}], "]"}], ",", "x"}], "]"}], " ", 
   "-", " ", 
   RowBox[{"(", 
    RowBox[{"1", " ", "-", " ", 
     RowBox[{"2", 
      RowBox[{
       RowBox[{"First", "[", "pairvec", "]"}], "/", 
       RowBox[{"Sqrt", "[", 
        RowBox[{"rrnorm", "[", 
         RowBox[{"\"\<2\>\"", ",", "pairvec"}], "]"}], "]"}]}], "*", "x"}], 
     " ", "+", " ", 
     RowBox[{"x", "^", "2"}]}], ")"}]}], " ", "//", " ", "Factor"}]], "Input",\
ExpressionUUID->"e7bd44ef-3b76-40c4-8ac2-fd4baa6423ae"],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"CharacteristicPolynomial", "[", 
    RowBox[{
     RowBox[{"rrmat", "[", 
      RowBox[{"\"\<2sn\>\"", ",", "pairvec"}], "]"}], ",", "x"}], "]"}], " ", 
   "+", " ", 
   RowBox[{"(", 
    RowBox[{"1", "-", 
     RowBox[{"x", "^", "2"}]}], ")"}]}], " ", "//", " ", "Factor"}]], "Input",\
ExpressionUUID->"f36dd44c-f15b-43f0-b392-fe15dd894a82"],

Cell[BoxData[
 RowBox[{"(*", " ", 
  RowBox[{"1", "+", 
   RowBox[{"1", "D"}]}], " ", "*)"}]], "Input",ExpressionUUID->"edb276ea-e3d1-\
40a7-b835-8845b285a519"],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"CharacteristicPolynomial", "[", 
    RowBox[{
     RowBox[{"rrmat", "[", 
      RowBox[{"\"\<11rn\>\"", ",", "pairvec"}], "]"}], ",", "x"}], "]"}], " ",
    "-", " ", 
   RowBox[{"(", 
    RowBox[{"1", " ", "-", " ", 
     RowBox[{"2", 
      RowBox[{
       RowBox[{"First", "[", "pairvec", "]"}], "/", 
       RowBox[{"Sqrt", "[", 
        RowBox[{"rrnorm", "[", 
         RowBox[{"\"\<11\>\"", ",", "pairvec"}], "]"}], "]"}]}], "*", "x"}], 
     " ", "+", " ", 
     RowBox[{"x", "^", "2"}]}], ")"}]}], " ", "//", " ", "Factor"}]], "Input",\
ExpressionUUID->"a1d6f190-2bbf-42b1-99be-3c93ac047cf2"],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"CharacteristicPolynomial", "[", 
    RowBox[{
     RowBox[{"rrmat", "[", 
      RowBox[{"\"\<11sn\>\"", ",", "pairvec"}], "]"}], ",", "x"}], "]"}], " ",
    "+", " ", 
   RowBox[{"(", 
    RowBox[{"1", "-", 
     RowBox[{"x", "^", "2"}]}], ")"}]}], " ", "//", " ", "Factor"}]], "Input",\
ExpressionUUID->"f4453222-f821-4207-a84c-cfc0edbc87e2"],

Cell[BoxData[
 RowBox[{"(*", " ", 
  RowBox[{"3", "D"}], " ", "*)"}]], "Input",ExpressionUUID->"e54610fb-f842-4c19-9826-75b11a23a353"],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"CharacteristicPolynomial", "[", 
    RowBox[{
     RowBox[{"rrmat", "[", 
      RowBox[{"\"\<3rn\>\"", ",", "quatvec"}], "]"}], ",", "x"}], "]"}], " ", 
   "-", " ", 
   RowBox[{
    RowBox[{"(", 
     RowBox[{"1", "-", "x"}], ")"}], 
    RowBox[{"(", 
     RowBox[{"1", " ", "-", " ", 
      RowBox[{"2", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{"2", 
          RowBox[{
           RowBox[{
            RowBox[{"First", "[", "quatvec", "]"}], "^", "2"}], "/", 
           RowBox[{"rrnorm", "[", 
            RowBox[{"\"\<3\>\"", ",", "quatvec"}], "]"}]}]}], "-", "1"}], 
        ")"}], "*", "x"}], "+", 
      RowBox[{"x", "^", "2"}]}], ")"}]}]}], " ", "//", " ", 
  "Factor"}]], "Input",ExpressionUUID->"630145b8-9897-480e-8f0d-d40174caf735"],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"CharacteristicPolynomial", "[", 
    RowBox[{
     RowBox[{"rrmat", "[", 
      RowBox[{"\"\<3sn\>\"", ",", "quatvec"}], "]"}], ",", "x"}], "]"}], " ", 
   "+", " ", 
   RowBox[{
    RowBox[{"(", 
     RowBox[{"1", "+", "x"}], ")"}], 
    RowBox[{"(", 
     RowBox[{"1", " ", "+", " ", 
      RowBox[{"2", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{"2", 
          RowBox[{
           RowBox[{
            RowBox[{"First", "[", "quatvec", "]"}], "^", "2"}], "/", 
           RowBox[{"rrnorm", "[", 
            RowBox[{"\"\<3\>\"", ",", "quatvec"}], "]"}]}]}], "-", "1"}], 
        ")"}], "*", "x"}], "+", 
      RowBox[{"x", "^", "2"}]}], ")"}]}]}], " ", "//", " ", 
  "Factor"}]], "Input",ExpressionUUID->"5dabf6e5-2fe3-4a3c-8e2c-cd34ee7ae923"],

Cell[BoxData[
 RowBox[{"(*", " ", 
  RowBox[{"2", "+", 
   RowBox[{"1", "D"}]}], " ", "*)"}]], "Input",ExpressionUUID->"007e46a0-8b9c-\
4361-acc3-7e5354d96bfd"],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"CharacteristicPolynomial", "[", 
    RowBox[{
     RowBox[{"rrmat", "[", 
      RowBox[{"\"\<21rrn\>\"", ",", "quatvec"}], "]"}], ",", "x"}], "]"}], 
   " ", "-", " ", 
   RowBox[{
    RowBox[{"(", 
     RowBox[{"1", "-", "x"}], ")"}], 
    RowBox[{"(", 
     RowBox[{"1", " ", "-", " ", 
      RowBox[{"2", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{"2", 
          RowBox[{
           RowBox[{
            RowBox[{"First", "[", "quatvec", "]"}], "^", "2"}], "/", 
           RowBox[{"rrnorm", "[", 
            RowBox[{"\"\<21\>\"", ",", "quatvec"}], "]"}]}]}], "-", "1"}], 
        ")"}], "*", "x"}], "+", 
      RowBox[{"x", "^", "2"}]}], ")"}]}]}], " ", "//", " ", 
  "Factor"}]], "Input",ExpressionUUID->"59ceb4c0-2e7c-4031-8020-f14f98b73e22"],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"CharacteristicPolynomial", "[", 
    RowBox[{
     RowBox[{"rrmat", "[", 
      RowBox[{"\"\<21rsn\>\"", ",", "quatvec"}], "]"}], ",", "x"}], "]"}], 
   " ", "+", " ", 
   RowBox[{
    RowBox[{"(", 
     RowBox[{"1", "+", "x"}], ")"}], 
    RowBox[{"(", 
     RowBox[{"1", " ", "-", " ", 
      RowBox[{"2", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{"(", 
          RowBox[{
           RowBox[{"2", 
            RowBox[{
             RowBox[{"First", "[", "quatvec", "]"}], "^", "2"}]}], "-", 
           RowBox[{"quatnorm", "[", "quatvec", "]"}]}], ")"}], "/", 
         RowBox[{"rrnorm", "[", 
          RowBox[{"\"\<21\>\"", ",", "quatvec"}], "]"}]}], ")"}], "*", "x"}], 
      "+", 
      RowBox[{"x", "^", "2"}]}], ")"}]}]}], " ", "//", " ", 
  "Factor"}]], "Input",ExpressionUUID->"52105514-eac5-4d1b-a44b-a5ae2a542c95"],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"CharacteristicPolynomial", "[", 
    RowBox[{
     RowBox[{"rrmat", "[", 
      RowBox[{"\"\<21srn\>\"", ",", "quatvec"}], "]"}], ",", "x"}], "]"}], 
   " ", "+", " ", 
   RowBox[{
    RowBox[{"(", 
     RowBox[{"1", "+", "x"}], ")"}], 
    RowBox[{"(", 
     RowBox[{"1", " ", "-", " ", 
      RowBox[{"2", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{"(", 
          RowBox[{
           RowBox[{
            RowBox[{"-", "2"}], 
            RowBox[{
             RowBox[{"quatvec", "[", 
              RowBox[{"[", "2", "]"}], "]"}], "^", "2"}]}], "+", 
           RowBox[{"quatnorm", "[", "quatvec", "]"}]}], ")"}], "/", 
         RowBox[{"rrnorm", "[", 
          RowBox[{"\"\<21\>\"", ",", "quatvec"}], "]"}]}], ")"}], "*", "x"}], 
      "+", 
      RowBox[{"x", "^", "2"}]}], ")"}]}]}], " ", "//", " ", 
  "Factor"}]], "Input",ExpressionUUID->"bebba37c-366c-4611-9fb9-8e7a1f457963"],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"CharacteristicPolynomial", "[", 
    RowBox[{
     RowBox[{"rrmat", "[", 
      RowBox[{"\"\<21ssn\>\"", ",", "quatvec"}], "]"}], ",", "x"}], "]"}], 
   " ", "-", " ", 
   RowBox[{
    RowBox[{"(", 
     RowBox[{"1", "-", "x"}], ")"}], 
    RowBox[{"(", 
     RowBox[{"1", " ", "-", " ", 
      RowBox[{"2", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{
          RowBox[{"(", 
           RowBox[{
            RowBox[{"-", "2"}], 
            RowBox[{
             RowBox[{"quatvec", "[", 
              RowBox[{"[", "2", "]"}], "]"}], "^", "2"}]}], ")"}], "/", 
          RowBox[{"rrnorm", "[", 
           RowBox[{"\"\<21\>\"", ",", "quatvec"}], "]"}]}], "-", "1"}], ")"}],
        "*", "x"}], "+", 
      RowBox[{"x", "^", "2"}]}], ")"}]}]}], " ", "//", " ", 
  "Factor"}]], "Input",ExpressionUUID->"c5dcdfa2-f376-42c5-8fdb-8d19069a80e2"],

Cell[BoxData[
 RowBox[{"(*", " ", 
  RowBox[{"4", "D"}], " ", "*)"}]], "Input",ExpressionUUID->"3d351207-e15d-460e-8897-0f344041a09a"],

Cell[BoxData[
 RowBox[{
  RowBox[{"qvpcp1", " ", "=", " ", 
   RowBox[{
    RowBox[{"(", 
     RowBox[{"Times", " ", "@@", " ", 
      RowBox[{"(", 
       RowBox[{"First", " ", "/@", " ", "quatvecpair"}], ")"}]}], ")"}], "/", 
    
    RowBox[{"Sqrt", "[", 
     RowBox[{"rrnorm", "[", 
      RowBox[{"\"\<4\>\"", ",", "quatvecpair"}], "]"}], "]"}]}]}], 
  ";"}]], "Input",ExpressionUUID->"4d8bcbfa-745f-46a0-8194-c3469a8a3b56"],

Cell[BoxData[
 RowBox[{
  RowBox[{"qvpcp2", " ", "=", " ", 
   RowBox[{"Sqrt", "[", 
    RowBox[{"Factor", "[", 
     RowBox[{"Times", " ", "@@", " ", 
      RowBox[{"(", 
       RowBox[{"1", "-", 
        RowBox[{
         RowBox[{
          RowBox[{"(", 
           RowBox[{"First", " ", "/@", " ", "quatvecpair"}], ")"}], "^", 
          "2"}], "/", 
         RowBox[{"(", 
          RowBox[{"quatnorm", " ", "/@", " ", "quatvecpair"}], ")"}]}]}], 
       ")"}]}], "]"}], "]"}]}], ";"}]], "Input",ExpressionUUID->"2f61421f-\
6976-4203-942c-55d007a04bff"],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{
    RowBox[{"CharacteristicPolynomial", "[", 
     RowBox[{
      RowBox[{"rrmat", "[", 
       RowBox[{"\"\<4rn\>\"", ",", "quatvecpair"}], "]"}], ",", "x"}], "]"}], 
    " ", "-", " ", 
    RowBox[{
     RowBox[{"(", 
      RowBox[{"1", " ", "-", " ", 
       RowBox[{"2", "*", 
        RowBox[{"(", 
         RowBox[{"qvpcp1", "+", "qvpcp2"}], ")"}], "*", "x"}], " ", "+", " ", 
       
       RowBox[{"x", "^", "2"}]}], ")"}], 
     RowBox[{"(", 
      RowBox[{"1", " ", "-", " ", 
       RowBox[{"2", "*", 
        RowBox[{"(", 
         RowBox[{"qvpcp1", "-", "qvpcp2"}], ")"}], "*", "x"}], " ", "+", " ", 
       
       RowBox[{"x", "^", "2"}]}], ")"}]}]}], " ", "//", " ", "Expand"}], " ", 
  "//", " ", "Factor"}]], "Input",ExpressionUUID->"8efca578-2087-4585-bfe2-\
16dc34f2959d"],

Cell[BoxData[
 RowBox[{
  RowBox[{"qvpcp3", " ", "=", " ", 
   RowBox[{
    RowBox[{"(", 
     RowBox[{
      RowBox[{"2", 
       RowBox[{"(", 
        RowBox[{"Times", " ", "@@", " ", 
         RowBox[{"(", 
          RowBox[{"First", " ", "/@", " ", "quatvecpair"}], ")"}]}], ")"}]}], 
      " ", "-", " ", 
      RowBox[{"(", 
       RowBox[{"Dot", " ", "@@", " ", "quatvecpair"}], ")"}]}], ")"}], "/", 
    RowBox[{"Sqrt", "[", 
     RowBox[{"rrnorm", "[", 
      RowBox[{"\"\<4\>\"", ",", "quatvecpair"}], "]"}], "]"}]}]}], 
  ";"}]], "Input",ExpressionUUID->"80ea89a5-7520-44e8-beca-e6e52d79d137"],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"CharacteristicPolynomial", "[", 
    RowBox[{
     RowBox[{"rrmat", "[", 
      RowBox[{"\"\<4sn\>\"", ",", "quatvecpair"}], "]"}], ",", "x"}], "]"}], 
   " ", "+", " ", 
   RowBox[{
    RowBox[{"(", 
     RowBox[{"1", "-", 
      RowBox[{"x", "^", "2"}]}], ")"}], 
    RowBox[{"(", 
     RowBox[{"1", " ", "-", 
      RowBox[{"2", "qvpcp3", "*", "x"}], " ", "+", " ", 
      RowBox[{"x", "^", "2"}]}], ")"}]}]}], " ", "//", " ", 
  "Factor"}]], "Input",ExpressionUUID->"9847ba40-e3fe-4aee-b015-a6b3c6631479"],

Cell[BoxData[
 RowBox[{"(*", " ", 
  RowBox[{"2", "+", 
   RowBox[{"2", "D"}]}], " ", "*)"}]], "Input",ExpressionUUID->"e02edf1d-2cad-\
4ab1-b9f3-a8b69b4f8ecc"],

Cell[BoxData[
 RowBox[{
  RowBox[{"qvpcpy1", " ", "=", " ", 
   RowBox[{
    RowBox[{"(", 
     RowBox[{"Times", " ", "@@", " ", 
      RowBox[{"(", 
       RowBox[{"First", " ", "/@", " ", "quatvecpair"}], ")"}]}], ")"}], "/", 
    
    RowBox[{"Sqrt", "[", 
     RowBox[{"rrnorm", "[", 
      RowBox[{"\"\<22\>\"", ",", "quatvecpair"}], "]"}], "]"}]}]}], 
  ";"}]], "Input",ExpressionUUID->"2154a0ee-ecee-471e-bd9a-a779f7bd488d"],

Cell[BoxData[
 RowBox[{
  RowBox[{"qvpcpy2", " ", "=", " ", 
   RowBox[{"Sqrt", "[", 
    RowBox[{"Factor", "[", 
     RowBox[{"Times", " ", "@@", " ", 
      RowBox[{"(", 
       RowBox[{"1", "-", 
        RowBox[{
         RowBox[{
          RowBox[{"(", 
           RowBox[{"First", " ", "/@", " ", "quatvecpair"}], ")"}], "^", 
          "2"}], "/", 
         RowBox[{"(", 
          RowBox[{
           RowBox[{
            RowBox[{"quatnorm", "[", 
             RowBox[{"rr22metbase", ",", "#"}], "]"}], "&"}], " ", " ", "/@", 
           " ", "quatvecpair"}], ")"}]}]}], ")"}]}], "]"}], "]"}]}], 
  ";"}]], "Input",ExpressionUUID->"cd3fcdda-ca95-497c-8c7c-03c8f50a1d68"],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{
    RowBox[{"CharacteristicPolynomial", "[", 
     RowBox[{
      RowBox[{"rrmat", "[", 
       RowBox[{"\"\<22rrn\>\"", ",", "quatvecpair"}], "]"}], ",", "x"}], 
     "]"}], " ", "-", " ", 
    RowBox[{
     RowBox[{"(", 
      RowBox[{"1", " ", "-", " ", 
       RowBox[{"2", "*", 
        RowBox[{"(", 
         RowBox[{"qvpcpy1", "+", "qvpcpy2"}], ")"}], "*", "x"}], " ", "+", 
       " ", 
       RowBox[{"x", "^", "2"}]}], ")"}], 
     RowBox[{"(", 
      RowBox[{"1", " ", "-", " ", 
       RowBox[{"2", "*", 
        RowBox[{"(", 
         RowBox[{"qvpcpy1", "-", "qvpcpy2"}], ")"}], "*", "x"}], " ", "+", 
       " ", 
       RowBox[{"x", "^", "2"}]}], ")"}]}]}], " ", "//", " ", "Expand"}], " ", 
  "//", " ", "Factor"}]], "Input",ExpressionUUID->"60268fed-787c-4c21-ab43-\
c4722fdb5043"],

Cell[BoxData[
 RowBox[{
  RowBox[{"qvpcpy3", " ", "=", " ", 
   RowBox[{
    RowBox[{"(", 
     RowBox[{
      RowBox[{"2", 
       RowBox[{"(", 
        RowBox[{"Times", " ", "@@", " ", 
         RowBox[{"(", 
          RowBox[{"First", " ", "/@", " ", "quatvecpair"}], ")"}]}], ")"}]}], 
      " ", "-", " ", 
      RowBox[{"(", 
       RowBox[{"Dot", " ", "@@", " ", 
        RowBox[{"(", 
         RowBox[{
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"1", ",", "1", ",", "1", ",", "1"}], "}"}], ",", 
            RowBox[{"Prepend", "[", 
             RowBox[{"rr22metbase", ",", "1"}], "]"}]}], "}"}], 
          "quatvecpair"}], ")"}]}], ")"}]}], ")"}], "/", 
    RowBox[{"Sqrt", "[", 
     RowBox[{"rrnorm", "[", 
      RowBox[{"\"\<22\>\"", ",", "quatvecpair"}], "]"}], "]"}]}]}], 
  ";"}]], "Input",ExpressionUUID->"32366e70-7529-4127-bc32-9b4a251954d0"],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"CharacteristicPolynomial", "[", 
    RowBox[{
     RowBox[{"rrmat", "[", 
      RowBox[{"\"\<22rsn\>\"", ",", "quatvecpair"}], "]"}], ",", "x"}], "]"}],
    " ", "+", " ", 
   RowBox[{
    RowBox[{"(", 
     RowBox[{"1", "-", 
      RowBox[{"x", "^", "2"}]}], ")"}], 
    RowBox[{"(", 
     RowBox[{"1", " ", "-", 
      RowBox[{"2", "qvpcpy3", "*", "x"}], " ", "+", " ", 
      RowBox[{"x", "^", "2"}]}], ")"}]}]}], " ", "//", " ", 
  "Factor"}]], "Input",ExpressionUUID->"98f8337b-3da5-4b4e-ba89-5ff2bef459bf"],

Cell[BoxData[
 RowBox[{
  RowBox[{"qvpcpy4", " ", "=", " ", 
   RowBox[{
    RowBox[{"(", 
     RowBox[{
      RowBox[{"2", 
       RowBox[{"(", 
        RowBox[{"Times", " ", "@@", " ", 
         RowBox[{"(", 
          RowBox[{"First", " ", "/@", " ", "quatvecpair"}], ")"}]}], ")"}]}], 
      " ", "+", 
      RowBox[{"(", 
       RowBox[{"Dot", " ", "@@", " ", 
        RowBox[{"(", 
         RowBox[{
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{
              RowBox[{"-", "1"}], ",", "1", ",", 
              RowBox[{"-", "1"}], ",", "1"}], "}"}], ",", 
            RowBox[{"Prepend", "[", 
             RowBox[{"rr22metbase", ",", "1"}], "]"}]}], "}"}], 
          "quatvecpair"}], ")"}]}], ")"}]}], ")"}], "/", 
    RowBox[{"Sqrt", "[", 
     RowBox[{"rrnorm", "[", 
      RowBox[{"\"\<22\>\"", ",", "quatvecpair"}], "]"}], "]"}]}]}], 
  ";"}]], "Input",ExpressionUUID->"96a2b080-296b-4b18-9c1a-f86a207fa874"],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"CharacteristicPolynomial", "[", 
    RowBox[{
     RowBox[{"rrmat", "[", 
      RowBox[{"\"\<22srn\>\"", ",", "quatvecpair"}], "]"}], ",", "x"}], "]"}],
    " ", "+", " ", 
   RowBox[{
    RowBox[{"(", 
     RowBox[{"1", "-", 
      RowBox[{"x", "^", "2"}]}], ")"}], 
    RowBox[{"(", 
     RowBox[{"1", " ", "-", 
      RowBox[{"2", "qvpcpy4", "*", "x"}], " ", "+", " ", 
      RowBox[{"x", "^", "2"}]}], ")"}]}]}], " ", "//", " ", 
  "Factor"}]], "Input",ExpressionUUID->"3c430e5d-bad9-4933-bdf4-58e609fc9dba"],

Cell[BoxData[
 RowBox[{
  RowBox[{"qvpcpy5", " ", "=", " ", 
   RowBox[{
    RowBox[{"(", 
     RowBox[{"Times", " ", "@@", " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{
         RowBox[{"#", "[", 
          RowBox[{"[", "3", "]"}], "]"}], "&"}], " ", "/@", " ", 
        "quatvecpair"}], ")"}]}], ")"}], "/", 
    RowBox[{"Sqrt", "[", 
     RowBox[{"rrnorm", "[", 
      RowBox[{"\"\<22\>\"", ",", "quatvecpair"}], "]"}], "]"}]}]}], 
  ";"}]], "Input",ExpressionUUID->"5a369228-d01a-4c63-a805-db9e78de9b40"],

Cell[BoxData[
 RowBox[{
  RowBox[{"qvpcpy6", " ", "=", " ", 
   RowBox[{"Sqrt", "[", 
    RowBox[{"Factor", "[", 
     RowBox[{"Times", " ", "@@", " ", 
      RowBox[{"(", 
       RowBox[{"1", "+", 
        RowBox[{
         RowBox[{
          RowBox[{"(", 
           RowBox[{
            RowBox[{
             RowBox[{"#", "[", 
              RowBox[{"[", "3", "]"}], "]"}], "&"}], " ", "/@", " ", 
            "quatvecpair"}], ")"}], "^", "2"}], "/", 
         RowBox[{"(", 
          RowBox[{
           RowBox[{
            RowBox[{"quatnorm", "[", 
             RowBox[{"rr22metbase", ",", "#"}], "]"}], "&"}], " ", " ", "/@", 
           " ", "quatvecpair"}], ")"}]}]}], ")"}]}], "]"}], "]"}]}], 
  ";"}]], "Input",ExpressionUUID->"566138b0-35aa-4d32-a76c-0f637a5630cb"],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{
    RowBox[{"CharacteristicPolynomial", "[", 
     RowBox[{
      RowBox[{"rrmat", "[", 
       RowBox[{"\"\<22ssn\>\"", ",", "quatvecpair"}], "]"}], ",", "x"}], 
     "]"}], " ", "-", " ", 
    RowBox[{
     RowBox[{"(", 
      RowBox[{"1", " ", "-", " ", 
       RowBox[{"2", "*", 
        RowBox[{"(", 
         RowBox[{"qvpcpy5", "+", "qvpcpy6"}], ")"}], "*", "x"}], " ", "+", 
       " ", 
       RowBox[{"x", "^", "2"}]}], ")"}], 
     RowBox[{"(", 
      RowBox[{"1", " ", "-", " ", 
       RowBox[{"2", "*", 
        RowBox[{"(", 
         RowBox[{"qvpcpy5", "-", "qvpcpy6"}], ")"}], "*", "x"}], " ", "+", 
       " ", 
       RowBox[{"x", "^", "2"}]}], ")"}]}]}], " ", "//", " ", "Expand"}], " ", 
  "//", " ", "Factor"}]], "Input",ExpressionUUID->"cb1032e7-ceb0-4720-8cb2-\
51fbd2a93670"],

Cell[BoxData[
 RowBox[{"(*", " ", 
  RowBox[{"3", "+", 
   RowBox[{"1", "D"}]}], " ", "*)"}]], "Input",ExpressionUUID->"ec1f11d3-e08a-\
481b-99d3-6ec3c6aed7cc"],

Cell[BoxData[
 RowBox[{
  RowBox[{"quatvecpair0", " ", "=", " ", "quatvecpair"}], ";"}]], "Input",Expr\
essionUUID->"8019e240-a479-4da1-bcbb-290b0e422b1a"],

Cell[BoxData[
 RowBox[{
  RowBox[{"quatvecpair", " ", "=", " ", 
   RowBox[{"quatvecpair1", " ", "=", " ", 
    RowBox[{"{", 
     RowBox[{
      RowBox[{"{", 
       RowBox[{"q10", ",", "q11", ",", "0", ",", "0"}], "}"}], ",", 
      RowBox[{"{", 
       RowBox[{"q20", ",", "0", ",", "q21", ",", "0"}], "}"}]}], "}"}]}]}], 
  ";"}]], "Input",ExpressionUUID->"cfe6d167-ec9a-4f23-ad0c-26f0636f1cc1"],

Cell[BoxData[
 RowBox[{
  RowBox[{"qvpcpx1", " ", "=", " ", 
   RowBox[{
    RowBox[{"(", 
     RowBox[{
      RowBox[{
       RowBox[{"First", "[", 
        RowBox[{"quatvecpair", "[", 
         RowBox[{"[", "1", "]"}], "]"}], "]"}], "^", "2"}], "+", 
      RowBox[{
       RowBox[{"First", "[", 
        RowBox[{"quatvecpair", "[", 
         RowBox[{"[", "2", "]"}], "]"}], "]"}], "^", "2"}]}], ")"}], "/", 
    RowBox[{"Sqrt", "[", 
     RowBox[{"rrnorm", "[", 
      RowBox[{"\"\<31\>\"", ",", "quatvecpair"}], "]"}], "]"}]}]}], 
  ";"}]], "Input",ExpressionUUID->"2be5d18f-eacf-4355-89d5-d3147828f4cb"],

Cell[BoxData[
 RowBox[{
  RowBox[{"qvpcpx2", " ", "=", " ", 
   RowBox[{
    RowBox[{"Sqrt", "[", 
     RowBox[{
      RowBox[{
       RowBox[{"(", 
        RowBox[{
         RowBox[{"abssqr", "[", 
          RowBox[{
           RowBox[{"Rest", "[", 
            RowBox[{"quatvecpair", "[", 
             RowBox[{"[", "1", "]"}], "]"}], "]"}], ",", "3"}], "]"}], "-", 
         RowBox[{"abssqr", "[", 
          RowBox[{
           RowBox[{"Rest", "[", 
            RowBox[{"quatvecpair", "[", 
             RowBox[{"[", "2", "]"}], "]"}], "]"}], ",", "3"}], "]"}]}], 
        ")"}], "^", "2"}], " ", "+", " ", 
      RowBox[{"4", 
       RowBox[{
        RowBox[{"(", 
         RowBox[{
          RowBox[{"Rest", "[", 
           RowBox[{"quatvecpair", "[", 
            RowBox[{"[", "1", "]"}], "]"}], "]"}], ".", 
          RowBox[{"Rest", "[", 
           RowBox[{"quatvecpair", "[", 
            RowBox[{"[", "2", "]"}], "]"}], "]"}]}], ")"}], "^", "2"}]}]}], 
     "]"}], "/", 
    RowBox[{"Sqrt", "[", 
     RowBox[{"rrnorm", "[", 
      RowBox[{"\"\<31\>\"", ",", "quatvecpair"}], "]"}], "]"}]}]}], 
  ";"}]], "Input",ExpressionUUID->"7e352c4a-1c9d-4810-995f-11fbba385d1f"],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{
    RowBox[{"CharacteristicPolynomial", "[", 
     RowBox[{
      RowBox[{"rrmat", "[", 
       RowBox[{"\"\<31rrn\>\"", ",", "quatvecpair"}], "]"}], ",", "x"}], 
     "]"}], " ", "-", " ", 
    RowBox[{
     RowBox[{"(", 
      RowBox[{"1", " ", "-", " ", 
       RowBox[{"2", "*", 
        RowBox[{"(", 
         RowBox[{"qvpcpx1", "+", "qvpcpx2"}], ")"}], "*", "x"}], " ", "+", 
       " ", 
       RowBox[{"x", "^", "2"}]}], ")"}], 
     RowBox[{"(", 
      RowBox[{"1", " ", "-", " ", 
       RowBox[{"2", "*", 
        RowBox[{"(", 
         RowBox[{"qvpcpx1", "-", "qvpcpx2"}], ")"}], "*", "x"}], " ", "+", 
       " ", 
       RowBox[{"x", "^", "2"}]}], ")"}]}]}], " ", "//", " ", "Expand"}], " ", 
  "//", " ", "Factor"}]], "Input",ExpressionUUID->"6349bbfa-e106-42f1-acfc-\
caa530f7ab3f"],

Cell[BoxData[
 RowBox[{
  RowBox[{"qvpcpx3", " ", "=", " ", 
   RowBox[{
    RowBox[{"(", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{
        RowBox[{
         RowBox[{"First", "[", 
          RowBox[{"quatvecpair", "[", 
           RowBox[{"[", "1", "]"}], "]"}], "]"}], "^", "2"}], "+", 
        RowBox[{
         RowBox[{"First", "[", 
          RowBox[{"quatvecpair", "[", 
           RowBox[{"[", "2", "]"}], "]"}], "]"}], "^", "2"}]}], ")"}], "-", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{"abssqr", "[", 
         RowBox[{
          RowBox[{"Rest", "[", 
           RowBox[{"quatvecpair", "[", 
            RowBox[{"[", "1", "]"}], "]"}], "]"}], ",", "3"}], "]"}], "+", 
        RowBox[{"abssqr", "[", 
         RowBox[{
          RowBox[{"Rest", "[", 
           RowBox[{"quatvecpair", "[", 
            RowBox[{"[", "2", "]"}], "]"}], "]"}], ",", "3"}], "]"}]}], 
       ")"}]}], ")"}], "/", 
    RowBox[{"Sqrt", "[", 
     RowBox[{"rrnorm", "[", 
      RowBox[{"\"\<31\>\"", ",", "quatvecpair"}], "]"}], "]"}]}]}], 
  ";"}]], "Input",ExpressionUUID->"3349437b-140a-4489-8063-048c796cebc4"],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"CharacteristicPolynomial", "[", 
    RowBox[{
     RowBox[{"rrmat", "[", 
      RowBox[{"\"\<31rsn\>\"", ",", "quatvecpair"}], "]"}], ",", "x"}], "]"}],
    " ", "+", " ", 
   RowBox[{
    RowBox[{"(", 
     RowBox[{"1", "-", 
      RowBox[{"x", "^", "2"}]}], ")"}], 
    RowBox[{"(", 
     RowBox[{"1", " ", "-", 
      RowBox[{"2", "qvpcpx3", "*", "x"}], " ", "+", " ", 
      RowBox[{"x", "^", "2"}]}], ")"}]}]}], " ", "//", " ", 
  "Factor"}]], "Input",ExpressionUUID->"66b8e624-2279-4540-b9a7-b38e3c30be52"],

Cell[BoxData[
 RowBox[{"(*", " ", 
  RowBox[{"3", "+", 
   RowBox[{"1", "D", " ", "solution", " ", "as", " ", "complex", " ", 
    RowBox[{"numbers", " ", "--"}], " ", "like", " ", "the", " ", "4", "D", 
    " ", "one", " ", "but", " ", "with", " ", 
    RowBox[{"{", 
     RowBox[{
      RowBox[{"q1", "+", 
       RowBox[{"I", "*", "q2"}]}], ",", 
      RowBox[{"q1", "-", 
       RowBox[{"I", "*", "q2"}]}]}], "}"}]}]}], " ", "*)"}]], "Input",Expressi\
onUUID->"7b3586b9-1284-43db-80bf-8f23191d402b"],

Cell[BoxData[
 RowBox[{
  RowBox[{"quatvecpaircplx", " ", "=", " ", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{
      RowBox[{"{", 
       RowBox[{"1", ",", "I"}], "}"}], ",", 
      RowBox[{"{", 
       RowBox[{"1", ",", 
        RowBox[{"-", "I"}]}], "}"}]}], "}"}], ".", "quatvecpair"}]}], 
  ";"}]], "Input",ExpressionUUID->"86481bb3-3993-4145-88e0-279726500c1a"],

Cell[BoxData[
 RowBox[{
  RowBox[{"qvpcpz1", " ", "=", " ", 
   RowBox[{
    RowBox[{"(", 
     RowBox[{"Times", " ", "@@", " ", 
      RowBox[{"(", 
       RowBox[{"First", " ", "/@", " ", "quatvecpaircplx"}], ")"}]}], ")"}], 
    "/", 
    RowBox[{"Sqrt", "[", 
     RowBox[{"rrnorm", "[", 
      RowBox[{"\"\<4\>\"", ",", "quatvecpaircplx"}], "]"}], "]"}]}]}], 
  ";"}]], "Input",ExpressionUUID->"7a15a5fc-9896-440f-bae0-128097531d47"],

Cell[BoxData[
 RowBox[{
  RowBox[{"qvpcpz2", " ", "=", " ", 
   RowBox[{"Sqrt", "[", 
    RowBox[{"Factor", "[", 
     RowBox[{"Times", " ", "@@", " ", 
      RowBox[{"(", 
       RowBox[{"1", "-", 
        RowBox[{
         RowBox[{
          RowBox[{"(", 
           RowBox[{"First", " ", "/@", " ", "quatvecpaircplx"}], ")"}], "^", 
          "2"}], "/", 
         RowBox[{"(", 
          RowBox[{"quatnorm", " ", "/@", " ", "quatvecpaircplx"}], ")"}]}]}], 
       ")"}]}], "]"}], "]"}]}], ";"}]], "Input",ExpressionUUID->"65236c5b-\
b63f-46cd-ba47-e85e6f9281e3"],

Cell[BoxData[
 RowBox[{
  RowBox[{"qvpcpz3", " ", "=", " ", 
   RowBox[{
    RowBox[{"(", 
     RowBox[{
      RowBox[{"2", 
       RowBox[{"(", 
        RowBox[{"Times", " ", "@@", " ", 
         RowBox[{"(", 
          RowBox[{"First", " ", "/@", " ", "quatvecpaircplx"}], ")"}]}], 
        ")"}]}], " ", "-", " ", 
      RowBox[{"(", 
       RowBox[{"Dot", " ", "@@", " ", "quatvecpaircplx"}], ")"}]}], ")"}], 
    "/", 
    RowBox[{"Sqrt", "[", 
     RowBox[{"rrnorm", "[", 
      RowBox[{"\"\<4\>\"", ",", "quatvecpaircplx"}], "]"}], "]"}]}]}], 
  ";"}]], "Input",ExpressionUUID->"e20b74f2-ef42-41b0-bd03-6d8cd1fff6eb"],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"qvpcpx1", "^", "2"}], " ", "-", " ", 
   RowBox[{"qvpcpz1", "^", "2"}]}], " ", "//", " ", "Factor"}]], "Input",Expre\
ssionUUID->"77b5e4bb-1a4c-4602-8951-d57b09ee349c"],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"qvpcpx2", "^", "2"}], " ", "-", " ", 
   RowBox[{"qvpcpz2", "^", "2"}]}], " ", "//", " ", "Factor"}]], "Input",Expre\
ssionUUID->"78482f6e-2f40-4f0a-b8de-4ed65d6c0632"],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"qvpcpx3", "^", "2"}], " ", "-", " ", 
   RowBox[{"qvpcpz3", "^", "2"}]}], " ", "//", " ", "Factor"}]], "Input",Expre\
ssionUUID->"96d7b956-5ad8-4483-bcf1-d34e11692f0b"],

Cell[BoxData[
 RowBox[{
  RowBox[{"quatvecpair", " ", "=", " ", "quatvecpair0"}], ";"}]], "Input",Expr\
essionUUID->"14534cb9-dae8-4202-bb51-0d7d9db49c87"],

Cell[BoxData[
 RowBox[{"(*", " ", 
  RowBox[{"Further", " ", "solutions"}], " ", "*)"}]], "Input",ExpressionUUID-\
>"467378bd-2439-4681-81d3-45525c26b4b3"],

Cell[BoxData[
 RowBox[{
  RowBox[{"quadsol", "[", "m_", "]"}], " ", ":=", " ", 
  RowBox[{
   RowBox[{
    RowBox[{"{", 
     RowBox[{"1", ",", "1"}], "}"}], "*", "m"}], " ", "+", " ", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{"1", ",", 
      RowBox[{"-", "1"}]}], "}"}], "*", 
    RowBox[{"Sqrt", "[", 
     RowBox[{
      RowBox[{"m", "^", "2"}], "-", "1"}], "]"}]}]}]}]], "Input",ExpressionUUI\
D->"0398880d-600b-408c-aedb-0a0632303c85"],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"1", " ", "-", " ", 
    RowBox[{"2", "*", "m", "*", "x"}], " ", "+", " ", 
    RowBox[{"x", "^", "2"}]}], " ", "/.", " ", 
   RowBox[{"Transpose", "[", 
    RowBox[{"{", 
     RowBox[{"Thread", "[", 
      RowBox[{"x", "\[Rule]", 
       RowBox[{"quadsol", "[", "m", "]"}]}], "]"}], "}"}], "]"}]}], " ", "//",
   " ", "Expand"}]], "Input",ExpressionUUID->"a5128c7f-efd9-4519-b6e3-\
1294de5dcf18"],

Cell[BoxData[
 RowBox[{
  RowBox[{"tetsol", "[", 
   RowBox[{"m1_", ",", "m2_"}], "]"}], " ", ":=", " ", 
  RowBox[{
   RowBox[{
    RowBox[{"(", 
     RowBox[{"Times", " ", "@@", " ", "#"}], ")"}], "&"}], " ", "/@", " ", 
   RowBox[{"Tuples", "[", 
    RowBox[{"quadsol", " ", "/@", " ", 
     RowBox[{"{", 
      RowBox[{"m1", ",", "m2"}], "}"}]}], "]"}]}]}]], "Input",ExpressionUUID->\
"a4e7659b-ffe7-4598-8865-f8f5567086b1"],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{
    RowBox[{"(", 
     RowBox[{"1", "-", 
      RowBox[{"2", "*", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{"m1", "*", "m2"}], "+", 
         RowBox[{
          RowBox[{"Sqrt", "[", 
           RowBox[{
            RowBox[{"m1", "^", "2"}], "-", "1"}], "]"}], "*", 
          RowBox[{"Sqrt", "[", 
           RowBox[{
            RowBox[{"m2", "^", "2"}], "-", "1"}], "]"}]}]}], ")"}], "*", 
       "x"}], "+", 
      RowBox[{"x", "^", "2"}]}], ")"}], "*", 
    RowBox[{"(", 
     RowBox[{"1", "-", 
      RowBox[{"2", "*", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{"m1", "*", "m2"}], "-", 
         RowBox[{
          RowBox[{"Sqrt", "[", 
           RowBox[{
            RowBox[{"m1", "^", "2"}], "-", "1"}], "]"}], "*", 
          RowBox[{"Sqrt", "[", 
           RowBox[{
            RowBox[{"m2", "^", "2"}], "-", "1"}], "]"}]}]}], ")"}], "*", 
       "x"}], "+", 
      RowBox[{"x", "^", "2"}]}], ")"}]}], "/.", " ", 
   RowBox[{"Transpose", "[", 
    RowBox[{"{", 
     RowBox[{"Thread", "[", 
      RowBox[{"x", "\[Rule]", 
       RowBox[{"tetsol", "[", 
        RowBox[{"m1", ",", "m2"}], "]"}]}], "]"}], "}"}], "]"}]}], " ", "//", 
  " ", "Expand"}]], "Input",ExpressionUUID->"146f708f-ea35-43de-8c2d-\
8b62f92335f4"],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{
    RowBox[{"(", 
     RowBox[{"1", "-", 
      RowBox[{"2", "*", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{"m1", "*", "m2"}], "+", 
         RowBox[{
          RowBox[{"Sqrt", "[", 
           RowBox[{
            RowBox[{"m1", "^", "2"}], "-", "1"}], "]"}], "*", 
          RowBox[{"Sqrt", "[", 
           RowBox[{
            RowBox[{"m2", "^", "2"}], "-", "1"}], "]"}]}]}], ")"}], "*", 
       "x"}], "+", 
      RowBox[{"x", "^", "2"}]}], ")"}], "*", 
    RowBox[{"(", 
     RowBox[{"1", "-", 
      RowBox[{"2", "*", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{"m1", "*", "m2"}], "-", 
         RowBox[{
          RowBox[{"Sqrt", "[", 
           RowBox[{
            RowBox[{"m1", "^", "2"}], "-", "1"}], "]"}], "*", 
          RowBox[{"Sqrt", "[", 
           RowBox[{
            RowBox[{"m2", "^", "2"}], "-", "1"}], "]"}]}]}], ")"}], "*", 
       "x"}], "+", 
      RowBox[{"x", "^", "2"}]}], ")"}]}], " ", "-", " ", 
   RowBox[{"(", 
    RowBox[{"1", "-", 
     RowBox[{"4", "*", "m1", "*", "m2", "*", "x"}], " ", "-", " ", 
     RowBox[{"2", "*", 
      RowBox[{"(", 
       RowBox[{"1", "-", 
        RowBox[{"2", 
         RowBox[{"m1", "^", "2"}]}], "-", 
        RowBox[{"2", 
         RowBox[{"m2", "^", "2"}]}]}], ")"}], "*", 
      RowBox[{"x", "^", "2"}]}], "-", 
     RowBox[{"4", "*", "m1", "*", "m2", "*", 
      RowBox[{"x", "^", "3"}]}], "+", 
     RowBox[{"x", "^", "4"}]}], ")"}]}], "//", " ", "Factor"}]], "Input",Expre\
ssionUUID->"41218064-4d17-4666-99a7-9610c0905b1f"]
}, Closed]],

Cell[CellGroupData[{

Cell["Eigensystems", "Subsection",ExpressionUUID->"feeabc3c-c487-4da3-84ec-eb4ab132a664"],

Cell[BoxData[
 RowBox[{
  RowBox[{"estest", "[", 
   RowBox[{"origmat_", ",", "egvals_", ",", "egvecs_"}], "]"}], " ", ":=", 
  " ", 
  RowBox[{
   RowBox[{"origmat", ".", 
    RowBox[{"Transpose", "[", "egvecs", "]"}]}], " ", "-", " ", 
   RowBox[{
    RowBox[{"Transpose", "[", "egvecs", "]"}], ".", 
    RowBox[{"DiagonalMatrix", "[", "egvals", "]"}]}]}]}]], "Input",ExpressionU\
UID->"7f02f5eb-34f0-4235-b3af-4712ae567b3c"],

Cell[BoxData[
 RowBox[{"(*", " ", 
  RowBox[{"Quaternions", " ", "-", " ", 
   RowBox[{"Pauli", " ", "matrices"}]}], " ", "*)"}]], "Input",ExpressionUUID-\
>"8c6e8fd5-9018-4015-8d96-de6b1fe23a35"],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"estest", "[", 
    RowBox[{
     RowBox[{"quatpauli", "[", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"Cos", "[", "ax", "]"}], ",", 
        RowBox[{
         RowBox[{"Sin", "[", "ax", "]"}], "*", 
         RowBox[{"Sin", "[", "ap", "]"}], "*", 
         RowBox[{"Cos", "[", "az", "]"}]}], ",", 
        RowBox[{
         RowBox[{"Sin", "[", "ax", "]"}], "*", 
         RowBox[{"Sin", "[", "ap", "]"}], "*", 
         RowBox[{"Sin", "[", "az", "]"}]}], ",", 
        RowBox[{
         RowBox[{"Sin", "[", "ax", "]"}], "*", 
         RowBox[{"Cos", "[", "ap", "]"}]}]}], "}"}], "]"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"Exp", "[", 
        RowBox[{"I", "*", "ax"}], "]"}], ",", 
       RowBox[{"Exp", "[", 
        RowBox[{
         RowBox[{"-", "I"}], "*", "ax"}], "]"}]}], "}"}], ",", 
     RowBox[{
      RowBox[{
       RowBox[{"(", 
        RowBox[{
         RowBox[{"{", 
          RowBox[{
           RowBox[{"Exp", "[", 
            RowBox[{
             RowBox[{"-", "I"}], "*", 
             RowBox[{"az", "/", "2"}]}], "]"}], ",", 
           RowBox[{"Exp", "[", 
            RowBox[{"I", "*", 
             RowBox[{"az", "/", "2"}]}], "]"}]}], "}"}], "*", "#"}], ")"}], 
       "&"}], " ", "/@", " ", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"{", 
         RowBox[{
          RowBox[{"Cos", "[", 
           RowBox[{"ap", "/", "2"}], "]"}], ",", 
          RowBox[{"Sin", "[", 
           RowBox[{"ap", "/", "2"}], "]"}]}], "}"}], ",", 
        RowBox[{"{", 
         RowBox[{
          RowBox[{"-", 
           RowBox[{"Sin", "[", 
            RowBox[{"ap", "/", "2"}], "]"}]}], ",", 
          RowBox[{"Cos", "[", 
           RowBox[{"ap", "/", "2"}], "]"}]}], "}"}]}], "}"}]}]}], "]"}], " ", 
   "//", " ", "TrigToExp"}], " ", "//", " ", "Factor"}]], "Input",ExpressionUU\
ID->"75f83e7c-dc88-4aae-b018-a6b4296dab1b"],

Cell[BoxData[
 RowBox[{"(*", " ", 
  RowBox[{"2", "D"}], " ", "*)"}]], "Input",ExpressionUUID->"05720380-6c45-4b45-a0de-e0f639f091e5"],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"estest", "[", 
    RowBox[{
     RowBox[{"rrmat", "[", 
      RowBox[{"\"\<2r\>\"", ",", "a"}], "]"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"Exp", "[", 
        RowBox[{"I", "*", "a"}], "]"}], ",", 
       RowBox[{"Exp", "[", 
        RowBox[{
         RowBox[{"-", "I"}], "*", "a"}], "]"}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"1", ",", 
         RowBox[{"-", "I"}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"1", ",", "I"}], "}"}]}], "}"}]}], "]"}], " ", "//", " ", 
   "TrigToExp"}], " ", "//", " ", "Factor"}]], "Input",ExpressionUUID->\
"4fbf9e0a-0956-41aa-b365-00b8462e26f3"],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"estest", "[", 
    RowBox[{
     RowBox[{"rrmat", "[", 
      RowBox[{"\"\<2s\>\"", ",", "a"}], "]"}], ",", 
     RowBox[{"{", 
      RowBox[{"1", ",", 
       RowBox[{"-", "1"}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
         RowBox[{"Cos", "[", 
          RowBox[{"a", "/", "2"}], "]"}], ",", 
         RowBox[{"Sin", "[", 
          RowBox[{"a", "/", "2"}], "]"}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", 
          RowBox[{"Sin", "[", 
           RowBox[{"a", "/", "2"}], "]"}]}], ",", 
         RowBox[{"Cos", "[", 
          RowBox[{"a", "/", "2"}], "]"}]}], "}"}]}], "}"}]}], "]"}], " ", "//",
    " ", "TrigToExp"}], " ", "//", " ", "Factor"}]], "Input",ExpressionUUID->\
"528e6e96-fc97-478d-b530-c0fc7689f00c"],

Cell[BoxData[
 RowBox[{"(*", " ", 
  RowBox[{"1", "+", 
   RowBox[{"1", "D"}]}], " ", "*)"}]], "Input",ExpressionUUID->"578c55e9-9334-\
4d85-9725-5f8fe47b6464"],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"estest", "[", 
    RowBox[{
     RowBox[{"rrmat", "[", 
      RowBox[{"\"\<11rr\>\"", ",", "a"}], "]"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"Exp", "[", "a", "]"}], ",", 
       RowBox[{"Exp", "[", 
        RowBox[{"-", "a"}], "]"}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"1", ",", "1"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"1", ",", 
         RowBox[{"-", "1"}]}], "}"}]}], "}"}]}], "]"}], " ", "//", " ", 
   "TrigToExp"}], " ", "//", " ", "Factor"}]], "Input",ExpressionUUID->\
"6e208502-726c-4a4c-9f5a-e356773bde7a"],

Cell[BoxData[
 RowBox[{
  RowBox[{"rrmat", "[", 
   RowBox[{"\"\<11rs\>\"", ",", "a"}], "]"}], " ", "-", " ", 
  RowBox[{"IdentityMatrix", "[", "2", "]"}]}]], "Input",ExpressionUUID->\
"dc08d7c7-c9c0-4e9b-95f8-760b335733bb"],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"estest", "[", 
    RowBox[{
     RowBox[{"rrmat", "[", 
      RowBox[{"\"\<11rs\>\"", ",", "a"}], "]"}], ",", 
     RowBox[{"{", 
      RowBox[{"1", ",", 
       RowBox[{"-", "1"}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
         RowBox[{"Cosh", "[", 
          RowBox[{"a", "/", "2"}], "]"}], ",", 
         RowBox[{"-", 
          RowBox[{"Sinh", "[", 
           RowBox[{"a", "/", "2"}], "]"}]}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", 
          RowBox[{"Sinh", "[", 
           RowBox[{"a", "/", "2"}], "]"}]}], ",", 
         RowBox[{"Cosh", "[", 
          RowBox[{"a", "/", "2"}], "]"}]}], "}"}]}], "}"}]}], "]"}], " ", "//",
    " ", "TrigToExp"}], " ", "//", " ", "Factor"}]], "Input",ExpressionUUID->\
"b5869f89-5365-4fa4-8e3a-191793be8c85"],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"estest", "[", 
    RowBox[{
     RowBox[{"rrmat", "[", 
      RowBox[{"\"\<11sr\>\"", ",", "a"}], "]"}], ",", 
     RowBox[{"{", 
      RowBox[{"1", ",", 
       RowBox[{"-", "1"}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", 
          RowBox[{"Sinh", "[", 
           RowBox[{"a", "/", "2"}], "]"}]}], ",", 
         RowBox[{"Cosh", "[", 
          RowBox[{"a", "/", "2"}], "]"}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"Cosh", "[", 
          RowBox[{"a", "/", "2"}], "]"}], ",", 
         RowBox[{"-", 
          RowBox[{"Sinh", "[", 
           RowBox[{"a", "/", "2"}], "]"}]}]}], "}"}]}], "}"}]}], "]"}], " ", "//",
    " ", "TrigToExp"}], " ", "//", " ", "Factor"}]], "Input",ExpressionUUID->\
"e343d0bc-a757-4387-bf1a-d52a325e6073"],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"estest", "[", 
    RowBox[{
     RowBox[{"rrmat", "[", 
      RowBox[{"\"\<11ss\>\"", ",", "a"}], "]"}], ",", 
     RowBox[{"-", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"Exp", "[", "a", "]"}], ",", 
        RowBox[{"Exp", "[", 
         RowBox[{"-", "a"}], "]"}]}], "}"}]}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"1", ",", "1"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"1", ",", 
         RowBox[{"-", "1"}]}], "}"}]}], "}"}]}], "]"}], " ", "//", " ", 
   "TrigToExp"}], " ", "//", " ", "Factor"}]], "Input",ExpressionUUID->\
"44be8a92-d69e-45a0-9cda-8ffd1fa7bcf3"],

Cell[BoxData[
 RowBox[{"(*", " ", 
  RowBox[{"3", "D", " ", "rotations"}], " ", "*)"}]], "Input",ExpressionUUID->\
"0ecd21ec-627e-4bc5-9608-9c622096940b"],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"estest", "[", 
    RowBox[{
     RowBox[{"rrmat", "[", 
      RowBox[{"\"\<3rv\>\"", ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"Cos", "[", "ax", "]"}], ",", 
         RowBox[{
          RowBox[{"Sin", "[", "ax", "]"}], "*", 
          RowBox[{"Sin", "[", "ap", "]"}], "*", 
          RowBox[{"Cos", "[", "az", "]"}]}], ",", 
         RowBox[{
          RowBox[{"Sin", "[", "ax", "]"}], "*", 
          RowBox[{"Sin", "[", "ap", "]"}], "*", 
          RowBox[{"Sin", "[", "az", "]"}]}], ",", 
         RowBox[{
          RowBox[{"Sin", "[", "ax", "]"}], "*", 
          RowBox[{"Cos", "[", "ap", "]"}]}]}], "}"}]}], "]"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"Exp", "[", 
        RowBox[{"2", "I", "*", "ax"}], "]"}], ",", 
       RowBox[{"Exp", "[", 
        RowBox[{
         RowBox[{"-", "2"}], "I", "*", "ax"}], "]"}], ",", "1"}], "}"}], ",", 
     
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
         RowBox[{
          RowBox[{
           RowBox[{"Cos", "[", "ap", "]"}], "*", 
           RowBox[{"Cos", "[", "az", "]"}]}], "-", 
          RowBox[{"I", "*", 
           RowBox[{"Sin", "[", "az", "]"}]}]}], ",", 
         RowBox[{
          RowBox[{
           RowBox[{"Cos", "[", "ap", "]"}], "*", 
           RowBox[{"Sin", "[", "az", "]"}]}], "+", 
          RowBox[{"I", "*", 
           RowBox[{"Cos", "[", "az", "]"}]}]}], ",", 
         RowBox[{"-", 
          RowBox[{"Sin", "[", "ap", "]"}]}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{
          RowBox[{
           RowBox[{"Cos", "[", "ap", "]"}], "*", 
           RowBox[{"Cos", "[", "az", "]"}]}], "+", 
          RowBox[{"I", "*", 
           RowBox[{"Sin", "[", "az", "]"}]}]}], ",", 
         RowBox[{
          RowBox[{
           RowBox[{"Cos", "[", "ap", "]"}], "*", 
           RowBox[{"Sin", "[", "az", "]"}]}], "-", 
          RowBox[{"I", "*", 
           RowBox[{"Cos", "[", "az", "]"}]}]}], ",", 
         RowBox[{"-", 
          RowBox[{"Sin", "[", "ap", "]"}]}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{
          RowBox[{"Sin", "[", "ap", "]"}], "*", 
          RowBox[{"Cos", "[", "az", "]"}]}], ",", 
         RowBox[{
          RowBox[{"Sin", "[", "ap", "]"}], "*", 
          RowBox[{"Sin", "[", "az", "]"}]}], ",", 
         RowBox[{"Cos", "[", "ap", "]"}]}], "}"}]}], "}"}]}], "]"}], " ", "//",
    " ", "TrigToExp"}], " ", "//", " ", "Factor"}]], "Input",ExpressionUUID->\
"a10f3b98-fa8e-4b2d-97c0-159da0788595"]
}, Closed]]
}, Closed]]
},
WindowSize->{629, 696},
WindowMargins->{{Automatic, 0}, {Automatic, 0}},
ShowSelection->True,
FrontEndVersion->"11.3 for Mac OS X x86 (32-bit, 64-bit Kernel) (March 5, \
2018)",
StyleDefinitions->"Default.nb"
]
(* End of Notebook Content *)

(* Internal cache information *)
(*CellTagsOutline
CellTagsIndex->{}
*)
(*CellTagsIndex
CellTagsIndex->{}
*)
(*NotebookFileOutline
Notebook[{
Cell[CellGroupData[{
Cell[422, 15, 86, 0, 67, "Section",ExpressionUUID->"0b36d350-b0b9-4652-9b48-4b98bffb0746"],
Cell[511, 17, 2931, 85, 1898, "Text",ExpressionUUID->"340aebc8-df4b-41a1-aca1-e1cb7b9732ee"]
}, Open  ]],
Cell[CellGroupData[{
Cell[3479, 107, 79, 0, 67, "Section",ExpressionUUID->"ce06a749-45b9-4dec-9ec9-ab5452adf62e"],
Cell[3561, 109, 291, 8, 32, "Input",ExpressionUUID->"d40a8e20-24a9-483e-a286-2acb6da76ed2"],
Cell[3855, 119, 367, 10, 32, "Input",ExpressionUUID->"0b12b223-0070-435f-b2a2-cabe7a1caae0"],
Cell[4225, 131, 283, 8, 32, "Input",ExpressionUUID->"0624d7f7-479b-4c78-8467-6af8ccb128a5"],
Cell[4511, 141, 631, 19, 54, "Input",ExpressionUUID->"d4c076d3-0133-49fa-9164-daff26c08db6"],
Cell[5145, 162, 284, 8, 32, "Input",ExpressionUUID->"0e16d25b-df90-4b28-b379-5fcf01fd7168"],
Cell[5432, 172, 257, 7, 32, "Input",ExpressionUUID->"7bdf2796-adb8-49e2-aaee-e9d26c838b33"],
Cell[5692, 181, 333, 9, 32, "Input",ExpressionUUID->"bc42c5ed-6b2b-4e18-b5d5-7073dd4f0149"],
Cell[6028, 192, 557, 16, 54, "Input",ExpressionUUID->"b68e47aa-a96b-4ee2-a832-258b7f582f16"],
Cell[6588, 210, 148, 3, 32, "Input",ExpressionUUID->"a992c9b5-d1a6-4397-bd7c-6f2790d03949"],
Cell[6739, 215, 492, 13, 75, "Input",ExpressionUUID->"75971ee8-7259-468e-9bcb-da2859ebf0e1"],
Cell[7234, 230, 209, 5, 32, "Input",ExpressionUUID->"26de9118-9fb6-4968-8910-f5ea10a59365"],
Cell[7446, 237, 209, 5, 32, "Input",ExpressionUUID->"bde18fed-a93b-4c9e-9ea5-842edf762bd8"],
Cell[7658, 244, 127, 1, 32, "Input",ExpressionUUID->"83da2f33-f6df-4a5a-be17-10cccdafacb7"],
Cell[7788, 247, 1370, 36, 159, "Input",ExpressionUUID->"d4805336-e9a1-467c-a9bc-01c2cc5efae7"],
Cell[9161, 285, 1711, 46, 201, "Input",ExpressionUUID->"dfdd2641-995b-4b6c-8431-a77d17e5620e"]
}, Closed]],
Cell[CellGroupData[{
Cell[10909, 336, 85, 0, 53, "Section",ExpressionUUID->"ac69234d-9679-409c-abb4-08c4b8d8952a"],
Cell[CellGroupData[{
Cell[11019, 340, 85, 0, 44, "Subsection",ExpressionUUID->"b76d344e-b33c-4df6-9256-5a92e5faa01e"],
Cell[11107, 342, 389, 9, 54, "Input",ExpressionUUID->"0b1679ba-69d4-4922-b8c4-a68d128c4d83"],
Cell[11499, 353, 1493, 40, 138, "Input",ExpressionUUID->"a9f36f73-bed6-4848-ae76-a9e59a70b19c"],
Cell[12995, 395, 214, 5, 32, "Input",ExpressionUUID->"cfe8b4d5-4056-46ee-bfa1-2181f7dd066f"],
Cell[13212, 402, 410, 12, 32, "Input",ExpressionUUID->"b60d99da-e6e6-44f2-ad1d-5c99bdf8b73a"],
Cell[13625, 416, 205, 5, 32, "Input",ExpressionUUID->"93860a73-7420-4fbc-9ffa-d46b66e9c9e4"],
Cell[13833, 423, 256, 6, 32, "Input",ExpressionUUID->"cc4791a6-2a5a-4352-a66e-29a650aa9c00"],
Cell[14092, 431, 326, 9, 32, "Input",ExpressionUUID->"546aa2af-b97d-4da2-9a3b-b30d77db11f8"],
Cell[14421, 442, 1056, 30, 96, "Input",ExpressionUUID->"2c186919-3f99-4367-a0ec-2a0b65a829a7"],
Cell[15480, 474, 600, 18, 54, "Input",ExpressionUUID->"217247d1-0bc8-4451-bcda-94796bdf1ac3"],
Cell[16083, 494, 127, 1, 32, "Input",ExpressionUUID->"b4f8937b-6ec5-460e-9bdf-a74abc7c2211"],
Cell[16213, 497, 3854, 100, 432, "Input",ExpressionUUID->"7467229d-9501-4971-a546-4d7ebdf6c6cf"],
Cell[20070, 599, 118, 1, 32, "Input",ExpressionUUID->"036323aa-4c26-40a5-b230-9e07c4880d26"]
}, Closed]],
Cell[CellGroupData[{
Cell[20225, 605, 92, 0, 36, "Subsection",ExpressionUUID->"d12c71d3-0338-4586-a799-360cb6a3d62b"],
Cell[20320, 607, 454, 9, 54, "Input",ExpressionUUID->"0b5f0abc-ea6c-4553-96c8-aa6c3f2e3f62"],
Cell[20777, 618, 1678, 46, 159, "Input",ExpressionUUID->"7b7b68dc-8e73-40b0-bc8d-fd2cedcfabf4"],
Cell[22458, 666, 815, 23, 96, "Input",ExpressionUUID->"fb72502f-63d3-4bb5-87ff-2c4e98f1e626"],
Cell[23276, 691, 310, 8, 32, "Input",ExpressionUUID->"0b5fb012-4108-4ec7-9efc-bd4eec2df0a3"],
Cell[23589, 701, 127, 1, 32, "Input",ExpressionUUID->"d0dcd466-012d-4a53-9876-3f759c40665a"],
Cell[23719, 704, 3852, 95, 474, "Input",ExpressionUUID->"7791be20-54cc-4505-b351-fb77dfe27c1d"],
Cell[27574, 801, 411, 12, 32, "Input",ExpressionUUID->"008f6c2f-006d-477d-8880-a32203b5be9f"],
Cell[27988, 815, 297, 8, 32, "Input",ExpressionUUID->"07406eec-7ee7-4657-95f3-36addd185266"],
Cell[28288, 825, 1052, 29, 96, "Input",ExpressionUUID->"9a4e0f0b-eafd-4904-9879-487c875bc4b7"],
Cell[29343, 856, 623, 18, 75, "Input",ExpressionUUID->"d4a6e11c-2434-4493-acac-4da8b1a065ed"],
Cell[29969, 876, 127, 1, 32, "Input",ExpressionUUID->"8b345d42-2d0d-4e60-adbe-d58d2e2a8b61"],
Cell[30099, 879, 1876, 50, 201, "Input",ExpressionUUID->"b1b66a05-ab16-45bc-82de-5e63b8d6bc38"],
Cell[31978, 931, 1876, 50, 201, "Input",ExpressionUUID->"8149fddb-62cb-404c-aeed-ab445bd3e065"],
Cell[33857, 983, 143, 3, 32, "Input",ExpressionUUID->"525cad80-1a54-425b-8e79-bbf0ecd8a328"]
}, Closed]],
Cell[CellGroupData[{
Cell[34037, 991, 91, 0, 36, "Subsection",ExpressionUUID->"4e527a71-ad45-4898-9c0b-fc11a31ab738"],
Cell[34131, 993, 242, 5, 32, "Input",ExpressionUUID->"52193444-47e8-4ab6-8a88-3bec4e80c4d9"],
Cell[34376, 1000, 2009, 54, 201, "Input",ExpressionUUID->"4580a087-3dcc-42f8-bf78-0a785ec6f213"],
Cell[36388, 1056, 1053, 29, 117, "Input",ExpressionUUID->"0bf1c7d7-417f-4e41-be94-46c604d0469c"],
Cell[37444, 1087, 346, 8, 54, "Input",ExpressionUUID->"aa9e80dc-90af-4465-8c96-f10db16766e2"],
Cell[37793, 1097, 127, 1, 32, "Input",ExpressionUUID->"d4c2a215-4811-4c3c-aa2c-f6a5145fc4ce"],
Cell[37923, 1100, 4405, 109, 558, "Input",ExpressionUUID->"dc71cc44-a35b-4e7a-8f12-1739e8e5c5c8"]
}, Closed]]
}, Closed]],
Cell[CellGroupData[{
Cell[42377, 1215, 76, 0, 53, "Section",ExpressionUUID->"eea65186-dca8-4b00-b6dc-a006c2ed764b"],
Cell[42456, 1217, 161, 3, 32, "Input",ExpressionUUID->"412925b5-892c-4ff1-8449-9a9a176f1b0e"],
Cell[42620, 1222, 387, 11, 32, "Input",ExpressionUUID->"4e726229-b7a6-4b02-8bfb-8ff098714c79"]
}, Closed]],
Cell[CellGroupData[{
Cell[43044, 1238, 76, 0, 53, "Section",ExpressionUUID->"cd97f825-46cd-4cc9-b349-0f2ef9ab66d1"],
Cell[CellGroupData[{
Cell[43145, 1242, 89, 0, 44, "Subsection",ExpressionUUID->"b61fed81-3593-4ba6-a0de-aef03539bac8"],
Cell[43237, 1244, 165, 3, 32, "Input",ExpressionUUID->"56ed7e7c-edae-435b-9bc2-4765233469e3"],
Cell[43405, 1249, 491, 15, 32, "Input",ExpressionUUID->"296ac48f-7ce0-4a5d-990e-c3120401407a"],
Cell[43899, 1266, 491, 15, 32, "Input",ExpressionUUID->"928dee44-b2dc-44a7-8cc3-dd980177a1b4"],
Cell[44393, 1283, 174, 4, 32, "Input",ExpressionUUID->"a0c23613-1f2b-4aa2-ba36-9168e27a25a3"],
Cell[44570, 1289, 632, 20, 32, "Input",ExpressionUUID->"1956f33e-c20a-483a-9d1c-31c91919a015"],
Cell[45205, 1311, 632, 20, 32, "Input",ExpressionUUID->"cd7cd00b-81cc-4c8f-9795-fa961f62d91f"],
Cell[45840, 1333, 240, 6, 32, "Input",ExpressionUUID->"78d79170-affb-4faa-aaf0-e946018e49d4"],
Cell[46083, 1341, 376, 10, 32, "Input",ExpressionUUID->"8754761b-4de7-4717-b17a-60c81e32a8b8"],
Cell[46462, 1353, 376, 10, 32, "Input",ExpressionUUID->"e4a1b35b-2b9f-466f-ab51-bec21b718dc5"],
Cell[46841, 1365, 219, 5, 32, "Input",ExpressionUUID->"5657f54c-159c-424b-98ee-c89900095e8f"],
Cell[47063, 1372, 127, 1, 32, "Input",ExpressionUUID->"19371a42-e9cd-4abe-9d4d-7b3d4a3919ac"],
Cell[47193, 1375, 850, 24, 75, "Input",ExpressionUUID->"b3f6c182-0e53-420c-95b7-7c3b8584ec08"],
Cell[48046, 1401, 547, 16, 54, "Input",ExpressionUUID->"e56b59ee-8bc2-4d76-9851-2f962a3c9e45"],
Cell[48596, 1419, 609, 17, 54, "Input",ExpressionUUID->"1b070750-67ce-4cda-a350-dc8866307e2d"],
Cell[49208, 1438, 1061, 31, 96, "Input",ExpressionUUID->"ab1237b6-d1d9-4951-9eb3-76ecf9b89a07"],
Cell[50272, 1471, 1870, 59, 117, "Input",ExpressionUUID->"c98a5b10-eb83-43cc-8b19-1e03abca6361"],
Cell[52145, 1532, 952, 27, 96, "Input",ExpressionUUID->"53786ebb-0a9e-4ec7-a411-70eed51740ac"]
}, Closed]],
Cell[CellGroupData[{
Cell[53134, 1564, 91, 0, 36, "Subsection",ExpressionUUID->"fbabf29c-050e-4ad9-a050-0ac535b59515"],
Cell[53228, 1566, 185, 3, 32, "Input",ExpressionUUID->"ff6ea8ac-f643-4b42-8ccf-9b36f44d3e88"],
Cell[53416, 1571, 474, 14, 32, "Input",ExpressionUUID->"757621b0-732c-4f0c-85fc-9dd581cd1f92"],
Cell[53893, 1587, 520, 16, 32, "Input",ExpressionUUID->"fc515b88-cb1e-46e8-93a3-c8b81a1926b8"],
Cell[54416, 1605, 520, 16, 32, "Input",ExpressionUUID->"fdd0a35c-be8e-48c9-9f41-809658564a71"],
Cell[54939, 1623, 566, 18, 32, "Input",ExpressionUUID->"566c1965-0b71-4304-8ec7-1e7b7749c699"],
Cell[55508, 1643, 147, 3, 32, "Input",ExpressionUUID->"1c78ed17-0c1b-4984-b391-5ff22d63b05d"],
Cell[55658, 1648, 608, 19, 32, "Input",ExpressionUUID->"adb92e55-99ac-41c5-9a9a-da30bc73608f"],
Cell[56269, 1669, 658, 21, 32, "Input",ExpressionUUID->"f919a115-e7e8-472c-af8b-8d61f795b482"],
Cell[56930, 1692, 317, 9, 32, "Input",ExpressionUUID->"03ed2364-654b-4d22-a83f-853b084a8f42"],
Cell[57250, 1703, 379, 10, 32, "Input",ExpressionUUID->"b9d77b97-10e9-45cf-9585-8199627149d5"],
Cell[57632, 1715, 379, 10, 32, "Input",ExpressionUUID->"18a01007-efe4-48a2-85dc-70f6fc43d5a7"],
Cell[58014, 1727, 292, 8, 32, "Input",ExpressionUUID->"f3dec7c7-1de5-4c6b-86b6-899b64721af0"],
Cell[58309, 1737, 127, 1, 32, "Input",ExpressionUUID->"f25ca4f8-eb43-49c7-90fe-171857966878"],
Cell[58439, 1740, 1582, 44, 117, "Input",ExpressionUUID->"805549f8-9c2e-409d-b865-50d5ff520f6b"],
Cell[60024, 1786, 2916, 81, 180, "Input",ExpressionUUID->"05a8b081-6d84-4aeb-a604-1f19da1217ae"]
}, Closed]]
}, Closed]],
Cell[CellGroupData[{
Cell[62989, 1873, 76, 0, 53, "Section",ExpressionUUID->"18fa306d-6ea5-45c2-8747-886bf9b50d3e"],
Cell[CellGroupData[{
Cell[63090, 1877, 90, 0, 44, "Subsection",ExpressionUUID->"0f342b70-c894-4a25-8ad3-fd3a7ae3db16"],
Cell[63183, 1879, 213, 5, 32, "Input",ExpressionUUID->"ab68d7d3-9ecd-4d99-84f8-cfde77db47e8"],
Cell[63399, 1886, 1098, 31, 96, "Input",ExpressionUUID->"dfa76282-0145-4418-ade6-eb5088fcd83e"],
Cell[64500, 1919, 275, 7, 32, "Input",ExpressionUUID->"030798f1-ff54-42b0-a827-397adf39c11c"],
Cell[64778, 1928, 218, 5, 32, "Input",ExpressionUUID->"89eceb2a-2efd-4cdc-a99b-6a7cd3aadbd6"],
Cell[64999, 1935, 342, 9, 32, "Input",ExpressionUUID->"261b28c7-8e94-4424-b15f-4951bba2d8de"],
Cell[65344, 1946, 342, 9, 32, "Input",ExpressionUUID->"02f2a414-de8b-4ea4-bd2d-23f9f8d643e6"],
Cell[65689, 1957, 218, 5, 32, "Input",ExpressionUUID->"6c5783f4-c460-4e08-87a6-64326e83bf56"],
Cell[65910, 1964, 127, 1, 32, "Input",ExpressionUUID->"5db3e26b-9b98-48da-931a-a4119cce5659"],
Cell[66040, 1967, 609, 17, 54, "Input",ExpressionUUID->"17902363-650a-483e-9349-114506379a85"],
Cell[66652, 1986, 422, 11, 54, "Input",ExpressionUUID->"b74e88c3-dda3-47aa-96ea-ffd6552ed508"],
Cell[67077, 1999, 939, 27, 96, "Input",ExpressionUUID->"67e3bb78-f18c-4b00-bedd-11845dff6ae3"]
}, Closed]],
Cell[CellGroupData[{
Cell[68053, 2031, 92, 0, 36, "Subsection",ExpressionUUID->"340b63ea-ccae-45cb-a242-19c4909ff717"],
Cell[68148, 2033, 245, 7, 32, "Input",ExpressionUUID->"5ad0cd05-0862-427a-a72d-e912e26dea4a"],
Cell[68396, 2042, 1308, 37, 138, "Input",ExpressionUUID->"1f929c31-48c7-48d2-8390-9b21230b1f59"],
Cell[69707, 2081, 402, 11, 32, "Input",ExpressionUUID->"71c6a46a-a5b8-42bb-a5b9-62efe173a5c0"],
Cell[70112, 2094, 402, 11, 32, "Input",ExpressionUUID->"9a7b849b-2148-4f01-96b6-c0c241c22b52"],
Cell[70517, 2107, 424, 12, 32, "Input",ExpressionUUID->"12a4c7e4-901a-473a-a881-566fd4e0c01b"],
Cell[70944, 2121, 253, 6, 32, "Input",ExpressionUUID->"b2c5b941-26a0-406e-bb07-d017cc5599c7"],
Cell[71200, 2129, 347, 9, 32, "Input",ExpressionUUID->"00ae7e13-0b2b-43d4-8daf-940124e63b8f"],
Cell[71550, 2140, 347, 9, 32, "Input",ExpressionUUID->"8627bff3-8c55-4257-a9ff-d2299cc5996b"],
Cell[71900, 2151, 347, 9, 32, "Input",ExpressionUUID->"4303771b-6f28-46bd-9cfc-f675198e0fcd"],
Cell[72250, 2162, 347, 9, 32, "Input",ExpressionUUID->"6137371e-b606-4085-8eff-59e79ee8924e"],
Cell[72600, 2173, 254, 6, 32, "Input",ExpressionUUID->"62f8354e-dc3f-4627-a7a1-7007168348d2"],
Cell[72857, 2181, 127, 1, 32, "Input",ExpressionUUID->"e8379159-5e01-4ef0-ae7a-31ca045f3924"],
Cell[72987, 2184, 807, 22, 75, "Input",ExpressionUUID->"196dbb26-3e91-41a9-806b-395a18fe6606"],
Cell[73797, 2208, 239, 5, 32, "Input",ExpressionUUID->"627c99de-2125-408a-b174-26969780d86a"],
Cell[74039, 2215, 388, 10, 32, "Input",ExpressionUUID->"0f82b827-49ef-4215-9dc7-6b4f71ef1b47"],
Cell[74430, 2227, 387, 10, 32, "Input",ExpressionUUID->"c63dbe9c-3b8a-4cbd-b64a-480e4b1ff688"],
Cell[74820, 2239, 387, 10, 32, "Input",ExpressionUUID->"fd4f2964-24ef-47e7-b933-9aedda122f4e"],
Cell[75210, 2251, 2236, 57, 222, "Input",ExpressionUUID->"fceb4c27-81a3-43ff-9353-628459cae856"]
}, Closed]]
}, Closed]],
Cell[CellGroupData[{
Cell[77495, 2314, 76, 0, 53, "Section",ExpressionUUID->"b39ad13b-68b9-433c-8356-0e8b85c955f3"],
Cell[CellGroupData[{
Cell[77596, 2318, 91, 0, 44, "Subsection",ExpressionUUID->"d8c52f81-b96b-41ea-8680-909c8e771199"],
Cell[77690, 2320, 333, 7, 54, "Input",ExpressionUUID->"56212ca7-7745-4651-883f-76f09ad8eb3f"],
Cell[78026, 2329, 1365, 38, 159, "Input",ExpressionUUID->"6d3d82b2-63f4-420e-9f16-b88e51d105ab"],
Cell[79394, 2369, 2786, 72, 264, "Input",ExpressionUUID->"db9afb74-3f99-4133-afa2-b7e3dc47fd36"],
Cell[82183, 2443, 414, 11, 54, "Input",ExpressionUUID->"2499b577-83fd-4bb5-bc33-cf76e53d2c20"],
Cell[82600, 2456, 294, 7, 32, "Input",ExpressionUUID->"c4036183-1e22-4167-8173-a68d29bfe35c"],
Cell[82897, 2465, 385, 10, 54, "Input",ExpressionUUID->"23a4e973-d45d-4264-a3e1-c41009a82d24"],
Cell[83285, 2477, 385, 10, 54, "Input",ExpressionUUID->"b57c9703-190e-4419-9e3b-71f9e72218b4"],
Cell[83673, 2489, 218, 5, 32, "Input",ExpressionUUID->"61c9d7da-4711-456e-8056-b2011d05aeab"],
Cell[83894, 2496, 127, 1, 32, "Input",ExpressionUUID->"58a364e3-84ca-4695-90c7-5df63df98c6b"],
Cell[84024, 2499, 558, 16, 54, "Input",ExpressionUUID->"ffd41782-0dd5-4868-8dbf-ef788be9f535"],
Cell[84585, 2517, 691, 20, 75, "Input",ExpressionUUID->"9b6a4b7b-e0b2-4c57-bd3d-7e1f0eb89d77"],
Cell[85279, 2539, 670, 19, 54, "Input",ExpressionUUID->"ea08d2bd-a700-4189-9dd2-20487b24e448"],
Cell[85952, 2560, 1161, 35, 75, "Input",ExpressionUUID->"ae126da9-18bf-43ea-a6f6-1322901567cb"],
Cell[87116, 2597, 952, 27, 96, "Input",ExpressionUUID->"3be07755-1307-4690-afb8-5649b4a1463b"]
}, Closed]],
Cell[CellGroupData[{
Cell[88105, 2629, 94, 0, 36, "Subsection",ExpressionUUID->"c7d72349-6851-46de-afc9-d771bd189d8b"],
Cell[88202, 2631, 685, 15, 96, "Input",ExpressionUUID->"807d58f5-7efa-4b26-ac05-e0a11a91ee9f"],
Cell[88890, 2648, 1361, 37, 159, "Input",ExpressionUUID->"e674ae9b-74e3-4a1d-b5f5-319dc4aad53c"],
Cell[90254, 2687, 1094, 32, 117, "Input",ExpressionUUID->"9b8a0445-b63c-4033-86d5-683f2e21b409"],
Cell[91351, 2721, 715, 22, 75, "Input",ExpressionUUID->"2610fc31-0571-4ce3-a45f-fdce578ee01f"],
Cell[92069, 2745, 3258, 86, 306, "Input",ExpressionUUID->"825d16a6-0061-4c4c-a049-86799a07b8f3"],
Cell[95330, 2833, 412, 11, 32, "Input",ExpressionUUID->"956a01d8-9124-4650-a847-0374e08615df"],
Cell[95745, 2846, 456, 13, 54, "Input",ExpressionUUID->"3ceda1d0-e130-4e20-b014-7cb751864994"],
Cell[96204, 2861, 478, 14, 54, "Input",ExpressionUUID->"b2ba165a-448c-4c1a-b0ac-58af63977b22"],
Cell[96685, 2877, 232, 5, 32, "Input",ExpressionUUID->"3ff088ed-fec9-4530-857a-805bddc108aa"],
Cell[96920, 2884, 381, 10, 32, "Input",ExpressionUUID->"dde3a5ad-b4d7-4c85-8a62-ea14822c7652"],
Cell[97304, 2896, 381, 10, 32, "Input",ExpressionUUID->"745810f1-4e7d-4e75-9e78-2b2e3da5d0ed"],
Cell[97688, 2908, 381, 10, 32, "Input",ExpressionUUID->"7885f5f3-e789-466e-a2c9-d1fa7924cf2b"],
Cell[98072, 2920, 381, 10, 32, "Input",ExpressionUUID->"d1ebf2b7-57d3-4c16-80d3-affd7e9dfaea"],
Cell[98456, 2932, 312, 8, 32, "Input",ExpressionUUID->"3870284b-0819-498e-91ca-11f5af5fdc31"],
Cell[98771, 2942, 127, 1, 32, "Input",ExpressionUUID->"2217b6e2-4b51-4329-bd9f-c487fee5d5b7"],
Cell[98901, 2945, 560, 16, 54, "Input",ExpressionUUID->"28e0e85f-ce88-468a-b997-f3893ac7c647"],
Cell[99464, 2963, 825, 24, 96, "Input",ExpressionUUID->"605f79f2-f500-4a72-9e99-94ad924b19d7"],
Cell[100292, 2989, 868, 24, 75, "Input",ExpressionUUID->"0ef5d3eb-8dc9-4553-b191-b316981b6f17"],
Cell[101163, 3015, 214, 5, 32, "Input",ExpressionUUID->"cdc9670f-60fb-42fa-b2e4-f1549112a91c"],
Cell[101380, 3022, 319, 9, 32, "Input",ExpressionUUID->"72a6a0b5-ad71-4d02-a455-bd95d65518c4"],
Cell[101702, 3033, 146, 3, 32, "Input",ExpressionUUID->"a73ce790-7789-4b86-b4a3-6beac8b85f7d"],
Cell[101851, 3038, 146, 3, 32, "Input",ExpressionUUID->"71fcb0c7-f5ac-47fb-91d7-2663f4a44934"],
Cell[102000, 3043, 2254, 57, 243, "Input",ExpressionUUID->"6f3bf535-2f5f-41a4-9515-76036e1674e7"],
Cell[104257, 3102, 214, 5, 32, "Input",ExpressionUUID->"b9cc857d-e383-4b54-a7a4-7842031aad30"],
Cell[104474, 3109, 2710, 76, 264, "Input",ExpressionUUID->"5c5517cb-5334-4271-a945-243dff32aece"],
Cell[107187, 3187, 231, 6, 32, "Input",ExpressionUUID->"a66ecf16-264c-4b63-9685-00b973ff2c22"],
Cell[107421, 3195, 197, 4, 32, "Input",ExpressionUUID->"a634fc38-d90d-41c1-8f30-02fc07af7403"],
Cell[107621, 3201, 501, 11, 54, "Input",ExpressionUUID->"5cb12620-defc-4a4c-bb5a-1db64c848073"],
Cell[108125, 3214, 759, 21, 54, "Input",ExpressionUUID->"f6bed398-e92c-41db-9eb1-1b9b56c4f69f"],
Cell[108887, 3237, 736, 20, 54, "Input",ExpressionUUID->"47405e61-7b0e-45bf-8313-f8e0cbfb8cab"],
Cell[109626, 3259, 1885, 55, 159, "Input",ExpressionUUID->"357b2c67-571a-4366-beac-ef66b4b91806"],
Cell[111514, 3316, 389, 10, 32, "Input",ExpressionUUID->"d640c4b9-3590-4f28-8209-dc7803a003e7"],
Cell[111906, 3328, 315, 8, 32, "Input",ExpressionUUID->"fe0ee5e5-e99c-4840-bdd0-197d8bd83c4a"]
}, Closed]],
Cell[CellGroupData[{
Cell[112258, 3341, 93, 0, 36, "Subsection",ExpressionUUID->"aa5e6424-4905-4d25-80a0-a72114dc0697"],
Cell[112354, 3343, 245, 7, 32, "Input",ExpressionUUID->"b1c86a59-6e4e-432d-afb4-06259d261ca8"],
Cell[112602, 3352, 1425, 39, 180, "Input",ExpressionUUID->"354c442d-763e-47cd-9496-1d5192be8ac0"],
Cell[114030, 3393, 3351, 90, 285, "Input",ExpressionUUID->"e9cf02e0-c6cd-4c1c-b20a-0333f467ffb7"],
Cell[117384, 3485, 412, 11, 32, "Input",ExpressionUUID->"6783eb6c-43da-40a9-ad9f-a308e081772b"],
Cell[117799, 3498, 412, 11, 32, "Input",ExpressionUUID->"614e4e49-147c-4ec3-b217-b16ec13bd03e"],
Cell[118214, 3511, 434, 12, 54, "Input",ExpressionUUID->"3f91974e-efbb-4273-9898-ca14ec803c52"],
Cell[118651, 3525, 392, 11, 54, "Input",ExpressionUUID->"a8e5cb74-14ae-4154-bfa8-588026c29724"],
Cell[119046, 3538, 381, 10, 32, "Input",ExpressionUUID->"fe3b519c-b158-43ad-a67b-5a385bb9d511"],
Cell[119430, 3550, 381, 10, 32, "Input",ExpressionUUID->"78ee862e-7b9b-472b-9fd4-21097321da82"],
Cell[119814, 3562, 381, 10, 32, "Input",ExpressionUUID->"0fa0b3ca-698e-41bf-9710-72b6dfb15e36"],
Cell[120198, 3574, 381, 10, 32, "Input",ExpressionUUID->"e4d72fa6-39ab-4c3c-82b8-04fda70a798e"],
Cell[120582, 3586, 334, 9, 32, "Input",ExpressionUUID->"35ff49cc-03e9-4318-ab40-e840458493d2"],
Cell[120919, 3597, 127, 1, 32, "Input",ExpressionUUID->"2c888828-34c7-4b23-9826-56635153b82d"],
Cell[121049, 3600, 560, 16, 54, "Input",ExpressionUUID->"b010b95b-0f7e-4243-bf9d-04ab781f6312"],
Cell[121612, 3618, 695, 20, 75, "Input",ExpressionUUID->"0df99362-fc54-4712-bd49-7e4b16417cec"],
Cell[122310, 3640, 868, 24, 75, "Input",ExpressionUUID->"5e1044aa-addd-4ab9-a955-a40c074ff89c"],
Cell[123181, 3666, 647, 17, 54, "Input",ExpressionUUID->"ad9d4807-659e-4ebf-9925-a82b4f2dc807"],
Cell[123831, 3685, 510, 14, 75, "Input",ExpressionUUID->"db9ebd0a-888a-49fa-a1c2-be8da7eacb4c"],
Cell[124344, 3701, 672, 19, 75, "Input",ExpressionUUID->"7d95b1aa-d62e-42d5-bb4a-ec22eee122fe"],
Cell[125019, 3722, 641, 18, 75, "Input",ExpressionUUID->"a0586318-b6ef-4e1d-a598-7fbaba6195fb"],
Cell[125663, 3742, 2254, 57, 243, "Input",ExpressionUUID->"2f19d703-2a36-45ef-9999-015c0686d64e"]
}, Closed]]
}, Closed]],
Cell[CellGroupData[{
Cell[127966, 3805, 101, 0, 53, "Section",ExpressionUUID->"c549e920-35d2-48b2-8eb2-620f8914212b"],
Cell[128070, 3807, 278, 5, 32, "Input",ExpressionUUID->"05aca496-3efb-4424-9ac4-73d074f47b54"],
Cell[128351, 3814, 444, 13, 32, "Input",ExpressionUUID->"dbb94a8c-c9f8-450c-8192-0619653e7cb3"],
Cell[128798, 3829, 386, 9, 54, "Input",ExpressionUUID->"40486093-53dc-489a-853d-1255ffc914af"],
Cell[129187, 3840, 1305, 36, 138, "Input",ExpressionUUID->"b851c4bb-d0e8-439b-b130-e80332df74bf"],
Cell[130495, 3878, 1306, 36, 138, "Input",ExpressionUUID->"45bad37c-9e8d-4690-b5cb-a3b743f25051"],
Cell[131804, 3916, 127, 1, 32, "Input",ExpressionUUID->"27fb6f47-7beb-49b6-9014-c72fe258558a"],
Cell[131934, 3919, 2548, 71, 264, "Input",ExpressionUUID->"dc11a7f2-8ad3-4ea3-b97e-b4310c253e7d"],
Cell[134485, 3992, 234, 6, 32, "Input",ExpressionUUID->"3c491c61-48c5-4c23-b7c7-6ef5f4b74d83"]
}, Closed]],
Cell[CellGroupData[{
Cell[134756, 4003, 101, 0, 53, "Section",ExpressionUUID->"74b6b812-0bb8-4504-99a7-0335172c8327"],
Cell[CellGroupData[{
Cell[134882, 4007, 103, 0, 44, "Subsection",ExpressionUUID->"69d22f95-b13f-47ab-a71a-558b5ef39424"],
Cell[134988, 4009, 583, 15, 75, "Input",ExpressionUUID->"1e226e12-72cd-4442-8e9e-e7baaf447ac5"],
Cell[135574, 4026, 184, 3, 32, "Input",ExpressionUUID->"effdfc4e-a792-43d0-af13-c0d8eeaa3f70"],
Cell[135761, 4031, 679, 19, 96, "Input",ExpressionUUID->"7276c7d5-b584-4929-9390-9045b10dbfd0"],
Cell[136443, 4052, 134, 2, 32, "Input",ExpressionUUID->"b5f31a8c-9b1b-4bf8-86a5-a55cd6066c60"],
Cell[136580, 4056, 645, 18, 75, "Input",ExpressionUUID->"e7bd44ef-3b76-40c4-8ac2-fd4baa6423ae"],
Cell[137228, 4076, 389, 11, 54, "Input",ExpressionUUID->"f36dd44c-f15b-43f0-b392-fe15dd894a82"],
Cell[137620, 4089, 160, 4, 32, "Input",ExpressionUUID->"edb276ea-e3d1-40a7-b835-8845b285a519"],
Cell[137783, 4095, 647, 18, 75, "Input",ExpressionUUID->"a1d6f190-2bbf-42b1-99be-3c93ac047cf2"],
Cell[138433, 4115, 390, 11, 54, "Input",ExpressionUUID->"f4453222-f821-4207-a84c-cfc0edbc87e2"],
Cell[138826, 4128, 134, 2, 32, "Input",ExpressionUUID->"e54610fb-f842-4c19-9826-75b11a23a353"],
Cell[138963, 4132, 806, 24, 75, "Input",ExpressionUUID->"630145b8-9897-480e-8f0d-d40174caf735"],
Cell[139772, 4158, 806, 24, 75, "Input",ExpressionUUID->"5dabf6e5-2fe3-4a3c-8e2c-cd34ee7ae923"],
Cell[140581, 4184, 160, 4, 32, "Input",ExpressionUUID->"007e46a0-8b9c-4361-acc3-7e5354d96bfd"],
Cell[140744, 4190, 809, 24, 75, "Input",ExpressionUUID->"59ceb4c0-2e7c-4031-8020-f14f98b73e22"],
Cell[141556, 4216, 887, 26, 117, "Input",ExpressionUUID->"52105514-eac5-4d1b-a44b-a5ae2a542c95"],
Cell[142446, 4244, 946, 28, 117, "Input",ExpressionUUID->"bebba37c-366c-4611-9fb9-8e7a1f457963"],
Cell[143395, 4274, 899, 27, 75, "Input",ExpressionUUID->"c5dcdfa2-f376-42c5-8fdb-8d19069a80e2"],
Cell[144297, 4303, 134, 2, 32, "Input",ExpressionUUID->"3d351207-e15d-460e-8897-0f344041a09a"],
Cell[144434, 4307, 429, 12, 54, "Input",ExpressionUUID->"4d8bcbfa-745f-46a0-8194-c3469a8a3b56"],
Cell[144866, 4321, 557, 16, 117, "Input",ExpressionUUID->"2f61421f-6976-4203-942c-55d007a04bff"],
Cell[145426, 4339, 838, 25, 75, "Input",ExpressionUUID->"8efca578-2087-4585-bfe2-16dc34f2959d"],
Cell[146267, 4366, 604, 17, 75, "Input",ExpressionUUID->"80ea89a5-7520-44e8-beca-e6e52d79d137"],
Cell[146874, 4385, 556, 16, 54, "Input",ExpressionUUID->"9847ba40-e3fe-4aee-b015-a6b3c6631479"],
Cell[147433, 4403, 160, 4, 32, "Input",ExpressionUUID->"e02edf1d-2cad-4ab1-b9f3-a8b69b4f8ecc"],
Cell[147596, 4409, 431, 12, 54, "Input",ExpressionUUID->"2154a0ee-ecee-471e-bd9a-a779f7bd488d"],
Cell[148030, 4423, 677, 19, 138, "Input",ExpressionUUID->"cd3fcdda-ca95-497c-8c7c-03c8f50a1d68"],
Cell[148710, 4444, 845, 25, 96, "Input",ExpressionUUID->"60268fed-787c-4c21-ab43-c4722fdb5043"],
Cell[149558, 4471, 909, 26, 96, "Input",ExpressionUUID->"32366e70-7529-4127-bc32-9b4a251954d0"],
Cell[150470, 4499, 559, 16, 54, "Input",ExpressionUUID->"98f8337b-3da5-4b4e-ba89-5ff2bef459bf"],
Cell[151032, 4517, 964, 28, 96, "Input",ExpressionUUID->"96a2b080-296b-4b18-9c1a-f86a207fa874"],
Cell[151999, 4547, 559, 16, 54, "Input",ExpressionUUID->"3c430e5d-bad9-4933-bdf4-58e609fc9dba"],
Cell[152561, 4565, 521, 15, 54, "Input",ExpressionUUID->"5a369228-d01a-4c63-a805-db9e78de9b40"],
Cell[153085, 4582, 777, 22, 138, "Input",ExpressionUUID->"566138b0-35aa-4d32-a76c-0f637a5630cb"],
Cell[153865, 4606, 845, 25, 96, "Input",ExpressionUUID->"cb1032e7-ceb0-4720-8cb2-51fbd2a93670"],
Cell[154713, 4633, 160, 4, 32, "Input",ExpressionUUID->"ec1f11d3-e08a-481b-99d3-6ec3c6aed7cc"],
Cell[154876, 4639, 155, 3, 32, "Input",ExpressionUUID->"8019e240-a479-4da1-bcbb-290b0e422b1a"],
Cell[155034, 4644, 399, 10, 32, "Input",ExpressionUUID->"cfe6d167-ec9a-4f23-ad0c-26f0636f1cc1"],
Cell[155436, 4656, 607, 17, 75, "Input",ExpressionUUID->"2be5d18f-eacf-4355-89d5-d3147828f4cb"],
Cell[156046, 4675, 1181, 34, 138, "Input",ExpressionUUID->"7e352c4a-1c9d-4810-995f-11fbba385d1f"],
Cell[157230, 4711, 845, 25, 96, "Input",ExpressionUUID->"6349bbfa-e106-42f1-acfc-caa530f7ab3f"],
Cell[158078, 4738, 1117, 32, 117, "Input",ExpressionUUID->"3349437b-140a-4489-8063-048c796cebc4"],
Cell[159198, 4772, 559, 16, 54, "Input",ExpressionUUID->"66b8e624-2279-4540-b9a7-b38e3c30be52"],
Cell[159760, 4790, 503, 12, 54, "Input",ExpressionUUID->"7b3586b9-1284-43db-80bf-8f23191d402b"],
Cell[160266, 4804, 368, 11, 32, "Input",ExpressionUUID->"86481bb3-3993-4145-88e0-279726500c1a"],
Cell[160637, 4817, 438, 12, 54, "Input",ExpressionUUID->"7a15a5fc-9896-440f-bae0-128097531d47"],
Cell[161078, 4831, 566, 16, 138, "Input",ExpressionUUID->"65236c5b-b63f-46cd-ba47-e85e6f9281e3"],
Cell[161647, 4849, 624, 18, 96, "Input",ExpressionUUID->"e20b74f2-ef42-41b0-bd03-6d8cd1fff6eb"],
Cell[162274, 4869, 215, 5, 32, "Input",ExpressionUUID->"77b5e4bb-1a4c-4602-8951-d57b09ee349c"],
Cell[162492, 4876, 215, 5, 32, "Input",ExpressionUUID->"78482f6e-2f40-4f0a-b8de-4ed65d6c0632"],
Cell[162710, 4883, 215, 5, 32, "Input",ExpressionUUID->"96d7b956-5ad8-4483-bcf1-d34e11692f0b"],
Cell[162928, 4890, 155, 3, 32, "Input",ExpressionUUID->"14534cb9-dae8-4202-bb51-0d7d9db49c87"],
Cell[163086, 4895, 155, 3, 32, "Input",ExpressionUUID->"467378bd-2439-4681-81d3-45525c26b4b3"],
Cell[163244, 4900, 443, 14, 32, "Input",ExpressionUUID->"0398880d-600b-408c-aedb-0a0632303c85"],
Cell[163690, 4916, 443, 12, 54, "Input",ExpressionUUID->"a5128c7f-efd9-4519-b6e3-1294de5dcf18"],
Cell[164136, 4930, 428, 12, 32, "Input",ExpressionUUID->"a4e7659b-ffe7-4598-8865-f8f5567086b1"],
Cell[164567, 4944, 1302, 41, 75, "Input",ExpressionUUID->"146f708f-ea35-43de-8c2d-8b62f92335f4"],
Cell[165872, 4987, 1574, 48, 96, "Input",ExpressionUUID->"41218064-4d17-4666-99a7-9610c0905b1f"]
}, Closed]],
Cell[CellGroupData[{
Cell[167483, 5040, 89, 0, 36, "Subsection",ExpressionUUID->"feeabc3c-c487-4da3-84ec-eb4ab132a664"],
Cell[167575, 5042, 427, 11, 75, "Input",ExpressionUUID->"7f02f5eb-34f0-4235-b3af-4712ae567b3c"],
Cell[168005, 5055, 196, 4, 32, "Input",ExpressionUUID->"8c6e8fd5-9018-4015-8d96-de6b1fe23a35"],
Cell[168204, 5061, 1920, 57, 138, "Input",ExpressionUUID->"75f83e7c-dc88-4aae-b018-a6b4296dab1b"],
Cell[170127, 5120, 134, 2, 32, "Input",ExpressionUUID->"05720380-6c45-4b45-a0de-e0f639f091e5"],
Cell[170264, 5124, 706, 22, 54, "Input",ExpressionUUID->"4fbf9e0a-0956-41aa-b365-00b8462e26f3"],
Cell[170973, 5148, 850, 26, 75, "Input",ExpressionUUID->"528e6e96-fc97-478d-b530-c0fc7689f00c"],
Cell[171826, 5176, 160, 4, 32, "Input",ExpressionUUID->"578c55e9-9334-4d85-9725-5f8fe47b6464"],
Cell[171989, 5182, 649, 20, 54, "Input",ExpressionUUID->"6e208502-726c-4a4c-9f5a-e356773bde7a"],
Cell[172641, 5204, 224, 5, 32, "Input",ExpressionUUID->"dc08d7c7-c9c0-4e9b-95f8-760b335733bb"],
Cell[172868, 5211, 883, 27, 75, "Input",ExpressionUUID->"b5869f89-5365-4fa4-8e3a-191793be8c85"],
Cell[173754, 5240, 883, 27, 75, "Input",ExpressionUUID->"e343d0bc-a757-4387-bf1a-d52a325e6073"],
Cell[174640, 5269, 675, 21, 54, "Input",ExpressionUUID->"44be8a92-d69e-45a0-9cda-8ffd1fa7bcf3"],
Cell[175318, 5292, 154, 3, 32, "Input",ExpressionUUID->"0ecd21ec-627e-4bc5-9608-9c622096940b"],
Cell[175475, 5297, 2574, 73, 180, "Input",ExpressionUUID->"a10f3b98-fa8e-4b2d-97c0-159da0788595"]
}, Closed]]
}, Closed]]
}
]
*)

