(* Content-type: application/vnd.wolfram.mathematica *)

(*** Wolfram Notebook File ***)
(* http://www.wolfram.com/nb *)

(* CreatedBy='Mathematica 11.3' *)

(*CacheID: 234*)
(* Internal cache information:
NotebookFileLineBreakTest
NotebookFileLineBreakTest
NotebookDataPosition[       158,          7]
NotebookDataLength[     43526,       1234]
NotebookOptionsPosition[     38313,       1168]
NotebookOutlinePosition[     38667,       1184]
CellTagsIndexPosition[     38624,       1181]
WindowFrame->Normal*)

(* Beginning of Notebook Content *)
Notebook[{
Cell["\<\
For working with projections of the sphere and the hyperbolic plane

Shape-preserving (conformal): stereographic, Poincar\[EAcute]
Geodesic-preserving: gnomonic, Klein-Beltrami

The hyperbolic surface is embedded in 3-space as one sheet of a two-sheet \
hyperboloid with rotational symmetry and 45-degree angle.

Tiling with triangles have been done in another notebook. Those are Schwarz \
triangles, with angles pi*{1/n1,1/n2,1/n3}
Sum of 1/n\[CloseCurlyQuote]s > 1 (sphere), = 1 (flat plane), <1 (hyperbolic \
plane)\
\>", "Text",ExpressionUUID->"e475f957-f3ae-45a6-86ee-4198af646947"],

Cell[BoxData[
 RowBox[{"(*", " ", "Curvature", " ", "*)"}]], "Input",
 CellLabel->"In[77]:=",ExpressionUUID->"b60cf421-064a-4cb1-9c48-7fec38d94b9d"],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"crv", "[", "\"\<sph\>\"", "]"}], " ", "=", " ", "1"}], ";", " ", 
  RowBox[{
   RowBox[{"crv", " ", "[", "\"\<hyp\>\"", "]"}], " ", "=", " ", 
   RowBox[{"-", "1"}]}], ";"}]], "Input",
 CellLabel->"In[78]:=",ExpressionUUID->"4f3f99cf-c77d-4f13-b282-ba00e9c21c52"],

Cell[BoxData[
 RowBox[{"(*", " ", 
  RowBox[{
   RowBox[{
   "Metric", " ", "of", " ", "the", " ", "surface", " ", "in", " ", "its", 
    " ", "containing", " ", "3"}], "-", "space"}], " ", "*)"}]], "Input",
 CellLabel->"In[79]:=",ExpressionUUID->"ec9c4845-de9f-47bf-8b7d-f6d238e5d37c"],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"met", "[", "t_", "]"}], " ", ":=", " ", 
   RowBox[{
    RowBox[{
     RowBox[{"DiagonalMatrix", "[", 
      RowBox[{"{", 
       RowBox[{"#", ",", "#", ",", "1"}], "}"}], "]"}], "&"}], " ", "@", " ", 
    
    RowBox[{"crv", "[", "t", "]"}]}]}], ";"}]], "Input",
 CellLabel->"In[80]:=",ExpressionUUID->"e8a7aca0-185a-477b-b5fb-101631e16275"],

Cell[BoxData[
 RowBox[{
  RowBox[{"metx", "[", "t_", "]"}], " ", ":=", " ", 
  RowBox[{
   RowBox[{
    RowBox[{"DiagonalMatrix", "[", 
     RowBox[{"{", 
      RowBox[{"1", ",", "1", ",", "#"}], "}"}], "]"}], "&"}], " ", "@", " ", 
   RowBox[{"crv", "[", "t", "]"}]}]}]], "Input",
 CellLabel->"In[81]:=",ExpressionUUID->"5a4b3255-6194-4ce7-bb2f-a7d26e3742c8"],

Cell[BoxData[
 RowBox[{"(*", " ", 
  RowBox[{"Inner", " ", "product", " ", "and", " ", "magnitude"}], " ", 
  "*)"}]], "Input",
 CellLabel->"In[82]:=",ExpressionUUID->"8246a360-6e6b-4120-bfe3-2cbaf9103f1e"],

Cell[BoxData[
 RowBox[{
  RowBox[{"ipd", "[", 
   RowBox[{"t_", ",", "x_", ",", "y_"}], "]"}], " ", ":=", " ", 
  RowBox[{"x", ".", 
   RowBox[{"met", "[", "t", "]"}], ".", "y"}]}]], "Input",
 CellLabel->"In[83]:=",ExpressionUUID->"c89ea8b8-5192-4d37-b546-257baf8ecd56"],

Cell[BoxData[
 RowBox[{
  RowBox[{"ipdx", "[", 
   RowBox[{"t_", ",", "x_", ",", "y_"}], "]"}], " ", ":=", " ", 
  RowBox[{"x", ".", 
   RowBox[{"metx", "[", "t", "]"}], ".", "y"}]}]], "Input",
 CellLabel->"In[84]:=",ExpressionUUID->"6ee0b065-ed97-420a-ac30-dd23431638c0"],

Cell[BoxData[
 RowBox[{
  RowBox[{"mag", "[", 
   RowBox[{"t_", ",", "x_"}], "]"}], " ", ":=", " ", 
  RowBox[{"ipd", "[", 
   RowBox[{"t", ",", "x", ",", "x"}], "]"}]}]], "Input",
 CellLabel->"In[85]:=",ExpressionUUID->"7ff82795-ba1d-4bcb-82de-779d85d86ff6"],

Cell[BoxData[
 RowBox[{
  RowBox[{"magx", "[", 
   RowBox[{"t_", ",", "x_"}], "]"}], " ", ":=", " ", 
  RowBox[{"ipdx", "[", 
   RowBox[{"t", ",", "x", ",", "x"}], "]"}]}]], "Input",
 CellLabel->"In[86]:=",ExpressionUUID->"210e3e84-9dcb-40de-a38a-369e08e03010"],

Cell[BoxData[
 RowBox[{
  RowBox[{"nrm", "[", 
   RowBox[{"t_", ",", "x_"}], "]"}], " ", ":=", " ", 
  RowBox[{"x", "/", 
   RowBox[{"Sqrt", "[", 
    RowBox[{"mag", "[", 
     RowBox[{"t", ",", "x"}], "]"}], "]"}]}]}]], "Input",
 CellLabel->"In[87]:=",ExpressionUUID->"cd78a215-3262-4486-802b-a3b3cee97ca7"],

Cell[BoxData[
 RowBox[{
  RowBox[{"nrmx", "[", 
   RowBox[{"t_", ",", "x_"}], "]"}], " ", ":=", " ", 
  RowBox[{"x", "/", 
   RowBox[{"Sqrt", "[", 
    RowBox[{"magx", "[", 
     RowBox[{"t", ",", "x"}], "]"}], "]"}]}]}]], "Input",
 CellLabel->"In[88]:=",ExpressionUUID->"fae73500-35ae-4898-8df3-c53e578eac43"],

Cell[BoxData[
 RowBox[{"(*", " ", 
  RowBox[{
  "Projections", " ", "from", " ", "surface", " ", "to", " ", "plane"}], " ", 
  "*)"}]], "Input",
 CellLabel->"In[89]:=",ExpressionUUID->"34533c68-bc31-4af3-8963-a5860b896431"],

Cell[BoxData[
 RowBox[{
  RowBox[{"proj", "[", 
   RowBox[{"\"\<cfm\>\"", ",", "x_"}], "]"}], " ", ":=", " ", 
  RowBox[{
   RowBox[{"Take", "[", 
    RowBox[{"x", ",", "2"}], "]"}], "/", 
   RowBox[{"(", 
    RowBox[{"1", "+", 
     RowBox[{"x", "[", 
      RowBox[{"[", "3", "]"}], "]"}]}], ")"}]}]}]], "Input",
 CellLabel->"In[90]:=",ExpressionUUID->"0a475567-7a3f-4219-a4bf-09b7d55ec050"],

Cell[BoxData[
 RowBox[{
  RowBox[{"proj", "[", 
   RowBox[{"\"\<gds\>\"", ",", "x_"}], "]"}], " ", ":=", " ", 
  RowBox[{
   RowBox[{"Take", "[", 
    RowBox[{"x", ",", "2"}], "]"}], "/", 
   RowBox[{"x", "[", 
    RowBox[{"[", "3", "]"}], "]"}]}]}]], "Input",
 CellLabel->"In[91]:=",ExpressionUUID->"3027e6e0-2cd8-42f3-b4bc-30c942f54363"],

Cell[BoxData[
 RowBox[{"(*", " ", 
  RowBox[{"Inverse", " ", "projections"}], " ", "*)"}]], "Input",
 CellLabel->"In[92]:=",ExpressionUUID->"69246167-f0ce-44cb-9352-ae2e873592f2"],

Cell[BoxData[
 RowBox[{
  RowBox[{"invproj", "[", 
   RowBox[{"\"\<sph\>\"", ",", "\"\<cfm\>\"", ",", "x_"}], "]"}], " ", ":=", 
  " ", 
  RowBox[{
   RowBox[{"Append", "[", 
    RowBox[{
     RowBox[{"2", "x"}], ",", 
     RowBox[{"1", "-", 
      RowBox[{"x", ".", "x"}]}]}], "]"}], "/", 
   RowBox[{"(", 
    RowBox[{"1", "+", 
     RowBox[{"x", ".", "x"}]}], ")"}]}]}]], "Input",
 CellLabel->"In[93]:=",ExpressionUUID->"144a73a0-13ed-4462-902a-3fa7b2f5ae42"],

Cell[BoxData[
 RowBox[{
  RowBox[{"invproj", "[", 
   RowBox[{"\"\<hyp\>\"", ",", "\"\<cfm\>\"", ",", "x_"}], "]"}], " ", ":=", 
  " ", 
  RowBox[{
   RowBox[{"Append", "[", 
    RowBox[{
     RowBox[{"2", "x"}], ",", 
     RowBox[{"1", "+", 
      RowBox[{"x", ".", "x"}]}]}], "]"}], "/", 
   RowBox[{"(", 
    RowBox[{"1", "-", 
     RowBox[{"x", ".", "x"}]}], ")"}]}]}]], "Input",
 CellLabel->"In[94]:=",ExpressionUUID->"f6f26975-1a7e-4c74-bfc9-949034469f34"],

Cell[BoxData[
 RowBox[{
  RowBox[{"invproj", "[", 
   RowBox[{"\"\<sph\>\"", ",", "\"\<gds\>\"", ",", "x_"}], "]"}], " ", ":=", 
  " ", 
  RowBox[{
   RowBox[{"Append", "[", 
    RowBox[{"x", ",", "1"}], "]"}], "/", 
   RowBox[{"Sqrt", "[", 
    RowBox[{"1", "+", 
     RowBox[{"x", ".", "x"}]}], "]"}]}]}]], "Input",
 CellLabel->"In[95]:=",ExpressionUUID->"da40baff-a06b-4d00-90e1-fb720f0eb60b"],

Cell[BoxData[
 RowBox[{
  RowBox[{"invproj", "[", 
   RowBox[{"\"\<hyp\>\"", ",", "\"\<gds\>\"", ",", "x_"}], "]"}], " ", ":=", 
  " ", 
  RowBox[{
   RowBox[{"Append", "[", 
    RowBox[{"x", ",", "1"}], "]"}], "/", 
   RowBox[{"Sqrt", "[", 
    RowBox[{"1", "-", 
     RowBox[{"x", ".", "x"}]}], "]"}]}]}]], "Input",
 CellLabel->"In[96]:=",ExpressionUUID->"a3121a8d-dfc3-4d82-8cda-914a76a26120"],

Cell[BoxData[
 RowBox[{"(*", " ", "Tests", " ", "*)"}]], "Input",
 CellLabel->"In[97]:=",ExpressionUUID->"83f2849a-3d07-46fd-96bd-0a0586a8ebbc"],

Cell[BoxData[
 RowBox[{
  RowBox[{"tstx2", " ", "=", " ", 
   RowBox[{"Array", "[", 
    RowBox[{"x", ",", "2"}], "]"}]}], ";"}]], "Input",
 CellLabel->"In[98]:=",ExpressionUUID->"b6bfaad0-6667-4c58-99d1-a83b66fb0c90"],

Cell[BoxData[
 RowBox[{"Table", "[", 
  RowBox[{
   RowBox[{"Factor", "[", 
    RowBox[{
     RowBox[{"mag", "[", 
      RowBox[{"t", ",", 
       RowBox[{"invproj", "[", 
        RowBox[{"t", ",", "u", ",", "tstx2"}], "]"}]}], "]"}], "-", "1"}], 
    "]"}], ",", 
   RowBox[{"{", 
    RowBox[{"t", ",", 
     RowBox[{"{", 
      RowBox[{"\"\<sph\>\"", ",", "\"\<hyp\>\""}], "}"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"u", ",", 
     RowBox[{"{", 
      RowBox[{"\"\<cfm\>\"", ",", "\"\<gds\>\""}], "}"}]}], "}"}]}], 
  "]"}]], "Input",
 CellLabel->"In[99]:=",ExpressionUUID->"d88f2d06-dc96-4621-b2f8-328ad5e3b16f"],

Cell[BoxData[
 RowBox[{"Table", "[", 
  RowBox[{
   RowBox[{"Factor", "[", 
    RowBox[{
     RowBox[{"proj", "[", 
      RowBox[{"u", ",", 
       RowBox[{"invproj", "[", 
        RowBox[{"t", ",", "u", ",", "tstx2"}], "]"}]}], "]"}], "-", "tstx2"}],
     "]"}], ",", 
   RowBox[{"{", 
    RowBox[{"t", ",", 
     RowBox[{"{", 
      RowBox[{"\"\<sph\>\"", ",", "\"\<hyp\>\""}], "}"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"u", ",", 
     RowBox[{"{", 
      RowBox[{"\"\<cfm\>\"", ",", "\"\<gds\>\""}], "}"}]}], "}"}]}], 
  "]"}]], "Input",
 CellLabel->
  "In[100]:=",ExpressionUUID->"a44d682e-0769-413d-80ec-815c50e481cf"],

Cell[BoxData[
 RowBox[{"(*", " ", 
  RowBox[{"3", "D", " ", "geodesic"}], " ", "*)"}]], "Input",
 CellLabel->
  "In[101]:=",ExpressionUUID->"c032401f-5b5a-4880-8df7-5d1fe6dbb0f2"],

Cell[BoxData[
 RowBox[{"(*", " ", "Spherical", " ", "*)"}]], "Input",
 CellLabel->
  "In[102]:=",ExpressionUUID->"c569bb66-bb14-445a-8a8b-d38ca0ef09b3"],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{
    RowBox[{"Total", "[", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{
        RowBox[{"proj", "[", 
         RowBox[{"\"\<cfm\>\"", ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"w", "*", 
             RowBox[{"Cos", "[", "a", "]"}]}], ",", 
            RowBox[{"Sin", "[", "a", "]"}], ",", 
            RowBox[{
             RowBox[{"Sqrt", "[", 
              RowBox[{"1", "-", 
               RowBox[{"w", "^", "2"}]}], "]"}], "*", 
             RowBox[{"Cos", "[", "a", "]"}]}]}], "}"}]}], "]"}], " ", "-", 
        " ", 
        RowBox[{"{", 
         RowBox[{
          RowBox[{
           RowBox[{"-", 
            RowBox[{"Sqrt", "[", 
             RowBox[{"1", "-", 
              RowBox[{"w", "^", "2"}]}], "]"}]}], "/", "w"}], ",", "0"}], 
         "}"}]}], ")"}], "^", "2"}], "]"}], " ", "-", " ", 
    RowBox[{"1", "/", 
     RowBox[{"w", "^", "2"}]}]}], " ", "//", " ", "Factor"}], " ", "//", " ", 
  "TrigReduce"}]], "Input",
 CellLabel->
  "In[103]:=",ExpressionUUID->"5315c8f0-5a3f-4c11-8b78-4291fcd6e8d2"],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{
    RowBox[{"Total", "[", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{
        RowBox[{"proj", "[", 
         RowBox[{"\"\<cfm\>\"", ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{
             RowBox[{"(", 
              RowBox[{"1", "/", 
               RowBox[{"Sqrt", "[", 
                RowBox[{"1", "+", 
                 RowBox[{"w", "^", "2"}]}], "]"}]}], ")"}], "*", 
             RowBox[{"Cos", "[", "a", "]"}]}], ",", 
            RowBox[{"Sin", "[", "a", "]"}], ",", 
            RowBox[{
             RowBox[{"(", 
              RowBox[{"w", "/", 
               RowBox[{"Sqrt", "[", 
                RowBox[{"1", "+", 
                 RowBox[{"w", "^", "2"}]}], "]"}]}], ")"}], "*", 
             RowBox[{"Cos", "[", "a", "]"}]}]}], "}"}]}], "]"}], " ", "-", 
        " ", 
        RowBox[{"{", 
         RowBox[{
          RowBox[{"-", "w"}], ",", "0"}], "}"}]}], ")"}], "^", "2"}], "]"}], 
    " ", "-", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{"w", "^", "2"}], "+", "1"}], ")"}]}], " ", "//", " ", 
   "Factor"}], " ", "//", " ", "TrigReduce"}]], "Input",
 CellLabel->
  "In[104]:=",ExpressionUUID->"dd4e7450-85c9-4d92-871d-5713f0f21e6b"],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{
    RowBox[{"{", 
     RowBox[{"1", ",", "0"}], "}"}], ".", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{"proj", "[", 
       RowBox[{"\"\<gds\>\"", ",", 
        RowBox[{"{", 
         RowBox[{
          RowBox[{"w", "*", 
           RowBox[{"Cos", "[", "a", "]"}]}], ",", 
          RowBox[{"Sin", "[", "a", "]"}], ",", 
          RowBox[{
           RowBox[{"Sqrt", "[", 
            RowBox[{"1", "-", 
             RowBox[{"w", "^", "2"}]}], "]"}], "*", 
           RowBox[{"Cos", "[", "a", "]"}]}]}], "}"}]}], "]"}], " ", "-", " ", 
      
      RowBox[{"{", 
       RowBox[{
        RowBox[{"w", "/", 
         RowBox[{"Sqrt", "[", 
          RowBox[{"1", "-", 
           RowBox[{"w", "^", "2"}]}], "]"}]}], ",", "0"}], "}"}]}], ")"}]}], "//",
    " ", "Factor"}], " ", "//", " ", "TrigReduce"}]], "Input",
 CellLabel->
  "In[247]:=",ExpressionUUID->"585c669d-49c1-4111-be37-6957b9499289"],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{
    RowBox[{"{", 
     RowBox[{"1", ",", "0"}], "}"}], ".", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{"proj", "[", 
       RowBox[{"\"\<gds\>\"", ",", 
        RowBox[{"{", 
         RowBox[{
          RowBox[{
           RowBox[{"(", 
            RowBox[{"1", "/", 
             RowBox[{"Sqrt", "[", 
              RowBox[{"1", "+", 
               RowBox[{"w", "^", "2"}]}], "]"}]}], ")"}], "*", 
           RowBox[{"Cos", "[", "a", "]"}]}], ",", 
          RowBox[{"Sin", "[", "a", "]"}], ",", 
          RowBox[{
           RowBox[{"(", 
            RowBox[{"w", "/", 
             RowBox[{"Sqrt", "[", 
              RowBox[{"1", "+", 
               RowBox[{"w", "^", "2"}]}], "]"}]}], ")"}], "*", 
           RowBox[{"Cos", "[", "a", "]"}]}]}], "}"}]}], "]"}], " ", "-", " ", 
      
      RowBox[{"{", 
       RowBox[{
        RowBox[{"1", "/", "w"}], ",", "0"}], "}"}]}], ")"}]}], "//", " ", 
   "Factor"}], " ", "//", " ", "TrigReduce"}]], "Input",
 CellLabel->
  "In[246]:=",ExpressionUUID->"2f365834-c122-4114-80c9-553b9fbd8022"],

Cell[BoxData[
 RowBox[{"(*", " ", "Hyperbolic", " ", "*)"}]], "Input",
 CellLabel->
  "In[105]:=",ExpressionUUID->"a9cc7842-5414-499d-9bf5-132e6349b9c1"],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{
    RowBox[{"Total", "[", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{
        RowBox[{"proj", "[", 
         RowBox[{"\"\<cfm\>\"", ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"w", "*", 
             RowBox[{"Cosh", "[", "a", "]"}]}], ",", 
            RowBox[{"Sinh", "[", "a", "]"}], ",", 
            RowBox[{
             RowBox[{"Sqrt", "[", 
              RowBox[{"1", "+", 
               RowBox[{"w", "^", "2"}]}], "]"}], "*", 
             RowBox[{"Cosh", "[", "a", "]"}]}]}], "}"}]}], "]"}], "-", 
        RowBox[{"{", 
         RowBox[{
          RowBox[{
           RowBox[{"Sqrt", "[", 
            RowBox[{"1", "+", 
             RowBox[{"w", "^", "2"}]}], "]"}], "/", "w"}], ",", "0"}], 
         "}"}]}], ")"}], "^", "2"}], "]"}], "-", 
    RowBox[{"1", "/", 
     RowBox[{"w", "^", "2"}]}]}], " ", "//", " ", "Factor"}], " ", "//", " ", 
  "TrigReduce"}]], "Input",
 CellLabel->
  "In[106]:=",ExpressionUUID->"1be27beb-7315-4dc6-ba30-bb27ca5cf2eb"],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{
    RowBox[{"Total", "[", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{
        RowBox[{"proj", "[", 
         RowBox[{"\"\<cfm\>\"", ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{
             RowBox[{"(", 
              RowBox[{"1", "/", 
               RowBox[{"Sqrt", "[", 
                RowBox[{
                 RowBox[{"w", "^", "2"}], "-", "1"}], "]"}]}], ")"}], "*", 
             RowBox[{"Cosh", "[", "a", "]"}]}], ",", 
            RowBox[{"Sinh", "[", "a", "]"}], ",", 
            RowBox[{
             RowBox[{"(", 
              RowBox[{"w", "/", 
               RowBox[{"Sqrt", "[", 
                RowBox[{
                 RowBox[{"w", "^", "2"}], "-", "1"}], "]"}]}], ")"}], "*", 
             RowBox[{"Cosh", "[", "a", "]"}]}]}], "}"}]}], "]"}], " ", "-", 
        " ", 
        RowBox[{"{", 
         RowBox[{"w", ",", "0"}], "}"}]}], ")"}], "^", "2"}], "]"}], " ", "-", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{"w", "^", "2"}], "-", "1"}], ")"}]}], " ", "//", " ", 
   "Factor"}], " ", "//", " ", "TrigReduce"}]], "Input",
 CellLabel->
  "In[107]:=",ExpressionUUID->"d14bb902-729f-48dd-b180-30b1830ba026"],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{
    RowBox[{"{", 
     RowBox[{"1", ",", "0"}], "}"}], ".", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{"proj", "[", 
       RowBox[{"\"\<gds\>\"", ",", 
        RowBox[{"{", 
         RowBox[{
          RowBox[{"w", "*", 
           RowBox[{"Cosh", "[", "a", "]"}]}], ",", 
          RowBox[{"Sinh", "[", "a", "]"}], ",", 
          RowBox[{
           RowBox[{"Sqrt", "[", 
            RowBox[{"1", "+", 
             RowBox[{"w", "^", "2"}]}], "]"}], "*", 
           RowBox[{"Cosh", "[", "a", "]"}]}]}], "}"}]}], "]"}], " ", "-", " ", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"w", "/", 
         RowBox[{"Sqrt", "[", 
          RowBox[{"1", "+", 
           RowBox[{"w", "^", "2"}]}], "]"}]}], ",", "0"}], "}"}]}], ")"}]}], "//",
    " ", "Factor"}], " ", "//", " ", "TrigReduce"}]], "Input",
 CellLabel->
  "In[248]:=",ExpressionUUID->"a84baeb9-c095-4db6-912d-f5b9268974ff"],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{
    RowBox[{"{", 
     RowBox[{"1", ",", "0"}], "}"}], ".", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{"proj", "[", 
       RowBox[{"\"\<gds\>\"", ",", 
        RowBox[{"{", 
         RowBox[{
          RowBox[{
           RowBox[{"(", 
            RowBox[{"1", "/", 
             RowBox[{"Sqrt", "[", 
              RowBox[{
               RowBox[{"w", "^", "2"}], "-", "1"}], "]"}]}], ")"}], "*", 
           RowBox[{"Cosh", "[", "a", "]"}]}], ",", 
          RowBox[{"Sinh", "[", "a", "]"}], ",", 
          RowBox[{
           RowBox[{"(", 
            RowBox[{"w", "/", 
             RowBox[{"Sqrt", "[", 
              RowBox[{
               RowBox[{"w", "^", "2"}], "-", "1"}], "]"}]}], ")"}], "*", 
           RowBox[{"Cosh", "[", "a", "]"}]}]}], "}"}]}], "]"}], " ", "-", " ", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"1", "/", "w"}], ",", "0"}], "}"}]}], ")"}]}], "//", " ", 
   "Factor"}], " ", "//", " ", "TrigReduce"}]], "Input",
 CellLabel->
  "In[249]:=",ExpressionUUID->"fb42c814-ff9e-4ce4-b7dc-56e19d349447"],

Cell[BoxData[
 RowBox[{"(*", " ", 
  RowBox[{"Rotations", ":", " ", 
   RowBox[{"quaternion", " ", "parameters"}]}], " ", "*)"}]], "Input",
 CellLabel->
  "In[108]:=",ExpressionUUID->"686d1c52-eedd-46cd-abac-0330e35747c0"],

Cell[BoxData[
 RowBox[{
  RowBox[{"rot", "[", 
   RowBox[{"\"\<sph\>\"", ",", "q_"}], "]"}], " ", ":=", " ", 
  RowBox[{"Module", "[", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{"q0", ",", "q1", ",", "q2", ",", "q3"}], "}"}], ",", 
    "\[IndentingNewLine]", 
    RowBox[{
     RowBox[{
      RowBox[{"{", 
       RowBox[{"q0", ",", "q1", ",", "q2", ",", "q3"}], "}"}], " ", "=", " ", 
      "q"}], ";", "\[IndentingNewLine]", 
     RowBox[{
      RowBox[{"{", 
       RowBox[{
        RowBox[{"{", 
         RowBox[{
          RowBox[{
           RowBox[{"q0", "^", "2"}], "+", 
           RowBox[{"q1", "^", "2"}], "-", 
           RowBox[{"q2", "^", "2"}], "-", 
           RowBox[{"q3", "^", "2"}]}], ",", 
          RowBox[{
           RowBox[{"2", "q1", "*", "q2"}], "-", 
           RowBox[{"2", "q0", "*", "q3"}]}], ",", 
          RowBox[{
           RowBox[{"2", "q1", "*", "q3"}], "+", 
           RowBox[{"2", "q0", "*", "q2"}]}]}], "}"}], ",", 
        "\[IndentingNewLine]", 
        RowBox[{"{", 
         RowBox[{
          RowBox[{
           RowBox[{"2", "q1", "*", "q2"}], "+", 
           RowBox[{"2", "q0", "*", "q3"}]}], ",", 
          RowBox[{
           RowBox[{"q0", "^", "2"}], "-", 
           RowBox[{"q1", "^", "2"}], "+", 
           RowBox[{"q2", "^", "2"}], "-", 
           RowBox[{"q3", "^", "2"}]}], ",", 
          RowBox[{
           RowBox[{"2", "q2", "*", "q3"}], "-", 
           RowBox[{"2", "q0", "*", "q1"}]}]}], "}"}], ",", 
        "\[IndentingNewLine]", 
        RowBox[{"{", 
         RowBox[{
          RowBox[{
           RowBox[{"2", "q1", "*", "q3"}], "-", 
           RowBox[{"2", "q0", "*", "q2"}]}], ",", 
          RowBox[{
           RowBox[{"2", "q2", "*", "q3"}], "+", 
           RowBox[{"2", "q0", "*", "q1"}]}], ",", 
          RowBox[{
           RowBox[{"q0", "^", "2"}], "-", 
           RowBox[{"q1", "^", "2"}], "-", 
           RowBox[{"q2", "^", "2"}], "+", 
           RowBox[{"q3", "^", "2"}]}]}], "}"}]}], "}"}], "/", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{"q0", "^", "2"}], "+", 
        RowBox[{"q1", "^", "2"}], "+", 
        RowBox[{"q2", "^", "2"}], "+", 
        RowBox[{"q3", "^", "2"}]}], ")"}]}]}]}], "\[IndentingNewLine]", 
   "]"}]}]], "Input",
 CellLabel->
  "In[109]:=",ExpressionUUID->"d459ecb2-5b9f-4b7e-aff6-34f8f3b57628"],

Cell[BoxData[
 RowBox[{
  RowBox[{"rot", "[", 
   RowBox[{"\"\<hyp\>\"", ",", "q_"}], "]"}], " ", ":=", " ", 
  RowBox[{"Module", "[", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{"q0", ",", "q1", ",", "q2", ",", "q3"}], "}"}], ",", 
    "\[IndentingNewLine]", 
    RowBox[{
     RowBox[{
      RowBox[{"{", 
       RowBox[{"q0", ",", "q1", ",", "q2", ",", "q3"}], "}"}], " ", "=", " ", 
      "q"}], ";", "\[IndentingNewLine]", 
     RowBox[{
      RowBox[{"{", 
       RowBox[{
        RowBox[{"{", 
         RowBox[{
          RowBox[{
           RowBox[{"q0", "^", "2"}], "-", 
           RowBox[{"q1", "^", "2"}], "+", 
           RowBox[{"q2", "^", "2"}], "-", 
           RowBox[{"q3", "^", "2"}]}], ",", 
          RowBox[{
           RowBox[{
            RowBox[{"-", "2"}], "q1", "*", "q2"}], "+", 
           RowBox[{"2", "q0", "*", "q3"}]}], ",", 
          RowBox[{
           RowBox[{"2", "q1", "*", "q3"}], "-", 
           RowBox[{"2", "q0", "*", "q2"}]}]}], "}"}], ",", 
        "\[IndentingNewLine]", 
        RowBox[{"{", 
         RowBox[{
          RowBox[{
           RowBox[{
            RowBox[{"-", "2"}], "q1", "*", "q2"}], "-", 
           RowBox[{"2", "q0", "*", "q3"}]}], ",", 
          RowBox[{
           RowBox[{"q0", "^", "2"}], "+", 
           RowBox[{"q1", "^", "2"}], "-", 
           RowBox[{"q2", "^", "2"}], "-", 
           RowBox[{"q3", "^", "2"}]}], ",", 
          RowBox[{
           RowBox[{"2", "q2", "*", "q3"}], "+", 
           RowBox[{"2", "q0", "*", "q1"}]}]}], "}"}], ",", 
        "\[IndentingNewLine]", 
        RowBox[{"{", 
         RowBox[{
          RowBox[{
           RowBox[{
            RowBox[{"-", "2"}], "q1", "*", "q3"}], "-", 
           RowBox[{"2", "q0", "*", "q2"}]}], ",", 
          RowBox[{
           RowBox[{
            RowBox[{"-", "2"}], "q2", "*", "q3"}], "+", 
           RowBox[{"2", "q0", "*", "q1"}]}], ",", 
          RowBox[{
           RowBox[{"q0", "^", "2"}], "+", 
           RowBox[{"q1", "^", "2"}], "+", 
           RowBox[{"q2", "^", "2"}], "+", 
           RowBox[{"q3", "^", "2"}]}]}], "}"}]}], "}"}], "/", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{"q0", "^", "2"}], "-", 
        RowBox[{"q1", "^", "2"}], "-", 
        RowBox[{"q2", "^", "2"}], "+", 
        RowBox[{"q3", "^", "2"}]}], ")"}]}]}]}], "\[IndentingNewLine]", 
   "]"}]}]], "Input",
 CellLabel->
  "In[110]:=",ExpressionUUID->"132027bf-dc1e-48b6-8990-216605c789ef"],

Cell[BoxData[
 RowBox[{
  RowBox[{"qtmlt", "[", 
   RowBox[{"\"\<sph\>\"", ",", "q1_", ",", "q2_"}], "]"}], " ", ":=", " ", 
  RowBox[{"Module", "[", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{
     "q11", ",", "q12", ",", "q13", ",", "q14", ",", "q21", ",", "q22", ",", 
      "q23", ",", "q24"}], "}"}], ",", "\[IndentingNewLine]", 
    RowBox[{
     RowBox[{
      RowBox[{"{", 
       RowBox[{"q11", ",", "q12", ",", "q13", ",", "q14"}], "}"}], " ", "=", 
      " ", "q1"}], ";", "\[IndentingNewLine]", 
     RowBox[{
      RowBox[{"{", 
       RowBox[{"q21", ",", "q22", ",", "q23", ",", "q24"}], "}"}], " ", "=", 
      " ", "q2"}], ";", "\[IndentingNewLine]", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{
        RowBox[{"q11", "*", "q21"}], "-", 
        RowBox[{"q12", "*", "q22"}], "-", 
        RowBox[{"q13", "*", "q23"}], "-", 
        RowBox[{"q14", "*", "q24"}]}], ",", 
       RowBox[{
        RowBox[{"q11", "*", "q22"}], "+", 
        RowBox[{"q12", "*", "q21"}], "+", 
        RowBox[{"q13", "*", "q24"}], "-", 
        RowBox[{"q14", "*", "q23"}]}], ",", "\[IndentingNewLine]", 
       RowBox[{
        RowBox[{"q11", "*", "q23"}], "+", 
        RowBox[{"q13", "*", "q21"}], "+", 
        RowBox[{"q14", "*", "q22"}], "-", 
        RowBox[{"q12", "*", "q24"}]}], ",", "\[IndentingNewLine]", 
       RowBox[{
        RowBox[{"q11", "*", "q24"}], "+", 
        RowBox[{"q14", "*", "q21"}], "+", 
        RowBox[{"q12", "*", "q23"}], "-", 
        RowBox[{"q13", "*", "q22"}]}]}], "}"}]}]}], "\[IndentingNewLine]", 
   "]"}]}]], "Input",
 CellLabel->
  "In[111]:=",ExpressionUUID->"90784fa4-49bb-4d4a-bfed-824dc94a2d85"],

Cell[BoxData[
 RowBox[{
  RowBox[{"qtmlt", "[", 
   RowBox[{"\"\<hyp\>\"", ",", "q1_", ",", "q2_"}], "]"}], " ", ":=", " ", 
  RowBox[{"Module", "[", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{
     "q11", ",", "q12", ",", "q13", ",", "q14", ",", "q21", ",", "q22", ",", 
      "q23", ",", "q24"}], "}"}], ",", "\[IndentingNewLine]", 
    RowBox[{
     RowBox[{
      RowBox[{"{", 
       RowBox[{"q11", ",", "q12", ",", "q13", ",", "q14"}], "}"}], " ", "=", 
      " ", "q1"}], ";", "\[IndentingNewLine]", 
     RowBox[{
      RowBox[{"{", 
       RowBox[{"q21", ",", "q22", ",", "q23", ",", "q24"}], "}"}], " ", "=", 
      " ", "q2"}], ";", "\[IndentingNewLine]", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{
        RowBox[{"q11", "*", "q21"}], "+", 
        RowBox[{"q12", "*", "q22"}], "+", 
        RowBox[{"q13", "*", "q23"}], "-", 
        RowBox[{"q14", "*", "q24"}]}], ",", 
       RowBox[{
        RowBox[{"q11", "*", "q22"}], "+", 
        RowBox[{"q12", "*", "q21"}], "-", 
        RowBox[{"q13", "*", "q24"}], "+", 
        RowBox[{"q14", "*", "q23"}]}], ",", "\[IndentingNewLine]", 
       RowBox[{
        RowBox[{"q11", "*", "q23"}], "+", 
        RowBox[{"q13", "*", "q21"}], "-", 
        RowBox[{"q14", "*", "q22"}], "+", 
        RowBox[{"q12", "*", "q24"}]}], ",", "\[IndentingNewLine]", 
       RowBox[{
        RowBox[{"q11", "*", "q24"}], "+", 
        RowBox[{"q14", "*", "q21"}], "+", 
        RowBox[{"q12", "*", "q23"}], "-", 
        RowBox[{"q13", "*", "q22"}]}]}], "}"}]}]}], "\[IndentingNewLine]", 
   "]"}]}]], "Input",
 CellLabel->
  "In[112]:=",ExpressionUUID->"2eff23dc-293f-4225-b0ff-bd348f661b67"],

Cell[BoxData[
 RowBox[{
  RowBox[{"asymtens", "[", "v_", "]"}], " ", ":=", " ", 
  RowBox[{"Table", "[", 
   RowBox[{
    RowBox[{"Sum", "[", 
     RowBox[{
      RowBox[{
       RowBox[{"Signature", "[", 
        RowBox[{"{", 
         RowBox[{"i", ",", "j", ",", "k"}], "}"}], "]"}], "*", 
       RowBox[{"v", "[", 
        RowBox[{"[", "k", "]"}], "]"}]}], ",", 
      RowBox[{"{", 
       RowBox[{"k", ",", "3"}], "}"}]}], "]"}], ",", 
    RowBox[{"{", 
     RowBox[{"i", ",", "3"}], "}"}], ",", 
    RowBox[{"{", 
     RowBox[{"j", ",", "3"}], "}"}]}], "]"}]}]], "Input",
 CellLabel->
  "In[113]:=",ExpressionUUID->"4c8f6af3-3a46-49fe-994c-ed7413f4495c"],

Cell[BoxData[
 RowBox[{
  RowBox[{"rotgen", "[", 
   RowBox[{"t_", ",", "q_"}], "]"}], " ", ":=", " ", 
  RowBox[{"Module", "[", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{"qs", ",", "qv", ",", "m", ",", "qvmag"}], "}"}], ",", 
    "\[IndentingNewLine]", 
    RowBox[{
     RowBox[{"qs", " ", "=", " ", 
      RowBox[{"q", "[", 
       RowBox[{"[", "1", "]"}], "]"}]}], ";", "\[IndentingNewLine]", 
     RowBox[{"qv", " ", "=", " ", 
      RowBox[{"q", "[", 
       RowBox[{"[", 
        RowBox[{"2", ";;", "4"}], "]"}], "]"}]}], ";", "\[IndentingNewLine]", 
     
     RowBox[{"m", " ", "=", " ", 
      RowBox[{"met", "[", "t", "]"}]}], ";", "\[IndentingNewLine]", 
     RowBox[{"qvmag", " ", "=", " ", 
      RowBox[{"mag", "[", 
       RowBox[{"t", ",", "qv"}], "]"}]}], ";", "\[IndentingNewLine]", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{
        RowBox[{
         RowBox[{"(", 
          RowBox[{
           RowBox[{"qs", "^", "2"}], "-", "qvmag"}], ")"}], "*", 
         RowBox[{"IdentityMatrix", "[", "3", "]"}]}], " ", "+", " ", 
        RowBox[{"2", "*", 
         RowBox[{"Outer", "[", 
          RowBox[{"Times", ",", "qv", ",", 
           RowBox[{"m", ".", "qv"}]}], "]"}]}], " ", "-", " ", 
        RowBox[{"2", "*", "qs", "*", 
         RowBox[{"(", 
          RowBox[{"m", ".", 
           RowBox[{"asymtens", "[", "qv", "]"}]}], ")"}]}]}], ")"}], "/", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{"qs", "^", "2"}], "+", "qvmag"}], ")"}]}]}]}], 
   "\[IndentingNewLine]", "]"}]}]], "Input",
 CellLabel->
  "In[114]:=",ExpressionUUID->"af084ebd-ed1a-438c-b680-67caface7a96"],

Cell[BoxData[
 RowBox[{
  RowBox[{"qmgen", "[", 
   RowBox[{"t_", ",", "q1_", ",", "q2_"}], "]"}], " ", ":=", " ", 
  RowBox[{"Module", "[", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{
     "qs1", ",", "qv1", ",", "qs2", ",", "qv2", ",", "m", ",", "qsx", ",", 
      "qvx"}], "}"}], ",", "\[IndentingNewLine]", 
    RowBox[{
     RowBox[{"qs1", " ", "=", " ", 
      RowBox[{"q1", "[", 
       RowBox[{"[", "1", "]"}], "]"}]}], ";", "\[IndentingNewLine]", 
     RowBox[{"qv1", " ", "=", " ", 
      RowBox[{"q1", "[", 
       RowBox[{"[", 
        RowBox[{"2", ";;", "4"}], "]"}], "]"}]}], ";", "\[IndentingNewLine]", 
     
     RowBox[{"qs2", " ", "=", " ", 
      RowBox[{"q2", "[", 
       RowBox[{"[", "1", "]"}], "]"}]}], ";", "\[IndentingNewLine]", 
     RowBox[{"qv2", " ", "=", " ", 
      RowBox[{"q2", "[", 
       RowBox[{"[", 
        RowBox[{"2", ";;", "4"}], "]"}], "]"}]}], ";", "\[IndentingNewLine]", 
     
     RowBox[{"m", " ", "=", " ", 
      RowBox[{"met", "[", "t", "]"}]}], ";", "\[IndentingNewLine]", 
     RowBox[{"qsx", " ", "=", " ", 
      RowBox[{
       RowBox[{"qs1", "*", "qs2"}], "-", 
       RowBox[{"ipd", "[", 
        RowBox[{"t", ",", "qv1", ",", "qv2"}], "]"}]}]}], ";", 
     "\[IndentingNewLine]", 
     RowBox[{"qvx", " ", "=", " ", 
      RowBox[{
       RowBox[{"qs1", "*", "qv2"}], " ", "+", " ", 
       RowBox[{"qs2", "*", "qv1"}], "+", 
       RowBox[{"m", ".", 
        RowBox[{"Cross", "[", 
         RowBox[{"qv1", ",", "qv2"}], "]"}]}]}]}], ";", "\[IndentingNewLine]", 
     RowBox[{"Prepend", "[", 
      RowBox[{"qvx", ",", "qsx"}], "]"}]}]}], "\[IndentingNewLine]", 
   "]"}]}]], "Input",
 CellLabel->
  "In[115]:=",ExpressionUUID->"c30d5dc0-ac24-45b3-9391-a6fc3921f1a5"],

Cell[BoxData[
 RowBox[{"(*", " ", "Tests", " ", "*)"}]], "Input",
 CellLabel->
  "In[116]:=",ExpressionUUID->"666f482b-9422-4573-ad84-ad5ad53e9fc9"],

Cell[BoxData[
 RowBox[{
  RowBox[{"tstq4", " ", "=", " ", 
   RowBox[{"Array", "[", 
    RowBox[{"q", ",", "4"}], "]"}]}], ";", 
  RowBox[{"tstqx4", "=", 
   RowBox[{"Array", "[", 
    RowBox[{"qx", ",", "4"}], "]"}]}], ";"}]], "Input",
 CellLabel->
  "In[117]:=",ExpressionUUID->"2d5ffe25-3d94-487e-9b3b-89e04b969b6b"],

Cell[BoxData[
 RowBox[{"Table", "[", 
  RowBox[{
   RowBox[{"Factor", "[", 
    RowBox[{
     RowBox[{
      RowBox[{"{", 
       RowBox[{
        RowBox[{
         RowBox[{"Det", "[", "#", "]"}], "-", "1"}], ",", 
        RowBox[{
         RowBox[{"#", ".", 
          RowBox[{"met", "[", "t", "]"}], ".", 
          RowBox[{"Transpose", "[", "#", "]"}]}], "-", 
         RowBox[{"met", "[", "t", "]"}]}], ",", 
        RowBox[{
         RowBox[{
          RowBox[{"Transpose", "[", "#", "]"}], ".", 
          RowBox[{"met", "[", "t", "]"}], ".", "#"}], "-", 
         RowBox[{"met", "[", "t", "]"}]}]}], "}"}], "&"}], " ", "@", " ", 
     RowBox[{"rot", "[", 
      RowBox[{"t", ",", "tstq4"}], "]"}]}], "]"}], ",", 
   RowBox[{"{", 
    RowBox[{"t", ",", 
     RowBox[{"{", 
      RowBox[{"\"\<sph\>\"", ",", "\"\<hyp\>\""}], "}"}]}], "}"}]}], 
  "]"}]], "Input",
 CellLabel->
  "In[118]:=",ExpressionUUID->"f2d58320-ce51-45d0-a012-5ee695e5a1cd"],

Cell[BoxData[
 RowBox[{
  RowBox[{"Table", "[", 
   RowBox[{
    RowBox[{
     RowBox[{"rotgen", "[", 
      RowBox[{"t", ",", "tstq4"}], "]"}], " ", "-", " ", 
     RowBox[{"rot", "[", 
      RowBox[{"t", ",", "tstq4"}], "]"}]}], ",", 
    RowBox[{"{", 
     RowBox[{"t", ",", 
      RowBox[{"{", 
       RowBox[{"\"\<sph\>\"", ",", "\"\<hyp\>\""}], "}"}]}], "}"}]}], "]"}], 
  " ", "//", " ", "Factor"}]], "Input",
 CellLabel->
  "In[119]:=",ExpressionUUID->"1e4e7f97-6e5b-4d7b-bfed-4f3376bf1680"],

Cell[BoxData[
 RowBox[{"Table", "[", 
  RowBox[{
   RowBox[{"Factor", "[", 
    RowBox[{
     RowBox[{"rot", "[", 
      RowBox[{"t", ",", 
       RowBox[{"qtmlt", "[", 
        RowBox[{"t", ",", "tstq4", ",", "tstqx4"}], "]"}]}], "]"}], "-", 
     RowBox[{
      RowBox[{"rot", "[", 
       RowBox[{"t", ",", "tstq4"}], "]"}], ".", 
      RowBox[{"rot", "[", 
       RowBox[{"t", ",", "tstqx4"}], "]"}]}]}], "]"}], ",", 
   RowBox[{"{", 
    RowBox[{"t", ",", 
     RowBox[{"{", 
      RowBox[{"\"\<sph\>\"", ",", "\"\<hyp\>\""}], "}"}]}], "}"}]}], 
  "]"}]], "Input",
 CellLabel->
  "In[120]:=",ExpressionUUID->"042408cc-4242-40a3-be5e-15083081d12e"],

Cell[BoxData[
 RowBox[{
  RowBox[{"Table", "[", 
   RowBox[{
    RowBox[{
     RowBox[{"qmgen", "[", 
      RowBox[{"t", ",", "tstq4", ",", "tstqx4"}], "]"}], " ", "-", " ", 
     RowBox[{"qtmlt", "[", 
      RowBox[{"t", ",", "tstq4", ",", "tstqx4"}], "]"}]}], ",", 
    RowBox[{"{", 
     RowBox[{"t", ",", 
      RowBox[{"{", 
       RowBox[{"\"\<sph\>\"", ",", "\"\<hyp\>\""}], "}"}]}], "}"}]}], "]"}], 
  " ", "//", " ", "Factor"}]], "Input",
 CellLabel->
  "In[121]:=",ExpressionUUID->"5166f574-e579-41a5-ab78-35f72be489c1"],

Cell[BoxData[
 RowBox[{"(*", " ", 
  RowBox[{"Tilted", " ", "circle"}], " ", "*)"}]], "Input",
 CellLabel->
  "In[250]:=",ExpressionUUID->"49363e06-66e2-44a3-8636-a4beec73660e"],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{
    RowBox[{
     RowBox[{"Total", "[", 
      RowBox[{
       RowBox[{"(", 
        RowBox[{
         RowBox[{"proj", "[", 
          RowBox[{"\"\<cfm\>\"", ",", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{
              RowBox[{"{", 
               RowBox[{
                RowBox[{"Sqrt", "[", 
                 RowBox[{"1", "-", 
                  RowBox[{"t", "^", "2"}]}], "]"}], ",", "0", ",", 
                RowBox[{"-", "t"}]}], "}"}], ",", 
              RowBox[{"{", 
               RowBox[{"0", ",", "1", ",", "0"}], "}"}], ",", 
              RowBox[{"{", 
               RowBox[{"t", ",", "0", ",", 
                RowBox[{"Sqrt", "[", 
                 RowBox[{"1", "-", 
                  RowBox[{"t", "^", "2"}]}], "]"}]}], "}"}]}], "}"}], ".", 
            RowBox[{"{", 
             RowBox[{
              RowBox[{"r", "*", 
               RowBox[{"Cos", "[", "a", "]"}]}], ",", 
              RowBox[{"r", "*", 
               RowBox[{"Sin", "[", "a", "]"}]}], ",", 
              RowBox[{"Sqrt", "[", 
               RowBox[{"1", "-", 
                RowBox[{"r", "^", "2"}]}], "]"}]}], "}"}]}]}], "]"}], "-", 
         RowBox[{"{", 
          RowBox[{
           RowBox[{
            RowBox[{"-", "t"}], "/", 
            RowBox[{"(", 
             RowBox[{
              RowBox[{"Sqrt", "[", 
               RowBox[{"1", "-", 
                RowBox[{"r", "^", "2"}]}], "]"}], "+", 
              RowBox[{"Sqrt", "[", 
               RowBox[{"1", "-", 
                RowBox[{"t", "^", "2"}]}], "]"}]}], ")"}]}], ",", "0"}], 
          "}"}]}], ")"}], "^", "2"}], "]"}], "-", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{"r", "/", 
        RowBox[{"(", 
         RowBox[{
          RowBox[{"Sqrt", "[", 
           RowBox[{"1", "-", 
            RowBox[{"r", "^", "2"}]}], "]"}], "+", 
          RowBox[{"Sqrt", "[", 
           RowBox[{"1", "-", 
            RowBox[{"t", "^", "2"}]}], "]"}]}], ")"}]}], ")"}], "^", "2"}]}], 
    "//", " ", "Factor"}], " ", "//", " ", "TrigReduce"}], " ", "//", " ", 
  "Factor"}]], "Input",
 CellLabel->
  "In[275]:=",ExpressionUUID->"c51271d6-5737-46d7-a15c-2d8efed5c0c6"],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{
    RowBox[{
     RowBox[{"Total", "[", 
      RowBox[{
       RowBox[{"(", 
        RowBox[{
         RowBox[{"proj", "[", 
          RowBox[{"\"\<cfm\>\"", ",", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{
              RowBox[{"{", 
               RowBox[{
                RowBox[{"Sqrt", "[", 
                 RowBox[{"1", "+", 
                  RowBox[{"t", "^", "2"}]}], "]"}], ",", "0", ",", 
                RowBox[{"-", "t"}]}], "}"}], ",", 
              RowBox[{"{", 
               RowBox[{"0", ",", "1", ",", "0"}], "}"}], ",", 
              RowBox[{"{", 
               RowBox[{
                RowBox[{"-", "t"}], ",", "0", ",", 
                RowBox[{"Sqrt", "[", 
                 RowBox[{"1", "+", 
                  RowBox[{"t", "^", "2"}]}], "]"}]}], "}"}]}], "}"}], ".", 
            RowBox[{"{", 
             RowBox[{
              RowBox[{"r", "*", 
               RowBox[{"Cos", "[", "a", "]"}]}], ",", 
              RowBox[{"r", "*", 
               RowBox[{"Sin", "[", "a", "]"}]}], ",", 
              RowBox[{"Sqrt", "[", 
               RowBox[{"1", "+", 
                RowBox[{"r", "^", "2"}]}], "]"}]}], "}"}]}]}], "]"}], "-", 
         RowBox[{"{", 
          RowBox[{
           RowBox[{
            RowBox[{"-", "t"}], "/", 
            RowBox[{"(", 
             RowBox[{
              RowBox[{"Sqrt", "[", 
               RowBox[{"1", "+", 
                RowBox[{"r", "^", "2"}]}], "]"}], "+", 
              RowBox[{"Sqrt", "[", 
               RowBox[{"1", "+", 
                RowBox[{"t", "^", "2"}]}], "]"}]}], ")"}]}], ",", "0"}], 
          "}"}]}], ")"}], "^", "2"}], "]"}], "-", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{"r", "/", 
        RowBox[{"(", 
         RowBox[{
          RowBox[{"Sqrt", "[", 
           RowBox[{"1", "+", 
            RowBox[{"r", "^", "2"}]}], "]"}], "+", 
          RowBox[{"Sqrt", "[", 
           RowBox[{"1", "+", 
            RowBox[{"t", "^", "2"}]}], "]"}]}], ")"}]}], ")"}], "^", "2"}]}], 
    "//", " ", "Factor"}], " ", "//", " ", "TrigReduce"}], " ", "//", " ", 
  "Factor"}]], "Input",
 CellLabel->
  "In[282]:=",ExpressionUUID->"0e5f4c48-3dcd-4df3-aa99-2e6dac952dc0"]
},
WindowSize->{808, 778},
WindowMargins->{{Automatic, 115}, {Automatic, 8}},
FrontEndVersion->"11.3 for Mac OS X x86 (32-bit, 64-bit Kernel) (March 5, \
2018)",
StyleDefinitions->"Default.nb"
]
(* End of Notebook Content *)

(* Internal cache information *)
(*CellTagsOutline
CellTagsIndex->{}
*)
(*CellTagsIndex
CellTagsIndex->{}
*)
(*NotebookFileOutline
Notebook[{
Cell[558, 20, 598, 13, 265, "Text",ExpressionUUID->"e475f957-f3ae-45a6-86ee-4198af646947"],
Cell[1159, 35, 148, 2, 30, "Input",ExpressionUUID->"b60cf421-064a-4cb1-9c48-7fec38d94b9d"],
Cell[1310, 39, 310, 7, 30, "Input",ExpressionUUID->"4f3f99cf-c77d-4f13-b282-ba00e9c21c52"],
Cell[1623, 48, 286, 6, 30, "Input",ExpressionUUID->"ec9c4845-de9f-47bf-8b7d-f6d238e5d37c"],
Cell[1912, 56, 389, 11, 30, "Input",ExpressionUUID->"e8a7aca0-185a-477b-b5fb-101631e16275"],
Cell[2304, 69, 360, 9, 30, "Input",ExpressionUUID->"5a4b3255-6194-4ce7-bb2f-a7d26e3742c8"],
Cell[2667, 80, 206, 4, 30, "Input",ExpressionUUID->"8246a360-6e6b-4120-bfe3-2cbaf9103f1e"],
Cell[2876, 86, 270, 6, 30, "Input",ExpressionUUID->"c89ea8b8-5192-4d37-b546-257baf8ecd56"],
Cell[3149, 94, 272, 6, 30, "Input",ExpressionUUID->"6ee0b065-ed97-420a-ac30-dd23431638c0"],
Cell[3424, 102, 259, 6, 30, "Input",ExpressionUUID->"7ff82795-ba1d-4bcb-82de-779d85d86ff6"],
Cell[3686, 110, 261, 6, 30, "Input",ExpressionUUID->"210e3e84-9dcb-40de-a38a-369e08e03010"],
Cell[3950, 118, 308, 8, 30, "Input",ExpressionUUID->"cd78a215-3262-4486-802b-a3b3cee97ca7"],
Cell[4261, 128, 310, 8, 30, "Input",ExpressionUUID->"fae73500-35ae-4898-8df3-c53e578eac43"],
Cell[4574, 138, 223, 5, 30, "Input",ExpressionUUID->"34533c68-bc31-4af3-8963-a5860b896431"],
Cell[4800, 145, 392, 11, 30, "Input",ExpressionUUID->"0a475567-7a3f-4219-a4bf-09b7d55ec050"],
Cell[5195, 158, 339, 9, 30, "Input",ExpressionUUID->"3027e6e0-2cd8-42f3-b4bc-30c942f54363"],
Cell[5537, 169, 179, 3, 30, "Input",ExpressionUUID->"69246167-f0ce-44cb-9352-ae2e873592f2"],
Cell[5719, 174, 462, 14, 30, "Input",ExpressionUUID->"144a73a0-13ed-4462-902a-3fa7b2f5ae42"],
Cell[6184, 190, 462, 14, 30, "Input",ExpressionUUID->"f6f26975-1a7e-4c74-bfc9-949034469f34"],
Cell[6649, 206, 396, 11, 30, "Input",ExpressionUUID->"da40baff-a06b-4d00-90e1-fb720f0eb60b"],
Cell[7048, 219, 396, 11, 30, "Input",ExpressionUUID->"a3121a8d-dfc3-4d82-8cda-914a76a26120"],
Cell[7447, 232, 144, 2, 30, "Input",ExpressionUUID->"83f2849a-3d07-46fd-96bd-0a0586a8ebbc"],
Cell[7594, 236, 218, 5, 30, "Input",ExpressionUUID->"b6bfaad0-6667-4c58-99d1-a83b66fb0c90"],
Cell[7815, 243, 623, 19, 30, "Input",ExpressionUUID->"d88f2d06-dc96-4621-b2f8-328ad5e3b16f"],
Cell[8441, 264, 632, 20, 52, "Input",ExpressionUUID->"a44d682e-0769-413d-80ec-815c50e481cf"],
Cell[9076, 286, 179, 4, 30, "Input",ExpressionUUID->"c032401f-5b5a-4880-8df7-5d1fe6dbb0f2"],
Cell[9258, 292, 152, 3, 30, "Input",ExpressionUUID->"c569bb66-bb14-445a-8a8b-d38ca0ef09b3"],
Cell[9413, 297, 1101, 33, 52, "Input",ExpressionUUID->"5315c8f0-5a3f-4c11-8b78-4291fcd6e8d2"],
Cell[10517, 332, 1240, 37, 73, "Input",ExpressionUUID->"dd4e7450-85c9-4d92-871d-5713f0f21e6b"],
Cell[11760, 371, 945, 29, 52, "Input",ExpressionUUID->"585c669d-49c1-4111-be37-6957b9499289"],
Cell[12708, 402, 1093, 33, 52, "Input",ExpressionUUID->"2f365834-c122-4114-80c9-553b9fbd8022"],
Cell[13804, 437, 153, 3, 30, "Input",ExpressionUUID->"a9cc7842-5414-499d-9bf5-132e6349b9c1"],
Cell[13960, 442, 1045, 31, 52, "Input",ExpressionUUID->"1be27beb-7315-4dc6-ba30-bb27ca5cf2eb"],
Cell[15008, 475, 1212, 35, 73, "Input",ExpressionUUID->"d14bb902-729f-48dd-b180-30b1830ba026"],
Cell[16223, 512, 941, 28, 52, "Input",ExpressionUUID->"a84baeb9-c095-4db6-912d-f5b9268974ff"],
Cell[17167, 542, 1089, 32, 52, "Input",ExpressionUUID->"fb42c814-ff9e-4ce4-b7dc-56e19d349447"],
Cell[18259, 576, 222, 5, 30, "Input",ExpressionUUID->"686d1c52-eedd-46cd-abac-0330e35747c0"],
Cell[18484, 583, 2325, 66, 157, "Input",ExpressionUUID->"d459ecb2-5b9f-4b7e-aff6-34f8f3b57628"],
Cell[20812, 651, 2437, 70, 157, "Input",ExpressionUUID->"132027bf-dc1e-48b6-8990-216605c789ef"],
Cell[23252, 723, 1644, 43, 157, "Input",ExpressionUUID->"90784fa4-49bb-4d4a-bfed-824dc94a2d85"],
Cell[24899, 768, 1644, 43, 157, "Input",ExpressionUUID->"2eff23dc-293f-4225-b0ff-bd348f661b67"],
Cell[26546, 813, 659, 20, 30, "Input",ExpressionUUID->"4c8f6af3-3a46-49fe-994c-ed7413f4495c"],
Cell[27208, 835, 1609, 44, 178, "Input",ExpressionUUID->"af084ebd-ed1a-438c-b680-67caface7a96"],
Cell[28820, 881, 1729, 46, 220, "Input",ExpressionUUID->"c30d5dc0-ac24-45b3-9391-a6fc3921f1a5"],
Cell[30552, 929, 148, 3, 30, "Input",ExpressionUUID->"666f482b-9422-4573-ad84-ad5ad53e9fc9"],
Cell[30703, 934, 319, 9, 30, "Input",ExpressionUUID->"2d5ffe25-3d94-487e-9b3b-89e04b969b6b"],
Cell[31025, 945, 950, 28, 73, "Input",ExpressionUUID->"f2d58320-ce51-45d0-a012-5ee695e5a1cd"],
Cell[31978, 975, 499, 15, 30, "Input",ExpressionUUID->"1e4e7f97-6e5b-4d7b-bfed-4f3376bf1680"],
Cell[32480, 992, 652, 20, 52, "Input",ExpressionUUID->"042408cc-4242-40a3-be5e-15083081d12e"],
Cell[33135, 1014, 530, 15, 52, "Input",ExpressionUUID->"5166f574-e579-41a5-ab78-35f72be489c1"],
Cell[33668, 1031, 177, 4, 30, "Input",ExpressionUUID->"49363e06-66e2-44a3-8636-a4beec73660e"],
Cell[33848, 1037, 2213, 63, 115, "Input",ExpressionUUID->"c51271d6-5737-46d7-a15c-2d8efed5c0c6"],
Cell[36064, 1102, 2245, 64, 115, "Input",ExpressionUUID->"0e5f4c48-3dcd-4df3-aa99-2e6dac952dc0"]
}
]
*)

