(* Content-type: application/mathematica *)

(*** Wolfram Notebook File ***)
(* http://www.wolfram.com/nb *)

(* CreatedBy='Mathematica 7.0' *)

(*CacheID: 234*)
(* Internal cache information:
NotebookFileLineBreakTest
NotebookFileLineBreakTest
NotebookDataPosition[       145,          7]
NotebookDataLength[      5213,        174]
NotebookOptionsPosition[      4754,        155]
NotebookOutlinePosition[      5114,        171]
CellTagsIndexPosition[      5071,        168]
WindowFrame->Normal*)

(* Beginning of Notebook Content *)
Notebook[{
Cell["\<\
Vector-to-Vector 3D Rotation
Needs notebook Rotoreflection Matrices and Quaternions - 2D 3D 4D

Finds a rotation matrix that rotates a vector to the direction of another \
vector.

Answer is as a quaternion. The solution is not unique, but a mixture of two \
extreme solutions, with a as the mixing angle for them. Those extreme \
solutions are:
* Rotation axis perpendicular to the two vectors
* Rotation axis halfway between the two vectors\
\>", "Text"],

Cell[BoxData[
 RowBox[{
  RowBox[{"vtovrtq", "[", 
   RowBox[{"n1_", ",", "n2_", ",", "a_"}], "]"}], " ", ":=", " ", 
  RowBox[{
   RowBox[{"Prepend", "[", 
    RowBox[{
     RowBox[{
      RowBox[{
       RowBox[{"(", 
        RowBox[{"n1", "+", "n2"}], ")"}], "*", 
       RowBox[{"Sin", "[", "a", "]"}]}], "-", 
      RowBox[{
       RowBox[{"Cross", "[", 
        RowBox[{"n1", ",", "n2"}], "]"}], "*", 
       RowBox[{"Cos", "[", "a", "]"}]}]}], ",", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{"1", "+", 
        RowBox[{"n1", ".", "n2"}]}], ")"}], "*", 
      RowBox[{"Cos", "[", "a", "]"}]}]}], "]"}], "/", 
   RowBox[{"Sqrt", "[", 
    RowBox[{"2", 
     RowBox[{"(", 
      RowBox[{"1", "+", 
       RowBox[{"n1", ".", "n2"}]}], ")"}]}], "]"}]}]}]], "Input"],

Cell[BoxData[
 RowBox[{
  RowBox[{"vtest1", " ", "=", " ", 
   RowBox[{"{", 
    RowBox[{"1", ",", "0", ",", "0"}], "}"}]}], ";", " ", 
  RowBox[{"vtest2", " ", "=", " ", 
   RowBox[{"{", 
    RowBox[{"csd", ",", 
     RowBox[{"Sqrt", "[", 
      RowBox[{"1", "-", 
       RowBox[{"csd", "^", "2"}]}], "]"}], ",", "0"}], "}"}]}], 
  ";"}]], "Input"],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"quatnorm", "[", 
    RowBox[{"vtovrtq", "[", 
     RowBox[{"vtest1", ",", "vtest2", ",", "a"}], "]"}], "]"}], " ", "//", 
   " ", "Factor"}], " ", "//", " ", "TrigReduce"}]], "Input"],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{
    RowBox[{"rrmat", "[", 
     RowBox[{"\"\<3rn\>\"", ",", 
      RowBox[{"vtovrtq", "[", 
       RowBox[{"vtest1", ",", "vtest2", ",", "a"}], "]"}]}], "]"}], ".", 
    "vtest1"}], " ", "-", " ", "vtest2"}], " ", "//", " ", 
  "Factor"}]], "Input"],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"(", 
    RowBox[{
     RowBox[{
      RowBox[{"rrmat", "[", 
       RowBox[{"\"\<3rn\>\"", ",", 
        RowBox[{"vtovrtq", "[", 
         RowBox[{"vtest1", ",", "vtest2", ",", "a"}], "]"}]}], "]"}], " ", "//",
       " ", "Factor"}], " ", "//", " ", "TrigReduce"}], ")"}], " ", "-", " ", 
   
   RowBox[{"(", 
    RowBox[{
     RowBox[{"dyad", "[", 
      RowBox[{"vtest2", ",", "vtest1"}], "]"}], " ", "+", " ", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{
        RowBox[{"IdentityMatrix", "[", "3", "]"}], "+", 
        RowBox[{"dyad", "[", 
         RowBox[{"vtest2", ",", "vtest1"}], "]"}], " ", "-", " ", 
        RowBox[{
         RowBox[{"dyad", "[", 
          RowBox[{
           RowBox[{"vtest1", "+", "vtest2"}], ",", 
           RowBox[{"vtest1", "+", "vtest2"}]}], "]"}], "/", 
         RowBox[{"(", 
          RowBox[{"1", "+", 
           RowBox[{"vtest1", ".", "vtest2"}]}], ")"}]}]}], ")"}], "*", 
      RowBox[{"Cos", "[", 
       RowBox[{"2", "a"}], "]"}]}], " ", "-", " ", 
     RowBox[{
      RowBox[{
       RowBox[{"(", 
        RowBox[{
         RowBox[{"dyad", "[", 
          RowBox[{
           RowBox[{"vtest1", "+", "vtest2"}], ",", 
           RowBox[{"Cross", "[", 
            RowBox[{"vtest1", ",", "vtest2"}], "]"}]}], "]"}], " ", "+", " ", 
         
         RowBox[{"dyad", "[", 
          RowBox[{
           RowBox[{"Cross", "[", 
            RowBox[{"vtest1", ",", "vtest2"}], "]"}], ",", 
           RowBox[{"vtest1", "+", "vtest2"}]}], "]"}], " ", "-", " ", 
         RowBox[{
          RowBox[{"(", 
           RowBox[{"1", "+", 
            RowBox[{"vtest1", ".", "vtest2"}]}], ")"}], "*", 
          RowBox[{"asymvt", "[", 
           RowBox[{"vtest1", "+", "vtest2"}], "]"}]}]}], ")"}], "/", 
       RowBox[{"(", 
        RowBox[{"2", 
         RowBox[{"(", 
          RowBox[{"1", "+", 
           RowBox[{"vtest1", ".", "vtest2"}]}], ")"}]}], ")"}]}], "*", 
      RowBox[{"Sin", "[", 
       RowBox[{"2", "a"}], "]"}]}]}], ")"}]}], " ", "//", " ", 
  "Factor"}]], "Input"]
},
WindowSize->{640, 696},
WindowMargins->{{Automatic, 191}, {Automatic, 17}},
FrontEndVersion->"11.0 for Mac OS X x86 (32-bit, 64-bit Kernel) (September \
21, 2016)",
StyleDefinitions->"Default.nb"
]
(* End of Notebook Content *)

(* Internal cache information *)
(*CellTagsOutline
CellTagsIndex->{}
*)
(*CellTagsIndex
CellTagsIndex->{}
*)
(*NotebookFileOutline
Notebook[{
Cell[545, 20, 466, 12, 182, "Text"],
Cell[1014, 34, 774, 25, 75, "Input"],
Cell[1791, 61, 349, 11, 32, "Input"],
Cell[2143, 74, 230, 6, 32, "Input"],
Cell[2376, 82, 296, 9, 54, "Input"],
Cell[2675, 93, 2075, 60, 201, "Input"]
}
]
*)

